{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "![Callysto.ca Banner](https://github.com/callysto/curriculum-notebooks/blob/master/callysto-notebook-banner-top.jpg?raw=true)\n",
    "\n",
    "<a href=\"https://hub.callysto.ca/jupyter/hub/user-redirect/git-pull?repo=https%3A%2F%2Fgithub.com%2Fcallysto%2Fcurriculum-notebooks&branch=master&subPath=Mathematics/RootFindingAlgorithms/root-finding-algorithms.ipynb&depth=1\" target=\"_parent\"><img src=\"https://raw.githubusercontent.com/callysto/curriculum-notebooks/master/open-in-callysto-button.svg?sanitize=true\" width=\"123\" height=\"24\" alt=\"Open in Callysto\"/></a>"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "scrolled": true,
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<script>\n",
       "  function code_toggle() {\n",
       "    if (code_shown){\n",
       "      $('div.input').hide('500');\n",
       "      $('#toggleButton').val('Show Code')\n",
       "    } else {\n",
       "      $('div.input').show('500');\n",
       "      $('#toggleButton').val('Hide Code')\n",
       "    }\n",
       "    code_shown = !code_shown\n",
       "  }\n",
       "\n",
       "  $( document ).ready(function(){\n",
       "    code_shown=false;\n",
       "    $('div.input').hide()\n",
       "  });\n",
       "</script>\n",
       "<p> Code is hidden for ease of viewing. Click the Show/Hide button to see. </>\n",
       "<form action=\"javascript:code_toggle()\"><input type=\"submit\" id=\"toggleButton\" value=\"Show Code\"></form>\n"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "%%html\n",
    "\n",
    "<script>\n",
    "  function code_toggle() {\n",
    "    if (code_shown){\n",
    "      $('div.input').hide('500');\n",
    "      $('#toggleButton').val('Show Code')\n",
    "    } else {\n",
    "      $('div.input').show('500');\n",
    "      $('#toggleButton').val('Hide Code')\n",
    "    }\n",
    "    code_shown = !code_shown\n",
    "  }\n",
    "\n",
    "  $( document ).ready(function(){\n",
    "    code_shown=false;\n",
    "    $('div.input').hide()\n",
    "  });\n",
    "</script>\n",
    "<p> Code is hidden for ease of viewing. Click the Show/Hide button to see. </>\n",
    "<form action=\"javascript:code_toggle()\"><input type=\"submit\" id=\"toggleButton\" value=\"Show Code\"></form>"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "scrolled": true,
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "        <script type=\"text/javascript\">\n",
       "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n",
       "        if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n",
       "        if (typeof require !== 'undefined') {\n",
       "        require.undef(\"plotly\");\n",
       "        requirejs.config({\n",
       "            paths: {\n",
       "                'plotly': ['https://cdn.plot.ly/plotly-latest.min']\n",
       "            }\n",
       "        });\n",
       "        require(['plotly'], function(Plotly) {\n",
       "            window._Plotly = Plotly;\n",
       "        });\n",
       "        }\n",
       "        </script>\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "import numpy as np\n",
    "import matplotlib.pyplot as plt\n",
    "from IPython.display import display, Math, Latex, HTML, clear_output, Markdown, Javascript\n",
    "import ipywidgets as widgets\n",
    "from ipywidgets import interact, interact_manual, FloatSlider, IntSlider, interactive, Layout \n",
    "from traitlets import traitlets\n",
    "import warnings\n",
    "\n",
    "\n",
    "import plotly as py\n",
    "import plotly.graph_objs as go\n",
    "from plotly.offline import download_plotlyjs, init_notebook_mode, plot, iplot\n",
    "init_notebook_mode(connected=True)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hidden": false
   },
   "source": [
    "# Root Finding Algorithms\n",
    "\n",
    "\n",
    "<img src = \"images/ezgif.com-gif-maker.gif\">\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hidden": false
   },
   "source": [
    "## Introduction\n",
    "---\n",
    "In this notebook you will gain an understanding of basic root-finding algorithms and their implementation. This topic is introduced with the goal of easing you into numerical solutions to mathematical problems. We will outline the advantages and disadvantages of solving a problem numerically rather than analytically. At the end of the notebook there will be example problems, in which you have the opportunity to implement these methods, yielding a broader understanding of their applicability and power.\n",
    "\n",
    "**Necessary background**:\n",
    "- Be able to factor quadratic polynomials\n",
    "- Understand basic python syntax\n",
    "- Read, graph, and analyze functions\n",
    "- Rudimentary algebra\n",
    "\n",
    "In this Notebook you will see examples of code to perform some basic root-finding algorithms. You will not be required to know how the code works or need to write any yourself. Nevertheless, you will be encouraged to manipulate some of the lines in order to input a function of your choice, but that is all. The pieces of code and algorithms can be simply thought of as tools to execute the task you want them to perform, and only running them will be a necessary to accomplish this task. Although the coding isn't required, I strongly encourage you to try to understand how and why it works. "
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hidden": false
   },
   "source": [
    "\n",
    "For a warm-up, we have created an exercise for you to determine the intervals on which a polynomial is $>$ 0. A first approach to this problem would be to find the roots of the polynomial and then analyze the behaviour in between these roots. We recommend converting the function into a form that you can graph in order to determine the behaviour on either side of the roots. Think about the possible forms of the graph, i.e. concavity, convexity, and what this tells you about the intervals where the function is positive. This type of analytical thinking will help further along in the notebook. </br>\n",
    "\n",
    "\n",
    "Given a polynomial of order $\\leq$ 3, find where the function is $>$ 0. \n",
    "Below is simply **a** method of approaching this problem, not necessarily the best or most effective. There are many ways one can go about this, each offering a different insight or understanding. Find what works best for you and try to understand why  you used this method (is it visual? is it solely algebraic? did you manipulate the function?).</br>\n",
    "\n",
    "**Example**:\n",
    "\n",
    "Find the interval on which $f(x) = x^2 - 3x +2 > 0$.</br>\n",
    "\n",
    "Solve for roots:</br>\n",
    "\n",
    "$f(x) = (x-1)(x-2)$</br>\n",
    "\n",
    "\n",
    "Using an inequality approach, if I picked a point, $c$ in the interval $(1,2)$, then (c-1)> 0 and (c-2)< 0. Therefore, our function evaluated at this point:\n",
    "\n",
    "$f(c)=(c-1)(c-2) < 0$. </br>\n",
    "\n",
    "We can deduce, by knowing the shape of a parabola, that the interval on which $f(x)>0$ is $x = (-\\infty,1)\\cup(2,\\infty)$\n",
    "\n",
    "By picking a point in between the roots we quickly found whether the function was concave up or down. Knowing what the graph of a parabola looks like, this quickly told us where the function was positive.\n",
    "\n",
    "Given a polynomial of order 2 or 3, find where the function $>$ 0. Try polynomials of 2nd order first and then 3rd for more of a challenge. Below, we will provide some algorithms that will make finding the roots of a third (or higher) order polynomial much less tedious. \n",
    "\n",
    "- Please input your answer in interval notation, using \"U\" for the union of intervals. Press **Enter** after typing your response.\n",
    "- For $\\infty$ type infinity\n",
    "- If the function is nowhere $ > 0$, then type \"Nowhere\"\n",
    "\n",
    "I recommend trying the exercise for a polynomial of order two, reviewing the content of the notebook and then trying for polynomials of order 3. Input answer in interval notation (i.e. (-4,-1)U(5,infinity) ):"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "bc196fdf631949b696213260bfdd84ef",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(button_style='info', description='Attempt Exercise (order 2)', layout=Layout(height='60p…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "def find_interval(poly_order):\n",
    "    poly_order = int(poly_order)\n",
    "    if poly_order > 3:\n",
    "        display('Order of polynomial must be less than or equal to 3')\n",
    "        display('Provide order of polynomial:')\n",
    "        \n",
    "    if poly_order == 3:    \n",
    "        C = np.random.randint(-5,5,poly_order)\n",
    "        C1 = -1*np.sum(C)\n",
    "        C2 = C[0]*C[1] + C[2]*(C[0]+C[1])\n",
    "        C3 = -1*C[0]*C[1]*C[2]\n",
    "        C11=C1\n",
    "        C22=C2\n",
    "        C33=C3\n",
    "        display(\"Find the interval where P(x) > 0 :\")\n",
    "        if C1>0:\n",
    "            str1 = '+' + str(C11) + 'x^2'\n",
    "        elif C1== 0:\n",
    "            str1 = ''\n",
    "        else:\n",
    "            str1=  str(C11) + 'x^2'\n",
    "        if C2>0:\n",
    "            str2 = '+' + str(C22) + 'x'\n",
    "        elif C2== 0:\n",
    "            str2=''\n",
    "        else:\n",
    "            str2= str(C22) + 'x'\n",
    "        if C3>0:\n",
    "            str3 = '+' + str(C33)\n",
    "        elif C3== 0:\n",
    "            str3=''\n",
    "        else:\n",
    "            str3= str(C33)\n",
    "            \n",
    "        a = \"P(x)= x^3\" + str1 + str2 + str3\n",
    "        \n",
    "        display(Math(a))\n",
    "        \n",
    "        def poly(x):\n",
    "            return x**3 + C1*x**2 + C2*x + C3\n",
    "        \n",
    "    if poly_order == 2:\n",
    "        C = np.random.randint(-5,5,poly_order)\n",
    "        C1 = -1*np.sum(C)\n",
    "        C2 = C[0]*C[1]\n",
    "        C11=C1\n",
    "        C22=C2\n",
    "        if C1>0:\n",
    "            str1 = '+' + str(C11) + 'x'\n",
    "        elif C1== 0:\n",
    "            str1 = ''\n",
    "        else:\n",
    "            str1=  str(C11) + 'x'\n",
    "        if C2>0:\n",
    "            str2 = '+' + str(C22)\n",
    "        elif C2== 0:\n",
    "            str2=''\n",
    "        else:\n",
    "            str2= str(C22) \n",
    "        display('Find the interval where P(x) > 0  :')\n",
    "        a = 'P(x) = x^2 ' + str1 + str2\n",
    "        display(Math(a))\n",
    "        def poly(x):\n",
    "            return x**2 + C1*x + C2\n",
    "    \n",
    "    Max = max(C)\n",
    "    Min = min(C)\n",
    "    M = [Min, Max]\n",
    "    V = np.sort(C)\n",
    "    eps = 0.1\n",
    "    \n",
    "    if poly_order ==3:\n",
    "        v = V[1]\n",
    "        if Max == Min and poly(Max +eps) > 0:\n",
    "                          interval = '('+str(Max)+',infinity)' #One single root, increasing\n",
    "        if Max == Min and poly(Max +eps) < 0:\n",
    "                          interval = '(-infinity,' + str( Max)+')' #One single root, decreasing\n",
    "                      \n",
    "        if poly(Max + eps) >0:\n",
    "#         interval = '(' + str(Max) + ', infinity)'\n",
    "            if v !=  Max and v!= Min:\n",
    "                          interval = '('+str(Min) + ',' + str(v) + ')U(' + str(Max) + ',infinity)'\n",
    "            if v == Max:\n",
    "                          interval = '(' + str(Min) + ', infinity)'\n",
    "            if v== Min:\n",
    "                          interval = '(' + str(Max) + ', infinity)'\n",
    "    \n",
    "        if poly(Max + eps) <0:\n",
    "#         interval = '(-infinty,' + str(Min) + ')'\n",
    "            if v != Max and v != Min:\n",
    "                          interval = '(-inifinity,' + str(Min) + 'U('+str(v) + ','+str(Max) + ')'\n",
    "            if v == Max:\n",
    "                          interval = '(-infinity,' + str( Max) + ')'\n",
    "            if v == Min:\n",
    "                          interval = '(-infinity,' + str(Min) + ')'\n",
    "                    \n",
    "    if poly_order == 2:\n",
    "            if Max == Min and poly(Max+eps)>0:\n",
    "                interval = '(-infinity,'+str(Min)+')U('+str(Min)+',infinity)' #one root, convex\n",
    "            elif poly(Max+eps)<0:\n",
    "                interval = '('+str(Min)+','+str(Max)+')' #Two distinct roots, Concave\n",
    "            elif poly(Max + eps)>0:\n",
    "                interval = '(-infinity,'+str(Min)+')U(' + str(Max)+',infinity)' #Two distinct roots, convex\n",
    "            else:\n",
    "                interval = 'Nowhere' #one root, concave \n",
    "    \n",
    "    x = np.linspace(-100,100,10000)\n",
    "    p = poly(x)\n",
    "    \n",
    "    return interval, p\n",
    "\n",
    "\n",
    "def check_answer(answer,interval,y):\n",
    "    \n",
    "    answer = answer.replace(\" \",\"\")\n",
    "    \n",
    "    if answer == \"\":\n",
    "        display(\"Please be sure to press enter after submitting your answer.\")\n",
    "    else:    \n",
    "        if answer != interval:\n",
    "            display(\"That's not quite right, try again.\")\n",
    "        if answer == interval:\n",
    "\n",
    "            display(\"Correct! Here's a visualization of the solution:\")\n",
    "            x1=np.linspace(-100,100,10000)\n",
    "            trace = go.Scatter(\n",
    "                x = x1,\n",
    "                y = y\n",
    "            )\n",
    "            layout = go.Layout(\n",
    "                xaxis = dict(\n",
    "                    title='x',\n",
    "                    titlefont=dict(\n",
    "                    family='Arial, serif',\n",
    "                    size=18,\n",
    "                    color='black'),\n",
    "                    range = [-10,10],\n",
    "                    ticks='inside',\n",
    "                    tick0=0,\n",
    "                    dtick=1\n",
    "                ),\n",
    "                yaxis = dict(\n",
    "                    title='P(x)',\n",
    "                    titlefont=dict(\n",
    "                    family='Arial, serif',\n",
    "                    size=18,\n",
    "                    color='black'),\n",
    "                    range = [-10,10],\n",
    "                    ticks='inside',\n",
    "                    tick0=0,\n",
    "                    dtick=1\n",
    "                ),\n",
    "            )\n",
    "\n",
    "            data = [trace]\n",
    "\n",
    "            fig = go.Figure(data=data, layout=layout)\n",
    "            iplot(fig)\n",
    "\n",
    "    return \n",
    "\n",
    "\n",
    "\n",
    "text2 = widgets.Text(disabled = False, placeholder = 'Enter Interval')\n",
    "out2 = widgets.Text(disabled  = True, value = None)\n",
    "text3 = widgets.Text(disabled = False, placeholder = 'Enter Interval')\n",
    "out3 = widgets.Text(disabled  = True, value = None)\n",
    "\n",
    "def bind_to_out2(sender):\n",
    "    out2.value = text2.value  \n",
    "    return out2.value\n",
    "\n",
    "text2.on_submit(bind_to_out2)\n",
    "\n",
    "def bind_to_out3(sender):\n",
    "    out3.value = text3.value  \n",
    "    return out3.value\n",
    "\n",
    "text3.on_submit(bind_to_out3)\n",
    "\n",
    "button2 = widgets.Button(description=\"Attempt Exercise (order 2)\", \n",
    "                         layout = Layout(width='30%', height='60px'),\n",
    "                         button_style = 'info'\n",
    "                        )\n",
    "button3 = widgets.Button(description=\"Attempt Exercise (order 3)\", \n",
    "                         layout = Layout(width='30%', height='60px'),\n",
    "                         button_style = 'info'\n",
    "                        )\n",
    "check_button2 = widgets.Button(description=\"Check your answer\", \n",
    "                              layout = Layout(width='30%', height='60px'),\n",
    "                              button_style = 'info'\n",
    "                             )\n",
    "check_button3 = widgets.Button(description=\"Check your answer\", \n",
    "                              layout = Layout(width='30%', height='60px'),\n",
    "                              button_style = 'info'\n",
    "                             )\n",
    "\n",
    "H1 = widgets.HBox([button2, button3])\n",
    "display(H1)\n",
    "\n",
    "def on_button_clicked2(b):\n",
    "    text2.value = \"\"\n",
    "    clear_output()\n",
    "    display(H1)\n",
    "    display(Javascript('IPython.notebook.execute_cell_range(IPython.notebook.get_selected_index()+0,IPython.notebook.get_selected_index()+1)'))\n",
    "    display(Javascript('IPython.notebook.execute_cell_range(IPython.notebook.get_selected_index()+1,IPython.notebook.get_selected_index()+2)'))\n",
    "\n",
    "button2.on_click(on_button_clicked2) \n",
    "\n",
    "\n",
    "def on_button_clicked3(b):\n",
    "    text3.value = \"\"\n",
    "    clear_output()\n",
    "    display(H1)\n",
    "    #Rerun this cell to avoid the multiple outputs \n",
    "    display(Javascript('IPython.notebook.execute_cell_range(IPython.notebook.get_selected_index()+0,IPython.notebook.get_selected_index()+1)'))\n",
    "    display(Javascript('IPython.notebook.execute_cell_range(IPython.notebook.get_selected_index()+2, IPython.notebook.get_selected_index()+3)'))\n",
    "\n",
    "button3.on_click(on_button_clicked3) \n",
    "\n",
    "    "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {
    "scrolled": false,
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'Find the interval where P(x) > 0  :'"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/latex": [
       "$\\displaystyle P(x) = x^2 +2x-15$"
      ],
      "text/plain": [
       "<IPython.core.display.Math object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "c8a7265a555b47c38d8fc65d2f26a817",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Text(value='', placeholder='Enter Interval')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "d283619ddddf4414a0e44cbc384f468c",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Button(button_style='info', description='Check your answer', layout=Layout(height='60px', width='30%'), style=…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "clear_output()\n",
    "interval2, y2 = find_interval(2)\n",
    "\n",
    "display(text2)\n",
    "display(check_button2)\n",
    "       \n",
    "def check2(b):\n",
    "    check_answer(out2.value,interval2,y2)\n",
    "    \n",
    "    \n",
    "check_button2.on_click(check2)\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'Find the interval where P(x) > 0 :'"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/latex": [
       "$\\displaystyle P(x)= x^3+9x^2+26x+24$"
      ],
      "text/plain": [
       "<IPython.core.display.Math object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "d7a894c5efe24a0d80da86a83fd10ae5",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Text(value='', placeholder='Enter Interval')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "74365e72defd404b9dbca01f9f678056",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Button(button_style='info', description='Check your answer', layout=Layout(height='60px', width='30%'), style=…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "interval3, y3 = find_interval(3)\n",
    "display(text3)\n",
    "display(check_button3)\n",
    "   \n",
    "def check3(b):\n",
    "    check_answer(out3.value,interval3,y3)\n",
    "    \n",
    "check_button3.on_click(check3)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hidden": false
   },
   "source": [
    "## Analytic vs. Numerical Solutions\n",
    "-----------------------------------------------------\n",
    "\n",
    "\n",
    "\n",
    "   Below we will outline the differences, pros and cons and methods of analytic vs. numerical solutions within the context of root finding. By solving for the roots of the polynomial and analyzing the graph of the function, you were able to explicitly determine an answer to the question posed. This is the benefit of these analytic expressions; they give you a nice and clear explicit answer. It is often the case that we can derive analytic solutions to simpler, well-posed problems. Now, what if the problem is not so well-posed? What if our analytic approach becomes way too complex or tedious? How would you approach this problem without finding zeroes? What if the polynomial is of $n^{\\rm th}$ order? For these cases we turn to a numerical approach, alleviating the work load and attaining the same end goal, but often with less accuracy.\n",
    "\n",
    "\n",
    "   Next we will walk you through different ways to approach this problem, and more complex problems of the same flavour, numerically. You will gain some insight into the implementation and benefit of numerical solutions while developing some basic skills in Python and numerical analysis.\n",
    "\n",
    "\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hidden": false
   },
   "source": [
    "## Inspection\n",
    "-----------------------\n",
    "\n",
    "In order to answer the question, \"On what interval(s) is $ f(x) > 0?$\", you probably found the roots of the polynomial and looked at the behaviour of the graph in between these roots. This can be done for nice polynomials with integer coefficients and a low-order, but becomes increasingly difficult the more terms there are and the less simple the polynomials starts looking. Nevertheless, your initial approach to this problem can still be taken, i.e. find the roots and analyze the behaviour in between these roots in order to determine where $f(x)>$ 0. Below we will discuss some algorithms used to determine roots of a polynomial.\n",
    "\n",
    "Take, for instance, the polynomial:\n",
    "$f(x) = x^3 -\\frac{7}{9}x^2 - \\frac{1}{4}x+\\frac{7}{36}$\n",
    "\n",
    "\n",
    "A great advantage of utilizing a numerical approach is that it allows for quick ways to approximate a solution. This is useful if the amount of error is negligible and all one is looking for is an estimation. A quick way to get an estimation for our solution in question is simply to plot $f(x)$. This is similar to what you would do on your graphing calculator, now just on the computer using code! If you would like to get started plotting with python, the best place to start is with matplotlib. It's quick to learn, if you know basic python syntax, and there are tons of internet resources to explore its capabilities and debug problems. For extensive documentation and functionality of the matplotlib library see https://matplotlib.org/. Click on plot function to inspect $f(x)$ above.\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "d10784c3b64c43719084f59975d9eb45",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Button(button_style='info', description='Plot Function', layout=Layout(height='60px', width='30%'), style=Butt…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "config": {
        "linkText": "Export to plot.ly",
        "plotlyServerURL": "https://plot.ly",
        "showLink": false
       },
       "data": [
        {
         "type": "scatter",
         "x": [
          -50,
          -49.8998998998999,
          -49.7997997997998,
          -49.6996996996997,
          -49.5995995995996,
          -49.4994994994995,
          -49.3993993993994,
          -49.2992992992993,
          -49.1991991991992,
          -49.0990990990991,
          -48.998998998999,
          -48.8988988988989,
          -48.7987987987988,
          -48.6986986986987,
          -48.5985985985986,
          -48.4984984984985,
          -48.3983983983984,
          -48.2982982982983,
          -48.1981981981982,
          -48.0980980980981,
          -47.997997997998,
          -47.8978978978979,
          -47.7977977977978,
          -47.6976976976977,
          -47.5975975975976,
          -47.4974974974975,
          -47.3973973973974,
          -47.2972972972973,
          -47.1971971971972,
          -47.0970970970971,
          -46.996996996997,
          -46.8968968968969,
          -46.7967967967968,
          -46.6966966966967,
          -46.5965965965966,
          -46.4964964964965,
          -46.3963963963964,
          -46.2962962962963,
          -46.1961961961962,
          -46.0960960960961,
          -45.995995995996,
          -45.8958958958959,
          -45.7957957957958,
          -45.6956956956957,
          -45.5955955955956,
          -45.4954954954955,
          -45.3953953953954,
          -45.2952952952953,
          -45.1951951951952,
          -45.0950950950951,
          -44.994994994995,
          -44.8948948948949,
          -44.7947947947948,
          -44.6946946946947,
          -44.5945945945946,
          -44.4944944944945,
          -44.394394394394396,
          -44.294294294294296,
          -44.194194194194196,
          -44.094094094094096,
          -43.993993993993996,
          -43.893893893893896,
          -43.793793793793796,
          -43.693693693693696,
          -43.593593593593596,
          -43.493493493493496,
          -43.393393393393396,
          -43.293293293293296,
          -43.193193193193196,
          -43.093093093093096,
          -42.992992992992995,
          -42.892892892892895,
          -42.792792792792795,
          -42.692692692692695,
          -42.592592592592595,
          -42.49249249249249,
          -42.392392392392395,
          -42.29229229229229,
          -42.192192192192195,
          -42.09209209209209,
          -41.991991991991995,
          -41.89189189189189,
          -41.791791791791795,
          -41.69169169169169,
          -41.591591591591595,
          -41.49149149149149,
          -41.391391391391394,
          -41.29129129129129,
          -41.191191191191194,
          -41.09109109109109,
          -40.990990990990994,
          -40.89089089089089,
          -40.790790790790794,
          -40.69069069069069,
          -40.590590590590594,
          -40.49049049049049,
          -40.390390390390394,
          -40.29029029029029,
          -40.190190190190194,
          -40.09009009009009,
          -39.98998998998999,
          -39.889889889889886,
          -39.78978978978979,
          -39.689689689689686,
          -39.58958958958959,
          -39.489489489489486,
          -39.38938938938939,
          -39.289289289289286,
          -39.189189189189186,
          -39.089089089089086,
          -38.988988988988986,
          -38.888888888888886,
          -38.788788788788786,
          -38.688688688688686,
          -38.588588588588586,
          -38.488488488488485,
          -38.388388388388385,
          -38.288288288288285,
          -38.188188188188185,
          -38.088088088088085,
          -37.987987987987985,
          -37.887887887887885,
          -37.787787787787785,
          -37.687687687687685,
          -37.587587587587585,
          -37.487487487487485,
          -37.387387387387385,
          -37.287287287287285,
          -37.187187187187185,
          -37.087087087087085,
          -36.986986986986985,
          -36.886886886886884,
          -36.786786786786784,
          -36.686686686686684,
          -36.586586586586584,
          -36.486486486486484,
          -36.386386386386384,
          -36.286286286286284,
          -36.186186186186184,
          -36.086086086086084,
          -35.985985985985984,
          -35.885885885885884,
          -35.785785785785784,
          -35.685685685685684,
          -35.585585585585584,
          -35.48548548548548,
          -35.38538538538538,
          -35.28528528528528,
          -35.18518518518518,
          -35.08508508508508,
          -34.98498498498498,
          -34.88488488488488,
          -34.78478478478478,
          -34.68468468468468,
          -34.58458458458458,
          -34.48448448448448,
          -34.38438438438438,
          -34.28428428428428,
          -34.18418418418418,
          -34.08408408408408,
          -33.98398398398398,
          -33.88388388388388,
          -33.78378378378378,
          -33.68368368368368,
          -33.58358358358358,
          -33.48348348348348,
          -33.38338338338338,
          -33.28328328328328,
          -33.18318318318318,
          -33.08308308308308,
          -32.98298298298298,
          -32.88288288288288,
          -32.78278278278278,
          -32.68268268268268,
          -32.58258258258258,
          -32.48248248248248,
          -32.38238238238238,
          -32.28228228228228,
          -32.18218218218218,
          -32.08208208208208,
          -31.98198198198198,
          -31.88188188188188,
          -31.78178178178178,
          -31.68168168168168,
          -31.58158158158158,
          -31.48148148148148,
          -31.38138138138138,
          -31.28128128128128,
          -31.18118118118118,
          -31.08108108108108,
          -30.98098098098098,
          -30.88088088088088,
          -30.78078078078078,
          -30.68068068068068,
          -30.58058058058058,
          -30.48048048048048,
          -30.38038038038038,
          -30.28028028028028,
          -30.18018018018018,
          -30.08008008008008,
          -29.97997997997998,
          -29.87987987987988,
          -29.77977977977978,
          -29.67967967967968,
          -29.57957957957958,
          -29.47947947947948,
          -29.37937937937938,
          -29.27927927927928,
          -29.17917917917918,
          -29.07907907907908,
          -28.97897897897898,
          -28.87887887887888,
          -28.77877877877878,
          -28.67867867867868,
          -28.578578578578576,
          -28.478478478478475,
          -28.378378378378375,
          -28.278278278278275,
          -28.178178178178175,
          -28.078078078078075,
          -27.977977977977975,
          -27.877877877877875,
          -27.777777777777775,
          -27.677677677677675,
          -27.577577577577575,
          -27.477477477477475,
          -27.377377377377375,
          -27.277277277277275,
          -27.177177177177175,
          -27.077077077077075,
          -26.976976976976974,
          -26.876876876876874,
          -26.776776776776774,
          -26.676676676676674,
          -26.576576576576574,
          -26.476476476476474,
          -26.376376376376374,
          -26.276276276276274,
          -26.176176176176174,
          -26.076076076076074,
          -25.975975975975974,
          -25.875875875875874,
          -25.775775775775774,
          -25.675675675675674,
          -25.575575575575574,
          -25.475475475475474,
          -25.375375375375373,
          -25.275275275275273,
          -25.175175175175173,
          -25.075075075075073,
          -24.974974974974973,
          -24.874874874874873,
          -24.774774774774773,
          -24.674674674674673,
          -24.574574574574573,
          -24.474474474474473,
          -24.374374374374373,
          -24.274274274274273,
          -24.174174174174173,
          -24.074074074074073,
          -23.973973973973973,
          -23.873873873873872,
          -23.773773773773772,
          -23.673673673673672,
          -23.573573573573572,
          -23.473473473473472,
          -23.373373373373372,
          -23.273273273273272,
          -23.173173173173172,
          -23.073073073073072,
          -22.972972972972972,
          -22.872872872872872,
          -22.772772772772772,
          -22.67267267267267,
          -22.57257257257257,
          -22.47247247247247,
          -22.37237237237237,
          -22.27227227227227,
          -22.17217217217217,
          -22.07207207207207,
          -21.97197197197197,
          -21.87187187187187,
          -21.77177177177177,
          -21.67167167167167,
          -21.57157157157157,
          -21.47147147147147,
          -21.37137137137137,
          -21.27127127127127,
          -21.17117117117117,
          -21.07107107107107,
          -20.97097097097097,
          -20.87087087087087,
          -20.77077077077077,
          -20.67067067067067,
          -20.57057057057057,
          -20.47047047047047,
          -20.37037037037037,
          -20.27027027027027,
          -20.17017017017017,
          -20.070070070070066,
          -19.969969969969966,
          -19.869869869869866,
          -19.769769769769766,
          -19.669669669669666,
          -19.569569569569566,
          -19.469469469469466,
          -19.369369369369366,
          -19.269269269269266,
          -19.169169169169166,
          -19.069069069069066,
          -18.968968968968966,
          -18.868868868868866,
          -18.768768768768766,
          -18.668668668668666,
          -18.568568568568566,
          -18.468468468468465,
          -18.368368368368365,
          -18.268268268268265,
          -18.168168168168165,
          -18.068068068068065,
          -17.967967967967965,
          -17.867867867867865,
          -17.767767767767765,
          -17.667667667667665,
          -17.567567567567565,
          -17.467467467467465,
          -17.367367367367365,
          -17.267267267267265,
          -17.167167167167165,
          -17.067067067067065,
          -16.966966966966964,
          -16.866866866866864,
          -16.766766766766764,
          -16.666666666666664,
          -16.566566566566564,
          -16.466466466466464,
          -16.366366366366364,
          -16.266266266266264,
          -16.166166166166164,
          -16.066066066066064,
          -15.965965965965964,
          -15.865865865865864,
          -15.765765765765764,
          -15.665665665665664,
          -15.565565565565564,
          -15.465465465465464,
          -15.365365365365363,
          -15.265265265265263,
          -15.165165165165163,
          -15.065065065065063,
          -14.964964964964963,
          -14.864864864864863,
          -14.764764764764763,
          -14.664664664664663,
          -14.564564564564563,
          -14.464464464464463,
          -14.364364364364363,
          -14.264264264264263,
          -14.164164164164163,
          -14.064064064064063,
          -13.963963963963963,
          -13.863863863863862,
          -13.763763763763762,
          -13.663663663663662,
          -13.563563563563562,
          -13.463463463463462,
          -13.363363363363362,
          -13.263263263263262,
          -13.163163163163162,
          -13.063063063063062,
          -12.962962962962962,
          -12.862862862862862,
          -12.762762762762762,
          -12.662662662662662,
          -12.562562562562562,
          -12.462462462462462,
          -12.362362362362362,
          -12.262262262262261,
          -12.162162162162161,
          -12.062062062062061,
          -11.961961961961961,
          -11.861861861861861,
          -11.761761761761761,
          -11.661661661661661,
          -11.561561561561561,
          -11.461461461461461,
          -11.36136136136136,
          -11.26126126126126,
          -11.16116116116116,
          -11.06106106106106,
          -10.96096096096096,
          -10.86086086086086,
          -10.76076076076076,
          -10.66066066066066,
          -10.56056056056056,
          -10.46046046046046,
          -10.36036036036036,
          -10.26026026026026,
          -10.16016016016016,
          -10.06006006006006,
          -9.95995995995996,
          -9.85985985985986,
          -9.75975975975976,
          -9.65965965965966,
          -9.55955955955956,
          -9.45945945945946,
          -9.35935935935936,
          -9.25925925925926,
          -9.15915915915916,
          -9.05905905905906,
          -8.95895895895896,
          -8.85885885885886,
          -8.75875875875876,
          -8.65865865865866,
          -8.558558558558559,
          -8.458458458458459,
          -8.358358358358359,
          -8.258258258258259,
          -8.158158158158159,
          -8.058058058058059,
          -7.957957957957959,
          -7.857857857857859,
          -7.7577577577577586,
          -7.6576576576576585,
          -7.557557557557558,
          -7.457457457457458,
          -7.357357357357358,
          -7.257257257257251,
          -7.157157157157151,
          -7.057057057057051,
          -6.956956956956951,
          -6.856856856856851,
          -6.756756756756751,
          -6.656656656656651,
          -6.556556556556551,
          -6.456456456456451,
          -6.3563563563563505,
          -6.2562562562562505,
          -6.15615615615615,
          -6.05605605605605,
          -5.95595595595595,
          -5.85585585585585,
          -5.75575575575575,
          -5.65565565565565,
          -5.55555555555555,
          -5.45545545545545,
          -5.35535535535535,
          -5.25525525525525,
          -5.15515515515515,
          -5.05505505505505,
          -4.95495495495495,
          -4.85485485485485,
          -4.7547547547547495,
          -4.6546546546546494,
          -4.554554554554549,
          -4.454454454454449,
          -4.354354354354349,
          -4.254254254254249,
          -4.154154154154149,
          -4.054054054054049,
          -3.953953953953949,
          -3.853853853853849,
          -3.753753753753749,
          -3.653653653653649,
          -3.5535535535535487,
          -3.4534534534534487,
          -3.3533533533533486,
          -3.2532532532532485,
          -3.1531531531531485,
          -3.0530530530530484,
          -2.9529529529529484,
          -2.8528528528528483,
          -2.7527527527527482,
          -2.652652652652648,
          -2.552552552552548,
          -2.452452452452448,
          -2.352352352352348,
          -2.252252252252248,
          -2.152152152152148,
          -2.0520520520520478,
          -1.9519519519519477,
          -1.8518518518518476,
          -1.7517517517517476,
          -1.6516516516516475,
          -1.5515515515515474,
          -1.4514514514514474,
          -1.3513513513513473,
          -1.2512512512512473,
          -1.1511511511511472,
          -1.0510510510510471,
          -0.9509509509509471,
          -0.850850850850847,
          -0.7507507507507469,
          -0.6506506506506469,
          -0.5505505505505468,
          -0.45045045045044674,
          -0.3503503503503467,
          -0.2502502502502466,
          -0.15015015015014654,
          -0.05005005005004648,
          0.050050050050053585,
          0.15015015015015365,
          0.2502502502502537,
          0.3503503503503538,
          0.45045045045045384,
          0.5505505505505539,
          0.650650650650654,
          0.750750750750754,
          0.8508508508508541,
          0.9509509509509542,
          1.0510510510510542,
          1.1511511511511543,
          1.2512512512512544,
          1.3513513513513544,
          1.4514514514514545,
          1.5515515515515546,
          1.6516516516516546,
          1.7517517517517547,
          1.8518518518518547,
          1.9519519519519548,
          2.052052052052055,
          2.152152152152155,
          2.252252252252255,
          2.352352352352355,
          2.452452452452455,
          2.552552552552555,
          2.6526526526526553,
          2.7527527527527553,
          2.8528528528528554,
          2.9529529529529555,
          3.0530530530530555,
          3.1531531531531556,
          3.2532532532532557,
          3.3533533533533557,
          3.453453453453456,
          3.553553553553556,
          3.653653653653656,
          3.753753753753756,
          3.853853853853856,
          3.953953953953956,
          4.054054054054056,
          4.154154154154156,
          4.254254254254256,
          4.354354354354356,
          4.454454454454456,
          4.5545545545545565,
          4.6546546546546566,
          4.754754754754757,
          4.854854854854857,
          4.954954954954957,
          5.055055055055057,
          5.155155155155157,
          5.255255255255257,
          5.355355355355357,
          5.455455455455457,
          5.555555555555557,
          5.655655655655657,
          5.755755755755757,
          5.855855855855857,
          5.955955955955957,
          6.0560560560560575,
          6.1561561561561575,
          6.256256256256258,
          6.356356356356358,
          6.456456456456458,
          6.556556556556558,
          6.656656656656658,
          6.756756756756758,
          6.856856856856858,
          6.956956956956958,
          7.057057057057058,
          7.157157157157158,
          7.257257257257258,
          7.357357357357358,
          7.457457457457458,
          7.557557557557558,
          7.6576576576576585,
          7.7577577577577586,
          7.857857857857859,
          7.957957957957959,
          8.058058058058059,
          8.158158158158159,
          8.258258258258259,
          8.358358358358359,
          8.458458458458459,
          8.558558558558559,
          8.65865865865866,
          8.75875875875876,
          8.85885885885886,
          8.95895895895896,
          9.05905905905906,
          9.15915915915916,
          9.25925925925926,
          9.35935935935936,
          9.45945945945946,
          9.55955955955956,
          9.65965965965966,
          9.75975975975976,
          9.859859859859867,
          9.959959959959967,
          10.060060060060067,
          10.160160160160167,
          10.260260260260267,
          10.360360360360367,
          10.460460460460467,
          10.560560560560567,
          10.660660660660668,
          10.760760760760768,
          10.860860860860868,
          10.960960960960968,
          11.061061061061068,
          11.161161161161168,
          11.261261261261268,
          11.361361361361368,
          11.461461461461468,
          11.561561561561568,
          11.661661661661668,
          11.761761761761768,
          11.861861861861868,
          11.961961961961968,
          12.062062062062068,
          12.162162162162168,
          12.262262262262269,
          12.362362362362369,
          12.462462462462469,
          12.562562562562569,
          12.662662662662669,
          12.762762762762769,
          12.862862862862869,
          12.962962962962969,
          13.063063063063069,
          13.16316316316317,
          13.26326326326327,
          13.36336336336337,
          13.46346346346347,
          13.56356356356357,
          13.66366366366367,
          13.76376376376377,
          13.86386386386387,
          13.96396396396397,
          14.06406406406407,
          14.164164164164163,
          14.26426426426427,
          14.364364364364363,
          14.46446446446447,
          14.564564564564563,
          14.66466466466467,
          14.764764764764763,
          14.86486486486487,
          14.964964964964963,
          15.06506506506507,
          15.165165165165163,
          15.26526526526527,
          15.365365365365363,
          15.46546546546547,
          15.565565565565564,
          15.66566566566567,
          15.765765765765764,
          15.86586586586587,
          15.965965965965964,
          16.06606606606607,
          16.166166166166164,
          16.26626626626627,
          16.366366366366364,
          16.46646646646647,
          16.566566566566564,
          16.66666666666667,
          16.766766766766764,
          16.86686686686687,
          16.966966966966964,
          17.06706706706707,
          17.167167167167165,
          17.267267267267272,
          17.367367367367365,
          17.467467467467472,
          17.567567567567565,
          17.667667667667672,
          17.767767767767765,
          17.867867867867872,
          17.967967967967965,
          18.068068068068072,
          18.168168168168165,
          18.268268268268272,
          18.36836836836838,
          18.468468468468473,
          18.56856856856858,
          18.668668668668673,
          18.76876876876878,
          18.868868868868873,
          18.96896896896898,
          19.069069069069073,
          19.16916916916918,
          19.269269269269273,
          19.36936936936938,
          19.469469469469473,
          19.56956956956958,
          19.669669669669673,
          19.76976976976978,
          19.869869869869873,
          19.96996996996998,
          20.070070070070074,
          20.17017017017018,
          20.270270270270274,
          20.37037037037038,
          20.470470470470474,
          20.57057057057058,
          20.670670670670674,
          20.77077077077078,
          20.870870870870874,
          20.97097097097098,
          21.071071071071074,
          21.17117117117118,
          21.271271271271274,
          21.37137137137138,
          21.471471471471475,
          21.57157157157158,
          21.671671671671675,
          21.771771771771782,
          21.871871871871875,
          21.971971971971982,
          22.072072072072075,
          22.172172172172182,
          22.272272272272275,
          22.372372372372382,
          22.472472472472475,
          22.572572572572582,
          22.672672672672675,
          22.772772772772782,
          22.872872872872875,
          22.972972972972983,
          23.073073073073076,
          23.173173173173183,
          23.273273273273276,
          23.373373373373383,
          23.473473473473476,
          23.573573573573583,
          23.673673673673676,
          23.773773773773783,
          23.873873873873876,
          23.973973973973983,
          24.074074074074076,
          24.174174174174183,
          24.274274274274276,
          24.374374374374383,
          24.474474474474476,
          24.574574574574584,
          24.674674674674677,
          24.774774774774784,
          24.874874874874877,
          24.974974974974984,
          25.075075075075077,
          25.175175175175184,
          25.275275275275277,
          25.375375375375384,
          25.475475475475477,
          25.575575575575584,
          25.675675675675677,
          25.775775775775784,
          25.875875875875877,
          25.975975975975985,
          26.076076076076077,
          26.176176176176185,
          26.276276276276278,
          26.376376376376385,
          26.476476476476478,
          26.576576576576585,
          26.676676676676678,
          26.776776776776785,
          26.876876876876878,
          26.976976976976985,
          27.077077077077078,
          27.177177177177185,
          27.27727727727728,
          27.377377377377385,
          27.47747747747748,
          27.577577577577586,
          27.67767767767768,
          27.777777777777786,
          27.87787787787788,
          27.977977977977986,
          28.07807807807808,
          28.178178178178186,
          28.27827827827828,
          28.378378378378386,
          28.47847847847848,
          28.578578578578586,
          28.67867867867868,
          28.778778778778786,
          28.87887887887888,
          28.978978978978986,
          29.07907907907908,
          29.179179179179187,
          29.27927927927928,
          29.379379379379387,
          29.47947947947948,
          29.579579579579587,
          29.67967967967968,
          29.779779779779787,
          29.87987987987988,
          29.979979979979987,
          30.08008008008008,
          30.180180180180187,
          30.28028028028028,
          30.380380380380387,
          30.48048048048048,
          30.580580580580587,
          30.68068068068068,
          30.780780780780788,
          30.88088088088088,
          30.980980980980988,
          31.08108108108108,
          31.181181181181188,
          31.28128128128128,
          31.381381381381388,
          31.48148148148148,
          31.581581581581588,
          31.68168168168168,
          31.78178178178179,
          31.88188188188188,
          31.98198198198199,
          32.08208208208208,
          32.18218218218219,
          32.28228228228228,
          32.38238238238239,
          32.48248248248248,
          32.58258258258259,
          32.68268268268268,
          32.78278278278279,
          32.88288288288288,
          32.98298298298299,
          33.08308308308308,
          33.18318318318319,
          33.28328328328328,
          33.38338338338339,
          33.48348348348348,
          33.58358358358359,
          33.68368368368368,
          33.78378378378379,
          33.88388388388388,
          33.98398398398399,
          34.08408408408408,
          34.18418418418419,
          34.28428428428428,
          34.38438438438439,
          34.48448448448448,
          34.58458458458459,
          34.68468468468468,
          34.78478478478479,
          34.88488488488488,
          34.98498498498499,
          35.08508508508508,
          35.18518518518519,
          35.28528528528528,
          35.38538538538539,
          35.4854854854855,
          35.58558558558559,
          35.6856856856857,
          35.78578578578579,
          35.8858858858859,
          35.98598598598599,
          36.0860860860861,
          36.18618618618619,
          36.2862862862863,
          36.38638638638639,
          36.4864864864865,
          36.58658658658659,
          36.6866866866867,
          36.78678678678679,
          36.8868868868869,
          36.98698698698699,
          37.0870870870871,
          37.18718718718719,
          37.2872872872873,
          37.38738738738739,
          37.4874874874875,
          37.58758758758759,
          37.6876876876877,
          37.78778778778779,
          37.8878878878879,
          37.98798798798799,
          38.0880880880881,
          38.18818818818819,
          38.2882882882883,
          38.38838838838839,
          38.4884884884885,
          38.58858858858859,
          38.6886886886887,
          38.78878878878879,
          38.8888888888889,
          38.98898898898899,
          39.0890890890891,
          39.18918918918919,
          39.2892892892893,
          39.38938938938939,
          39.4894894894895,
          39.58958958958959,
          39.6896896896897,
          39.78978978978979,
          39.8898898898899,
          39.98998998998999,
          40.0900900900901,
          40.190190190190194,
          40.2902902902903,
          40.390390390390394,
          40.4904904904905,
          40.590590590590594,
          40.6906906906907,
          40.790790790790794,
          40.8908908908909,
          40.990990990990994,
          41.0910910910911,
          41.191191191191194,
          41.2912912912913,
          41.391391391391394,
          41.4914914914915,
          41.591591591591595,
          41.6916916916917,
          41.791791791791795,
          41.8918918918919,
          41.991991991991995,
          42.0920920920921,
          42.192192192192195,
          42.2922922922923,
          42.392392392392395,
          42.4924924924925,
          42.592592592592595,
          42.6926926926927,
          42.792792792792795,
          42.8928928928929,
          42.992992992992995,
          43.0930930930931,
          43.193193193193196,
          43.2932932932933,
          43.393393393393396,
          43.4934934934935,
          43.593593593593596,
          43.6936936936937,
          43.793793793793796,
          43.8938938938939,
          43.993993993993996,
          44.0940940940941,
          44.194194194194196,
          44.2942942942943,
          44.394394394394396,
          44.494494494494504,
          44.5945945945946,
          44.694694694694704,
          44.7947947947948,
          44.894894894894904,
          44.994994994995,
          45.095095095095104,
          45.1951951951952,
          45.295295295295304,
          45.3953953953954,
          45.495495495495504,
          45.5955955955956,
          45.695695695695704,
          45.7957957957958,
          45.895895895895904,
          45.995995995996,
          46.096096096096105,
          46.1961961961962,
          46.296296296296305,
          46.3963963963964,
          46.496496496496505,
          46.5965965965966,
          46.696696696696705,
          46.7967967967968,
          46.896896896896905,
          46.996996996997,
          47.097097097097105,
          47.1971971971972,
          47.297297297297305,
          47.3973973973974,
          47.497497497497505,
          47.5975975975976,
          47.697697697697706,
          47.7977977977978,
          47.897897897897906,
          47.997997997998,
          48.098098098098106,
          48.1981981981982,
          48.298298298298306,
          48.3983983983984,
          48.498498498498506,
          48.5985985985986,
          48.698698698698706,
          48.7987987987988,
          48.898898898898906,
          48.998998998999,
          49.09909909909911,
          49.1991991991992,
          49.29929929929931,
          49.3993993993994,
          49.49949949949951,
          49.5995995995996,
          49.69969969969971,
          49.7997997997998,
          49.89989989989991,
          50
         ],
         "y": [
          -126931.75,
          -126174.74850578986,
          -125420.76258926906,
          -124669.78623240154,
          -123921.81341715126,
          -123176.83812548216,
          -122434.85433935816,
          -121695.85604074322,
          -120959.83721160126,
          -120226.79183389623,
          -119496.71388959208,
          -118769.59736065273,
          -118045.43622904213,
          -117324.22447672422,
          -116605.95608566294,
          -115890.62503782223,
          -115178.22531516603,
          -114468.75089965828,
          -113762.19577326292,
          -113058.5539179439,
          -112357.81931566513,
          -111659.98594839059,
          -110965.04779808417,
          -110272.99884670986,
          -109583.83307623157,
          -108897.54446861324,
          -108214.12700581884,
          -107533.57466981227,
          -106855.8814425575,
          -106181.04130601845,
          -105509.04824215907,
          -104839.8962329433,
          -104173.57926033507,
          -103510.09130629833,
          -102849.42635279703,
          -102191.57838179509,
          -101536.54137525645,
          -100884.30931514507,
          -100234.87618342487,
          -99588.2359620598,
          -98944.3826330138,
          -98303.31017825079,
          -97665.01257973474,
          -97029.48381942957,
          -96396.71787929923,
          -95766.70874130767,
          -95139.45038741881,
          -94514.93679959659,
          -93893.16195980496,
          -93274.11985000786,
          -92657.80445216922,
          -92044.209748253,
          -91433.3297202231,
          -90825.15835004351,
          -90219.68961967812,
          -89616.91751109093,
          -89016.83600624581,
          -88419.43908710676,
          -87824.72073563769,
          -87232.67493380255,
          -86643.29566356527,
          -86056.57690688981,
          -85472.51264574008,
          -84891.09686208003,
          -84312.3235378736,
          -83736.18665508475,
          -83162.6801956774,
          -82591.7981416155,
          -82023.53447486297,
          -81457.88317738377,
          -80894.83823114184,
          -80334.39361810111,
          -79776.54332022552,
          -79221.28131947904,
          -78668.60159782556,
          -78118.49813722902,
          -77570.96491965344,
          -77025.99592706264,
          -76483.5851414207,
          -75943.7265446914,
          -75406.41411883885,
          -74871.64184582682,
          -74339.40370761942,
          -73809.69368618041,
          -73282.5057634739,
          -72757.8339214637,
          -72235.67214211385,
          -71716.01440738818,
          -71198.85469925078,
          -70684.18699966541,
          -70172.0052905962,
          -69662.3035540069,
          -69155.07577186161,
          -68650.31592612414,
          -68148.01799875856,
          -67648.17597172868,
          -67150.78382699857,
          -66655.83554653202,
          -66163.32511229314,
          -65673.24650624569,
          -65185.59371035379,
          -64700.36070658122,
          -64217.54147689205,
          -63737.1300032501,
          -63259.120267619444,
          -62783.506251963874,
          -62310.28193824748,
          -61839.44130843405,
          -61370.97834448764,
          -60904.88702837215,
          -60441.16134205153,
          -59979.7952674897,
          -59520.78278665062,
          -59064.117881498205,
          -58609.79453399642,
          -58157.80672610919,
          -57708.14843980047,
          -57260.81365703418,
          -56815.79635977427,
          -56373.09052998469,
          -55932.690149629365,
          -55494.58920067224,
          -55058.78166507726,
          -54625.261524808346,
          -54194.02276182946,
          -53765.05935810453,
          -53338.36529559751,
          -52913.934556272325,
          -52491.76112209291,
          -52071.83897502322,
          -51654.16209702719,
          -51238.724470068766,
          -50825.52007611187,
          -50414.54289712045,
          -50005.78691505846,
          -49599.24611188982,
          -49194.914469578485,
          -48792.78597008838,
          -48392.85459538346,
          -47995.114327427655,
          -47599.55914818491,
          -47206.183039619165,
          -46814.97998369435,
          -46425.94396237442,
          -46039.06895762331,
          -45654.34895140494,
          -45271.77792568329,
          -44891.34986242227,
          -44513.058743585825,
          -44136.89855113789,
          -43762.863267042434,
          -43390.94687326336,
          -43021.14335176463,
          -42653.44668451017,
          -42287.850853463926,
          -41924.34984058984,
          -41562.937627851854,
          -41203.6081972139,
          -40846.35553063993,
          -40491.173610093865,
          -40138.056417539665,
          -39786.99793494126,
          -39437.99214426259,
          -39091.033027467594,
          -38746.11456652022,
          -38403.230743384396,
          -38062.37554002407,
          -37723.54293840318,
          -37386.726920485664,
          -37051.921468235465,
          -36719.120563616525,
          -36388.31818859278,
          -36059.50832512817,
          -35732.684955186625,
          -35407.84206073211,
          -35084.97362372853,
          -34764.07362613986,
          -34445.13604993002,
          -34128.15487706296,
          -33813.12408950261,
          -33500.037669212914,
          -33188.88959815782,
          -32879.67385830125,
          -32572.38443160716,
          -32267.01530003948,
          -31963.56044556216,
          -31662.01385013913,
          -31362.369495734332,
          -31064.62136431171,
          -30768.763437835205,
          -30474.78969826875,
          -30182.694127576287,
          -29892.470707721757,
          -29604.113420669106,
          -29317.616248382266,
          -29032.973172825183,
          -28750.178175961788,
          -28469.225239756026,
          -28190.108346171837,
          -27912.82147717316,
          -27637.358614723937,
          -27363.713740788105,
          -27091.880837329605,
          -26821.853886312383,
          -26553.62686970037,
          -26287.19376945751,
          -26022.548567547743,
          -25759.685245935005,
          -25498.59778658324,
          -25239.280171456387,
          -24981.726382518387,
          -24725.930401733174,
          -24471.886211064695,
          -24219.58779247689,
          -23969.02912793369,
          -23720.204199399046,
          -23473.106988836895,
          -23227.73147821117,
          -22984.071649485824,
          -22742.121484624786,
          -22501.874965591996,
          -22263.3260743514,
          -22026.468792866934,
          -21791.297103102537,
          -21557.80498702215,
          -21325.98642658972,
          -21095.835403769175,
          -20867.345900524462,
          -20640.511898819517,
          -20415.327380618284,
          -20191.786327884703,
          -19969.882722582704,
          -19749.610546676246,
          -19530.96378212925,
          -19313.936410905662,
          -19098.522414969433,
          -18884.715776284487,
          -18672.51047681477,
          -18461.90049852422,
          -18252.879823376785,
          -18045.442433336397,
          -17839.582310366997,
          -17635.293436432527,
          -17432.569793496925,
          -17231.40536352413,
          -17031.79412847809,
          -16833.730070322734,
          -16637.207171022004,
          -16442.219412539846,
          -16248.760776840196,
          -16056.825245886994,
          -15866.40680164418,
          -15677.499426075694,
          -15490.097101145477,
          -15304.193808817465,
          -15119.783531055604,
          -14936.860249823829,
          -14755.417947086082,
          -14575.450604806303,
          -14396.95220494843,
          -14219.916729476405,
          -14044.338160354166,
          -13870.210479545654,
          -13697.527669014813,
          -13526.283710725575,
          -13356.472586641885,
          -13188.088278727682,
          -13021.124768946906,
          -12855.576039263497,
          -12691.436071641392,
          -12528.698848044536,
          -12367.358350436865,
          -12207.40856078232,
          -12048.843461044842,
          -11891.65703318837,
          -11735.843259176845,
          -11581.396120974203,
          -11428.30960054439,
          -11276.57767985134,
          -11126.194340858996,
          -10977.153565531298,
          -10829.449335832187,
          -10683.075633725599,
          -10538.02644117548,
          -10394.29574014576,
          -10251.87751260039,
          -10110.765740503302,
          -9970.95440581844,
          -9832.437490509745,
          -9695.208976541151,
          -9559.262845876603,
          -9424.59308048004,
          -9291.193662315402,
          -9159.058573346627,
          -9028.181795537657,
          -8898.557310852431,
          -8770.179101254887,
          -8643.04114870897,
          -8517.137435178618,
          -8392.461942627762,
          -8269.008653020355,
          -8146.771548320334,
          -8025.7446104916335,
          -7905.9218214981975,
          -7787.297163303965,
          -7669.864617872876,
          -7553.61816716887,
          -7438.551793155886,
          -7324.659477797866,
          -7211.935203058749,
          -7100.372950902474,
          -6989.966703292983,
          -6880.710442194213,
          -6772.598149570106,
          -6665.6238073846025,
          -6559.78139760164,
          -6455.064902185161,
          -6351.468303099103,
          -6248.985582307408,
          -6147.6107217740155,
          -6047.337703462864,
          -5948.160509337894,
          -5850.073121363046,
          -5753.06952150226,
          -5657.143691719475,
          -5562.289613978631,
          -5468.50127024367,
          -5375.772642478529,
          -5284.097712647149,
          -5193.470462713471,
          -5103.884874641433,
          -5015.334930394977,
          -4927.814611938041,
          -4841.317901234565,
          -4755.838780248492,
          -4671.371230943757,
          -4587.909235284305,
          -4505.4467752340715,
          -4423.977832756998,
          -4343.496389817026,
          -4263.996428378094,
          -4185.471930404142,
          -4107.916877859109,
          -4031.3252527069367,
          -3955.6910369115635,
          -3881.00821243693,
          -3807.2707612469762,
          -3734.4726653056423,
          -3662.6079065768677,
          -3591.6704670245917,
          -3521.6543286127558,
          -3452.553473305298,
          -3384.3618830661603,
          -3317.073539859281,
          -3250.6824256486,
          -3185.1825223980586,
          -3120.567812071595,
          -3056.8322766331507,
          -2993.969898046665,
          -2931.9746582760768,
          -2870.840539285328,
          -2810.561523038357,
          -2751.1315914991037,
          -2692.544726631509,
          -2634.794910399511,
          -2577.8761247670523,
          -2521.7823516980707,
          -2466.507573156507,
          -2412.045771106301,
          -2358.390927511392,
          -2305.5370243357206,
          -2253.4780435432267,
          -2202.2079670978496,
          -2151.72077696353,
          -2102.0104551042077,
          -2053.0709834838217,
          -2004.8963440663126,
          -1957.4805188156206,
          -1910.817489695685,
          -1864.9012386704464,
          -1819.725747703844,
          -1775.284998759818,
          -1731.5729738023083,
          -1688.5836547952547,
          -1646.3110237025976,
          -1604.7490624882764,
          -1563.8917531162308,
          -1523.7330775504015,
          -1484.267017754728,
          -1445.48755569315,
          -1407.3886733296076,
          -1369.9643526280404,
          -1333.2085755523892,
          -1297.1153240665928,
          -1261.678580134592,
          -1226.8923257203264,
          -1192.7505427877354,
          -1159.2472133007598,
          -1126.3763192233387,
          -1094.1318425194127,
          -1062.5077651529211,
          -1031.4980690878042,
          -1001.0967362880019,
          -971.2977487174539,
          -942.0950883401005,
          -913.482737119881,
          -885.4546770207359,
          -858.0048900066047,
          -831.1273580414277,
          -804.8160630891442,
          -779.0649871136948,
          -753.868112079019,
          -729.2194199490568,
          -705.1128926877482,
          -681.542512259033,
          -658.502260626851,
          -635.9861197551425,
          -613.9880716078469,
          -592.5020981489045,
          -571.5221813422551,
          -551.0423031518385,
          -531.0564455415948,
          -511.5585904754637,
          -492.5427199173853,
          -474.00281583129936,
          -455.93286018114594,
          -438.3268349308648,
          -421.17872204439476,
          -404.4825034856781,
          -388.23216121865346,
          -372.42167720726087,
          -357.0450334154402,
          -342.09621180713134,
          -327.5691943462741,
          -313.45796299680853,
          -299.75649972267456,
          -286.458786487812,
          -273.5588052561608,
          -261.05053799166086,
          -248.92796665825205,
          -237.18507321987437,
          -225.8158396404677,
          -214.8142478839719,
          -204.17427991432692,
          -193.88991769547266,
          -183.95514319134907,
          -174.36393836589602,
          -165.11028518305338,
          -156.18816560676115,
          -147.59156160095918,
          -139.3144551295874,
          -131.3508281565857,
          -123.69466264589403,
          -116.33994056145225,
          -109.28064386720028,
          -102.51075452707808,
          -96.0242545050255,
          -89.81512576498247,
          -83.87735027088893,
          -78.20490998668473,
          -72.79178687630983,
          -67.63196290370412,
          -62.719420032807506,
          -58.04814022755991,
          -53.61210545190125,
          -49.40529766977141,
          -45.42169884511031,
          -41.65529094185787,
          -38.10005592395399,
          -34.749975755338575,
          -31.599032399951547,
          -28.641207821732817,
          -25.870483984622275,
          -23.280842852559854,
          -20.866266389485453,
          -18.620736559338983,
          -16.538235326060352,
          -14.612744653589472,
          -12.838246505866255,
          -11.208722846830609,
          -9.718155640422442,
          -8.360526850581666,
          -7.12981844124819,
          -6.020012376361925,
          -5.025090619862781,
          -4.1390351356906665,
          -3.355827887785492,
          -2.6694508400871664,
          -2.073885956535601,
          -1.563115201070706,
          -1.1311205376323896,
          -0.7718839301605627,
          -0.47938734259513516,
          -0.2476127388760165,
          -0.0705420829431169,
          0.057842661263653755,
          0.14355952980438572,
          0.19262655873916906,
          0.21106178412809387,
          0.20488324203125033,
          0.1801089685087285,
          0.14275699962061855,
          0.09884537142701055,
          0.054392119987994675,
          0.01541528136366102,
          -0.012067108385900305,
          -0.022037013200599226,
          -0.0084763970203455,
          0.034632776214951005,
          0.11330854256538017,
          0.2335689380910322,
          0.40143199885199743,
          0.622915760908366,
          0.9040382603202275,
          1.2508175331476727,
          1.6692716154507914,
          2.1654185432896735,
          2.74527635272441,
          3.414863079815089,
          4.180196760621803,
          5.047295431204642,
          6.022177127623694,
          7.1108598859390515,
          8.319361742210804,
          9.653700732499038,
          11.119894892863849,
          12.723962259365322,
          14.471920868063554,
          16.369788755018625,
          18.423583956290635,
          20.639324507939676,
          23.023028446025826,
          25.580713806609182,
          28.318398625749833,
          31.24210093950788,
          34.35783878394339,
          37.671630195116464,
          41.18949320908721,
          44.91744586191569,
          48.86150618966201,
          53.02769222838626,
          57.42202201414852,
          62.050513583008886,
          66.91918497102745,
          72.0340542142643,
          77.40113934877954,
          83.02645841063323,
          88.91602943588549,
          95.07587046059638,
          101.51199952082605,
          108.23043465263451,
          115.23719389208188,
          122.53829527522828,
          130.1397568381338,
          138.04759661685847,
          146.26783264746243,
          154.80648296600575,
          163.6695656085485,
          172.86309861115086,
          182.39310000987285,
          192.26558784077454,
          202.48658013991604,
          213.0620949433575,
          223.99815028715892,
          235.30076420738047,
          246.97595474008213,
          259.0297399213241,
          271.4681377871665,
          284.2971663736692,
          297.5228437168925,
          311.15118785289644,
          325.18821681774114,
          339.6399486474867,
          354.51240137819303,
          369.81159304592035,
          385.54354168672876,
          401.7142653366784,
          418.32978203182927,
          435.39610980824153,
          452.91926670197523,
          470.9052707490904,
          489.36013998564727,
          508.28989244770577,
          527.7005461713261,
          547.5981191925682,
          567.9886295474926,
          588.8780952721588,
          610.2725344026273,
          632.1779649749581,
          654.6004050252111,
          677.5458725894465,
          701.0203857037245,
          725.0299624041052,
          749.5806207266484,
          774.6783787074146,
          800.3292543824635,
          826.5392657878556,
          853.3144309596505,
          880.6607679339105,
          908.5842947466921,
          937.091029434057,
          966.1869900320651,
          995.8781945767769,
          1026.170661104252,
          1057.0704076505513,
          1088.583452251734,
          1120.7158129438608,
          1153.4735077629912,
          1186.862554745186,
          1220.888971926505,
          1255.5587773430082,
          1290.8779890307553,
          1326.8526250258074,
          1363.4887033642235,
          1400.7922420820646,
          1438.76925921539,
          1477.4257728002606,
          1516.7678008727357,
          1556.8013614688762,
          1597.5324726247416,
          1638.9671523763916,
          1681.1114187598873,
          1723.9712898112882,
          1767.5527835666546,
          1811.8619180620467,
          1856.9047113335241,
          1902.687181417147,
          1949.215346348976,
          1996.4952241650708,
          2044.5328329014915,
          2093.334190594298,
          2142.905315279551,
          2193.25222499331,
          2244.3809377716357,
          2296.297471650587,
          2349.007844666225,
          2402.5180748546104,
          2456.834180251802,
          2511.9621788938603,
          2567.908088816845,
          2624.677928056817,
          2682.2777146498324,
          2740.7134666319625,
          2799.9912020392517,
          2860.116938907777,
          2921.0966952735803,
          2982.9364891727405,
          3045.6423386412994,
          3109.220261715335,
          3173.6762764308883,
          3239.0164008240395,
          3305.246652930829,
          3372.373050787336,
          3440.4016124296018,
          3509.338355893705,
          3579.189299215687,
          3649.960460431628,
          3721.6578575775666,
          3794.287508689584,
          3867.8554318037195,
          3942.3676449560544,
          4017.830166182628,
          4094.2490135195203,
          4171.630205002772,
          4249.979758668463,
          4329.303692552632,
          4409.608024691361,
          4490.89877312069,
          4573.181955876698,
          4656.463590995425,
          4740.749696512953,
          4826.046290465319,
          4912.359390888606,
          4999.695015818853,
          5088.059183292139,
          5177.457911344505,
          5267.897218012033,
          5359.3831213307585,
          5451.921639336769,
          5545.518790066094,
          5640.180591554825,
          5735.913061838991,
          5832.722218954683,
          5930.614080937946,
          6029.594665824825,
          6129.669991651411,
          6230.846076453731,
          6333.12893826788,
          6436.524595129883,
          6541.039065075833,
          6646.67836614176,
          6753.448516363752,
          6861.355533777842,
          6970.405436420118,
          7080.604242326611,
          7191.957969533411,
          7304.472636076548,
          7418.154259992113,
          7533.008859316134,
          7649.042452084703,
          7766.2610563338485,
          7884.670690099661,
          8004.277371418172,
          8125.087118325472,
          8247.105948857587,
          8370.339881050611,
          8494.794932940575,
          8620.477122563563,
          8747.392467955611,
          8875.546987152808,
          9004.946698191181,
          9135.597619106826,
          9267.505767935763,
          9400.677162714095,
          9535.117821477843,
          9670.8337622631,
          9807.831003105894,
          9946.11556204232,
          10085.693457108402,
          10226.570706340237,
          10368.753327773846,
          10512.24733944533,
          10657.058759390706,
          10803.19360564608,
          10950.657896247467,
          11099.45764923097,
          11249.598882632605,
          11401.087614488475,
          11553.929862834599,
          11708.13164570708,
          11863.698981141935,
          12020.63788717527,
          12178.954381843092,
          12338.654483181515,
          12499.74420922655,
          12662.229578014305,
          12826.11660758079,
          12991.411315962116,
          13158.119721194293,
          13326.24784131343,
          13495.80169435554,
          13666.78729835673,
          13839.210671353008,
          14013.077831380491,
          14188.394796475184,
          14365.1675846732,
          14543.402214010546,
          14723.104702523333,
          14904.281068247574,
          15086.937329219374,
          15271.079503474748,
          15456.713609049804,
          15643.845663980548,
          15832.4816863031,
          16022.627694053459,
          16214.289705267744,
          16407.47373798196,
          16602.18581023222,
          16798.43194005453,
          16996.218145485003,
          17195.55044455965,
          17396.43485531458,
          17598.877395785803,
          17802.884084009427,
          18008.460938021468,
          18215.61397585803,
          18424.34921555512,
          18634.67267514886,
          18846.59037267525,
          19060.108326170408,
          19275.232553670336,
          19491.969073211152,
          19710.323902828855,
          19930.303060559567,
          20151.91256443929,
          20375.15843250414,
          20600.04668279012,
          20826.58333333335,
          21054.774402169827,
          21284.62590733568,
          21516.143866866896,
          21749.334298799607,
          21984.203221169802,
          22220.756652013613,
          22459.000609367027,
          22698.941111266173,
          22940.58417574705,
          23183.935820845778,
          23429.002064598353,
          23675.788925040903,
          23924.30242020942,
          24174.548568140035,
          24426.53338686873,
          24680.262894431646,
          24935.743108864765,
          25192.980048204216,
          25451.979730485997,
          25712.748173746233,
          25975.291396020915,
          26239.615415346176,
          26505.726249758,
          26773.629917292525,
          27043.332435985732,
          27314.83982387376,
          27588.15809899259,
          27863.29327937836,
          28140.25138306705,
          28419.03842809481,
          28699.660432497607,
          28982.123414311583,
          29266.43339157273,
          29552.596382317173,
          29840.6184045809,
          30130.50547640005,
          30422.2636158106,
          30715.89884084869,
          31011.417169550306,
          31308.82461995159,
          31608.12721008851,
          31909.33095799722,
          32212.44188171369,
          32517.46599927406,
          32824.40932871432,
          33133.2778880706,
          33444.07769537888,
          33756.81476867531,
          34071.495125995854,
          34388.12478537667,
          34706.70976485373,
          35027.25608246317,
          35349.769756240974,
          35674.25680422328,
          36000.723244446075,
          36329.175094945494,
          36659.61837375752,
          36992.05909891829,
          37326.50328846378,
          37662.956960430136,
          38001.42613285333,
          38341.91682376952,
          38684.43505121467,
          39028.98683322493,
          39375.57818783627,
          39724.21513308484,
          40074.903687006605,
          40427.64986763774,
          40782.45969301417,
          41139.33918117209,
          41498.29435014743,
          41859.33121797638,
          42222.45580269487,
          42587.67412233909,
          42954.99219494498,
          43324.41603854872,
          43695.951671186296,
          44069.60511089372,
          44445.38237570717,
          44823.2894836626,
          45203.33245279616,
          45585.51730114382,
          45969.85004674173,
          46356.336707625866,
          46744.98330183238,
          47135.79584739722,
          47528.780362356556,
          47923.942864746365,
          48321.28937260278,
          48720.82590396178,
          49122.55847685951,
          49526.49310933193,
          49932.63581941522,
          50340.992625145314,
          50751.569544558406,
          51164.37259569042,
          51579.40779657755,
          51996.68116525572,
          52416.19871976112,
          52837.96647812969,
          53261.9904583976,
          53688.276678600814,
          54116.831156775486,
          54547.65991095757,
          54980.768959183246,
          55416.16431948844,
          55853.85200990935,
          56293.838048481906,
          56736.1284532423,
          57180.72924222645,
          57627.64643347056,
          58076.88604501056,
          58528.45409488261,
          58982.35660112269,
          59438.59958176695,
          59897.18905485134,
          60358.13103841205,
          60821.431550485,
          61287.09660910639,
          61755.132232312135,
          62225.544438138444,
          62698.33924462124,
          63173.5226697967,
          63651.100731700775,
          64131.079448369645,
          64613.464837839245,
          65098.26291814575,
          65585.47970732508,
          66075.12122341349,
          66567.19348444683,
          67061.70250846134,
          67558.65431349294,
          68058.05491757783,
          68559.91033875191,
          69064.22659505138,
          69571.0097045122,
          70080.26568517053,
          70592.00055506227,
          71106.22033222369,
          71622.93103469066,
          72142.13868049938,
          72663.84928768579,
          73188.0688742861,
          73714.8034583362,
          74244.05905787229,
          74775.84169093032,
          75310.15737554646,
          75847.01212975665,
          76386.41197159709,
          76928.36291910367,
          77472.87099031264,
          78019.94220325987,
          78569.5825759816,
          79121.79812651372,
          79676.59487289246,
          80233.97883315371,
          80793.95602533368,
          81356.53246746829,
          81921.71417759376,
          82489.507173746,
          83059.91747396118,
          83632.95109627525,
          84208.6140587244,
          84786.91237934456,
          85367.85207617194,
          85951.43916724241,
          86537.67967059223,
          87126.57960425729,
          87718.1449862738,
          88312.38183467767,
          88909.2961675051,
          89508.89400279202,
          90111.18135857463,
          90716.16425288883,
          91323.84870377084,
          91934.24072925658,
          92547.34634738225,
          93163.17157618374,
          93781.72243369732,
          94403.00493795883,
          95027.02510700452,
          95653.78895887028,
          96283.30251159234,
          96915.5717832066,
          97550.60279174928,
          98188.40155525626,
          98828.9740917638,
          99472.32641930775,
          100118.46455592437,
          100767.39451964953,
          101419.1223285195,
          102073.65400057012,
          102730.99555383764,
          103391.15300635796,
          104054.13237616731,
          104719.93968130155,
          105388.58093979696,
          106060.06216968938,
          106734.38938901506,
          107411.56861580991,
          108091.60586811013,
          108774.50716395162,
          109460.27852137061,
          110148.925958403,
          110840.45549308503,
          111534.87314345254,
          112232.18492754182,
          112932.39686338871,
          113635.5149690295,
          114341.5452625,
          115050.49376183651,
          115762.36648507488,
          116477.16945025137,
          117194.90867540182,
          117915.59017856253,
          118639.21997776933,
          119365.80409105851,
          120095.34853646588,
          120827.85933202774,
          121563.34249577994,
          122301.80404575873,
          123043.25
         ]
        }
       ],
       "layout": {
        "template": {
         "data": {
          "bar": [
           {
            "error_x": {
             "color": "#2a3f5f"
            },
            "error_y": {
             "color": "#2a3f5f"
            },
            "marker": {
             "line": {
              "color": "#E5ECF6",
              "width": 0.5
             }
            },
            "type": "bar"
           }
          ],
          "barpolar": [
           {
            "marker": {
             "line": {
              "color": "#E5ECF6",
              "width": 0.5
             }
            },
            "type": "barpolar"
           }
          ],
          "carpet": [
           {
            "aaxis": {
             "endlinecolor": "#2a3f5f",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "#2a3f5f"
            },
            "baxis": {
             "endlinecolor": "#2a3f5f",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "#2a3f5f"
            },
            "type": "carpet"
           }
          ],
          "choropleth": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "choropleth"
           }
          ],
          "contour": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "contour"
           }
          ],
          "contourcarpet": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "contourcarpet"
           }
          ],
          "heatmap": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "heatmap"
           }
          ],
          "heatmapgl": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "heatmapgl"
           }
          ],
          "histogram": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "histogram"
           }
          ],
          "histogram2d": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "histogram2d"
           }
          ],
          "histogram2dcontour": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "histogram2dcontour"
           }
          ],
          "mesh3d": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "mesh3d"
           }
          ],
          "parcoords": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "parcoords"
           }
          ],
          "pie": [
           {
            "automargin": true,
            "type": "pie"
           }
          ],
          "scatter": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatter"
           }
          ],
          "scatter3d": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatter3d"
           }
          ],
          "scattercarpet": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattercarpet"
           }
          ],
          "scattergeo": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattergeo"
           }
          ],
          "scattergl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattergl"
           }
          ],
          "scattermapbox": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattermapbox"
           }
          ],
          "scatterpolar": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterpolar"
           }
          ],
          "scatterpolargl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterpolargl"
           }
          ],
          "scatterternary": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterternary"
           }
          ],
          "surface": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "surface"
           }
          ],
          "table": [
           {
            "cells": {
             "fill": {
              "color": "#EBF0F8"
             },
             "line": {
              "color": "white"
             }
            },
            "header": {
             "fill": {
              "color": "#C8D4E3"
             },
             "line": {
              "color": "white"
             }
            },
            "type": "table"
           }
          ]
         },
         "layout": {
          "annotationdefaults": {
           "arrowcolor": "#2a3f5f",
           "arrowhead": 0,
           "arrowwidth": 1
          },
          "coloraxis": {
           "colorbar": {
            "outlinewidth": 0,
            "ticks": ""
           }
          },
          "colorscale": {
           "diverging": [
            [
             0,
             "#8e0152"
            ],
            [
             0.1,
             "#c51b7d"
            ],
            [
             0.2,
             "#de77ae"
            ],
            [
             0.3,
             "#f1b6da"
            ],
            [
             0.4,
             "#fde0ef"
            ],
            [
             0.5,
             "#f7f7f7"
            ],
            [
             0.6,
             "#e6f5d0"
            ],
            [
             0.7,
             "#b8e186"
            ],
            [
             0.8,
             "#7fbc41"
            ],
            [
             0.9,
             "#4d9221"
            ],
            [
             1,
             "#276419"
            ]
           ],
           "sequential": [
            [
             0,
             "#0d0887"
            ],
            [
             0.1111111111111111,
             "#46039f"
            ],
            [
             0.2222222222222222,
             "#7201a8"
            ],
            [
             0.3333333333333333,
             "#9c179e"
            ],
            [
             0.4444444444444444,
             "#bd3786"
            ],
            [
             0.5555555555555556,
             "#d8576b"
            ],
            [
             0.6666666666666666,
             "#ed7953"
            ],
            [
             0.7777777777777778,
             "#fb9f3a"
            ],
            [
             0.8888888888888888,
             "#fdca26"
            ],
            [
             1,
             "#f0f921"
            ]
           ],
           "sequentialminus": [
            [
             0,
             "#0d0887"
            ],
            [
             0.1111111111111111,
             "#46039f"
            ],
            [
             0.2222222222222222,
             "#7201a8"
            ],
            [
             0.3333333333333333,
             "#9c179e"
            ],
            [
             0.4444444444444444,
             "#bd3786"
            ],
            [
             0.5555555555555556,
             "#d8576b"
            ],
            [
             0.6666666666666666,
             "#ed7953"
            ],
            [
             0.7777777777777778,
             "#fb9f3a"
            ],
            [
             0.8888888888888888,
             "#fdca26"
            ],
            [
             1,
             "#f0f921"
            ]
           ]
          },
          "colorway": [
           "#636efa",
           "#EF553B",
           "#00cc96",
           "#ab63fa",
           "#FFA15A",
           "#19d3f3",
           "#FF6692",
           "#B6E880",
           "#FF97FF",
           "#FECB52"
          ],
          "font": {
           "color": "#2a3f5f"
          },
          "geo": {
           "bgcolor": "white",
           "lakecolor": "white",
           "landcolor": "#E5ECF6",
           "showlakes": true,
           "showland": true,
           "subunitcolor": "white"
          },
          "hoverlabel": {
           "align": "left"
          },
          "hovermode": "closest",
          "mapbox": {
           "style": "light"
          },
          "paper_bgcolor": "white",
          "plot_bgcolor": "#E5ECF6",
          "polar": {
           "angularaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "bgcolor": "#E5ECF6",
           "radialaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           }
          },
          "scene": {
           "xaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           },
           "yaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           },
           "zaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           }
          },
          "shapedefaults": {
           "line": {
            "color": "#2a3f5f"
           }
          },
          "ternary": {
           "aaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "baxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "bgcolor": "#E5ECF6",
           "caxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           }
          },
          "title": {
           "x": 0.05
          },
          "xaxis": {
           "automargin": true,
           "gridcolor": "white",
           "linecolor": "white",
           "ticks": "",
           "title": {
            "standoff": 15
           },
           "zerolinecolor": "white",
           "zerolinewidth": 2
          },
          "yaxis": {
           "automargin": true,
           "gridcolor": "white",
           "linecolor": "white",
           "ticks": "",
           "title": {
            "standoff": 15
           },
           "zerolinecolor": "white",
           "zerolinewidth": 2
          }
         }
        },
        "xaxis": {
         "dtick": 1,
         "range": [
          -1,
          1
         ],
         "showticklabels": true,
         "tick0": 0,
         "tickangle": 0,
         "ticks": "outside",
         "title": {
          "font": {
           "color": "black",
           "family": "Arial, serif",
           "size": 18
          },
          "text": "x"
         }
        },
        "yaxis": {
         "dtick": 1,
         "range": [
          -1,
          1
         ],
         "tick0": 0,
         "ticks": "outside",
         "title": {
          "font": {
           "color": "black",
           "family": "Arial, serif",
           "size": 18
          },
          "text": "P(x)"
         }
        }
       }
      },
      "text/html": [
       "<div>\n",
       "        \n",
       "        \n",
       "            <div id=\"a60e4cc3-2f8e-4f72-a9b9-af665ed5fdc0\" class=\"plotly-graph-div\" style=\"height:525px; width:100%;\"></div>\n",
       "            <script type=\"text/javascript\">\n",
       "                require([\"plotly\"], function(Plotly) {\n",
       "                    window.PLOTLYENV=window.PLOTLYENV || {};\n",
       "                    \n",
       "                if (document.getElementById(\"a60e4cc3-2f8e-4f72-a9b9-af665ed5fdc0\")) {\n",
       "                    Plotly.newPlot(\n",
       "                        'a60e4cc3-2f8e-4f72-a9b9-af665ed5fdc0',\n",
       "                        [{\"type\": \"scatter\", \"x\": [-50.0, -49.8998998998999, -49.7997997997998, -49.6996996996997, -49.5995995995996, -49.4994994994995, -49.3993993993994, -49.2992992992993, -49.1991991991992, -49.0990990990991, -48.998998998999, -48.8988988988989, -48.7987987987988, -48.6986986986987, -48.5985985985986, -48.4984984984985, -48.3983983983984, -48.2982982982983, -48.1981981981982, -48.0980980980981, -47.997997997998, -47.8978978978979, -47.7977977977978, -47.6976976976977, -47.5975975975976, -47.4974974974975, -47.3973973973974, -47.2972972972973, -47.1971971971972, -47.0970970970971, -46.996996996997, -46.8968968968969, -46.7967967967968, -46.6966966966967, -46.5965965965966, -46.4964964964965, -46.3963963963964, -46.2962962962963, -46.1961961961962, -46.0960960960961, -45.995995995996, -45.8958958958959, -45.7957957957958, -45.6956956956957, -45.5955955955956, -45.4954954954955, -45.3953953953954, -45.2952952952953, -45.1951951951952, -45.0950950950951, -44.994994994995, -44.8948948948949, -44.7947947947948, -44.6946946946947, -44.5945945945946, -44.4944944944945, -44.394394394394396, -44.294294294294296, -44.194194194194196, -44.094094094094096, -43.993993993993996, -43.893893893893896, -43.793793793793796, -43.693693693693696, -43.593593593593596, -43.493493493493496, -43.393393393393396, -43.293293293293296, -43.193193193193196, -43.093093093093096, -42.992992992992995, -42.892892892892895, -42.792792792792795, -42.692692692692695, -42.592592592592595, -42.49249249249249, -42.392392392392395, -42.29229229229229, -42.192192192192195, -42.09209209209209, -41.991991991991995, -41.89189189189189, -41.791791791791795, -41.69169169169169, -41.591591591591595, -41.49149149149149, -41.391391391391394, -41.29129129129129, -41.191191191191194, -41.09109109109109, -40.990990990990994, -40.89089089089089, -40.790790790790794, -40.69069069069069, -40.590590590590594, -40.49049049049049, -40.390390390390394, -40.29029029029029, -40.190190190190194, -40.09009009009009, -39.98998998998999, -39.889889889889886, -39.78978978978979, -39.689689689689686, -39.58958958958959, -39.489489489489486, -39.38938938938939, -39.289289289289286, -39.189189189189186, -39.089089089089086, -38.988988988988986, -38.888888888888886, -38.788788788788786, -38.688688688688686, -38.588588588588586, -38.488488488488485, -38.388388388388385, -38.288288288288285, -38.188188188188185, -38.088088088088085, -37.987987987987985, -37.887887887887885, -37.787787787787785, -37.687687687687685, -37.587587587587585, -37.487487487487485, -37.387387387387385, -37.287287287287285, -37.187187187187185, -37.087087087087085, -36.986986986986985, -36.886886886886884, -36.786786786786784, -36.686686686686684, -36.586586586586584, -36.486486486486484, -36.386386386386384, -36.286286286286284, -36.186186186186184, -36.086086086086084, -35.985985985985984, -35.885885885885884, -35.785785785785784, -35.685685685685684, -35.585585585585584, -35.48548548548548, -35.38538538538538, -35.28528528528528, -35.18518518518518, -35.08508508508508, -34.98498498498498, -34.88488488488488, -34.78478478478478, -34.68468468468468, -34.58458458458458, -34.48448448448448, -34.38438438438438, -34.28428428428428, -34.18418418418418, -34.08408408408408, -33.98398398398398, -33.88388388388388, -33.78378378378378, -33.68368368368368, -33.58358358358358, -33.48348348348348, -33.38338338338338, -33.28328328328328, -33.18318318318318, -33.08308308308308, -32.98298298298298, -32.88288288288288, -32.78278278278278, -32.68268268268268, -32.58258258258258, -32.48248248248248, -32.38238238238238, -32.28228228228228, -32.18218218218218, -32.08208208208208, -31.98198198198198, -31.88188188188188, -31.78178178178178, -31.68168168168168, -31.58158158158158, -31.48148148148148, -31.38138138138138, -31.28128128128128, -31.18118118118118, -31.08108108108108, -30.98098098098098, -30.88088088088088, -30.78078078078078, -30.68068068068068, -30.58058058058058, -30.48048048048048, -30.38038038038038, -30.28028028028028, -30.18018018018018, -30.08008008008008, -29.97997997997998, -29.87987987987988, -29.77977977977978, -29.67967967967968, -29.57957957957958, -29.47947947947948, -29.37937937937938, -29.27927927927928, -29.17917917917918, -29.07907907907908, -28.97897897897898, -28.87887887887888, -28.77877877877878, -28.67867867867868, -28.578578578578576, -28.478478478478475, -28.378378378378375, -28.278278278278275, -28.178178178178175, -28.078078078078075, -27.977977977977975, -27.877877877877875, -27.777777777777775, -27.677677677677675, -27.577577577577575, -27.477477477477475, -27.377377377377375, -27.277277277277275, -27.177177177177175, -27.077077077077075, -26.976976976976974, -26.876876876876874, -26.776776776776774, -26.676676676676674, -26.576576576576574, -26.476476476476474, -26.376376376376374, -26.276276276276274, -26.176176176176174, -26.076076076076074, -25.975975975975974, -25.875875875875874, -25.775775775775774, -25.675675675675674, -25.575575575575574, -25.475475475475474, -25.375375375375373, -25.275275275275273, -25.175175175175173, -25.075075075075073, -24.974974974974973, -24.874874874874873, -24.774774774774773, -24.674674674674673, -24.574574574574573, -24.474474474474473, -24.374374374374373, -24.274274274274273, -24.174174174174173, -24.074074074074073, -23.973973973973973, -23.873873873873872, -23.773773773773772, -23.673673673673672, -23.573573573573572, -23.473473473473472, -23.373373373373372, -23.273273273273272, -23.173173173173172, -23.073073073073072, -22.972972972972972, -22.872872872872872, -22.772772772772772, -22.67267267267267, -22.57257257257257, -22.47247247247247, -22.37237237237237, -22.27227227227227, -22.17217217217217, -22.07207207207207, -21.97197197197197, -21.87187187187187, -21.77177177177177, -21.67167167167167, -21.57157157157157, -21.47147147147147, -21.37137137137137, -21.27127127127127, -21.17117117117117, -21.07107107107107, -20.97097097097097, -20.87087087087087, -20.77077077077077, -20.67067067067067, -20.57057057057057, -20.47047047047047, -20.37037037037037, -20.27027027027027, -20.17017017017017, -20.070070070070066, -19.969969969969966, -19.869869869869866, -19.769769769769766, -19.669669669669666, -19.569569569569566, -19.469469469469466, -19.369369369369366, -19.269269269269266, -19.169169169169166, -19.069069069069066, -18.968968968968966, -18.868868868868866, -18.768768768768766, -18.668668668668666, -18.568568568568566, -18.468468468468465, -18.368368368368365, -18.268268268268265, -18.168168168168165, -18.068068068068065, -17.967967967967965, -17.867867867867865, -17.767767767767765, -17.667667667667665, -17.567567567567565, -17.467467467467465, -17.367367367367365, -17.267267267267265, -17.167167167167165, -17.067067067067065, -16.966966966966964, -16.866866866866864, -16.766766766766764, -16.666666666666664, -16.566566566566564, -16.466466466466464, -16.366366366366364, -16.266266266266264, -16.166166166166164, -16.066066066066064, -15.965965965965964, -15.865865865865864, -15.765765765765764, -15.665665665665664, -15.565565565565564, -15.465465465465464, -15.365365365365363, -15.265265265265263, -15.165165165165163, -15.065065065065063, -14.964964964964963, -14.864864864864863, -14.764764764764763, -14.664664664664663, -14.564564564564563, -14.464464464464463, -14.364364364364363, -14.264264264264263, -14.164164164164163, -14.064064064064063, -13.963963963963963, -13.863863863863862, -13.763763763763762, -13.663663663663662, -13.563563563563562, -13.463463463463462, -13.363363363363362, -13.263263263263262, -13.163163163163162, -13.063063063063062, -12.962962962962962, -12.862862862862862, -12.762762762762762, -12.662662662662662, -12.562562562562562, -12.462462462462462, -12.362362362362362, -12.262262262262261, -12.162162162162161, -12.062062062062061, -11.961961961961961, -11.861861861861861, -11.761761761761761, -11.661661661661661, -11.561561561561561, -11.461461461461461, -11.36136136136136, -11.26126126126126, -11.16116116116116, -11.06106106106106, -10.96096096096096, -10.86086086086086, -10.76076076076076, -10.66066066066066, -10.56056056056056, -10.46046046046046, -10.36036036036036, -10.26026026026026, -10.16016016016016, -10.06006006006006, -9.95995995995996, -9.85985985985986, -9.75975975975976, -9.65965965965966, -9.55955955955956, -9.45945945945946, -9.35935935935936, -9.25925925925926, -9.15915915915916, -9.05905905905906, -8.95895895895896, -8.85885885885886, -8.75875875875876, -8.65865865865866, -8.558558558558559, -8.458458458458459, -8.358358358358359, -8.258258258258259, -8.158158158158159, -8.058058058058059, -7.957957957957959, -7.857857857857859, -7.7577577577577586, -7.6576576576576585, -7.557557557557558, -7.457457457457458, -7.357357357357358, -7.257257257257251, -7.157157157157151, -7.057057057057051, -6.956956956956951, -6.856856856856851, -6.756756756756751, -6.656656656656651, -6.556556556556551, -6.456456456456451, -6.3563563563563505, -6.2562562562562505, -6.15615615615615, -6.05605605605605, -5.95595595595595, -5.85585585585585, -5.75575575575575, -5.65565565565565, -5.55555555555555, -5.45545545545545, -5.35535535535535, -5.25525525525525, -5.15515515515515, -5.05505505505505, -4.95495495495495, -4.85485485485485, -4.7547547547547495, -4.6546546546546494, -4.554554554554549, -4.454454454454449, -4.354354354354349, -4.254254254254249, -4.154154154154149, -4.054054054054049, -3.953953953953949, -3.853853853853849, -3.753753753753749, -3.653653653653649, -3.5535535535535487, -3.4534534534534487, -3.3533533533533486, -3.2532532532532485, -3.1531531531531485, -3.0530530530530484, -2.9529529529529484, -2.8528528528528483, -2.7527527527527482, -2.652652652652648, -2.552552552552548, -2.452452452452448, -2.352352352352348, -2.252252252252248, -2.152152152152148, -2.0520520520520478, -1.9519519519519477, -1.8518518518518476, -1.7517517517517476, -1.6516516516516475, -1.5515515515515474, -1.4514514514514474, -1.3513513513513473, -1.2512512512512473, -1.1511511511511472, -1.0510510510510471, -0.9509509509509471, -0.850850850850847, -0.7507507507507469, -0.6506506506506469, -0.5505505505505468, -0.45045045045044674, -0.3503503503503467, -0.2502502502502466, -0.15015015015014654, -0.05005005005004648, 0.050050050050053585, 0.15015015015015365, 0.2502502502502537, 0.3503503503503538, 0.45045045045045384, 0.5505505505505539, 0.650650650650654, 0.750750750750754, 0.8508508508508541, 0.9509509509509542, 1.0510510510510542, 1.1511511511511543, 1.2512512512512544, 1.3513513513513544, 1.4514514514514545, 1.5515515515515546, 1.6516516516516546, 1.7517517517517547, 1.8518518518518547, 1.9519519519519548, 2.052052052052055, 2.152152152152155, 2.252252252252255, 2.352352352352355, 2.452452452452455, 2.552552552552555, 2.6526526526526553, 2.7527527527527553, 2.8528528528528554, 2.9529529529529555, 3.0530530530530555, 3.1531531531531556, 3.2532532532532557, 3.3533533533533557, 3.453453453453456, 3.553553553553556, 3.653653653653656, 3.753753753753756, 3.853853853853856, 3.953953953953956, 4.054054054054056, 4.154154154154156, 4.254254254254256, 4.354354354354356, 4.454454454454456, 4.5545545545545565, 4.6546546546546566, 4.754754754754757, 4.854854854854857, 4.954954954954957, 5.055055055055057, 5.155155155155157, 5.255255255255257, 5.355355355355357, 5.455455455455457, 5.555555555555557, 5.655655655655657, 5.755755755755757, 5.855855855855857, 5.955955955955957, 6.0560560560560575, 6.1561561561561575, 6.256256256256258, 6.356356356356358, 6.456456456456458, 6.556556556556558, 6.656656656656658, 6.756756756756758, 6.856856856856858, 6.956956956956958, 7.057057057057058, 7.157157157157158, 7.257257257257258, 7.357357357357358, 7.457457457457458, 7.557557557557558, 7.6576576576576585, 7.7577577577577586, 7.857857857857859, 7.957957957957959, 8.058058058058059, 8.158158158158159, 8.258258258258259, 8.358358358358359, 8.458458458458459, 8.558558558558559, 8.65865865865866, 8.75875875875876, 8.85885885885886, 8.95895895895896, 9.05905905905906, 9.15915915915916, 9.25925925925926, 9.35935935935936, 9.45945945945946, 9.55955955955956, 9.65965965965966, 9.75975975975976, 9.859859859859867, 9.959959959959967, 10.060060060060067, 10.160160160160167, 10.260260260260267, 10.360360360360367, 10.460460460460467, 10.560560560560567, 10.660660660660668, 10.760760760760768, 10.860860860860868, 10.960960960960968, 11.061061061061068, 11.161161161161168, 11.261261261261268, 11.361361361361368, 11.461461461461468, 11.561561561561568, 11.661661661661668, 11.761761761761768, 11.861861861861868, 11.961961961961968, 12.062062062062068, 12.162162162162168, 12.262262262262269, 12.362362362362369, 12.462462462462469, 12.562562562562569, 12.662662662662669, 12.762762762762769, 12.862862862862869, 12.962962962962969, 13.063063063063069, 13.16316316316317, 13.26326326326327, 13.36336336336337, 13.46346346346347, 13.56356356356357, 13.66366366366367, 13.76376376376377, 13.86386386386387, 13.96396396396397, 14.06406406406407, 14.164164164164163, 14.26426426426427, 14.364364364364363, 14.46446446446447, 14.564564564564563, 14.66466466466467, 14.764764764764763, 14.86486486486487, 14.964964964964963, 15.06506506506507, 15.165165165165163, 15.26526526526527, 15.365365365365363, 15.46546546546547, 15.565565565565564, 15.66566566566567, 15.765765765765764, 15.86586586586587, 15.965965965965964, 16.06606606606607, 16.166166166166164, 16.26626626626627, 16.366366366366364, 16.46646646646647, 16.566566566566564, 16.66666666666667, 16.766766766766764, 16.86686686686687, 16.966966966966964, 17.06706706706707, 17.167167167167165, 17.267267267267272, 17.367367367367365, 17.467467467467472, 17.567567567567565, 17.667667667667672, 17.767767767767765, 17.867867867867872, 17.967967967967965, 18.068068068068072, 18.168168168168165, 18.268268268268272, 18.36836836836838, 18.468468468468473, 18.56856856856858, 18.668668668668673, 18.76876876876878, 18.868868868868873, 18.96896896896898, 19.069069069069073, 19.16916916916918, 19.269269269269273, 19.36936936936938, 19.469469469469473, 19.56956956956958, 19.669669669669673, 19.76976976976978, 19.869869869869873, 19.96996996996998, 20.070070070070074, 20.17017017017018, 20.270270270270274, 20.37037037037038, 20.470470470470474, 20.57057057057058, 20.670670670670674, 20.77077077077078, 20.870870870870874, 20.97097097097098, 21.071071071071074, 21.17117117117118, 21.271271271271274, 21.37137137137138, 21.471471471471475, 21.57157157157158, 21.671671671671675, 21.771771771771782, 21.871871871871875, 21.971971971971982, 22.072072072072075, 22.172172172172182, 22.272272272272275, 22.372372372372382, 22.472472472472475, 22.572572572572582, 22.672672672672675, 22.772772772772782, 22.872872872872875, 22.972972972972983, 23.073073073073076, 23.173173173173183, 23.273273273273276, 23.373373373373383, 23.473473473473476, 23.573573573573583, 23.673673673673676, 23.773773773773783, 23.873873873873876, 23.973973973973983, 24.074074074074076, 24.174174174174183, 24.274274274274276, 24.374374374374383, 24.474474474474476, 24.574574574574584, 24.674674674674677, 24.774774774774784, 24.874874874874877, 24.974974974974984, 25.075075075075077, 25.175175175175184, 25.275275275275277, 25.375375375375384, 25.475475475475477, 25.575575575575584, 25.675675675675677, 25.775775775775784, 25.875875875875877, 25.975975975975985, 26.076076076076077, 26.176176176176185, 26.276276276276278, 26.376376376376385, 26.476476476476478, 26.576576576576585, 26.676676676676678, 26.776776776776785, 26.876876876876878, 26.976976976976985, 27.077077077077078, 27.177177177177185, 27.27727727727728, 27.377377377377385, 27.47747747747748, 27.577577577577586, 27.67767767767768, 27.777777777777786, 27.87787787787788, 27.977977977977986, 28.07807807807808, 28.178178178178186, 28.27827827827828, 28.378378378378386, 28.47847847847848, 28.578578578578586, 28.67867867867868, 28.778778778778786, 28.87887887887888, 28.978978978978986, 29.07907907907908, 29.179179179179187, 29.27927927927928, 29.379379379379387, 29.47947947947948, 29.579579579579587, 29.67967967967968, 29.779779779779787, 29.87987987987988, 29.979979979979987, 30.08008008008008, 30.180180180180187, 30.28028028028028, 30.380380380380387, 30.48048048048048, 30.580580580580587, 30.68068068068068, 30.780780780780788, 30.88088088088088, 30.980980980980988, 31.08108108108108, 31.181181181181188, 31.28128128128128, 31.381381381381388, 31.48148148148148, 31.581581581581588, 31.68168168168168, 31.78178178178179, 31.88188188188188, 31.98198198198199, 32.08208208208208, 32.18218218218219, 32.28228228228228, 32.38238238238239, 32.48248248248248, 32.58258258258259, 32.68268268268268, 32.78278278278279, 32.88288288288288, 32.98298298298299, 33.08308308308308, 33.18318318318319, 33.28328328328328, 33.38338338338339, 33.48348348348348, 33.58358358358359, 33.68368368368368, 33.78378378378379, 33.88388388388388, 33.98398398398399, 34.08408408408408, 34.18418418418419, 34.28428428428428, 34.38438438438439, 34.48448448448448, 34.58458458458459, 34.68468468468468, 34.78478478478479, 34.88488488488488, 34.98498498498499, 35.08508508508508, 35.18518518518519, 35.28528528528528, 35.38538538538539, 35.4854854854855, 35.58558558558559, 35.6856856856857, 35.78578578578579, 35.8858858858859, 35.98598598598599, 36.0860860860861, 36.18618618618619, 36.2862862862863, 36.38638638638639, 36.4864864864865, 36.58658658658659, 36.6866866866867, 36.78678678678679, 36.8868868868869, 36.98698698698699, 37.0870870870871, 37.18718718718719, 37.2872872872873, 37.38738738738739, 37.4874874874875, 37.58758758758759, 37.6876876876877, 37.78778778778779, 37.8878878878879, 37.98798798798799, 38.0880880880881, 38.18818818818819, 38.2882882882883, 38.38838838838839, 38.4884884884885, 38.58858858858859, 38.6886886886887, 38.78878878878879, 38.8888888888889, 38.98898898898899, 39.0890890890891, 39.18918918918919, 39.2892892892893, 39.38938938938939, 39.4894894894895, 39.58958958958959, 39.6896896896897, 39.78978978978979, 39.8898898898899, 39.98998998998999, 40.0900900900901, 40.190190190190194, 40.2902902902903, 40.390390390390394, 40.4904904904905, 40.590590590590594, 40.6906906906907, 40.790790790790794, 40.8908908908909, 40.990990990990994, 41.0910910910911, 41.191191191191194, 41.2912912912913, 41.391391391391394, 41.4914914914915, 41.591591591591595, 41.6916916916917, 41.791791791791795, 41.8918918918919, 41.991991991991995, 42.0920920920921, 42.192192192192195, 42.2922922922923, 42.392392392392395, 42.4924924924925, 42.592592592592595, 42.6926926926927, 42.792792792792795, 42.8928928928929, 42.992992992992995, 43.0930930930931, 43.193193193193196, 43.2932932932933, 43.393393393393396, 43.4934934934935, 43.593593593593596, 43.6936936936937, 43.793793793793796, 43.8938938938939, 43.993993993993996, 44.0940940940941, 44.194194194194196, 44.2942942942943, 44.394394394394396, 44.494494494494504, 44.5945945945946, 44.694694694694704, 44.7947947947948, 44.894894894894904, 44.994994994995, 45.095095095095104, 45.1951951951952, 45.295295295295304, 45.3953953953954, 45.495495495495504, 45.5955955955956, 45.695695695695704, 45.7957957957958, 45.895895895895904, 45.995995995996, 46.096096096096105, 46.1961961961962, 46.296296296296305, 46.3963963963964, 46.496496496496505, 46.5965965965966, 46.696696696696705, 46.7967967967968, 46.896896896896905, 46.996996996997, 47.097097097097105, 47.1971971971972, 47.297297297297305, 47.3973973973974, 47.497497497497505, 47.5975975975976, 47.697697697697706, 47.7977977977978, 47.897897897897906, 47.997997997998, 48.098098098098106, 48.1981981981982, 48.298298298298306, 48.3983983983984, 48.498498498498506, 48.5985985985986, 48.698698698698706, 48.7987987987988, 48.898898898898906, 48.998998998999, 49.09909909909911, 49.1991991991992, 49.29929929929931, 49.3993993993994, 49.49949949949951, 49.5995995995996, 49.69969969969971, 49.7997997997998, 49.89989989989991, 50.0], \"y\": [-126931.75, -126174.74850578986, -125420.76258926906, -124669.78623240154, -123921.81341715126, -123176.83812548216, -122434.85433935816, -121695.85604074322, -120959.83721160126, -120226.79183389623, -119496.71388959208, -118769.59736065273, -118045.43622904213, -117324.22447672422, -116605.95608566294, -115890.62503782223, -115178.22531516603, -114468.75089965828, -113762.19577326292, -113058.5539179439, -112357.81931566513, -111659.98594839059, -110965.04779808417, -110272.99884670986, -109583.83307623157, -108897.54446861324, -108214.12700581884, -107533.57466981227, -106855.8814425575, -106181.04130601845, -105509.04824215907, -104839.8962329433, -104173.57926033507, -103510.09130629833, -102849.42635279703, -102191.57838179509, -101536.54137525645, -100884.30931514507, -100234.87618342487, -99588.2359620598, -98944.3826330138, -98303.31017825079, -97665.01257973474, -97029.48381942957, -96396.71787929923, -95766.70874130767, -95139.45038741881, -94514.93679959659, -93893.16195980496, -93274.11985000786, -92657.80445216922, -92044.209748253, -91433.3297202231, -90825.15835004351, -90219.68961967812, -89616.91751109093, -89016.83600624581, -88419.43908710676, -87824.72073563769, -87232.67493380255, -86643.29566356527, -86056.57690688981, -85472.51264574008, -84891.09686208003, -84312.3235378736, -83736.18665508475, -83162.6801956774, -82591.7981416155, -82023.53447486297, -81457.88317738377, -80894.83823114184, -80334.39361810111, -79776.54332022552, -79221.28131947904, -78668.60159782556, -78118.49813722902, -77570.96491965344, -77025.99592706264, -76483.5851414207, -75943.7265446914, -75406.41411883885, -74871.64184582682, -74339.40370761942, -73809.69368618041, -73282.5057634739, -72757.8339214637, -72235.67214211385, -71716.01440738818, -71198.85469925078, -70684.18699966541, -70172.0052905962, -69662.3035540069, -69155.07577186161, -68650.31592612414, -68148.01799875856, -67648.17597172868, -67150.78382699857, -66655.83554653202, -66163.32511229314, -65673.24650624569, -65185.59371035379, -64700.36070658122, -64217.54147689205, -63737.1300032501, -63259.120267619444, -62783.506251963874, -62310.28193824748, -61839.44130843405, -61370.97834448764, -60904.88702837215, -60441.16134205153, -59979.7952674897, -59520.78278665062, -59064.117881498205, -58609.79453399642, -58157.80672610919, -57708.14843980047, -57260.81365703418, -56815.79635977427, -56373.09052998469, -55932.690149629365, -55494.58920067224, -55058.78166507726, -54625.261524808346, -54194.02276182946, -53765.05935810453, -53338.36529559751, -52913.934556272325, -52491.76112209291, -52071.83897502322, -51654.16209702719, -51238.724470068766, -50825.52007611187, -50414.54289712045, -50005.78691505846, -49599.24611188982, -49194.914469578485, -48792.78597008838, -48392.85459538346, -47995.114327427655, -47599.55914818491, -47206.183039619165, -46814.97998369435, -46425.94396237442, -46039.06895762331, -45654.34895140494, -45271.77792568329, -44891.34986242227, -44513.058743585825, -44136.89855113789, -43762.863267042434, -43390.94687326336, -43021.14335176463, -42653.44668451017, -42287.850853463926, -41924.34984058984, -41562.937627851854, -41203.6081972139, -40846.35553063993, -40491.173610093865, -40138.056417539665, -39786.99793494126, -39437.99214426259, -39091.033027467594, -38746.11456652022, -38403.230743384396, -38062.37554002407, -37723.54293840318, -37386.726920485664, -37051.921468235465, -36719.120563616525, -36388.31818859278, -36059.50832512817, -35732.684955186625, -35407.84206073211, -35084.97362372853, -34764.07362613986, -34445.13604993002, -34128.15487706296, -33813.12408950261, -33500.037669212914, -33188.88959815782, -32879.67385830125, -32572.38443160716, -32267.01530003948, -31963.56044556216, -31662.01385013913, -31362.369495734332, -31064.62136431171, -30768.763437835205, -30474.78969826875, -30182.694127576287, -29892.470707721757, -29604.113420669106, -29317.616248382266, -29032.973172825183, -28750.178175961788, -28469.225239756026, -28190.108346171837, -27912.82147717316, -27637.358614723937, -27363.713740788105, -27091.880837329605, -26821.853886312383, -26553.62686970037, -26287.19376945751, -26022.548567547743, -25759.685245935005, -25498.59778658324, -25239.280171456387, -24981.726382518387, -24725.930401733174, -24471.886211064695, -24219.58779247689, -23969.02912793369, -23720.204199399046, -23473.106988836895, -23227.73147821117, -22984.071649485824, -22742.121484624786, -22501.874965591996, -22263.3260743514, -22026.468792866934, -21791.297103102537, -21557.80498702215, -21325.98642658972, -21095.835403769175, -20867.345900524462, -20640.511898819517, -20415.327380618284, -20191.786327884703, -19969.882722582704, -19749.610546676246, -19530.96378212925, -19313.936410905662, -19098.522414969433, -18884.715776284487, -18672.51047681477, -18461.90049852422, -18252.879823376785, -18045.442433336397, -17839.582310366997, -17635.293436432527, -17432.569793496925, -17231.40536352413, -17031.79412847809, -16833.730070322734, -16637.207171022004, -16442.219412539846, -16248.760776840196, -16056.825245886994, -15866.40680164418, -15677.499426075694, -15490.097101145477, -15304.193808817465, -15119.783531055604, -14936.860249823829, -14755.417947086082, -14575.450604806303, -14396.95220494843, -14219.916729476405, -14044.338160354166, -13870.210479545654, -13697.527669014813, -13526.283710725575, -13356.472586641885, -13188.088278727682, -13021.124768946906, -12855.576039263497, -12691.436071641392, -12528.698848044536, -12367.358350436865, -12207.40856078232, -12048.843461044842, -11891.65703318837, -11735.843259176845, -11581.396120974203, -11428.30960054439, -11276.57767985134, -11126.194340858996, -10977.153565531298, -10829.449335832187, -10683.075633725599, -10538.02644117548, -10394.29574014576, -10251.87751260039, -10110.765740503302, -9970.95440581844, -9832.437490509745, -9695.208976541151, -9559.262845876603, -9424.59308048004, -9291.193662315402, -9159.058573346627, -9028.181795537657, -8898.557310852431, -8770.179101254887, -8643.04114870897, -8517.137435178618, -8392.461942627762, -8269.008653020355, -8146.771548320334, -8025.7446104916335, -7905.9218214981975, -7787.297163303965, -7669.864617872876, -7553.61816716887, -7438.551793155886, -7324.659477797866, -7211.935203058749, -7100.372950902474, -6989.966703292983, -6880.710442194213, -6772.598149570106, -6665.6238073846025, -6559.78139760164, -6455.064902185161, -6351.468303099103, -6248.985582307408, -6147.6107217740155, -6047.337703462864, -5948.160509337894, -5850.073121363046, -5753.06952150226, -5657.143691719475, -5562.289613978631, -5468.50127024367, -5375.772642478529, -5284.097712647149, -5193.470462713471, -5103.884874641433, -5015.334930394977, -4927.814611938041, -4841.317901234565, -4755.838780248492, -4671.371230943757, -4587.909235284305, -4505.4467752340715, -4423.977832756998, -4343.496389817026, -4263.996428378094, -4185.471930404142, -4107.916877859109, -4031.3252527069367, -3955.6910369115635, -3881.00821243693, -3807.2707612469762, -3734.4726653056423, -3662.6079065768677, -3591.6704670245917, -3521.6543286127558, -3452.553473305298, -3384.3618830661603, -3317.073539859281, -3250.6824256486, -3185.1825223980586, -3120.567812071595, -3056.8322766331507, -2993.969898046665, -2931.9746582760768, -2870.840539285328, -2810.561523038357, -2751.1315914991037, -2692.544726631509, -2634.794910399511, -2577.8761247670523, -2521.7823516980707, -2466.507573156507, -2412.045771106301, -2358.390927511392, -2305.5370243357206, -2253.4780435432267, -2202.2079670978496, -2151.72077696353, -2102.0104551042077, -2053.0709834838217, -2004.8963440663126, -1957.4805188156206, -1910.817489695685, -1864.9012386704464, -1819.725747703844, -1775.284998759818, -1731.5729738023083, -1688.5836547952547, -1646.3110237025976, -1604.7490624882764, -1563.8917531162308, -1523.7330775504015, -1484.267017754728, -1445.48755569315, -1407.3886733296076, -1369.9643526280404, -1333.2085755523892, -1297.1153240665928, -1261.678580134592, -1226.8923257203264, -1192.7505427877354, -1159.2472133007598, -1126.3763192233387, -1094.1318425194127, -1062.5077651529211, -1031.4980690878042, -1001.0967362880019, -971.2977487174539, -942.0950883401005, -913.482737119881, -885.4546770207359, -858.0048900066047, -831.1273580414277, -804.8160630891442, -779.0649871136948, -753.868112079019, -729.2194199490568, -705.1128926877482, -681.542512259033, -658.502260626851, -635.9861197551425, -613.9880716078469, -592.5020981489045, -571.5221813422551, -551.0423031518385, -531.0564455415948, -511.5585904754637, -492.5427199173853, -474.00281583129936, -455.93286018114594, -438.3268349308648, -421.17872204439476, -404.4825034856781, -388.23216121865346, -372.42167720726087, -357.0450334154402, -342.09621180713134, -327.5691943462741, -313.45796299680853, -299.75649972267456, -286.458786487812, -273.5588052561608, -261.05053799166086, -248.92796665825205, -237.18507321987437, -225.8158396404677, -214.8142478839719, -204.17427991432692, -193.88991769547266, -183.95514319134907, -174.36393836589602, -165.11028518305338, -156.18816560676115, -147.59156160095918, -139.3144551295874, -131.3508281565857, -123.69466264589403, -116.33994056145225, -109.28064386720028, -102.51075452707808, -96.0242545050255, -89.81512576498247, -83.87735027088893, -78.20490998668473, -72.79178687630983, -67.63196290370412, -62.719420032807506, -58.04814022755991, -53.61210545190125, -49.40529766977141, -45.42169884511031, -41.65529094185787, -38.10005592395399, -34.749975755338575, -31.599032399951547, -28.641207821732817, -25.870483984622275, -23.280842852559854, -20.866266389485453, -18.620736559338983, -16.538235326060352, -14.612744653589472, -12.838246505866255, -11.208722846830609, -9.718155640422442, -8.360526850581666, -7.12981844124819, -6.020012376361925, -5.025090619862781, -4.1390351356906665, -3.355827887785492, -2.6694508400871664, -2.073885956535601, -1.563115201070706, -1.1311205376323896, -0.7718839301605627, -0.47938734259513516, -0.2476127388760165, -0.0705420829431169, 0.057842661263653755, 0.14355952980438572, 0.19262655873916906, 0.21106178412809387, 0.20488324203125033, 0.1801089685087285, 0.14275699962061855, 0.09884537142701055, 0.054392119987994675, 0.01541528136366102, -0.012067108385900305, -0.022037013200599226, -0.0084763970203455, 0.034632776214951005, 0.11330854256538017, 0.2335689380910322, 0.40143199885199743, 0.622915760908366, 0.9040382603202275, 1.2508175331476727, 1.6692716154507914, 2.1654185432896735, 2.74527635272441, 3.414863079815089, 4.180196760621803, 5.047295431204642, 6.022177127623694, 7.1108598859390515, 8.319361742210804, 9.653700732499038, 11.119894892863849, 12.723962259365322, 14.471920868063554, 16.369788755018625, 18.423583956290635, 20.639324507939676, 23.023028446025826, 25.580713806609182, 28.318398625749833, 31.24210093950788, 34.35783878394339, 37.671630195116464, 41.18949320908721, 44.91744586191569, 48.86150618966201, 53.02769222838626, 57.42202201414852, 62.050513583008886, 66.91918497102745, 72.0340542142643, 77.40113934877954, 83.02645841063323, 88.91602943588549, 95.07587046059638, 101.51199952082605, 108.23043465263451, 115.23719389208188, 122.53829527522828, 130.1397568381338, 138.04759661685847, 146.26783264746243, 154.80648296600575, 163.6695656085485, 172.86309861115086, 182.39310000987285, 192.26558784077454, 202.48658013991604, 213.0620949433575, 223.99815028715892, 235.30076420738047, 246.97595474008213, 259.0297399213241, 271.4681377871665, 284.2971663736692, 297.5228437168925, 311.15118785289644, 325.18821681774114, 339.6399486474867, 354.51240137819303, 369.81159304592035, 385.54354168672876, 401.7142653366784, 418.32978203182927, 435.39610980824153, 452.91926670197523, 470.9052707490904, 489.36013998564727, 508.28989244770577, 527.7005461713261, 547.5981191925682, 567.9886295474926, 588.8780952721588, 610.2725344026273, 632.1779649749581, 654.6004050252111, 677.5458725894465, 701.0203857037245, 725.0299624041052, 749.5806207266484, 774.6783787074146, 800.3292543824635, 826.5392657878556, 853.3144309596505, 880.6607679339105, 908.5842947466921, 937.091029434057, 966.1869900320651, 995.8781945767769, 1026.170661104252, 1057.0704076505513, 1088.583452251734, 1120.7158129438608, 1153.4735077629912, 1186.862554745186, 1220.888971926505, 1255.5587773430082, 1290.8779890307553, 1326.8526250258074, 1363.4887033642235, 1400.7922420820646, 1438.76925921539, 1477.4257728002606, 1516.7678008727357, 1556.8013614688762, 1597.5324726247416, 1638.9671523763916, 1681.1114187598873, 1723.9712898112882, 1767.5527835666546, 1811.8619180620467, 1856.9047113335241, 1902.687181417147, 1949.215346348976, 1996.4952241650708, 2044.5328329014915, 2093.334190594298, 2142.905315279551, 2193.25222499331, 2244.3809377716357, 2296.297471650587, 2349.007844666225, 2402.5180748546104, 2456.834180251802, 2511.9621788938603, 2567.908088816845, 2624.677928056817, 2682.2777146498324, 2740.7134666319625, 2799.9912020392517, 2860.116938907777, 2921.0966952735803, 2982.9364891727405, 3045.6423386412994, 3109.220261715335, 3173.6762764308883, 3239.0164008240395, 3305.246652930829, 3372.373050787336, 3440.4016124296018, 3509.338355893705, 3579.189299215687, 3649.960460431628, 3721.6578575775666, 3794.287508689584, 3867.8554318037195, 3942.3676449560544, 4017.830166182628, 4094.2490135195203, 4171.630205002772, 4249.979758668463, 4329.303692552632, 4409.608024691361, 4490.89877312069, 4573.181955876698, 4656.463590995425, 4740.749696512953, 4826.046290465319, 4912.359390888606, 4999.695015818853, 5088.059183292139, 5177.457911344505, 5267.897218012033, 5359.3831213307585, 5451.921639336769, 5545.518790066094, 5640.180591554825, 5735.913061838991, 5832.722218954683, 5930.614080937946, 6029.594665824825, 6129.669991651411, 6230.846076453731, 6333.12893826788, 6436.524595129883, 6541.039065075833, 6646.67836614176, 6753.448516363752, 6861.355533777842, 6970.405436420118, 7080.604242326611, 7191.957969533411, 7304.472636076548, 7418.154259992113, 7533.008859316134, 7649.042452084703, 7766.2610563338485, 7884.670690099661, 8004.277371418172, 8125.087118325472, 8247.105948857587, 8370.339881050611, 8494.794932940575, 8620.477122563563, 8747.392467955611, 8875.546987152808, 9004.946698191181, 9135.597619106826, 9267.505767935763, 9400.677162714095, 9535.117821477843, 9670.8337622631, 9807.831003105894, 9946.11556204232, 10085.693457108402, 10226.570706340237, 10368.753327773846, 10512.24733944533, 10657.058759390706, 10803.19360564608, 10950.657896247467, 11099.45764923097, 11249.598882632605, 11401.087614488475, 11553.929862834599, 11708.13164570708, 11863.698981141935, 12020.63788717527, 12178.954381843092, 12338.654483181515, 12499.74420922655, 12662.229578014305, 12826.11660758079, 12991.411315962116, 13158.119721194293, 13326.24784131343, 13495.80169435554, 13666.78729835673, 13839.210671353008, 14013.077831380491, 14188.394796475184, 14365.1675846732, 14543.402214010546, 14723.104702523333, 14904.281068247574, 15086.937329219374, 15271.079503474748, 15456.713609049804, 15643.845663980548, 15832.4816863031, 16022.627694053459, 16214.289705267744, 16407.47373798196, 16602.18581023222, 16798.43194005453, 16996.218145485003, 17195.55044455965, 17396.43485531458, 17598.877395785803, 17802.884084009427, 18008.460938021468, 18215.61397585803, 18424.34921555512, 18634.67267514886, 18846.59037267525, 19060.108326170408, 19275.232553670336, 19491.969073211152, 19710.323902828855, 19930.303060559567, 20151.91256443929, 20375.15843250414, 20600.04668279012, 20826.58333333335, 21054.774402169827, 21284.62590733568, 21516.143866866896, 21749.334298799607, 21984.203221169802, 22220.756652013613, 22459.000609367027, 22698.941111266173, 22940.58417574705, 23183.935820845778, 23429.002064598353, 23675.788925040903, 23924.30242020942, 24174.548568140035, 24426.53338686873, 24680.262894431646, 24935.743108864765, 25192.980048204216, 25451.979730485997, 25712.748173746233, 25975.291396020915, 26239.615415346176, 26505.726249758, 26773.629917292525, 27043.332435985732, 27314.83982387376, 27588.15809899259, 27863.29327937836, 28140.25138306705, 28419.03842809481, 28699.660432497607, 28982.123414311583, 29266.43339157273, 29552.596382317173, 29840.6184045809, 30130.50547640005, 30422.2636158106, 30715.89884084869, 31011.417169550306, 31308.82461995159, 31608.12721008851, 31909.33095799722, 32212.44188171369, 32517.46599927406, 32824.40932871432, 33133.2778880706, 33444.07769537888, 33756.81476867531, 34071.495125995854, 34388.12478537667, 34706.70976485373, 35027.25608246317, 35349.769756240974, 35674.25680422328, 36000.723244446075, 36329.175094945494, 36659.61837375752, 36992.05909891829, 37326.50328846378, 37662.956960430136, 38001.42613285333, 38341.91682376952, 38684.43505121467, 39028.98683322493, 39375.57818783627, 39724.21513308484, 40074.903687006605, 40427.64986763774, 40782.45969301417, 41139.33918117209, 41498.29435014743, 41859.33121797638, 42222.45580269487, 42587.67412233909, 42954.99219494498, 43324.41603854872, 43695.951671186296, 44069.60511089372, 44445.38237570717, 44823.2894836626, 45203.33245279616, 45585.51730114382, 45969.85004674173, 46356.336707625866, 46744.98330183238, 47135.79584739722, 47528.780362356556, 47923.942864746365, 48321.28937260278, 48720.82590396178, 49122.55847685951, 49526.49310933193, 49932.63581941522, 50340.992625145314, 50751.569544558406, 51164.37259569042, 51579.40779657755, 51996.68116525572, 52416.19871976112, 52837.96647812969, 53261.9904583976, 53688.276678600814, 54116.831156775486, 54547.65991095757, 54980.768959183246, 55416.16431948844, 55853.85200990935, 56293.838048481906, 56736.1284532423, 57180.72924222645, 57627.64643347056, 58076.88604501056, 58528.45409488261, 58982.35660112269, 59438.59958176695, 59897.18905485134, 60358.13103841205, 60821.431550485, 61287.09660910639, 61755.132232312135, 62225.544438138444, 62698.33924462124, 63173.5226697967, 63651.100731700775, 64131.079448369645, 64613.464837839245, 65098.26291814575, 65585.47970732508, 66075.12122341349, 66567.19348444683, 67061.70250846134, 67558.65431349294, 68058.05491757783, 68559.91033875191, 69064.22659505138, 69571.0097045122, 70080.26568517053, 70592.00055506227, 71106.22033222369, 71622.93103469066, 72142.13868049938, 72663.84928768579, 73188.0688742861, 73714.8034583362, 74244.05905787229, 74775.84169093032, 75310.15737554646, 75847.01212975665, 76386.41197159709, 76928.36291910367, 77472.87099031264, 78019.94220325987, 78569.5825759816, 79121.79812651372, 79676.59487289246, 80233.97883315371, 80793.95602533368, 81356.53246746829, 81921.71417759376, 82489.507173746, 83059.91747396118, 83632.95109627525, 84208.6140587244, 84786.91237934456, 85367.85207617194, 85951.43916724241, 86537.67967059223, 87126.57960425729, 87718.1449862738, 88312.38183467767, 88909.2961675051, 89508.89400279202, 90111.18135857463, 90716.16425288883, 91323.84870377084, 91934.24072925658, 92547.34634738225, 93163.17157618374, 93781.72243369732, 94403.00493795883, 95027.02510700452, 95653.78895887028, 96283.30251159234, 96915.5717832066, 97550.60279174928, 98188.40155525626, 98828.9740917638, 99472.32641930775, 100118.46455592437, 100767.39451964953, 101419.1223285195, 102073.65400057012, 102730.99555383764, 103391.15300635796, 104054.13237616731, 104719.93968130155, 105388.58093979696, 106060.06216968938, 106734.38938901506, 107411.56861580991, 108091.60586811013, 108774.50716395162, 109460.27852137061, 110148.925958403, 110840.45549308503, 111534.87314345254, 112232.18492754182, 112932.39686338871, 113635.5149690295, 114341.5452625, 115050.49376183651, 115762.36648507488, 116477.16945025137, 117194.90867540182, 117915.59017856253, 118639.21997776933, 119365.80409105851, 120095.34853646588, 120827.85933202774, 121563.34249577994, 122301.80404575873, 123043.25]}],\n",
       "                        {\"template\": {\"data\": {\"bar\": [{\"error_x\": {\"color\": \"#2a3f5f\"}, \"error_y\": {\"color\": \"#2a3f5f\"}, \"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"bar\"}], \"barpolar\": [{\"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"barpolar\"}], \"carpet\": [{\"aaxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"baxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"type\": \"carpet\"}], \"choropleth\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"choropleth\"}], \"contour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"contour\"}], \"contourcarpet\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"contourcarpet\"}], \"heatmap\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmap\"}], \"heatmapgl\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmapgl\"}], \"histogram\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"histogram\"}], \"histogram2d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2d\"}], \"histogram2dcontour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2dcontour\"}], \"mesh3d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"mesh3d\"}], \"parcoords\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"parcoords\"}], \"pie\": [{\"automargin\": true, \"type\": \"pie\"}], \"scatter\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter\"}], \"scatter3d\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter3d\"}], \"scattercarpet\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattercarpet\"}], \"scattergeo\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergeo\"}], \"scattergl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergl\"}], \"scattermapbox\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattermapbox\"}], \"scatterpolar\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolar\"}], \"scatterpolargl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolargl\"}], \"scatterternary\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterternary\"}], \"surface\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"surface\"}], \"table\": [{\"cells\": {\"fill\": {\"color\": \"#EBF0F8\"}, \"line\": {\"color\": \"white\"}}, \"header\": {\"fill\": {\"color\": \"#C8D4E3\"}, \"line\": {\"color\": \"white\"}}, \"type\": \"table\"}]}, \"layout\": {\"annotationdefaults\": {\"arrowcolor\": \"#2a3f5f\", \"arrowhead\": 0, \"arrowwidth\": 1}, \"coloraxis\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"colorscale\": {\"diverging\": [[0, \"#8e0152\"], [0.1, \"#c51b7d\"], [0.2, \"#de77ae\"], [0.3, \"#f1b6da\"], [0.4, \"#fde0ef\"], [0.5, \"#f7f7f7\"], [0.6, \"#e6f5d0\"], [0.7, \"#b8e186\"], [0.8, \"#7fbc41\"], [0.9, \"#4d9221\"], [1, \"#276419\"]], \"sequential\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"sequentialminus\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]]}, \"colorway\": [\"#636efa\", \"#EF553B\", \"#00cc96\", \"#ab63fa\", \"#FFA15A\", \"#19d3f3\", \"#FF6692\", \"#B6E880\", \"#FF97FF\", \"#FECB52\"], \"font\": {\"color\": \"#2a3f5f\"}, \"geo\": {\"bgcolor\": \"white\", \"lakecolor\": \"white\", \"landcolor\": \"#E5ECF6\", \"showlakes\": true, \"showland\": true, \"subunitcolor\": \"white\"}, \"hoverlabel\": {\"align\": \"left\"}, \"hovermode\": \"closest\", \"mapbox\": {\"style\": \"light\"}, \"paper_bgcolor\": \"white\", \"plot_bgcolor\": \"#E5ECF6\", \"polar\": {\"angularaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"radialaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"scene\": {\"xaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"yaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"zaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}}, \"shapedefaults\": {\"line\": {\"color\": \"#2a3f5f\"}}, \"ternary\": {\"aaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"baxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"caxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"title\": {\"x\": 0.05}, \"xaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}, \"yaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}}}, \"xaxis\": {\"dtick\": 1, \"range\": [-1, 1], \"showticklabels\": true, \"tick0\": 0, \"tickangle\": 0, \"ticks\": \"outside\", \"title\": {\"font\": {\"color\": \"black\", \"family\": \"Arial, serif\", \"size\": 18}, \"text\": \"x\"}}, \"yaxis\": {\"dtick\": 1, \"range\": [-1, 1], \"tick0\": 0, \"ticks\": \"outside\", \"title\": {\"font\": {\"color\": \"black\", \"family\": \"Arial, serif\", \"size\": 18}, \"text\": \"P(x)\"}}},\n",
       "                        {\"responsive\": true}\n",
       "                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('a60e4cc3-2f8e-4f72-a9b9-af665ed5fdc0');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })\n",
       "                };\n",
       "                });\n",
       "            </script>\n",
       "        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "button = widgets.Button(description=\"Plot Function\", \n",
    "                        layout = Layout(width='30%', height='60px'),\n",
    "                        button_style = 'info'\n",
    "                       )\n",
    "display(button)\n",
    "def on_button_clicked(b):\n",
    "    \n",
    "    x = np.linspace(-50,50,1000)\n",
    "    y = x**3 - (7/9)*x**2 - (1/4)*x + 7/36   \n",
    "    trace = go.Scatter(\n",
    "        x = x,\n",
    "        y = y\n",
    "    )\n",
    "    layout = go.Layout(\n",
    "        xaxis = dict(\n",
    "            title='x',\n",
    "            titlefont=dict(\n",
    "            family='Arial, serif',\n",
    "            size=18,\n",
    "            color='black'),\n",
    "            showticklabels=True,\n",
    "            tickangle=0,\n",
    "            range = [-1,1],\n",
    "            ticks='outside',\n",
    "            tick0=0,\n",
    "            dtick=1\n",
    "        ),\n",
    "        yaxis = dict(\n",
    "            title='P(x)',\n",
    "            titlefont=dict(\n",
    "            family='Arial, serif',\n",
    "            size=18,\n",
    "            color='black'),\n",
    "            range = [-1,1],\n",
    "            ticks='outside',\n",
    "            tick0=0,\n",
    "            dtick=1\n",
    "        ),\n",
    "    )\n",
    "\n",
    "    data = [trace]\n",
    "\n",
    "    fig = go.Figure(data=data, layout=layout)\n",
    "\n",
    "    iplot(fig)\n",
    "    \n",
    "button.on_click(on_button_clicked) \n",
    "on_button_clicked(0)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hidden": false
   },
   "source": [
    "---\n",
    "Purely by inspection, we were able to observe where the roots of this function lie: $x \\approx -\\frac{1}{2},\\frac{1}{2},\\frac{3}{4}$. This was a nice and clean numerical solution to a problem that would've been much more difficult to solve analytically. Although this may seem convenient and albeit simple, this estimation approach is primitive. It is rare that a problem would ever require this simple of a solution, but nonetheless we found the roots of the polynomial. By simply graphing the solution, we were also able to see easily where the function was greater than zero. "
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hidden": false
   },
   "source": [
    "Here we will provide an exercise to determine roots of a function based on arbitrary parameters and visualize how a graph of the function changes for different values of these parameters. </br>\n",
    "Learning outcomes:\n",
    "- You will understand how arbitrary parameters change the graph of a quadratic polynomial function\n",
    "- Understand how to determine the roots given arbitrary values\n",
    "- See how the roots change under changing the values of the parameter\n",
    "\n",
    "First we provide the steps to derive the famous \"Quadratic Formula\", try following them on your own, click **Show Answer** to see the answer. \n",
    "\n",
    "Starting with an arbitrary polynomial, $P(x) = ax^2 + bx + c$, where $a \\ne 0$:\n",
    "\n",
    "1. Set $P(x) = 0$. \n",
    "2. Complete the square.\n",
    "3. Rearrange the equation, isolating \"$x$\".\n",
    "---"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "57cb38e2040b4c71ac1800dd4b62a0d2",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Button(button_style='info', description='Show Answer', layout=Layout(height='60px', width='30%'), style=Button…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "button = widgets.Button(description=\"Show Answer\", \n",
    "                        layout = Layout(width='30%', height='60px'),\n",
    "                         button_style = 'info'\n",
    "                       )\n",
    "display(button)\n",
    "\n",
    "def on_button_clicked(b):\n",
    "    display(Markdown('$ P(x) = ax^2 + bx + c = 0$ </br> </br> \\\n",
    "    Complete the square, first dividing by a:</br> </br> \\\n",
    "    $\\\\frac{P(x)}{a} = (x+\\\\frac{b}{2a})^2 + \\\\frac{c}{a} - \\\\frac{b^2}{4a}= 0$ </br> </br>\\\n",
    "    Rearrange for $x$: </br> </br> \\\n",
    "    $(x+\\\\frac{b}{2a})^2 = \\\\frac{b^2}{4a^2} -\\\\frac{c}{a} = \\\\frac{b^2 - 4ac}{4a^2}$ \\\n",
    "    $\\Rightarrow x+\\\\frac{b}{2a} = \\pm \\\\frac{\\sqrt{b^2-4ac}}{\\sqrt{4a^2}}$ </br> \\\n",
    "    $\\Rightarrow x = -\\\\frac{b}{2a} \\pm \\\\frac{\\sqrt{b^2-4ac}}{2a}$'))\n",
    "    button_clicked = 1\n",
    "button.on_click(on_button_clicked)\n",
    "    \n",
    "    "
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hidden": false
   },
   "source": [
    "---\n",
    "A potential use of inspection would be our initial exercise: \"Find the intervals where $f(x) > 0$ \". The next cell has been left for you to input the values $(a,b,c,d)$ for a third order polynomial in the form $f(x) = ax^3 + bx^2 + cx + d$ the function that our first exercise output, see if you can use inspection to obtain the correct interval. Also, by setting $a$ to zero, see observe how the roots change for a quadratic function. Think about how changing these parameters changes the roots obtained from the \"Quadratic formula\" (e.g. what does increasing the value of $c$ do?). Press the \"Plot Function\" to start this exercise."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {
    "scrolled": false,
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "ebc0284652a64a3bb549ae77c71e5a6b",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Button(button_style='info', description='Plot Function', layout=Layout(height='60px', width='30%'), style=Butt…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "879dbb2873b7455a963c5149e395a041",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Output()"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "05e13f5b9d954b16a565311bf76638a9",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(IntSlider(value=1, description='$a$:', max=10, min=-10), IntSlider(value=1, description='$b$:',…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "#function to graph third order polynomial with given inputs:\n",
    "def plot3(a,b,c,d):\n",
    "    x = np.linspace(-50,50,1000)\n",
    "    y = a*x**3 + b*x**2 + c*x + d   \n",
    "    trace = go.Scatter(\n",
    "        x = x,\n",
    "        y = y\n",
    "    )\n",
    "    layout = go.Layout(\n",
    "        xaxis = dict(\n",
    "            title='x',\n",
    "            titlefont=dict(\n",
    "            family='Arial, serif',\n",
    "            size=18,\n",
    "            color='black'),\n",
    "            showticklabels=True,\n",
    "            tickangle=0,\n",
    "            range = [-15,15],\n",
    "            ticks='outside',\n",
    "            tick0=0,\n",
    "            dtick=1\n",
    "        ),\n",
    "        yaxis = dict(\n",
    "            title='P(x)',\n",
    "            titlefont=dict(\n",
    "            family='Arial, serif',\n",
    "            size=18,\n",
    "            color='black'),\n",
    "            range = [-25,25],\n",
    "            ticks='outside',\n",
    "            tick0=0,\n",
    "            dtick=5\n",
    "        ),\n",
    "    )\n",
    "\n",
    "    data = [trace]\n",
    "\n",
    "    fig = go.Figure(data=data, layout=layout)\n",
    "\n",
    "    iplot(fig)\n",
    "\n",
    "    return \n",
    "\n",
    "a = widgets.IntSlider(\n",
    "    value=1, \n",
    "    min=-10,\n",
    "    max=10,\n",
    "    step=1.0,\n",
    "    description=r'$a$:',\n",
    "    disabled=False\n",
    ")\n",
    "b = widgets.IntSlider(\n",
    "    value=1,\n",
    "    min=-10,\n",
    "    max=10,\n",
    "    description=r'$b$:',\n",
    "    disabled=False\n",
    ")\n",
    "c = widgets.IntSlider(\n",
    "    value=1,\n",
    "    min=-10,\n",
    "    max=10,\n",
    "    description=r'$c$:',\n",
    "    disabled=False\n",
    ")\n",
    "d = widgets.IntSlider(\n",
    "    value=1,\n",
    "    min=-10,\n",
    "    max=10,\n",
    "    description=r'$d$:',\n",
    "    disabled=False\n",
    ")\n",
    "H = widgets.HBox([a,b,c,d])\n",
    "\n",
    "abc = widgets.interactive_output(plot3, {'a': a, 'b': b, 'c': c, 'd': d})\n",
    "\n",
    "                  \n",
    "button = widgets.Button(description=\"Plot Function\", \n",
    "                        layout = Layout(width='30%', height='60px'),\n",
    "                         button_style = 'info'\n",
    "                       )\n",
    "display(button)\n",
    "def on_button_clicked(b):\n",
    "      \n",
    "    button_clicked = display(abc,H)\n",
    "    d.value = 0 #this is so it plots, widget has to change value in order to observe change\n",
    "    \n",
    "button.on_click(on_button_clicked)    \n",
    "\n",
    "on_button_clicked(0)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hidden": false
   },
   "source": [
    "We will now proceed into some algorithmic numerical methods for root finding. These methods are useful as they can be easily integrated into a computer program. These are some of the more basic methods but they are often combined with each other, or with other methods, for more robust applications that require greater accuracy and less processing time. We first introduce how to use these methods analytically, then introduce a sketch of the code in python syntax. The analytic approach provides a means of solving the problem, while the numerical approach speeds the calculations up. Combining the two approaches provides insight into potential problems that arise in the computations and how to remedy them."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hidden": false
   },
   "source": [
    "## Bisection Method\n",
    "---\n",
    "\n",
    "The bisection method is a simple algorithm to quickly find an approximation for a root. The basic idea of the method is to initially take an interval, $[a,b]$ over which a function $f$ is continuous, such that $f(a)$ and $f(b)$ have different signs (so you know that there is a root in between). We then split the interval into two and check the new endpoints of each subinterval. Let $c = (a+b)/2$ be the midpoint of the interval. If the function values at the endpoints of one of these two subintervals have identical signs (that is, if $f(a)$ and $f(c)$ have the same signs or $f(b)$ and $f(c)$ have the same signs) then this subinterval is discarded, knowing that a root must lie within the other subinterval. Note that a root could also exist within the other interval but it is not guaranteed. We then divide this subinterval into two and repeat the same analysis on it. Eventually, up to an accuracy that we are happy with, we will have a small interval within which a root is found. \n",
    "\n",
    "### Analytical Approach\n",
    "\n",
    "Try this method, analytically, for $f(x)= x^2-4$ and the initial interval $[0,5]$. Try three iterations of the algorithm, and see the accuracy you obtain. Would you be happy with this accuracy? Do you feel this was quick enough? Click \"Show Answer\" to see the calculations, after you have done so yourself of course...\n",
    "\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "edf3344c1f3746e2841259f0c407a63d",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Button(button_style='info', description='Show Answer', layout=Layout(height='60px', width='30%'), style=Button…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "button = widgets.Button(description=\"Show Answer\", \n",
    "                        layout = Layout(width='30%', height='60px'),\n",
    "                         button_style = 'info'\n",
    "                       )\n",
    "display(button)\n",
    "\n",
    "def on_button_clicked(b):\n",
    "    display(Markdown('Firstly, $f(0) = -4$ and $\\\\rm f(5) = 21$, which have opposite signs, so this is a valid interval to start with. </br> </br> \\\n",
    "    Split the interval in two: $c_1 = \\\\frac{0+5}{2} = 2.5$. </br> </br> \\\n",
    "    Check the sign of the function for on each subinterval endpoint (i.e. check the sign of $f(c)$):  $f(2.5) = 2.25$, therefore our new interval is $[0,2.5]$.</br> </br> \\\n",
    "    Split interval again and check signs of function at the middle: $c_2 = \\\\frac{2.5+0}{2} = 1.75$ , $f(1.75) = -0.9375$ </br> </br> \\\n",
    "    $\\Rightarrow$ new interval is $[1.75,2.5]$, $c_3 = \\\\frac{1.75+2.5}{2}$, $f(c_3) = 0.515625$, new interval = $[1.75,2.125]$ </br> </br> \\\n",
    "    root is approximately $c_4 = \\\\frac{1.75 + 2.125}{2} = 1.9375$ </br> </br> \\\n",
    "    Percent error: $\\\\frac{2-1.9375}{2} x 100\\% = 3.125 \\%$'))\n",
    "    button_clicked = 1\n",
    "button.on_click(on_button_clicked)\n",
    "\n",
    "    \n",
    "    "
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hidden": false
   },
   "source": [
    "***\n",
    "We can clearly see that the method is somewhat slow and *really* good accuracy is hard to achieve. Nevertheless, it narrowed down our intervals and gave us a fairly good approximation to the root. What about the other root at $x = -2$, how could we have obtained this root? Well, with a different set of initial conditions (our initial interval). The initial conditions play a very important role for this method as they can yield different results for a root. Try this same procedure, now instead with $[-5,0]$ as your starting point. Your answer after each iteration should be the same, except with a different sign. \n",
    "\n",
    "This serves to illustrate a flaw in a lot of root finding algorithms; the sensitivity to the initial guess. Many of these algorithms require a good educated guess to work properly. Moreover, the algorithm can only determine one root for each initial guess, which is another disadvantage.\n",
    "\n",
    "\n",
    "***"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hidden": false
   },
   "source": [
    "### Numerical Approach\n",
    "\n",
    "Specify the initial interval and the tolerance (accuracy) that you would like to achieve:\n",
    "```python\n",
    "x0 = -1\n",
    "x1 = 1\n",
    "tol = 0.01\n",
    "```\n",
    "\n",
    "Define the function you would like to find the root for:\n",
    "```python\n",
    "def f(x):\n",
    "    return x**3 - (7/9)*x**2 -(1/4)*x + 7/36\n",
    "```\n",
    "This function can accept a single number or a whole list of numbers: it returns an output that applies a function to the given number or every number in the given list. Now we can begin the algorithm. First we set up the initial conditions:\n",
    "```python\n",
    "c =(x1 + x0)/2  #where c is the mid-point, as defined in the analytical solution\n",
    "if (f(x0) > 0 and f(x1) > 0) or (f(x0) < 0 and f(x1) < 0): \n",
    "    print('Pick new initial conditions') #The Bisection method does not apply for these cases\n",
    "else:\n",
    "    while f(c) > tol:  #run the loop until your tolerance is satisfied\n",
    "\n",
    "        if f(c) == 0:\n",
    "            break   # you have found a root; break out of the while loop\n",
    "        if sign(f(c)) == sign(f(x0)):\n",
    "            x0 = c #Interval [x0,c] does not necessarily have a root; x0 is set to c\n",
    "        if sign(f(c)) == sign(f(x1)):\n",
    "            x1 = c #Interval [c,x1] does not necessarily have root; x1 is set to c\n",
    "                    \n",
    "        c = (x1+x0)/2  # update the value of c, based on the current values of x0 and x1\n",
    "    print(c)\n",
    "```\n",
    "\n",
    "### What does the `while` statement do?\n",
    "\n",
    "The statement \n",
    "```python \n",
    "while f(c) > tol:\n",
    "```\n",
    "deserves some unpacking. This is what is known as a while loop, and is an essential tool used in programming. The indented code written after the colon will be executed until the conditional statement $f(c) > \\rm tol$ doesn't hold anymore. Here is a visual interpretation of this process:\n",
    "\n",
    "\n",
    "\n",
    "\n",
    "<img src=\"images/while_loop.png\" width = \"40%\" height = \"100px\">\n",
    "\n",
    "\n",
    "\n",
    "**Common errors that occur**:\n",
    "\n",
    "- Infinite loop: this is probably the most common error that occurs with a while loop. This happens if the statement is always true, i.e. the code block never makes the conditional statement false.\n",
    "- Loop is not entered: This occurs if the conditional statement is not initially satisfied. This depends on our initial guess for $[x_0,x_1]$.\n",
    "\n",
    "\n",
    "The next cell is an illustration of how one could write a piece of code to execute this algorithm. The default initial conditions are $x_0 = -1$, $x_1 = 1$. The same code is included in the cell afterwards, if you would like to change the inital conditions or the function itself, press the \"show code\" to manipulate the algorithm. "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'Root =  -0.75'"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "#Bisection Method algorithm\n",
    "\n",
    "\n",
    "#Specify the initial interval\n",
    "x0 = -1\n",
    "x1 = 1\n",
    "\n",
    "#Specify tolerance (accuracy) you want:\n",
    "tol = 0.01\n",
    "    \n",
    "#Function (of your choice) we will use our function from before:\n",
    "def f(x):\n",
    "    return x**3 - (7/9)*x**2 -(1/4)*x + 7/36 \n",
    "\n",
    "#Defining a sign function\n",
    "def sign(x):\n",
    "    if x < 0:\n",
    "        sign = 0\n",
    "    if x >= 0:\n",
    "        sign = 1\n",
    "    return sign        \n",
    "\n",
    "#Bisection method algorithm\n",
    "c = (x1+x0)/2  #Midpoint\n",
    "if (f(x0) > 0 and f(x1) > 0) or (f(x0) < 0 and f(x1) < 0): \n",
    "    print('Pick new initial conditions') #The Bisection method does not apply for these cases\n",
    "else:\n",
    "    while f(c) > tol:  #run the loop until your tolerance is satisfied\n",
    "        c = (x1+x0)/2\n",
    "        if f(c) == 0:\n",
    "            break   # you have found a root; break out of the while loop\n",
    "        if sign(f(c)) == sign(f(x0)):\n",
    "            x0 = c #Interval [x0,c] does not necessarily have a root; x0 is set to c\n",
    "        if sign(f(c))== sign(f(x1)):\n",
    "            x1 = c #Interval [c,x1] does not necessarily have root; x1 is set to c\n",
    "        root = (x1+x0)/2\n",
    "    display('Root =  ' + str(round(root,4))) \n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hidden": false
   },
   "source": [
    "## Secant Method\n",
    "____\n",
    "\n",
    "Here we will walk you through a root-finding algorithm known as the *secant method* which provides quick approximations of roots. For a quick review or another reference of this method and other root finding algorithms, please see https://en.wikipedia.org/wiki/Root-finding_algorithm. \n",
    "\n",
    "In this section of the tutorial we will demonstrate the basics of the method and walk you through some of the elementary steps you would need to write a root-finding algorithm implementing the secant method yourself. \n",
    "\n",
    "### Analytical approach\n",
    "---\n",
    "The secant method employs successive operations, known as iterations, of finding the root of a *secant line* of a function $f(x)$.  \n",
    "\n",
    "A secant line can thought of as a line which intersects a curve at two points. Given the domain $[a,b]$ and a continuous function $ f:[a,b] \\mapsto \\mathbb{R}$, take two points $ x_0, x_1 \\in [a,b]$. The secant line between these two points, in slope-intercept form is given as:\n",
    "\n",
    "$$\n",
    "s(x) = \\frac{f(x_1)-f(x_0)}{x_1-x_0}(x-x_1) + f(x_1)\n",
    "$$\n",
    "\n",
    "The next step in the algorithm is to find the $x$ intercept of this line:\n",
    "\n",
    "\n",
    "\\begin{equation}\n",
    "\\begin{split}\n",
    "s(x) &= 0 = \\frac{f(x_1)-f(x_0)}{x_1-x_0}(x-x_1) + f(x_1)\n",
    "\\\\& \\Rightarrow x = x_1 - f(x_1)\\frac{x_1-x_0}{f(x_1)-f(x_0)}\n",
    "\\end{split}\n",
    "\\end{equation}\n",
    "\n",
    "\n",
    "This point now becomes our next endpoint, i.e.:\n",
    "\n",
    "\\begin{equation}\n",
    "x_2 = x_1 - f(x_1)\\frac{x_1-x_0}{f(x_1)-f(x_0)}\n",
    "\\end{equation}\n",
    "\n",
    "We now *iterate* this algorithm, applying the same process successively, until our algorithm yields a value $f(x_n) \\approx 0$ after *n* iterations.\n",
    "\n",
    "\\begin{equation}\n",
    "\\begin{split}\n",
    "x_3 &= x_2 - f(x_2)\\frac{x_2-x_1}{f(x_2)-f(x_1)}\n",
    "\\\\ x_4 &= x_3 - f(x_3)\\frac{x_3-x_2}{f(x_3)-f(x_2)}\n",
    "\\\\& .\n",
    "\\\\& .\n",
    "\\\\& .\n",
    "\\\\ x_n &= x_{n-1} - f(x_{n-1}) \\frac{x_{n-1}-x_{n-2}}{f(x_{n-1})-f(x_{n-2})}\n",
    "\\end{split}\n",
    "\\end{equation}\n",
    "\n",
    "### Numerical Approach\n",
    "\n",
    "The algorithm to implement the secant method is given as follows. \n",
    "```python\n",
    "#same function as for the bisection method\n",
    "def f(x):\n",
    "    return x**3 - (7/9)*x**2 -(1/4)*x + 7/36  #Function to employ algorithm on\n",
    "\n",
    "#initial conditions\n",
    "n = 20 #number of iterations you want to use\n",
    "\n",
    "for i in range(1,n):  \n",
    "    x2 = x1-f(x1)*((x1-x0)/(f(x1)-f(x0))) #equivalent to what we had defined analytically\n",
    "    x0 = x1  #update the values\n",
    "    x1 = x2  #update\n",
    "    \n",
    "print(x1)\n",
    "    break\n",
    "```\n",
    "\n",
    "### What does the `for` statement do?\n",
    "The statement \n",
    "```python\n",
    "for i in range(1,n):\n",
    "```\n",
    "also deserves some explanation. This is another essential programming tool known as the *for loop*. Within the `for` statement, the indented code block is executed, then the next iteration of the loop is performed, in our case $i \\mapsto i+1$, and this continues until all iterations are done ($i = n$). It provides a means of counting or iterating through a process. In our case these are the iterations of the secant method. \n",
    "\n",
    "**Note**: The `print(x1)` statement is outside of the indented block. This means that x1 is printed after the loop has finished. If the statement were included within the block, then x1 would be every time (how many times would x1 be printed?).\n",
    "\n",
    "\n",
    "Below is a visualization of the algorithm at work. Input the initial values of $x_0$ and $x_1$ below and press \"Iterate\" to see how the algorithm searches for the roots of the same function used in the \"Inspection\" example. This will give you a sense how this algorithm works and the problems it may run into. Reset the cell by pressing restart and playing around with different initial conditions to gain a better sense of how the algorithm works. Does it seem faster than the bisection method? How many iterations are required until it converges to the solution with the accuracy you wanted? Did it even converge? Notice how different initial guesses can make the algorithm converge to different roots.\n",
    "\n",
    "Try working through the algorithm analytically, on paper with a function of your choice, beforehand. See how fast you can obtain a root and to what accuracy.\n",
    "\n",
    "\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "metadata": {
    "scrolled": false,
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "# Secant method visualization\n",
    "#First we define our arbitrary function\n",
    "x = np.linspace(-10,10,10000)\n",
    "f = x**3 - (7/9)*x**2 -(1/4)*x + 7/36 #Underlying plot\n",
    "\n",
    "def func(x):\n",
    "    return x**3 - (7/9)*x**2 -(1/4)*x + 7/36  #Function to employ algorithm on\n",
    "\n",
    "class LoadedButton(widgets.Button):\n",
    "    #A button that can holds a value as a attribute.\n",
    "\n",
    "    def __init__(self, value=None, *args, **kwargs):\n",
    "        super(LoadedButton, self).__init__(*args, **kwargs)\n",
    "        # Create the value attribute.\n",
    "        self.add_traits(value=traitlets.Any(value))\n",
    "\n",
    "\n",
    "def secantmethod(x0,x1,n,tol):\n",
    "    \n",
    "    if str.isdigit(x0) == False or str.isdigit(x1) == False or str.isdigit(tol) == False:  \n",
    "        print(\"Please input a number\")\n",
    "    else:\n",
    "        if x0 and x1 != None:    \n",
    "            x0.replace(\" \",\"\")\n",
    "            x1.replace(\" \",\"\")\n",
    "            tol.replace(\" \",\"\") \n",
    "            x0 = np.array(x0).astype(np.float)\n",
    "            x1 = np.array(x1).astype(np.float)\n",
    "            tol = np.array(tol).astype(np.float)\n",
    "\n",
    "            for i in range (1,n):\n",
    "                x2 = x1-func(x1)*((x1-x0)/(func(x1)-func(x0)))\n",
    "                x0 = x1\n",
    "                x1 = x2\n",
    "                if abs(x1-x0)< tol:\n",
    "\n",
    "                    display(Markdown(\"Secant method has provided the root to within the specified tolerance\"))                \n",
    "                    display(Markdown('Root = '+ str(round(x1,4))))\n",
    "                    break\n",
    "                \n",
    "    return x0, x1\n",
    " \n",
    "\n",
    "x0s_in = widgets.Text(placeholder = \"Enter a Value\")\n",
    "x0s_out = widgets.Text(value = None, disabled = True)\n",
    "x1s_in = widgets.Text(placeholder = \"Enter a Value\")\n",
    "x1s_out = widgets.Text(value = None, disabled = True)\n",
    "tols_in = widgets.Text(placeholder = \"Enter a Value\")\n",
    "tols_out = widgets.Text(value = None, disabled = True)\n",
    "\n",
    "def bind_x0(sender):\n",
    "    x0s_out.value = x0s_in.value\n",
    "    return x0s_out.value\n",
    "def bind_x1(sender):\n",
    "    x1s_out.value = x1s_in.value\n",
    "    return x1s_out.value\n",
    "def bind_tol(sender):\n",
    "    tols_out.value = tols_in.value\n",
    "    return tols_out.value\n",
    "\n",
    "x1s_in.on_submit(bind_x1)\n",
    "x0s_in.on_submit(bind_x0)\n",
    "tols_in.on_submit(bind_tol)\n",
    "\n",
    "lb = LoadedButton(description=\"Iterate\", value=0, \n",
    "                  layout = Layout(width='30%', height='60px'),\n",
    "                  button_style = 'info'\n",
    "                 )\n",
    "\n",
    "restart_button = widgets.Button(description=\"Restart\", \n",
    "                        layout = Layout(width='30%', height='60px'),\n",
    "                        button_style = 'info'\n",
    "                       )\n",
    "\n",
    "\n",
    "def on_button_clicked(b):\n",
    "    x0s_in.value = \"\"\n",
    "    x1s_in.value = \"\"\n",
    "    tols_in.value = \"\"\n",
    "    lb.value = 0\n",
    "    display(Javascript('IPython.notebook.execute_cell_range(IPython.notebook.get_selected_index(),IPython.notebook.get_selected_index()+1)'))\n",
    "\n",
    "    \n",
    "restart_button.on_click(on_button_clicked)    \n",
    "\n",
    "\n",
    "def add_num(n):\n",
    "    display(Javascript('IPython.notebook.execute_cell_range(IPython.notebook.get_selected_index()+1,IPython.notebook.get_selected_index()+2)'))\n",
    "    lb.value = lb.value + 1       \n",
    "    return lb.value\n",
    "\n",
    "lb.on_click(add_num)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "85140c4924cf414f89ba99a42822bed4",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Button(button_style='info', description='Restart', layout=Layout(height='60px', width='30%'), style=ButtonStyl…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/plain": [
       "'Input a value for x0'"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "8ffd855b6c1b4964a2a13348a88fe725",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Text(value='', placeholder='Enter a Value')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/plain": [
       "'Input a value for x1'"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "f2dac9ec0083449c81aeb7ef07b90fe2",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Text(value='', placeholder='Enter a Value')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/plain": [
       "'Specify an accuracy'"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "5e4e28fdfdbd418ea82ca30c21dec581",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Text(value='', placeholder='Enter a Value')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "36c58bd487554085a2be5af7fca265fc",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "LoadedButton(button_style='info', description='Iterate', layout=Layout(height='60px', width='30%'), style=Butt…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "clear_output()\n",
    "display(restart_button)\n",
    "display('Input a value for x0')\n",
    "display(x0s_in)\n",
    "display(\"Input a value for x1\")\n",
    "display(x1s_in)\n",
    "display(\"Specify an accuracy\")\n",
    "display(tols_in)\n",
    "display(lb)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "metadata": {
    "scrolled": false,
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "if lb.value == 0:\n",
    "    clear_output()\n",
    "    \n",
    "if lb.value != 0:\n",
    "    if x0s_out.value == '' or x1s_out.value == '' or tols_out.value == '':\n",
    "        display(\"Please be sure to press enter after submitting values\")\n",
    "    else:\n",
    "        x_0, x_1 = secantmethod(x0s_out.value,x1s_out.value,lb.value,tols_out.value)\n",
    "        x_0 = float(x_0)\n",
    "        x_1 = float(x_1)\n",
    "        \n",
    "        trace1 = go.Scatter(\n",
    "            x = [x_0,x_1], \n",
    "            y = [func(x_0),func(x_1)]\n",
    "        )\n",
    "        trace2 = go.Scatter(\n",
    "            x = x,\n",
    "            y = f\n",
    "        )\n",
    "        layout = go.Layout(\n",
    "            showlegend = False,\n",
    "            xaxis = dict(\n",
    "                title='x',\n",
    "                titlefont=dict(\n",
    "                family='Arial, sans-serif',\n",
    "                size=18,\n",
    "                color='black'),\n",
    "                showticklabels=True,\n",
    "                tickangle=0,\n",
    "                range = [-15,15],\n",
    "               # autotick=True,\n",
    "                ticks='outside',\n",
    "            ),\n",
    "            yaxis = dict(\n",
    "                title='P(x)',\n",
    "                titlefont=dict(\n",
    "                family='Arial, sans-serif',\n",
    "                size=18,\n",
    "                color='black'),\n",
    "                range = [-10,10],\n",
    "               # autotick=True,\n",
    "                ticks='outside',\n",
    "            ),\n",
    "        )\n",
    "\n",
    "        data = [trace1,trace2]\n",
    "        fig = go.Figure(data = data, layout = layout)\n",
    "        iplot(fig)\n",
    "     \n",
    "\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "collapsed": true,
    "hidden": false
   },
   "source": [
    "## Transcendental equations\n",
    "---\n",
    "\n",
    "A nice application of root finding occurs when one is faced with a transcendental equation. Below we will walk you through how to solve these equations numerically using the methods we have previously discussed.\n",
    "\n",
    "### What is a transcendental equation? \n",
    "\n",
    "A *transcendental equation* is defined as an equation which contains a transcendental function of the variable being solved for.\n",
    "\n",
    "Examples:\n",
    "- $x = e^x$\n",
    "- $\\tan(x) = x$\n",
    "- $\\ln(x) = e^x$\n",
    "\n",
    "These equations may look intimidating, but by formulating their solution as a root finding problem and applying the methods we learned in this notebook, they become solvable. Developing these tools and being exposed to these types of problems will aid you if you are ever faced with an equation of this type in the future. \n",
    "\n",
    "Firstly, we illustrate how to use these techniques to solve the problem $\\cos(x) = x$ and then provide some practice problems where you get the opportunity to manipulate the code from our example.\n",
    "\n",
    "***\n",
    "### Problem Statement\n",
    "\n",
    "Find all solutions of the equation: $\\cos(x) = x$.\n",
    "\n",
    "Firstly, the problem can be formulated as: find the roots of $f(x) = \\cos(x) - x$ (why are these equivalent?). Let's first apply Inspection in order to get a sense of what this function looks like and where it may have roots/solutions. The next cell plots the function on a grid so we can visually \"inspect\" where the root is approximately. Use the interactive function 'zoom' to see where the function crosses the $x$ axis more precisely.\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 14,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "1c226b9c2f7f42fb8605d69ec622cbee",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Button(button_style='info', description='Analyze Graph', layout=Layout(height='60px', width='30%'), style=Butt…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "config": {
        "linkText": "Export to plot.ly",
        "plotlyServerURL": "https://plot.ly",
        "showLink": false
       },
       "data": [
        {
         "line": {
          "color": "black"
         },
         "name": "P(x) = cos(x) - x",
         "type": "scatter",
         "x": [
          -50,
          -49.8998998998999,
          -49.7997997997998,
          -49.6996996996997,
          -49.5995995995996,
          -49.4994994994995,
          -49.3993993993994,
          -49.2992992992993,
          -49.1991991991992,
          -49.0990990990991,
          -48.998998998999,
          -48.8988988988989,
          -48.7987987987988,
          -48.6986986986987,
          -48.5985985985986,
          -48.4984984984985,
          -48.3983983983984,
          -48.2982982982983,
          -48.1981981981982,
          -48.0980980980981,
          -47.997997997998,
          -47.8978978978979,
          -47.7977977977978,
          -47.6976976976977,
          -47.5975975975976,
          -47.4974974974975,
          -47.3973973973974,
          -47.2972972972973,
          -47.1971971971972,
          -47.0970970970971,
          -46.996996996997,
          -46.8968968968969,
          -46.7967967967968,
          -46.6966966966967,
          -46.5965965965966,
          -46.4964964964965,
          -46.3963963963964,
          -46.2962962962963,
          -46.1961961961962,
          -46.0960960960961,
          -45.995995995996,
          -45.8958958958959,
          -45.7957957957958,
          -45.6956956956957,
          -45.5955955955956,
          -45.4954954954955,
          -45.3953953953954,
          -45.2952952952953,
          -45.1951951951952,
          -45.0950950950951,
          -44.994994994995,
          -44.8948948948949,
          -44.7947947947948,
          -44.6946946946947,
          -44.5945945945946,
          -44.4944944944945,
          -44.394394394394396,
          -44.294294294294296,
          -44.194194194194196,
          -44.094094094094096,
          -43.993993993993996,
          -43.893893893893896,
          -43.793793793793796,
          -43.693693693693696,
          -43.593593593593596,
          -43.493493493493496,
          -43.393393393393396,
          -43.293293293293296,
          -43.193193193193196,
          -43.093093093093096,
          -42.992992992992995,
          -42.892892892892895,
          -42.792792792792795,
          -42.692692692692695,
          -42.592592592592595,
          -42.49249249249249,
          -42.392392392392395,
          -42.29229229229229,
          -42.192192192192195,
          -42.09209209209209,
          -41.991991991991995,
          -41.89189189189189,
          -41.791791791791795,
          -41.69169169169169,
          -41.591591591591595,
          -41.49149149149149,
          -41.391391391391394,
          -41.29129129129129,
          -41.191191191191194,
          -41.09109109109109,
          -40.990990990990994,
          -40.89089089089089,
          -40.790790790790794,
          -40.69069069069069,
          -40.590590590590594,
          -40.49049049049049,
          -40.390390390390394,
          -40.29029029029029,
          -40.190190190190194,
          -40.09009009009009,
          -39.98998998998999,
          -39.889889889889886,
          -39.78978978978979,
          -39.689689689689686,
          -39.58958958958959,
          -39.489489489489486,
          -39.38938938938939,
          -39.289289289289286,
          -39.189189189189186,
          -39.089089089089086,
          -38.988988988988986,
          -38.888888888888886,
          -38.788788788788786,
          -38.688688688688686,
          -38.588588588588586,
          -38.488488488488485,
          -38.388388388388385,
          -38.288288288288285,
          -38.188188188188185,
          -38.088088088088085,
          -37.987987987987985,
          -37.887887887887885,
          -37.787787787787785,
          -37.687687687687685,
          -37.587587587587585,
          -37.487487487487485,
          -37.387387387387385,
          -37.287287287287285,
          -37.187187187187185,
          -37.087087087087085,
          -36.986986986986985,
          -36.886886886886884,
          -36.786786786786784,
          -36.686686686686684,
          -36.586586586586584,
          -36.486486486486484,
          -36.386386386386384,
          -36.286286286286284,
          -36.186186186186184,
          -36.086086086086084,
          -35.985985985985984,
          -35.885885885885884,
          -35.785785785785784,
          -35.685685685685684,
          -35.585585585585584,
          -35.48548548548548,
          -35.38538538538538,
          -35.28528528528528,
          -35.18518518518518,
          -35.08508508508508,
          -34.98498498498498,
          -34.88488488488488,
          -34.78478478478478,
          -34.68468468468468,
          -34.58458458458458,
          -34.48448448448448,
          -34.38438438438438,
          -34.28428428428428,
          -34.18418418418418,
          -34.08408408408408,
          -33.98398398398398,
          -33.88388388388388,
          -33.78378378378378,
          -33.68368368368368,
          -33.58358358358358,
          -33.48348348348348,
          -33.38338338338338,
          -33.28328328328328,
          -33.18318318318318,
          -33.08308308308308,
          -32.98298298298298,
          -32.88288288288288,
          -32.78278278278278,
          -32.68268268268268,
          -32.58258258258258,
          -32.48248248248248,
          -32.38238238238238,
          -32.28228228228228,
          -32.18218218218218,
          -32.08208208208208,
          -31.98198198198198,
          -31.88188188188188,
          -31.78178178178178,
          -31.68168168168168,
          -31.58158158158158,
          -31.48148148148148,
          -31.38138138138138,
          -31.28128128128128,
          -31.18118118118118,
          -31.08108108108108,
          -30.98098098098098,
          -30.88088088088088,
          -30.78078078078078,
          -30.68068068068068,
          -30.58058058058058,
          -30.48048048048048,
          -30.38038038038038,
          -30.28028028028028,
          -30.18018018018018,
          -30.08008008008008,
          -29.97997997997998,
          -29.87987987987988,
          -29.77977977977978,
          -29.67967967967968,
          -29.57957957957958,
          -29.47947947947948,
          -29.37937937937938,
          -29.27927927927928,
          -29.17917917917918,
          -29.07907907907908,
          -28.97897897897898,
          -28.87887887887888,
          -28.77877877877878,
          -28.67867867867868,
          -28.578578578578576,
          -28.478478478478475,
          -28.378378378378375,
          -28.278278278278275,
          -28.178178178178175,
          -28.078078078078075,
          -27.977977977977975,
          -27.877877877877875,
          -27.777777777777775,
          -27.677677677677675,
          -27.577577577577575,
          -27.477477477477475,
          -27.377377377377375,
          -27.277277277277275,
          -27.177177177177175,
          -27.077077077077075,
          -26.976976976976974,
          -26.876876876876874,
          -26.776776776776774,
          -26.676676676676674,
          -26.576576576576574,
          -26.476476476476474,
          -26.376376376376374,
          -26.276276276276274,
          -26.176176176176174,
          -26.076076076076074,
          -25.975975975975974,
          -25.875875875875874,
          -25.775775775775774,
          -25.675675675675674,
          -25.575575575575574,
          -25.475475475475474,
          -25.375375375375373,
          -25.275275275275273,
          -25.175175175175173,
          -25.075075075075073,
          -24.974974974974973,
          -24.874874874874873,
          -24.774774774774773,
          -24.674674674674673,
          -24.574574574574573,
          -24.474474474474473,
          -24.374374374374373,
          -24.274274274274273,
          -24.174174174174173,
          -24.074074074074073,
          -23.973973973973973,
          -23.873873873873872,
          -23.773773773773772,
          -23.673673673673672,
          -23.573573573573572,
          -23.473473473473472,
          -23.373373373373372,
          -23.273273273273272,
          -23.173173173173172,
          -23.073073073073072,
          -22.972972972972972,
          -22.872872872872872,
          -22.772772772772772,
          -22.67267267267267,
          -22.57257257257257,
          -22.47247247247247,
          -22.37237237237237,
          -22.27227227227227,
          -22.17217217217217,
          -22.07207207207207,
          -21.97197197197197,
          -21.87187187187187,
          -21.77177177177177,
          -21.67167167167167,
          -21.57157157157157,
          -21.47147147147147,
          -21.37137137137137,
          -21.27127127127127,
          -21.17117117117117,
          -21.07107107107107,
          -20.97097097097097,
          -20.87087087087087,
          -20.77077077077077,
          -20.67067067067067,
          -20.57057057057057,
          -20.47047047047047,
          -20.37037037037037,
          -20.27027027027027,
          -20.17017017017017,
          -20.070070070070066,
          -19.969969969969966,
          -19.869869869869866,
          -19.769769769769766,
          -19.669669669669666,
          -19.569569569569566,
          -19.469469469469466,
          -19.369369369369366,
          -19.269269269269266,
          -19.169169169169166,
          -19.069069069069066,
          -18.968968968968966,
          -18.868868868868866,
          -18.768768768768766,
          -18.668668668668666,
          -18.568568568568566,
          -18.468468468468465,
          -18.368368368368365,
          -18.268268268268265,
          -18.168168168168165,
          -18.068068068068065,
          -17.967967967967965,
          -17.867867867867865,
          -17.767767767767765,
          -17.667667667667665,
          -17.567567567567565,
          -17.467467467467465,
          -17.367367367367365,
          -17.267267267267265,
          -17.167167167167165,
          -17.067067067067065,
          -16.966966966966964,
          -16.866866866866864,
          -16.766766766766764,
          -16.666666666666664,
          -16.566566566566564,
          -16.466466466466464,
          -16.366366366366364,
          -16.266266266266264,
          -16.166166166166164,
          -16.066066066066064,
          -15.965965965965964,
          -15.865865865865864,
          -15.765765765765764,
          -15.665665665665664,
          -15.565565565565564,
          -15.465465465465464,
          -15.365365365365363,
          -15.265265265265263,
          -15.165165165165163,
          -15.065065065065063,
          -14.964964964964963,
          -14.864864864864863,
          -14.764764764764763,
          -14.664664664664663,
          -14.564564564564563,
          -14.464464464464463,
          -14.364364364364363,
          -14.264264264264263,
          -14.164164164164163,
          -14.064064064064063,
          -13.963963963963963,
          -13.863863863863862,
          -13.763763763763762,
          -13.663663663663662,
          -13.563563563563562,
          -13.463463463463462,
          -13.363363363363362,
          -13.263263263263262,
          -13.163163163163162,
          -13.063063063063062,
          -12.962962962962962,
          -12.862862862862862,
          -12.762762762762762,
          -12.662662662662662,
          -12.562562562562562,
          -12.462462462462462,
          -12.362362362362362,
          -12.262262262262261,
          -12.162162162162161,
          -12.062062062062061,
          -11.961961961961961,
          -11.861861861861861,
          -11.761761761761761,
          -11.661661661661661,
          -11.561561561561561,
          -11.461461461461461,
          -11.36136136136136,
          -11.26126126126126,
          -11.16116116116116,
          -11.06106106106106,
          -10.96096096096096,
          -10.86086086086086,
          -10.76076076076076,
          -10.66066066066066,
          -10.56056056056056,
          -10.46046046046046,
          -10.36036036036036,
          -10.26026026026026,
          -10.16016016016016,
          -10.06006006006006,
          -9.95995995995996,
          -9.85985985985986,
          -9.75975975975976,
          -9.65965965965966,
          -9.55955955955956,
          -9.45945945945946,
          -9.35935935935936,
          -9.25925925925926,
          -9.15915915915916,
          -9.05905905905906,
          -8.95895895895896,
          -8.85885885885886,
          -8.75875875875876,
          -8.65865865865866,
          -8.558558558558559,
          -8.458458458458459,
          -8.358358358358359,
          -8.258258258258259,
          -8.158158158158159,
          -8.058058058058059,
          -7.957957957957959,
          -7.857857857857859,
          -7.7577577577577586,
          -7.6576576576576585,
          -7.557557557557558,
          -7.457457457457458,
          -7.357357357357358,
          -7.257257257257251,
          -7.157157157157151,
          -7.057057057057051,
          -6.956956956956951,
          -6.856856856856851,
          -6.756756756756751,
          -6.656656656656651,
          -6.556556556556551,
          -6.456456456456451,
          -6.3563563563563505,
          -6.2562562562562505,
          -6.15615615615615,
          -6.05605605605605,
          -5.95595595595595,
          -5.85585585585585,
          -5.75575575575575,
          -5.65565565565565,
          -5.55555555555555,
          -5.45545545545545,
          -5.35535535535535,
          -5.25525525525525,
          -5.15515515515515,
          -5.05505505505505,
          -4.95495495495495,
          -4.85485485485485,
          -4.7547547547547495,
          -4.6546546546546494,
          -4.554554554554549,
          -4.454454454454449,
          -4.354354354354349,
          -4.254254254254249,
          -4.154154154154149,
          -4.054054054054049,
          -3.953953953953949,
          -3.853853853853849,
          -3.753753753753749,
          -3.653653653653649,
          -3.5535535535535487,
          -3.4534534534534487,
          -3.3533533533533486,
          -3.2532532532532485,
          -3.1531531531531485,
          -3.0530530530530484,
          -2.9529529529529484,
          -2.8528528528528483,
          -2.7527527527527482,
          -2.652652652652648,
          -2.552552552552548,
          -2.452452452452448,
          -2.352352352352348,
          -2.252252252252248,
          -2.152152152152148,
          -2.0520520520520478,
          -1.9519519519519477,
          -1.8518518518518476,
          -1.7517517517517476,
          -1.6516516516516475,
          -1.5515515515515474,
          -1.4514514514514474,
          -1.3513513513513473,
          -1.2512512512512473,
          -1.1511511511511472,
          -1.0510510510510471,
          -0.9509509509509471,
          -0.850850850850847,
          -0.7507507507507469,
          -0.6506506506506469,
          -0.5505505505505468,
          -0.45045045045044674,
          -0.3503503503503467,
          -0.2502502502502466,
          -0.15015015015014654,
          -0.05005005005004648,
          0.050050050050053585,
          0.15015015015015365,
          0.2502502502502537,
          0.3503503503503538,
          0.45045045045045384,
          0.5505505505505539,
          0.650650650650654,
          0.750750750750754,
          0.8508508508508541,
          0.9509509509509542,
          1.0510510510510542,
          1.1511511511511543,
          1.2512512512512544,
          1.3513513513513544,
          1.4514514514514545,
          1.5515515515515546,
          1.6516516516516546,
          1.7517517517517547,
          1.8518518518518547,
          1.9519519519519548,
          2.052052052052055,
          2.152152152152155,
          2.252252252252255,
          2.352352352352355,
          2.452452452452455,
          2.552552552552555,
          2.6526526526526553,
          2.7527527527527553,
          2.8528528528528554,
          2.9529529529529555,
          3.0530530530530555,
          3.1531531531531556,
          3.2532532532532557,
          3.3533533533533557,
          3.453453453453456,
          3.553553553553556,
          3.653653653653656,
          3.753753753753756,
          3.853853853853856,
          3.953953953953956,
          4.054054054054056,
          4.154154154154156,
          4.254254254254256,
          4.354354354354356,
          4.454454454454456,
          4.5545545545545565,
          4.6546546546546566,
          4.754754754754757,
          4.854854854854857,
          4.954954954954957,
          5.055055055055057,
          5.155155155155157,
          5.255255255255257,
          5.355355355355357,
          5.455455455455457,
          5.555555555555557,
          5.655655655655657,
          5.755755755755757,
          5.855855855855857,
          5.955955955955957,
          6.0560560560560575,
          6.1561561561561575,
          6.256256256256258,
          6.356356356356358,
          6.456456456456458,
          6.556556556556558,
          6.656656656656658,
          6.756756756756758,
          6.856856856856858,
          6.956956956956958,
          7.057057057057058,
          7.157157157157158,
          7.257257257257258,
          7.357357357357358,
          7.457457457457458,
          7.557557557557558,
          7.6576576576576585,
          7.7577577577577586,
          7.857857857857859,
          7.957957957957959,
          8.058058058058059,
          8.158158158158159,
          8.258258258258259,
          8.358358358358359,
          8.458458458458459,
          8.558558558558559,
          8.65865865865866,
          8.75875875875876,
          8.85885885885886,
          8.95895895895896,
          9.05905905905906,
          9.15915915915916,
          9.25925925925926,
          9.35935935935936,
          9.45945945945946,
          9.55955955955956,
          9.65965965965966,
          9.75975975975976,
          9.859859859859867,
          9.959959959959967,
          10.060060060060067,
          10.160160160160167,
          10.260260260260267,
          10.360360360360367,
          10.460460460460467,
          10.560560560560567,
          10.660660660660668,
          10.760760760760768,
          10.860860860860868,
          10.960960960960968,
          11.061061061061068,
          11.161161161161168,
          11.261261261261268,
          11.361361361361368,
          11.461461461461468,
          11.561561561561568,
          11.661661661661668,
          11.761761761761768,
          11.861861861861868,
          11.961961961961968,
          12.062062062062068,
          12.162162162162168,
          12.262262262262269,
          12.362362362362369,
          12.462462462462469,
          12.562562562562569,
          12.662662662662669,
          12.762762762762769,
          12.862862862862869,
          12.962962962962969,
          13.063063063063069,
          13.16316316316317,
          13.26326326326327,
          13.36336336336337,
          13.46346346346347,
          13.56356356356357,
          13.66366366366367,
          13.76376376376377,
          13.86386386386387,
          13.96396396396397,
          14.06406406406407,
          14.164164164164163,
          14.26426426426427,
          14.364364364364363,
          14.46446446446447,
          14.564564564564563,
          14.66466466466467,
          14.764764764764763,
          14.86486486486487,
          14.964964964964963,
          15.06506506506507,
          15.165165165165163,
          15.26526526526527,
          15.365365365365363,
          15.46546546546547,
          15.565565565565564,
          15.66566566566567,
          15.765765765765764,
          15.86586586586587,
          15.965965965965964,
          16.06606606606607,
          16.166166166166164,
          16.26626626626627,
          16.366366366366364,
          16.46646646646647,
          16.566566566566564,
          16.66666666666667,
          16.766766766766764,
          16.86686686686687,
          16.966966966966964,
          17.06706706706707,
          17.167167167167165,
          17.267267267267272,
          17.367367367367365,
          17.467467467467472,
          17.567567567567565,
          17.667667667667672,
          17.767767767767765,
          17.867867867867872,
          17.967967967967965,
          18.068068068068072,
          18.168168168168165,
          18.268268268268272,
          18.36836836836838,
          18.468468468468473,
          18.56856856856858,
          18.668668668668673,
          18.76876876876878,
          18.868868868868873,
          18.96896896896898,
          19.069069069069073,
          19.16916916916918,
          19.269269269269273,
          19.36936936936938,
          19.469469469469473,
          19.56956956956958,
          19.669669669669673,
          19.76976976976978,
          19.869869869869873,
          19.96996996996998,
          20.070070070070074,
          20.17017017017018,
          20.270270270270274,
          20.37037037037038,
          20.470470470470474,
          20.57057057057058,
          20.670670670670674,
          20.77077077077078,
          20.870870870870874,
          20.97097097097098,
          21.071071071071074,
          21.17117117117118,
          21.271271271271274,
          21.37137137137138,
          21.471471471471475,
          21.57157157157158,
          21.671671671671675,
          21.771771771771782,
          21.871871871871875,
          21.971971971971982,
          22.072072072072075,
          22.172172172172182,
          22.272272272272275,
          22.372372372372382,
          22.472472472472475,
          22.572572572572582,
          22.672672672672675,
          22.772772772772782,
          22.872872872872875,
          22.972972972972983,
          23.073073073073076,
          23.173173173173183,
          23.273273273273276,
          23.373373373373383,
          23.473473473473476,
          23.573573573573583,
          23.673673673673676,
          23.773773773773783,
          23.873873873873876,
          23.973973973973983,
          24.074074074074076,
          24.174174174174183,
          24.274274274274276,
          24.374374374374383,
          24.474474474474476,
          24.574574574574584,
          24.674674674674677,
          24.774774774774784,
          24.874874874874877,
          24.974974974974984,
          25.075075075075077,
          25.175175175175184,
          25.275275275275277,
          25.375375375375384,
          25.475475475475477,
          25.575575575575584,
          25.675675675675677,
          25.775775775775784,
          25.875875875875877,
          25.975975975975985,
          26.076076076076077,
          26.176176176176185,
          26.276276276276278,
          26.376376376376385,
          26.476476476476478,
          26.576576576576585,
          26.676676676676678,
          26.776776776776785,
          26.876876876876878,
          26.976976976976985,
          27.077077077077078,
          27.177177177177185,
          27.27727727727728,
          27.377377377377385,
          27.47747747747748,
          27.577577577577586,
          27.67767767767768,
          27.777777777777786,
          27.87787787787788,
          27.977977977977986,
          28.07807807807808,
          28.178178178178186,
          28.27827827827828,
          28.378378378378386,
          28.47847847847848,
          28.578578578578586,
          28.67867867867868,
          28.778778778778786,
          28.87887887887888,
          28.978978978978986,
          29.07907907907908,
          29.179179179179187,
          29.27927927927928,
          29.379379379379387,
          29.47947947947948,
          29.579579579579587,
          29.67967967967968,
          29.779779779779787,
          29.87987987987988,
          29.979979979979987,
          30.08008008008008,
          30.180180180180187,
          30.28028028028028,
          30.380380380380387,
          30.48048048048048,
          30.580580580580587,
          30.68068068068068,
          30.780780780780788,
          30.88088088088088,
          30.980980980980988,
          31.08108108108108,
          31.181181181181188,
          31.28128128128128,
          31.381381381381388,
          31.48148148148148,
          31.581581581581588,
          31.68168168168168,
          31.78178178178179,
          31.88188188188188,
          31.98198198198199,
          32.08208208208208,
          32.18218218218219,
          32.28228228228228,
          32.38238238238239,
          32.48248248248248,
          32.58258258258259,
          32.68268268268268,
          32.78278278278279,
          32.88288288288288,
          32.98298298298299,
          33.08308308308308,
          33.18318318318319,
          33.28328328328328,
          33.38338338338339,
          33.48348348348348,
          33.58358358358359,
          33.68368368368368,
          33.78378378378379,
          33.88388388388388,
          33.98398398398399,
          34.08408408408408,
          34.18418418418419,
          34.28428428428428,
          34.38438438438439,
          34.48448448448448,
          34.58458458458459,
          34.68468468468468,
          34.78478478478479,
          34.88488488488488,
          34.98498498498499,
          35.08508508508508,
          35.18518518518519,
          35.28528528528528,
          35.38538538538539,
          35.4854854854855,
          35.58558558558559,
          35.6856856856857,
          35.78578578578579,
          35.8858858858859,
          35.98598598598599,
          36.0860860860861,
          36.18618618618619,
          36.2862862862863,
          36.38638638638639,
          36.4864864864865,
          36.58658658658659,
          36.6866866866867,
          36.78678678678679,
          36.8868868868869,
          36.98698698698699,
          37.0870870870871,
          37.18718718718719,
          37.2872872872873,
          37.38738738738739,
          37.4874874874875,
          37.58758758758759,
          37.6876876876877,
          37.78778778778779,
          37.8878878878879,
          37.98798798798799,
          38.0880880880881,
          38.18818818818819,
          38.2882882882883,
          38.38838838838839,
          38.4884884884885,
          38.58858858858859,
          38.6886886886887,
          38.78878878878879,
          38.8888888888889,
          38.98898898898899,
          39.0890890890891,
          39.18918918918919,
          39.2892892892893,
          39.38938938938939,
          39.4894894894895,
          39.58958958958959,
          39.6896896896897,
          39.78978978978979,
          39.8898898898899,
          39.98998998998999,
          40.0900900900901,
          40.190190190190194,
          40.2902902902903,
          40.390390390390394,
          40.4904904904905,
          40.590590590590594,
          40.6906906906907,
          40.790790790790794,
          40.8908908908909,
          40.990990990990994,
          41.0910910910911,
          41.191191191191194,
          41.2912912912913,
          41.391391391391394,
          41.4914914914915,
          41.591591591591595,
          41.6916916916917,
          41.791791791791795,
          41.8918918918919,
          41.991991991991995,
          42.0920920920921,
          42.192192192192195,
          42.2922922922923,
          42.392392392392395,
          42.4924924924925,
          42.592592592592595,
          42.6926926926927,
          42.792792792792795,
          42.8928928928929,
          42.992992992992995,
          43.0930930930931,
          43.193193193193196,
          43.2932932932933,
          43.393393393393396,
          43.4934934934935,
          43.593593593593596,
          43.6936936936937,
          43.793793793793796,
          43.8938938938939,
          43.993993993993996,
          44.0940940940941,
          44.194194194194196,
          44.2942942942943,
          44.394394394394396,
          44.494494494494504,
          44.5945945945946,
          44.694694694694704,
          44.7947947947948,
          44.894894894894904,
          44.994994994995,
          45.095095095095104,
          45.1951951951952,
          45.295295295295304,
          45.3953953953954,
          45.495495495495504,
          45.5955955955956,
          45.695695695695704,
          45.7957957957958,
          45.895895895895904,
          45.995995995996,
          46.096096096096105,
          46.1961961961962,
          46.296296296296305,
          46.3963963963964,
          46.496496496496505,
          46.5965965965966,
          46.696696696696705,
          46.7967967967968,
          46.896896896896905,
          46.996996996997,
          47.097097097097105,
          47.1971971971972,
          47.297297297297305,
          47.3973973973974,
          47.497497497497505,
          47.5975975975976,
          47.697697697697706,
          47.7977977977978,
          47.897897897897906,
          47.997997997998,
          48.098098098098106,
          48.1981981981982,
          48.298298298298306,
          48.3983983983984,
          48.498498498498506,
          48.5985985985986,
          48.698698698698706,
          48.7987987987988,
          48.898898898898906,
          48.998998998999,
          49.09909909909911,
          49.1991991991992,
          49.29929929929931,
          49.3993993993994,
          49.49949949949951,
          49.5995995995996,
          49.69969969969971,
          49.7997997997998,
          49.89989989989991,
          50
         ],
         "y": [
          50.964966028492114,
          50.83381555906627,
          50.69331503791033,
          50.54386894054957,
          50.385971302631134,
          50.22020077380413,
          50.047214824472555,
          49.86774316342115,
          49.682580432214735,
          49.49257824951214,
          49.298636684944654,
          49.10169524791932,
          48.902723481564564,
          48.702711255988085,
          48.50265885802788,
          48.30356697671445,
          48.106426684706335,
          47.91220951600165,
          47.72185773926406,
          47.536274924143555,
          47.35631689503887,
          47.18278316286936,
          47.01640892063862,
          46.85785768292766,
          46.70771464300846,
          46.56648081408435,
          46.434568013313104,
          46.312294738831056,
          46.19988298105615,
          46.09745600019396,
          46.005037092197696,
          45.92254935553688,
          45.849816461109825,
          45.78656441759167,
          45.732424314544076,
          45.68693601582335,
          45.649552766309824,
          45.61964666583761,
          45.59651495552133,
          45.579387053543456,
          45.56743226996215,
          45.55976812330155,
          45.5554691756617,
          45.55357629789369,
          45.55310627208052,
          45.55306163518651,
          45.55244066532418,
          45.55024741065927,
          45.54550166054795,
          45.537248759078494,
          45.52456916276747,
          45.50658764672206,
          45.48248206709942,
          45.45149159213632,
          45.41292431934272,
          45.366164202598426,
          45.31067721980116,
          45.24601671931752,
          45.171827891709995,
          45.08785132197059,
          44.99392558669724,
          44.889988870211006,
          44.77607958343406,
          44.652335979332285,
          44.51899476877281,
          44.376388750653796,
          44.22494348003305,
          44.065173007612835,
          43.89767473323594,
          43.723123424917866,
          43.54226446329484,
          43.355906379121755,
          43.16491275853221,
          42.97019359710253,
          42.77269618927993,
          42.573395644386764,
          42.373285124151735,
          42.173365899506074,
          41.97463732619358,
          41.77808683955436,
          41.58468006865216,
          41.395351168718406,
          41.210993468702135,
          41.032450527558694,
          40.860507688819325,
          40.6958842179938,
          40.53922610152446,
          40.39109957938553,
          40.25198547607771,
          40.12227438677365,
          40.00226276680973,
          39.89214996367401,
          39.79203622120591,
          39.70192167598824,
          39.621706355979875,
          39.55119118140236,
          39.490079957860274,
          39.43798234174051,
          39.39441774820227,
          39.35882016263197,
          39.33054380739257,
          39.30886960713363,
          39.29301238793361,
          39.28212873819899,
          39.27532545261953,
          39.27166847464156,
          39.27019224793029,
          39.26990938319747,
          39.26982054361318,
          39.2689244498325,
          39.26622790446998,
          39.26075573566021,
          39.251560560152896,
          39.23773226819764,
          39.21840713525883,
          39.192776469337325,
          39.16009470732467,
          39.119686879331994,
          39.07095536626318,
          39.01338588297766,
          38.94655262714156,
          38.87012254221842,
          38.783858651920106,
          38.687622432734216,
          38.58137520077524,
          38.465178499074725,
          38.339193481432986,
          38.20367929900105,
          38.0589905057459,
          37.905573508774516,
          37.743962099055004,
          37.57477210727965,
          37.39869523837368,
          37.216492146376524,
          37.028984819027535,
          36.837048348299234,
          36.64160216926873,
          36.443600855040664,
          36.244024559880096,
          36.04386920623527,
          35.84413651389462,
          35.64582397110272,
          35.44991484804109,
          35.25736835265544,
          35.06911002738603,
          34.886022482945805,
          34.708936561916644,
          34.538623020630894,
          34.3757848126163,
          34.22105005086004,
          34.074965719351226,
          33.93799219685983,
          33.81049864777822,
          33.69275932617048,
          33.58495083003232,
          33.487150333250916,
          33.399334812965726,
          33.32138128006565,
          33.25306801051498,
          33.1940767651804,
          33.143995975934885,
          33.102324866140435,
          33.06847846425648,
          33.041793460379665,
          33.02153484708108,
          33.00690327805522,
          32.997043070908305,
          32.99105077396463,
          32.98798421132311,
          32.98687191560777,
          32.98672285397474,
          32.98653635000214,
          32.985312102128304,
          32.98206019833698,
          32.97581102682591,
          32.965624983436385,
          32.95060187865638,
          32.92988995001732,
          32.90269438965554,
          32.868285301663164,
          32.82600500956227,
          32.77527464074213,
          32.71559992193853,
          32.646576127732594,
          32.5678921325266,
          32.47933352542953,
          32.380784756867335,
          32.27223029542667,
          32.153754783350216,
          32.025542189126845,
          31.887873965660503,
          31.74112623245773,
          31.585766010044757,
          31.422346544313932,
          31.251501767610595,
          31.073939952014108,
          30.890436618354304,
          30.701826771955904,
          30.508996542844017,
          30.312874314106217,
          30.114421427231097,
          29.91462255747826,
          29.714475855638455,
          29.514982954881113,
          29.317138942737568,
          29.121922398616928,
          28.93028559659581,
          28.74314497156827,
          28.561371944205654,
          28.385784196583796,
          28.217137485823148,
          28.056118077700827,
          27.903335875986812,
          27.759318316291058,
          27.624505085554283,
          27.49924372004916,
          27.383786125963166,
          27.278286057397974,
          27.18279757703472,
          27.09727451487649,
          27.02157093048692,
          26.955442574097106,
          26.898549331952733,
          26.850458631419414,
          26.810649771755465,
          26.778519137193854,
          26.753386240141708,
          26.734500533994872,
          26.721048927359877,
          26.71216392445348,
          26.706932310180772,
          26.70440429293976,
          26.70360301361775,
          26.70353432557859,
          26.703196747726825,
          26.70159149100202,
          26.69773245792132,
          26.69065611505816,
          26.679431139617222,
          26.663167743527257,
          26.641026581702135,
          26.612227155283602,
          26.57605562573519,
          26.53187196155533,
          26.479116346058973,
          26.41731478207536,
          26.34608383744939,
          26.265134483836334,
          26.1742749903571,
          26.0734128431438,
          25.96255567155766,
          25.84181117180644,
          25.711386028725958,
          25.571583846520504,
          25.422802109178953,
          25.265528200997785,
          25.100334527052254,
          24.927872782467904,
          24.748867427866593,
          24.564108436308654,
          24.37444338434639,
          24.180768966370668,
          23.984022017206083,
          23.785170132833528,
          23.585201983142333,
          23.385117413697447,
          23.18591743561953,
          22.98859420379584,
          22.794121083756835,
          22.603442906665464,
          22.417466509983083,
          22.2370516585156,
          22.063002436735314,
          21.89605919855568,
          21.736891155155153,
          21.586089675058318,
          21.444162363551694,
          21.311527980709105,
          21.188512248905646,
          21.07534459179403,
          20.972155837391593,
          20.878976908273856,
          20.795738511988034,
          20.722271834785932,
          20.65831023173083,
          20.603491896257534,
          20.55736348245891,
          20.51938464383373,
          20.488933443055394,
          20.46531257860078,
          20.44775636590026,
          20.43543840311592,
          20.42747984480082,
          20.422958200606168,
          20.42091657094661,
          20.420373227159406,
          20.420331440243956,
          20.419789459779736,
          20.417750543117016,
          20.41323293443143,
          20.405279693735466,
          20.392968277442094,
          20.375419774563095,
          20.3518077060724,
          20.321366299338127,
          20.28339815478245,
          20.237281228013327,
          20.18247505752521,
          20.118526175619206,
          20.045072648370226,
          19.961847699188606,
          19.868682379698235,
          19.76550726119128,
          19.65235312972524,
          19.52935067790319,
          19.396729196423106,
          19.25481427849596,
          19.10402456011519,
          18.944867528812942,
          18.77793444286435,
          18.60389441180712,
          18.423487697540256,
          18.237518303069127,
          18.046845923095837,
          17.852377337042928,
          17.655057330680602,
          17.455859237247065,
          17.255775192761156,
          17.055806203087812,
          16.85695212220161,
          16.66020164198263,
          16.466522393763515,
          16.27685126072764,
          16.09208499814754,
          15.913071255370582,
          15.740600089436702,
          15.575396055291163,
          15.418110951782378,
          15.269317296069477,
          15.129502591771695,
          14.999064448244914,
          14.878306599849557,
          14.767435865063604,
          14.66656007588504,
          14.575686998253902,
          14.494724254302286,
          14.423480247210701,
          14.361666079411464,
          14.308898444934666,
          14.26470346693956,
          14.228521442011251,
          14.199712443724396,
          14.177562729372887,
          14.161291885723502,
          14.15006064225259,
          14.14297927364233,
          14.139116507413494,
          14.13750884751456,
          14.13717022052245,
          14.137101847880368,
          14.136302245335209,
          14.13377724946349,
          14.128549970903578,
          14.119670574645772,
          14.10622578946327,
          14.087348051278724,
          14.062224188926086,
          14.030103565348806,
          13.99030559272738,
          13.942226546297341,
          13.885345608640016,
          13.8192300839326,
          13.743539729954259,
          13.658030164477632,
          13.56255531194208,
          13.457068865913435,
          13.341624752688542,
          13.216376591403197,
          13.08157615604864,
          12.93757085479444,
          12.784800251853898,
          12.623791666713924,
          12.455154894788407,
          12.27957610235017,
          12.097810956863347,
          11.910677061493077,
          11.719045769535619,
          11.523833460720107,
          11.325992366720701,
          11.12650103773103,
          10.9263545455464,
          10.726554521237263,
          10.528099127153386,
          10.331973063655717,
          10.139137710625176,
          9.950521502448307,
          9.767010632842222,
          9.589440182579013,
          9.418585758935915,
          9.255155730574232,
          9.099784135588834,
          8.953024333730474,
          8.815343466352724,
          8.687117779548748,
          8.568628857301036,
          8.460060802356608,
          8.361498393051779,
          8.272926234539764,
          8.19422891291875,
          8.125192150717336,
          8.06550495216903,
          8.014762716798018,
          7.972471290144013,
          7.938051911071724,
          7.91084700613407,
          7.890126772977966,
          7.875096486881784,
          7.8649044572739,
          7.858650554574298,
          7.855395221991364,
          7.854168882050742,
          7.853981643681259,
          7.853833212673781,
          7.8527229062928265,
          7.8496596717779665,
          7.843672008433134,
          7.8338176939671955,
          7.819193217708903,
          7.798942826254041,
          7.772267090982757,
          7.738430911671965,
          7.696770876073312,
          7.646701901775089,
          7.587723093851966,
          7.519422759657731,
          7.4414825305545875,
          7.353680549313652,
          7.255893691275447,
          7.148098797032878,
          7.030372904295483,
          6.90289247661361,
          6.765931636684276,
          6.619859421926256,
          6.465136089800675,
          6.302308509866994,
          6.1320046887075925,
          5.954927482535561,
          5.771847560432996,
          5.583595688669487,
          5.3910544133476295,
          5.195149224646148,
          4.996839291121254,
          4.797107856831352,
          4.596952397425843,
          4.397374633751995,
          4.199370502960314,
          4.003920187514351,
          3.8119783019311737,
          3.6244643354995882,
          3.4422534466604064,
          3.2661677012123684,
          3.096967842063867,
          2.93534567292897,
          2.781917132219646,
          2.6372161264760465,
          2.501689185072515,
          2.3756909897145873,
          2.259480823484193,
          2.1532199749840197,
          2.056970123569874,
          1.970692721837573,
          1.8942493815466799,
          1.8274032591173583,
          1.7698214268292074,
          1.7210782059824283,
          1.6806594286508267,
          1.6479675853593996,
          1.622327807149682,
          1.6029946221424085,
          1.589159418953044,
          1.5799585422389575,
          1.5744819393283238,
          1.5717822713635923,
          1.5708843977417972,
          1.5707951388966603,
          1.5705132196807678,
          1.5690392937980067,
          1.565385948924981,
          1.5585875923534835,
          1.5477101181822615,
          1.5318602592733872,
          1.5101945303445676,
          1.481927672662136,
          1.446340515789284,
          1.4027871776803316,
          1.3507015310360984,
          1.289602871181384,
          1.2191007287196611,
          1.1388987787822893,
          1.048797807734152,
          0.9486977076340516,
          0.838598478481988,
          0.718600228219159,
          0.5889021704806812,
          0.44980063013519467,
          0.3016860765792271,
          0.14503921448797885,
          -0.019573828839369756,
          -0.1915071713571388,
          -0.3700416426285197,
          -0.554391983919846,
          -0.7437147099488244,
          -0.9371165535775273,
          -1.1336634089047022,
          -1.332389683222141,
          -1.5323079642064488,
          -1.732418905561512,
          -1.931721232139917,
          -2.1292217643753855,
          -2.3239453616649515,
          -2.514944685151065,
          -2.7013096821619005,
          -2.8821766973548266,
          -3.0567371193453083,
          -3.224245476254081,
          -3.384026899122679,
          -3.5354838784760996,
          -3.678102246388148,
          -3.8114563241590256,
          -3.935213184068332,
          -4.049135982536231,
          -4.153086331322284,
          -4.24702568302231,
          -4.331015716992116,
          -4.405217721834387,
          -4.469890980631055,
          -4.525390175087655,
          -4.57216183457853,
          -4.610739865643834,
          -4.641740206695531,
          -4.665854661447693,
          -4.683843972808711,
          -4.696530206577325,
          -4.704788521194349,
          -4.709538405948585,
          -4.711734475357104,
          -4.712356911883456,
          -4.712401652678147,
          -4.712870418588445,
          -4.7147606852637525,
          -4.71905569676247,
          -4.726714621640814,
          -4.738662950077504,
          -4.75578322817514,
          -4.778906222203309,
          -4.808802601244108,
          -4.846175221510629,
          -4.891652089585248,
          -4.945780075027429,
          -5.0090194352982955,
          -5.081739207816623,
          -5.164213515279429,
          -5.25661882123706,
          -5.359032163399057,
          -5.471430382358323,
          -5.593690353455379,
          -5.7255902194613455,
          -5.866811611738424,
          -6.016942837640402,
          -6.175483002241949,
          -6.341847023131357,
          -6.515371488060274,
          -6.695321296805613,
          -6.880897020747521,
          -7.071242906481783,
          -7.26545544333715,
          -7.46259240902249,
          -7.6616823028417365,
          -7.861734072034459,
          -8.061747033865176,
          -8.260720894124754,
          -8.45766576174202,
          -8.651612059242618,
          -8.841620229834934,
          -9.026790143938952,
          -9.206270110983048,
          -9.379265406245594,
          -9.545046227373506,
          -9.702955000919701,
          -9.852412965748888,
          -9.992925967400783,
          -10.12408940539957,
          -10.245592283978755,
          -10.35722032566694,
          -10.458858116562311,
          -10.550490261818084,
          -10.632201539770572,
          -10.704176053166796,
          -10.766695385989252,
          -10.82013578433109,
          -10.864964389545891,
          -10.901734561384409,
          -10.93108033794151,
          -10.9537100878785,
          -10.970399418472613,
          -10.981983410495946,
          -10.989348257665606,
          -10.993422394368135,
          -10.995167200484458,
          -10.99556737637552,
          -10.995621084391091,
          -10.99632995560162,
          -10.998689061802414,
          -11.003676953187103,
          -11.012245861429845,
          -11.025312166259775,
          -11.043747220973154,
          -11.068368628735117,
          -11.099932057009802,
          -11.139123672070026,
          -11.186553269329686,
          -11.242748168275686,
          -11.308147933121331,
          -11.383099972036186,
          -11.467856059011496,
          -11.56256981318305,
          -11.667295160847699,
          -11.781985795571272,
          -11.906495641793134,
          -12.040580317285919,
          -12.183899579828793,
          -12.336020733598955,
          -12.49642296117773,
          -12.66450253780065,
          -12.839578875648215,
          -13.020901337663867,
          -13.207656752681565,
          -13.398977556623962,
          -13.593950478264249,
          -13.79162568259273,
          -13.991026280247771,
          -14.191158107805876,
          -14.391019681013978,
          -14.589612221315232,
          -14.78594965528661,
          -14.979068486876535,
          -15.168037443605838,
          -15.351966800156639,
          -15.530017286005343,
          -15.701408487918675,
          -15.86542666319058,
          -16.02143188539566,
          -16.168864451119074,
          -16.307250483520026,
          -16.43620667662865,
          -16.555444132877223,
          -16.664771255446297,
          -16.764095666467924,
          -16.853425131882176,
          -16.932867483687016,
          -17.002629540360438,
          -17.06301503626285,
          -17.114421580750154,
          -17.157336677441563,
          -17.192332843496228,
          -17.220061877762546,
          -17.241248335185787,
          -17.25668227280589,
          -17.267211339970213,
          -17.273732291951298,
          -17.27718201193252,
          -17.278528131246517,
          -17.278759341773373,
          -17.278875497487665,
          -17.279877604254327,
          -17.282757798092202,
          -17.288489412239493,
          -17.298017232466403,
          -17.312248038195477,
          -17.33204152412881,
          -17.358201693271784,
          -17.39146880752339,
          -17.432511976421345,
          -17.481922458240778,
          -17.54020774051383,
          -17.607786459233953,
          -17.6849842076121,
          -17.772030276346264,
          -17.869055358039503,
          -17.97609023874934,
          -18.093065489767913,
          -18.219812162719144,
          -18.35606348101333,
          -18.501457510725427,
          -18.655540784156493,
          -18.81777283980103,
          -18.987531633266943,
          -19.164119764976462,
          -19.346771462297653,
          -19.534660246204496,
          -19.726907205708716,
          -19.922589797223345,
          -20.12075108076081,
          -20.320409300496806,
          -20.520567713781542,
          -20.720224570194553,
          -20.91838314073518,
          -21.114061696740738,
          -21.306303338625828,
          -21.4941855760417,
          -21.676829563541364,
          -21.853408899286965,
          -22.023157898708817,
          -22.185379260283845,
          -22.339451046685415,
          -22.48483291141233,
          -22.621071508557414,
          -22.747805031555522,
          -22.86476683546989,
          -22.97178810655236,
          -23.068799552350118,
          -23.155832095438708,
          -23.23301656383544,
          -23.300582381193056,
          -23.35885526988663,
          -23.408253989989994,
          -23.449286146789664,
          -23.482543108810233,
          -23.508694087230143,
          -23.52847943596286,
          -23.542703239480684,
          -23.55222526258951,
          -23.557952342750703,
          -23.560829311127215,
          -23.561829533249497,
          -23.56194516400481,
          -23.562177214513817,
          -23.56352553034146,
          -23.566978781377077,
          -23.573504563601556,
          -23.58403971183949,
          -23.599480920481753,
          -23.62067576608064,
          -23.648414221696495,
          -23.68342074795116,
          -23.726347039970197,
          -23.777765502828846,
          -23.838163520823596,
          -23.907938577943305,
          -23.987394278392294,
          -24.07673730700635,
          -24.176075359993256,
          -24.285416066714216,
          -24.40466691330137,
          -24.533636168875592,
          -24.672034805092192,
          -24.819479389796026,
          -24.97549592581637,
          -25.139524596468153,
          -25.31092537024983,
          -25.488984408624898,
          -25.672921212735144,
          -25.861896437494394,
          -26.05502029483145,
          -26.251361461950935,
          -26.449956405426345,
          -26.649819027774765,
          -26.84995053993582,
          -27.049349460813996,
          -27.2470216437732,
          -27.441990229700675,
          -27.63330542699449,
          -27.820054020559684,
          -28.00136851461306,
          -28.176435817761103,
          -28.344505383399703,
          -28.50489672393594,
          -28.65700622360283,
          -28.800313181658648,
          -28.934385025469044,
          -29.058881641279665,
          -29.173558779321645,
          -29.27827049915858,
          -29.372970630793592,
          -29.457713236907793,
          -29.532652071602875,
          -29.5980390410663,
          -29.65422168157075,
          -29.701639680056932,
          -29.74082047213481,
          -29.772373961574363,
          -29.79698641415271,
          -29.81541358699029,
          -29.82847316216295,
          -29.837036560342032,
          -29.84202021642159,
          -29.844376404478247,
          -29.845083703921105,
          -29.8451372022815,
          -29.845538532728863,
          -29.847285846053943,
          -29.851363817516344,
          -29.858733788604656,
          -29.870324142406457,
          -29.887021008946853,
          -29.90965939355057,
          -29.93901481704743,
          -29.975795551516807,
          -30.02063552930403,
          -30.07408799630146,
          -30.136619973035316,
          -30.208607579012153,
          -30.290332267135895,
          -30.38197800589543,
          -30.483629437533427,
          -30.595271030636567,
          -30.71678723563077,
          -30.847963641625046,
          -30.98848912302163,
          -31.1379589544017,
          -31.295878862501,
          -31.461669974708837,
          -31.63467461454724,
          -31.8141628861084,
          -31.999339981528575,
          -32.18935413833927,
          -32.38330516702838,
          -32.58025346343727,
          -32.77922941576362,
          -32.97924311199124,
          -33.17929425055839,
          -33.37838215504327,
          -33.575515792601934,
          -33.769723695858474,
          -33.960063688911745,
          -34.1456323200861,
          -34.3255739069877,
          -34.49908910331109,
          -34.66544290162733,
          -34.82397199203309,
          -34.97409140298777,
          -35.11530035785339,
          -35.247187288502914,
          -35.369433955803046,
          -35.48181863571805,
          -35.584218339136854,
          -35.676610043198885,
          -35.75907092179135,
          -35.831777572909935,
          -35.89500425061875,
          -35.94912011931012,
          -35.994585557754064,
          -36.03194754993967,
          -36.06183420885412,
          -36.08494848802517,
          -36.102061143785136,
          -36.11400301871593,
          -36.12165672353048,
          -36.125947800669046,
          -36.12783545807735,
          -36.128302965936896,
          -36.12834781249227,
          -36.128971717531904,
          -36.13117060350404,
          -36.135924624673734,
          -36.14418835414564,
          -36.156881226996845,
          -36.174878335199885,
          -36.19900166649412,
          -36.23001187491897,
          -36.26860066539966,
          -36.31538386862847,
          -36.370895275573524,
          -36.43558129334179,
          -36.50979647590025,
          -36.593799974399936,
          -36.68775294264117,
          -36.79171692365547,
          -36.905653233557366,
          -37.02942334883443,
          -37.162790293198526,
          -37.3054210101132,
          -37.4568896972446,
          -37.61668206945211,
          -37.78420050763967,
          -37.95877004191835,
          -38.13964510917976,
          -38.32601701742469,
          -38.51702204211759,
          -38.71175007350801,
          -38.9092537283457,
          -39.10855783476521,
          -39.30866919538113,
          -39.5085865308485,
          -39.70731050433744,
          -39.90385372655965,
          -40.09725064118041,
          -40.28656719164598,
          -40.47091017264617,
          -40.649436172587414,
          -40.82136001754823,
          -40.985962632178115,
          -41.14259823884009,
          -41.29070082292051,
          -41.42978979957863,
          -41.55947482520131,
          -41.67945970539315,
          -41.789545360375676,
          -41.88963181810777,
          -41.97971921517226,
          -42.059907795408535,
          -42.13039690630468,
          -42.19148300319705,
          -42.243556681258326,
          -42.28709876498918,
          -42.322675494363864,
          -42.35093285582469,
          -42.372590114881454,
          -42.388432615065376,
          -42.39930391533183,
          -42.40609734462981,
          -42.40974705819081,
          -42.4112186850785,
          -42.411499660633055,
          -42.41158934059821,
          -42.412488995905264,
          -42.41519178828286,
          -42.42067282705338,
          -42.429879406664035,
          -42.44372152269115,
          -42.463062761268326,
          -42.48871165315045,
          -42.52141357897376,
          -42.561843306753744,
          -42.6105982363332,
          -42.668192418414385,
          -42.735051408055114,
          -42.81150800415353,
          -42.89779891757679,
          -42.994062401290755,
          -43.10033686621761,
          -43.2165604966784,
          -43.34257186927109,
          -43.478111568987636,
          -43.622824786390574,
          -43.77626486984647,
          -43.93789779725308,
          -44.107107522490175,
          -44.28320214306775,
          -44.46542082722252,
          -44.652941431111714,
          -44.844888729842445,
          -45.04034317993134,
          -45.23835012546662,
          -45.4379293558045,
          -45.638084919110675,
          -45.83781509349772,
          -46.036122415929896,
          -46.23202366849026,
          -46.42455972202985,
          -46.612805138648746,
          -46.795877436871066,
          -46.972945926754996,
          -47.14324002648297,
          -47.30605697716966,
          -47.46076887864912,
          -47.60682897580174,
          -47.74377713248377,
          -47.87124443825692,
          -47.9889569017963,
          -48.096738194000245,
          -48.19451141333825,
          -48.28229985576355,
          -48.36022678148169,
          -48.42851418091065,
          -48.48748055218674,
          -48.537537712467746,
          -48.57918667495698,
          -48.61301263292644,
          -48.639679100957125,
          -48.65992127205264,
          -48.67453865713234,
          -48.684387080594945,
          -48.69037011209046,
          -48.693430020282555,
          -48.69453833916932,
          -48.69468614140931,
          -48.694874116033034,
          -48.69610254987848,
          -48.699361313053345,
          -48.705619948686056,
          -48.715817966183664,
          -48.730855435177446,
          -48.751583974326245,
          -48.778798225194876,
          -48.813227896568065,
          -48.855530458849834,
          -48.90628456168927,
          -48.96598424073354,
          -49.035033971507886
         ]
        }
       ],
       "layout": {
        "template": {
         "data": {
          "bar": [
           {
            "error_x": {
             "color": "#2a3f5f"
            },
            "error_y": {
             "color": "#2a3f5f"
            },
            "marker": {
             "line": {
              "color": "#E5ECF6",
              "width": 0.5
             }
            },
            "type": "bar"
           }
          ],
          "barpolar": [
           {
            "marker": {
             "line": {
              "color": "#E5ECF6",
              "width": 0.5
             }
            },
            "type": "barpolar"
           }
          ],
          "carpet": [
           {
            "aaxis": {
             "endlinecolor": "#2a3f5f",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "#2a3f5f"
            },
            "baxis": {
             "endlinecolor": "#2a3f5f",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "#2a3f5f"
            },
            "type": "carpet"
           }
          ],
          "choropleth": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "choropleth"
           }
          ],
          "contour": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "contour"
           }
          ],
          "contourcarpet": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "contourcarpet"
           }
          ],
          "heatmap": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "heatmap"
           }
          ],
          "heatmapgl": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "heatmapgl"
           }
          ],
          "histogram": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "histogram"
           }
          ],
          "histogram2d": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "histogram2d"
           }
          ],
          "histogram2dcontour": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "histogram2dcontour"
           }
          ],
          "mesh3d": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "mesh3d"
           }
          ],
          "parcoords": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "parcoords"
           }
          ],
          "pie": [
           {
            "automargin": true,
            "type": "pie"
           }
          ],
          "scatter": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatter"
           }
          ],
          "scatter3d": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatter3d"
           }
          ],
          "scattercarpet": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattercarpet"
           }
          ],
          "scattergeo": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattergeo"
           }
          ],
          "scattergl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattergl"
           }
          ],
          "scattermapbox": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattermapbox"
           }
          ],
          "scatterpolar": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterpolar"
           }
          ],
          "scatterpolargl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterpolargl"
           }
          ],
          "scatterternary": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterternary"
           }
          ],
          "surface": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "surface"
           }
          ],
          "table": [
           {
            "cells": {
             "fill": {
              "color": "#EBF0F8"
             },
             "line": {
              "color": "white"
             }
            },
            "header": {
             "fill": {
              "color": "#C8D4E3"
             },
             "line": {
              "color": "white"
             }
            },
            "type": "table"
           }
          ]
         },
         "layout": {
          "annotationdefaults": {
           "arrowcolor": "#2a3f5f",
           "arrowhead": 0,
           "arrowwidth": 1
          },
          "coloraxis": {
           "colorbar": {
            "outlinewidth": 0,
            "ticks": ""
           }
          },
          "colorscale": {
           "diverging": [
            [
             0,
             "#8e0152"
            ],
            [
             0.1,
             "#c51b7d"
            ],
            [
             0.2,
             "#de77ae"
            ],
            [
             0.3,
             "#f1b6da"
            ],
            [
             0.4,
             "#fde0ef"
            ],
            [
             0.5,
             "#f7f7f7"
            ],
            [
             0.6,
             "#e6f5d0"
            ],
            [
             0.7,
             "#b8e186"
            ],
            [
             0.8,
             "#7fbc41"
            ],
            [
             0.9,
             "#4d9221"
            ],
            [
             1,
             "#276419"
            ]
           ],
           "sequential": [
            [
             0,
             "#0d0887"
            ],
            [
             0.1111111111111111,
             "#46039f"
            ],
            [
             0.2222222222222222,
             "#7201a8"
            ],
            [
             0.3333333333333333,
             "#9c179e"
            ],
            [
             0.4444444444444444,
             "#bd3786"
            ],
            [
             0.5555555555555556,
             "#d8576b"
            ],
            [
             0.6666666666666666,
             "#ed7953"
            ],
            [
             0.7777777777777778,
             "#fb9f3a"
            ],
            [
             0.8888888888888888,
             "#fdca26"
            ],
            [
             1,
             "#f0f921"
            ]
           ],
           "sequentialminus": [
            [
             0,
             "#0d0887"
            ],
            [
             0.1111111111111111,
             "#46039f"
            ],
            [
             0.2222222222222222,
             "#7201a8"
            ],
            [
             0.3333333333333333,
             "#9c179e"
            ],
            [
             0.4444444444444444,
             "#bd3786"
            ],
            [
             0.5555555555555556,
             "#d8576b"
            ],
            [
             0.6666666666666666,
             "#ed7953"
            ],
            [
             0.7777777777777778,
             "#fb9f3a"
            ],
            [
             0.8888888888888888,
             "#fdca26"
            ],
            [
             1,
             "#f0f921"
            ]
           ]
          },
          "colorway": [
           "#636efa",
           "#EF553B",
           "#00cc96",
           "#ab63fa",
           "#FFA15A",
           "#19d3f3",
           "#FF6692",
           "#B6E880",
           "#FF97FF",
           "#FECB52"
          ],
          "font": {
           "color": "#2a3f5f"
          },
          "geo": {
           "bgcolor": "white",
           "lakecolor": "white",
           "landcolor": "#E5ECF6",
           "showlakes": true,
           "showland": true,
           "subunitcolor": "white"
          },
          "hoverlabel": {
           "align": "left"
          },
          "hovermode": "closest",
          "mapbox": {
           "style": "light"
          },
          "paper_bgcolor": "white",
          "plot_bgcolor": "#E5ECF6",
          "polar": {
           "angularaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "bgcolor": "#E5ECF6",
           "radialaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           }
          },
          "scene": {
           "xaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           },
           "yaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           },
           "zaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           }
          },
          "shapedefaults": {
           "line": {
            "color": "#2a3f5f"
           }
          },
          "ternary": {
           "aaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "baxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "bgcolor": "#E5ECF6",
           "caxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           }
          },
          "title": {
           "x": 0.05
          },
          "xaxis": {
           "automargin": true,
           "gridcolor": "white",
           "linecolor": "white",
           "ticks": "",
           "title": {
            "standoff": 15
           },
           "zerolinecolor": "white",
           "zerolinewidth": 2
          },
          "yaxis": {
           "automargin": true,
           "gridcolor": "white",
           "linecolor": "white",
           "ticks": "",
           "title": {
            "standoff": 15
           },
           "zerolinecolor": "white",
           "zerolinewidth": 2
          }
         }
        },
        "title": {
         "text": "Transcendental Equation Inspection"
        },
        "xaxis": {
         "dtick": 5,
         "range": [
          -20,
          20
         ],
         "showticklabels": true,
         "tick0": 0,
         "tickangle": -90,
         "ticks": "outside",
         "title": {
          "font": {
           "color": "black",
           "family": "Arial, serif",
           "size": 18
          },
          "text": "x"
         }
        },
        "yaxis": {
         "dtick": 5,
         "range": [
          -20,
          20
         ],
         "tick0": 0,
         "ticks": "outside",
         "title": {
          "font": {
           "color": "black",
           "family": "Arial, serif",
           "size": 18
          },
          "text": "P(x)"
         }
        }
       }
      },
      "text/html": [
       "<div>\n",
       "        \n",
       "        \n",
       "            <div id=\"deab80a1-0f14-4227-99d9-d2fe34003e3f\" class=\"plotly-graph-div\" style=\"height:525px; width:100%;\"></div>\n",
       "            <script type=\"text/javascript\">\n",
       "                require([\"plotly\"], function(Plotly) {\n",
       "                    window.PLOTLYENV=window.PLOTLYENV || {};\n",
       "                    \n",
       "                if (document.getElementById(\"deab80a1-0f14-4227-99d9-d2fe34003e3f\")) {\n",
       "                    Plotly.newPlot(\n",
       "                        'deab80a1-0f14-4227-99d9-d2fe34003e3f',\n",
       "                        [{\"line\": {\"color\": \"black\"}, \"name\": \"P(x) = cos(x) - x\", \"type\": \"scatter\", \"x\": [-50.0, -49.8998998998999, -49.7997997997998, -49.6996996996997, -49.5995995995996, -49.4994994994995, -49.3993993993994, -49.2992992992993, -49.1991991991992, -49.0990990990991, -48.998998998999, -48.8988988988989, -48.7987987987988, -48.6986986986987, -48.5985985985986, -48.4984984984985, -48.3983983983984, -48.2982982982983, -48.1981981981982, -48.0980980980981, -47.997997997998, -47.8978978978979, -47.7977977977978, -47.6976976976977, -47.5975975975976, -47.4974974974975, -47.3973973973974, -47.2972972972973, -47.1971971971972, -47.0970970970971, -46.996996996997, -46.8968968968969, -46.7967967967968, -46.6966966966967, -46.5965965965966, -46.4964964964965, -46.3963963963964, -46.2962962962963, -46.1961961961962, -46.0960960960961, -45.995995995996, -45.8958958958959, -45.7957957957958, -45.6956956956957, -45.5955955955956, -45.4954954954955, -45.3953953953954, -45.2952952952953, -45.1951951951952, -45.0950950950951, -44.994994994995, -44.8948948948949, -44.7947947947948, -44.6946946946947, -44.5945945945946, -44.4944944944945, -44.394394394394396, -44.294294294294296, -44.194194194194196, -44.094094094094096, -43.993993993993996, -43.893893893893896, -43.793793793793796, -43.693693693693696, -43.593593593593596, -43.493493493493496, -43.393393393393396, -43.293293293293296, -43.193193193193196, -43.093093093093096, -42.992992992992995, -42.892892892892895, -42.792792792792795, -42.692692692692695, -42.592592592592595, -42.49249249249249, -42.392392392392395, -42.29229229229229, -42.192192192192195, -42.09209209209209, -41.991991991991995, -41.89189189189189, -41.791791791791795, -41.69169169169169, -41.591591591591595, -41.49149149149149, -41.391391391391394, -41.29129129129129, -41.191191191191194, -41.09109109109109, -40.990990990990994, -40.89089089089089, -40.790790790790794, -40.69069069069069, -40.590590590590594, -40.49049049049049, -40.390390390390394, -40.29029029029029, -40.190190190190194, -40.09009009009009, -39.98998998998999, -39.889889889889886, -39.78978978978979, -39.689689689689686, -39.58958958958959, -39.489489489489486, -39.38938938938939, -39.289289289289286, -39.189189189189186, -39.089089089089086, -38.988988988988986, -38.888888888888886, -38.788788788788786, -38.688688688688686, -38.588588588588586, -38.488488488488485, -38.388388388388385, -38.288288288288285, -38.188188188188185, -38.088088088088085, -37.987987987987985, -37.887887887887885, -37.787787787787785, -37.687687687687685, -37.587587587587585, -37.487487487487485, -37.387387387387385, -37.287287287287285, -37.187187187187185, -37.087087087087085, -36.986986986986985, -36.886886886886884, -36.786786786786784, -36.686686686686684, -36.586586586586584, -36.486486486486484, -36.386386386386384, -36.286286286286284, -36.186186186186184, -36.086086086086084, -35.985985985985984, -35.885885885885884, -35.785785785785784, -35.685685685685684, -35.585585585585584, -35.48548548548548, -35.38538538538538, -35.28528528528528, -35.18518518518518, -35.08508508508508, -34.98498498498498, -34.88488488488488, -34.78478478478478, -34.68468468468468, -34.58458458458458, -34.48448448448448, -34.38438438438438, -34.28428428428428, -34.18418418418418, -34.08408408408408, -33.98398398398398, -33.88388388388388, -33.78378378378378, -33.68368368368368, -33.58358358358358, -33.48348348348348, -33.38338338338338, -33.28328328328328, -33.18318318318318, -33.08308308308308, -32.98298298298298, -32.88288288288288, -32.78278278278278, -32.68268268268268, -32.58258258258258, -32.48248248248248, -32.38238238238238, -32.28228228228228, -32.18218218218218, -32.08208208208208, -31.98198198198198, -31.88188188188188, -31.78178178178178, -31.68168168168168, -31.58158158158158, -31.48148148148148, -31.38138138138138, -31.28128128128128, -31.18118118118118, -31.08108108108108, -30.98098098098098, -30.88088088088088, -30.78078078078078, -30.68068068068068, -30.58058058058058, -30.48048048048048, -30.38038038038038, -30.28028028028028, -30.18018018018018, -30.08008008008008, -29.97997997997998, -29.87987987987988, -29.77977977977978, -29.67967967967968, -29.57957957957958, -29.47947947947948, -29.37937937937938, -29.27927927927928, -29.17917917917918, -29.07907907907908, -28.97897897897898, -28.87887887887888, -28.77877877877878, -28.67867867867868, -28.578578578578576, -28.478478478478475, -28.378378378378375, -28.278278278278275, -28.178178178178175, -28.078078078078075, -27.977977977977975, -27.877877877877875, -27.777777777777775, -27.677677677677675, -27.577577577577575, -27.477477477477475, -27.377377377377375, -27.277277277277275, -27.177177177177175, -27.077077077077075, -26.976976976976974, -26.876876876876874, -26.776776776776774, -26.676676676676674, -26.576576576576574, -26.476476476476474, -26.376376376376374, -26.276276276276274, -26.176176176176174, -26.076076076076074, -25.975975975975974, -25.875875875875874, -25.775775775775774, -25.675675675675674, -25.575575575575574, -25.475475475475474, -25.375375375375373, -25.275275275275273, -25.175175175175173, -25.075075075075073, -24.974974974974973, -24.874874874874873, -24.774774774774773, -24.674674674674673, -24.574574574574573, -24.474474474474473, -24.374374374374373, -24.274274274274273, -24.174174174174173, -24.074074074074073, -23.973973973973973, -23.873873873873872, -23.773773773773772, -23.673673673673672, -23.573573573573572, -23.473473473473472, -23.373373373373372, -23.273273273273272, -23.173173173173172, -23.073073073073072, -22.972972972972972, -22.872872872872872, -22.772772772772772, -22.67267267267267, -22.57257257257257, -22.47247247247247, -22.37237237237237, -22.27227227227227, -22.17217217217217, -22.07207207207207, -21.97197197197197, -21.87187187187187, -21.77177177177177, -21.67167167167167, -21.57157157157157, -21.47147147147147, -21.37137137137137, -21.27127127127127, -21.17117117117117, -21.07107107107107, -20.97097097097097, -20.87087087087087, -20.77077077077077, -20.67067067067067, -20.57057057057057, -20.47047047047047, -20.37037037037037, -20.27027027027027, -20.17017017017017, -20.070070070070066, -19.969969969969966, -19.869869869869866, -19.769769769769766, -19.669669669669666, -19.569569569569566, -19.469469469469466, -19.369369369369366, -19.269269269269266, -19.169169169169166, -19.069069069069066, -18.968968968968966, -18.868868868868866, -18.768768768768766, -18.668668668668666, -18.568568568568566, -18.468468468468465, -18.368368368368365, -18.268268268268265, -18.168168168168165, -18.068068068068065, -17.967967967967965, -17.867867867867865, -17.767767767767765, -17.667667667667665, -17.567567567567565, -17.467467467467465, -17.367367367367365, -17.267267267267265, -17.167167167167165, -17.067067067067065, -16.966966966966964, -16.866866866866864, -16.766766766766764, -16.666666666666664, -16.566566566566564, -16.466466466466464, -16.366366366366364, -16.266266266266264, -16.166166166166164, -16.066066066066064, -15.965965965965964, -15.865865865865864, -15.765765765765764, -15.665665665665664, -15.565565565565564, -15.465465465465464, -15.365365365365363, -15.265265265265263, -15.165165165165163, -15.065065065065063, -14.964964964964963, -14.864864864864863, -14.764764764764763, -14.664664664664663, -14.564564564564563, -14.464464464464463, -14.364364364364363, -14.264264264264263, -14.164164164164163, -14.064064064064063, -13.963963963963963, -13.863863863863862, -13.763763763763762, -13.663663663663662, -13.563563563563562, -13.463463463463462, -13.363363363363362, -13.263263263263262, -13.163163163163162, -13.063063063063062, -12.962962962962962, -12.862862862862862, -12.762762762762762, -12.662662662662662, -12.562562562562562, -12.462462462462462, -12.362362362362362, -12.262262262262261, -12.162162162162161, -12.062062062062061, -11.961961961961961, -11.861861861861861, -11.761761761761761, -11.661661661661661, -11.561561561561561, -11.461461461461461, -11.36136136136136, -11.26126126126126, -11.16116116116116, -11.06106106106106, -10.96096096096096, -10.86086086086086, -10.76076076076076, -10.66066066066066, -10.56056056056056, -10.46046046046046, -10.36036036036036, -10.26026026026026, -10.16016016016016, -10.06006006006006, -9.95995995995996, -9.85985985985986, -9.75975975975976, -9.65965965965966, -9.55955955955956, -9.45945945945946, -9.35935935935936, -9.25925925925926, -9.15915915915916, -9.05905905905906, -8.95895895895896, -8.85885885885886, -8.75875875875876, -8.65865865865866, -8.558558558558559, -8.458458458458459, -8.358358358358359, -8.258258258258259, -8.158158158158159, -8.058058058058059, -7.957957957957959, -7.857857857857859, -7.7577577577577586, -7.6576576576576585, -7.557557557557558, -7.457457457457458, -7.357357357357358, -7.257257257257251, -7.157157157157151, -7.057057057057051, -6.956956956956951, -6.856856856856851, -6.756756756756751, -6.656656656656651, -6.556556556556551, -6.456456456456451, -6.3563563563563505, -6.2562562562562505, -6.15615615615615, -6.05605605605605, -5.95595595595595, -5.85585585585585, -5.75575575575575, -5.65565565565565, -5.55555555555555, -5.45545545545545, -5.35535535535535, -5.25525525525525, -5.15515515515515, -5.05505505505505, -4.95495495495495, -4.85485485485485, -4.7547547547547495, -4.6546546546546494, -4.554554554554549, -4.454454454454449, -4.354354354354349, -4.254254254254249, -4.154154154154149, -4.054054054054049, -3.953953953953949, -3.853853853853849, -3.753753753753749, -3.653653653653649, -3.5535535535535487, -3.4534534534534487, -3.3533533533533486, -3.2532532532532485, -3.1531531531531485, -3.0530530530530484, -2.9529529529529484, -2.8528528528528483, -2.7527527527527482, -2.652652652652648, -2.552552552552548, -2.452452452452448, -2.352352352352348, -2.252252252252248, -2.152152152152148, -2.0520520520520478, -1.9519519519519477, -1.8518518518518476, -1.7517517517517476, -1.6516516516516475, -1.5515515515515474, -1.4514514514514474, -1.3513513513513473, -1.2512512512512473, -1.1511511511511472, -1.0510510510510471, -0.9509509509509471, -0.850850850850847, -0.7507507507507469, -0.6506506506506469, -0.5505505505505468, -0.45045045045044674, -0.3503503503503467, -0.2502502502502466, -0.15015015015014654, -0.05005005005004648, 0.050050050050053585, 0.15015015015015365, 0.2502502502502537, 0.3503503503503538, 0.45045045045045384, 0.5505505505505539, 0.650650650650654, 0.750750750750754, 0.8508508508508541, 0.9509509509509542, 1.0510510510510542, 1.1511511511511543, 1.2512512512512544, 1.3513513513513544, 1.4514514514514545, 1.5515515515515546, 1.6516516516516546, 1.7517517517517547, 1.8518518518518547, 1.9519519519519548, 2.052052052052055, 2.152152152152155, 2.252252252252255, 2.352352352352355, 2.452452452452455, 2.552552552552555, 2.6526526526526553, 2.7527527527527553, 2.8528528528528554, 2.9529529529529555, 3.0530530530530555, 3.1531531531531556, 3.2532532532532557, 3.3533533533533557, 3.453453453453456, 3.553553553553556, 3.653653653653656, 3.753753753753756, 3.853853853853856, 3.953953953953956, 4.054054054054056, 4.154154154154156, 4.254254254254256, 4.354354354354356, 4.454454454454456, 4.5545545545545565, 4.6546546546546566, 4.754754754754757, 4.854854854854857, 4.954954954954957, 5.055055055055057, 5.155155155155157, 5.255255255255257, 5.355355355355357, 5.455455455455457, 5.555555555555557, 5.655655655655657, 5.755755755755757, 5.855855855855857, 5.955955955955957, 6.0560560560560575, 6.1561561561561575, 6.256256256256258, 6.356356356356358, 6.456456456456458, 6.556556556556558, 6.656656656656658, 6.756756756756758, 6.856856856856858, 6.956956956956958, 7.057057057057058, 7.157157157157158, 7.257257257257258, 7.357357357357358, 7.457457457457458, 7.557557557557558, 7.6576576576576585, 7.7577577577577586, 7.857857857857859, 7.957957957957959, 8.058058058058059, 8.158158158158159, 8.258258258258259, 8.358358358358359, 8.458458458458459, 8.558558558558559, 8.65865865865866, 8.75875875875876, 8.85885885885886, 8.95895895895896, 9.05905905905906, 9.15915915915916, 9.25925925925926, 9.35935935935936, 9.45945945945946, 9.55955955955956, 9.65965965965966, 9.75975975975976, 9.859859859859867, 9.959959959959967, 10.060060060060067, 10.160160160160167, 10.260260260260267, 10.360360360360367, 10.460460460460467, 10.560560560560567, 10.660660660660668, 10.760760760760768, 10.860860860860868, 10.960960960960968, 11.061061061061068, 11.161161161161168, 11.261261261261268, 11.361361361361368, 11.461461461461468, 11.561561561561568, 11.661661661661668, 11.761761761761768, 11.861861861861868, 11.961961961961968, 12.062062062062068, 12.162162162162168, 12.262262262262269, 12.362362362362369, 12.462462462462469, 12.562562562562569, 12.662662662662669, 12.762762762762769, 12.862862862862869, 12.962962962962969, 13.063063063063069, 13.16316316316317, 13.26326326326327, 13.36336336336337, 13.46346346346347, 13.56356356356357, 13.66366366366367, 13.76376376376377, 13.86386386386387, 13.96396396396397, 14.06406406406407, 14.164164164164163, 14.26426426426427, 14.364364364364363, 14.46446446446447, 14.564564564564563, 14.66466466466467, 14.764764764764763, 14.86486486486487, 14.964964964964963, 15.06506506506507, 15.165165165165163, 15.26526526526527, 15.365365365365363, 15.46546546546547, 15.565565565565564, 15.66566566566567, 15.765765765765764, 15.86586586586587, 15.965965965965964, 16.06606606606607, 16.166166166166164, 16.26626626626627, 16.366366366366364, 16.46646646646647, 16.566566566566564, 16.66666666666667, 16.766766766766764, 16.86686686686687, 16.966966966966964, 17.06706706706707, 17.167167167167165, 17.267267267267272, 17.367367367367365, 17.467467467467472, 17.567567567567565, 17.667667667667672, 17.767767767767765, 17.867867867867872, 17.967967967967965, 18.068068068068072, 18.168168168168165, 18.268268268268272, 18.36836836836838, 18.468468468468473, 18.56856856856858, 18.668668668668673, 18.76876876876878, 18.868868868868873, 18.96896896896898, 19.069069069069073, 19.16916916916918, 19.269269269269273, 19.36936936936938, 19.469469469469473, 19.56956956956958, 19.669669669669673, 19.76976976976978, 19.869869869869873, 19.96996996996998, 20.070070070070074, 20.17017017017018, 20.270270270270274, 20.37037037037038, 20.470470470470474, 20.57057057057058, 20.670670670670674, 20.77077077077078, 20.870870870870874, 20.97097097097098, 21.071071071071074, 21.17117117117118, 21.271271271271274, 21.37137137137138, 21.471471471471475, 21.57157157157158, 21.671671671671675, 21.771771771771782, 21.871871871871875, 21.971971971971982, 22.072072072072075, 22.172172172172182, 22.272272272272275, 22.372372372372382, 22.472472472472475, 22.572572572572582, 22.672672672672675, 22.772772772772782, 22.872872872872875, 22.972972972972983, 23.073073073073076, 23.173173173173183, 23.273273273273276, 23.373373373373383, 23.473473473473476, 23.573573573573583, 23.673673673673676, 23.773773773773783, 23.873873873873876, 23.973973973973983, 24.074074074074076, 24.174174174174183, 24.274274274274276, 24.374374374374383, 24.474474474474476, 24.574574574574584, 24.674674674674677, 24.774774774774784, 24.874874874874877, 24.974974974974984, 25.075075075075077, 25.175175175175184, 25.275275275275277, 25.375375375375384, 25.475475475475477, 25.575575575575584, 25.675675675675677, 25.775775775775784, 25.875875875875877, 25.975975975975985, 26.076076076076077, 26.176176176176185, 26.276276276276278, 26.376376376376385, 26.476476476476478, 26.576576576576585, 26.676676676676678, 26.776776776776785, 26.876876876876878, 26.976976976976985, 27.077077077077078, 27.177177177177185, 27.27727727727728, 27.377377377377385, 27.47747747747748, 27.577577577577586, 27.67767767767768, 27.777777777777786, 27.87787787787788, 27.977977977977986, 28.07807807807808, 28.178178178178186, 28.27827827827828, 28.378378378378386, 28.47847847847848, 28.578578578578586, 28.67867867867868, 28.778778778778786, 28.87887887887888, 28.978978978978986, 29.07907907907908, 29.179179179179187, 29.27927927927928, 29.379379379379387, 29.47947947947948, 29.579579579579587, 29.67967967967968, 29.779779779779787, 29.87987987987988, 29.979979979979987, 30.08008008008008, 30.180180180180187, 30.28028028028028, 30.380380380380387, 30.48048048048048, 30.580580580580587, 30.68068068068068, 30.780780780780788, 30.88088088088088, 30.980980980980988, 31.08108108108108, 31.181181181181188, 31.28128128128128, 31.381381381381388, 31.48148148148148, 31.581581581581588, 31.68168168168168, 31.78178178178179, 31.88188188188188, 31.98198198198199, 32.08208208208208, 32.18218218218219, 32.28228228228228, 32.38238238238239, 32.48248248248248, 32.58258258258259, 32.68268268268268, 32.78278278278279, 32.88288288288288, 32.98298298298299, 33.08308308308308, 33.18318318318319, 33.28328328328328, 33.38338338338339, 33.48348348348348, 33.58358358358359, 33.68368368368368, 33.78378378378379, 33.88388388388388, 33.98398398398399, 34.08408408408408, 34.18418418418419, 34.28428428428428, 34.38438438438439, 34.48448448448448, 34.58458458458459, 34.68468468468468, 34.78478478478479, 34.88488488488488, 34.98498498498499, 35.08508508508508, 35.18518518518519, 35.28528528528528, 35.38538538538539, 35.4854854854855, 35.58558558558559, 35.6856856856857, 35.78578578578579, 35.8858858858859, 35.98598598598599, 36.0860860860861, 36.18618618618619, 36.2862862862863, 36.38638638638639, 36.4864864864865, 36.58658658658659, 36.6866866866867, 36.78678678678679, 36.8868868868869, 36.98698698698699, 37.0870870870871, 37.18718718718719, 37.2872872872873, 37.38738738738739, 37.4874874874875, 37.58758758758759, 37.6876876876877, 37.78778778778779, 37.8878878878879, 37.98798798798799, 38.0880880880881, 38.18818818818819, 38.2882882882883, 38.38838838838839, 38.4884884884885, 38.58858858858859, 38.6886886886887, 38.78878878878879, 38.8888888888889, 38.98898898898899, 39.0890890890891, 39.18918918918919, 39.2892892892893, 39.38938938938939, 39.4894894894895, 39.58958958958959, 39.6896896896897, 39.78978978978979, 39.8898898898899, 39.98998998998999, 40.0900900900901, 40.190190190190194, 40.2902902902903, 40.390390390390394, 40.4904904904905, 40.590590590590594, 40.6906906906907, 40.790790790790794, 40.8908908908909, 40.990990990990994, 41.0910910910911, 41.191191191191194, 41.2912912912913, 41.391391391391394, 41.4914914914915, 41.591591591591595, 41.6916916916917, 41.791791791791795, 41.8918918918919, 41.991991991991995, 42.0920920920921, 42.192192192192195, 42.2922922922923, 42.392392392392395, 42.4924924924925, 42.592592592592595, 42.6926926926927, 42.792792792792795, 42.8928928928929, 42.992992992992995, 43.0930930930931, 43.193193193193196, 43.2932932932933, 43.393393393393396, 43.4934934934935, 43.593593593593596, 43.6936936936937, 43.793793793793796, 43.8938938938939, 43.993993993993996, 44.0940940940941, 44.194194194194196, 44.2942942942943, 44.394394394394396, 44.494494494494504, 44.5945945945946, 44.694694694694704, 44.7947947947948, 44.894894894894904, 44.994994994995, 45.095095095095104, 45.1951951951952, 45.295295295295304, 45.3953953953954, 45.495495495495504, 45.5955955955956, 45.695695695695704, 45.7957957957958, 45.895895895895904, 45.995995995996, 46.096096096096105, 46.1961961961962, 46.296296296296305, 46.3963963963964, 46.496496496496505, 46.5965965965966, 46.696696696696705, 46.7967967967968, 46.896896896896905, 46.996996996997, 47.097097097097105, 47.1971971971972, 47.297297297297305, 47.3973973973974, 47.497497497497505, 47.5975975975976, 47.697697697697706, 47.7977977977978, 47.897897897897906, 47.997997997998, 48.098098098098106, 48.1981981981982, 48.298298298298306, 48.3983983983984, 48.498498498498506, 48.5985985985986, 48.698698698698706, 48.7987987987988, 48.898898898898906, 48.998998998999, 49.09909909909911, 49.1991991991992, 49.29929929929931, 49.3993993993994, 49.49949949949951, 49.5995995995996, 49.69969969969971, 49.7997997997998, 49.89989989989991, 50.0], \"y\": [50.964966028492114, 50.83381555906627, 50.69331503791033, 50.54386894054957, 50.385971302631134, 50.22020077380413, 50.047214824472555, 49.86774316342115, 49.682580432214735, 49.49257824951214, 49.298636684944654, 49.10169524791932, 48.902723481564564, 48.702711255988085, 48.50265885802788, 48.30356697671445, 48.106426684706335, 47.91220951600165, 47.72185773926406, 47.536274924143555, 47.35631689503887, 47.18278316286936, 47.01640892063862, 46.85785768292766, 46.70771464300846, 46.56648081408435, 46.434568013313104, 46.312294738831056, 46.19988298105615, 46.09745600019396, 46.005037092197696, 45.92254935553688, 45.849816461109825, 45.78656441759167, 45.732424314544076, 45.68693601582335, 45.649552766309824, 45.61964666583761, 45.59651495552133, 45.579387053543456, 45.56743226996215, 45.55976812330155, 45.5554691756617, 45.55357629789369, 45.55310627208052, 45.55306163518651, 45.55244066532418, 45.55024741065927, 45.54550166054795, 45.537248759078494, 45.52456916276747, 45.50658764672206, 45.48248206709942, 45.45149159213632, 45.41292431934272, 45.366164202598426, 45.31067721980116, 45.24601671931752, 45.171827891709995, 45.08785132197059, 44.99392558669724, 44.889988870211006, 44.77607958343406, 44.652335979332285, 44.51899476877281, 44.376388750653796, 44.22494348003305, 44.065173007612835, 43.89767473323594, 43.723123424917866, 43.54226446329484, 43.355906379121755, 43.16491275853221, 42.97019359710253, 42.77269618927993, 42.573395644386764, 42.373285124151735, 42.173365899506074, 41.97463732619358, 41.77808683955436, 41.58468006865216, 41.395351168718406, 41.210993468702135, 41.032450527558694, 40.860507688819325, 40.6958842179938, 40.53922610152446, 40.39109957938553, 40.25198547607771, 40.12227438677365, 40.00226276680973, 39.89214996367401, 39.79203622120591, 39.70192167598824, 39.621706355979875, 39.55119118140236, 39.490079957860274, 39.43798234174051, 39.39441774820227, 39.35882016263197, 39.33054380739257, 39.30886960713363, 39.29301238793361, 39.28212873819899, 39.27532545261953, 39.27166847464156, 39.27019224793029, 39.26990938319747, 39.26982054361318, 39.2689244498325, 39.26622790446998, 39.26075573566021, 39.251560560152896, 39.23773226819764, 39.21840713525883, 39.192776469337325, 39.16009470732467, 39.119686879331994, 39.07095536626318, 39.01338588297766, 38.94655262714156, 38.87012254221842, 38.783858651920106, 38.687622432734216, 38.58137520077524, 38.465178499074725, 38.339193481432986, 38.20367929900105, 38.0589905057459, 37.905573508774516, 37.743962099055004, 37.57477210727965, 37.39869523837368, 37.216492146376524, 37.028984819027535, 36.837048348299234, 36.64160216926873, 36.443600855040664, 36.244024559880096, 36.04386920623527, 35.84413651389462, 35.64582397110272, 35.44991484804109, 35.25736835265544, 35.06911002738603, 34.886022482945805, 34.708936561916644, 34.538623020630894, 34.3757848126163, 34.22105005086004, 34.074965719351226, 33.93799219685983, 33.81049864777822, 33.69275932617048, 33.58495083003232, 33.487150333250916, 33.399334812965726, 33.32138128006565, 33.25306801051498, 33.1940767651804, 33.143995975934885, 33.102324866140435, 33.06847846425648, 33.041793460379665, 33.02153484708108, 33.00690327805522, 32.997043070908305, 32.99105077396463, 32.98798421132311, 32.98687191560777, 32.98672285397474, 32.98653635000214, 32.985312102128304, 32.98206019833698, 32.97581102682591, 32.965624983436385, 32.95060187865638, 32.92988995001732, 32.90269438965554, 32.868285301663164, 32.82600500956227, 32.77527464074213, 32.71559992193853, 32.646576127732594, 32.5678921325266, 32.47933352542953, 32.380784756867335, 32.27223029542667, 32.153754783350216, 32.025542189126845, 31.887873965660503, 31.74112623245773, 31.585766010044757, 31.422346544313932, 31.251501767610595, 31.073939952014108, 30.890436618354304, 30.701826771955904, 30.508996542844017, 30.312874314106217, 30.114421427231097, 29.91462255747826, 29.714475855638455, 29.514982954881113, 29.317138942737568, 29.121922398616928, 28.93028559659581, 28.74314497156827, 28.561371944205654, 28.385784196583796, 28.217137485823148, 28.056118077700827, 27.903335875986812, 27.759318316291058, 27.624505085554283, 27.49924372004916, 27.383786125963166, 27.278286057397974, 27.18279757703472, 27.09727451487649, 27.02157093048692, 26.955442574097106, 26.898549331952733, 26.850458631419414, 26.810649771755465, 26.778519137193854, 26.753386240141708, 26.734500533994872, 26.721048927359877, 26.71216392445348, 26.706932310180772, 26.70440429293976, 26.70360301361775, 26.70353432557859, 26.703196747726825, 26.70159149100202, 26.69773245792132, 26.69065611505816, 26.679431139617222, 26.663167743527257, 26.641026581702135, 26.612227155283602, 26.57605562573519, 26.53187196155533, 26.479116346058973, 26.41731478207536, 26.34608383744939, 26.265134483836334, 26.1742749903571, 26.0734128431438, 25.96255567155766, 25.84181117180644, 25.711386028725958, 25.571583846520504, 25.422802109178953, 25.265528200997785, 25.100334527052254, 24.927872782467904, 24.748867427866593, 24.564108436308654, 24.37444338434639, 24.180768966370668, 23.984022017206083, 23.785170132833528, 23.585201983142333, 23.385117413697447, 23.18591743561953, 22.98859420379584, 22.794121083756835, 22.603442906665464, 22.417466509983083, 22.2370516585156, 22.063002436735314, 21.89605919855568, 21.736891155155153, 21.586089675058318, 21.444162363551694, 21.311527980709105, 21.188512248905646, 21.07534459179403, 20.972155837391593, 20.878976908273856, 20.795738511988034, 20.722271834785932, 20.65831023173083, 20.603491896257534, 20.55736348245891, 20.51938464383373, 20.488933443055394, 20.46531257860078, 20.44775636590026, 20.43543840311592, 20.42747984480082, 20.422958200606168, 20.42091657094661, 20.420373227159406, 20.420331440243956, 20.419789459779736, 20.417750543117016, 20.41323293443143, 20.405279693735466, 20.392968277442094, 20.375419774563095, 20.3518077060724, 20.321366299338127, 20.28339815478245, 20.237281228013327, 20.18247505752521, 20.118526175619206, 20.045072648370226, 19.961847699188606, 19.868682379698235, 19.76550726119128, 19.65235312972524, 19.52935067790319, 19.396729196423106, 19.25481427849596, 19.10402456011519, 18.944867528812942, 18.77793444286435, 18.60389441180712, 18.423487697540256, 18.237518303069127, 18.046845923095837, 17.852377337042928, 17.655057330680602, 17.455859237247065, 17.255775192761156, 17.055806203087812, 16.85695212220161, 16.66020164198263, 16.466522393763515, 16.27685126072764, 16.09208499814754, 15.913071255370582, 15.740600089436702, 15.575396055291163, 15.418110951782378, 15.269317296069477, 15.129502591771695, 14.999064448244914, 14.878306599849557, 14.767435865063604, 14.66656007588504, 14.575686998253902, 14.494724254302286, 14.423480247210701, 14.361666079411464, 14.308898444934666, 14.26470346693956, 14.228521442011251, 14.199712443724396, 14.177562729372887, 14.161291885723502, 14.15006064225259, 14.14297927364233, 14.139116507413494, 14.13750884751456, 14.13717022052245, 14.137101847880368, 14.136302245335209, 14.13377724946349, 14.128549970903578, 14.119670574645772, 14.10622578946327, 14.087348051278724, 14.062224188926086, 14.030103565348806, 13.99030559272738, 13.942226546297341, 13.885345608640016, 13.8192300839326, 13.743539729954259, 13.658030164477632, 13.56255531194208, 13.457068865913435, 13.341624752688542, 13.216376591403197, 13.08157615604864, 12.93757085479444, 12.784800251853898, 12.623791666713924, 12.455154894788407, 12.27957610235017, 12.097810956863347, 11.910677061493077, 11.719045769535619, 11.523833460720107, 11.325992366720701, 11.12650103773103, 10.9263545455464, 10.726554521237263, 10.528099127153386, 10.331973063655717, 10.139137710625176, 9.950521502448307, 9.767010632842222, 9.589440182579013, 9.418585758935915, 9.255155730574232, 9.099784135588834, 8.953024333730474, 8.815343466352724, 8.687117779548748, 8.568628857301036, 8.460060802356608, 8.361498393051779, 8.272926234539764, 8.19422891291875, 8.125192150717336, 8.06550495216903, 8.014762716798018, 7.972471290144013, 7.938051911071724, 7.91084700613407, 7.890126772977966, 7.875096486881784, 7.8649044572739, 7.858650554574298, 7.855395221991364, 7.854168882050742, 7.853981643681259, 7.853833212673781, 7.8527229062928265, 7.8496596717779665, 7.843672008433134, 7.8338176939671955, 7.819193217708903, 7.798942826254041, 7.772267090982757, 7.738430911671965, 7.696770876073312, 7.646701901775089, 7.587723093851966, 7.519422759657731, 7.4414825305545875, 7.353680549313652, 7.255893691275447, 7.148098797032878, 7.030372904295483, 6.90289247661361, 6.765931636684276, 6.619859421926256, 6.465136089800675, 6.302308509866994, 6.1320046887075925, 5.954927482535561, 5.771847560432996, 5.583595688669487, 5.3910544133476295, 5.195149224646148, 4.996839291121254, 4.797107856831352, 4.596952397425843, 4.397374633751995, 4.199370502960314, 4.003920187514351, 3.8119783019311737, 3.6244643354995882, 3.4422534466604064, 3.2661677012123684, 3.096967842063867, 2.93534567292897, 2.781917132219646, 2.6372161264760465, 2.501689185072515, 2.3756909897145873, 2.259480823484193, 2.1532199749840197, 2.056970123569874, 1.970692721837573, 1.8942493815466799, 1.8274032591173583, 1.7698214268292074, 1.7210782059824283, 1.6806594286508267, 1.6479675853593996, 1.622327807149682, 1.6029946221424085, 1.589159418953044, 1.5799585422389575, 1.5744819393283238, 1.5717822713635923, 1.5708843977417972, 1.5707951388966603, 1.5705132196807678, 1.5690392937980067, 1.565385948924981, 1.5585875923534835, 1.5477101181822615, 1.5318602592733872, 1.5101945303445676, 1.481927672662136, 1.446340515789284, 1.4027871776803316, 1.3507015310360984, 1.289602871181384, 1.2191007287196611, 1.1388987787822893, 1.048797807734152, 0.9486977076340516, 0.838598478481988, 0.718600228219159, 0.5889021704806812, 0.44980063013519467, 0.3016860765792271, 0.14503921448797885, -0.019573828839369756, -0.1915071713571388, -0.3700416426285197, -0.554391983919846, -0.7437147099488244, -0.9371165535775273, -1.1336634089047022, -1.332389683222141, -1.5323079642064488, -1.732418905561512, -1.931721232139917, -2.1292217643753855, -2.3239453616649515, -2.514944685151065, -2.7013096821619005, -2.8821766973548266, -3.0567371193453083, -3.224245476254081, -3.384026899122679, -3.5354838784760996, -3.678102246388148, -3.8114563241590256, -3.935213184068332, -4.049135982536231, -4.153086331322284, -4.24702568302231, -4.331015716992116, -4.405217721834387, -4.469890980631055, -4.525390175087655, -4.57216183457853, -4.610739865643834, -4.641740206695531, -4.665854661447693, -4.683843972808711, -4.696530206577325, -4.704788521194349, -4.709538405948585, -4.711734475357104, -4.712356911883456, -4.712401652678147, -4.712870418588445, -4.7147606852637525, -4.71905569676247, -4.726714621640814, -4.738662950077504, -4.75578322817514, -4.778906222203309, -4.808802601244108, -4.846175221510629, -4.891652089585248, -4.945780075027429, -5.0090194352982955, -5.081739207816623, -5.164213515279429, -5.25661882123706, -5.359032163399057, -5.471430382358323, -5.593690353455379, -5.7255902194613455, -5.866811611738424, -6.016942837640402, -6.175483002241949, -6.341847023131357, -6.515371488060274, -6.695321296805613, -6.880897020747521, -7.071242906481783, -7.26545544333715, -7.46259240902249, -7.6616823028417365, -7.861734072034459, -8.061747033865176, -8.260720894124754, -8.45766576174202, -8.651612059242618, -8.841620229834934, -9.026790143938952, -9.206270110983048, -9.379265406245594, -9.545046227373506, -9.702955000919701, -9.852412965748888, -9.992925967400783, -10.12408940539957, -10.245592283978755, -10.35722032566694, -10.458858116562311, -10.550490261818084, -10.632201539770572, -10.704176053166796, -10.766695385989252, -10.82013578433109, -10.864964389545891, -10.901734561384409, -10.93108033794151, -10.9537100878785, -10.970399418472613, -10.981983410495946, -10.989348257665606, -10.993422394368135, -10.995167200484458, -10.99556737637552, -10.995621084391091, -10.99632995560162, -10.998689061802414, -11.003676953187103, -11.012245861429845, -11.025312166259775, -11.043747220973154, -11.068368628735117, -11.099932057009802, -11.139123672070026, -11.186553269329686, -11.242748168275686, -11.308147933121331, -11.383099972036186, -11.467856059011496, -11.56256981318305, -11.667295160847699, -11.781985795571272, -11.906495641793134, -12.040580317285919, -12.183899579828793, -12.336020733598955, -12.49642296117773, -12.66450253780065, -12.839578875648215, -13.020901337663867, -13.207656752681565, -13.398977556623962, -13.593950478264249, -13.79162568259273, -13.991026280247771, -14.191158107805876, -14.391019681013978, -14.589612221315232, -14.78594965528661, -14.979068486876535, -15.168037443605838, -15.351966800156639, -15.530017286005343, -15.701408487918675, -15.86542666319058, -16.02143188539566, -16.168864451119074, -16.307250483520026, -16.43620667662865, -16.555444132877223, -16.664771255446297, -16.764095666467924, -16.853425131882176, -16.932867483687016, -17.002629540360438, -17.06301503626285, -17.114421580750154, -17.157336677441563, -17.192332843496228, -17.220061877762546, -17.241248335185787, -17.25668227280589, -17.267211339970213, -17.273732291951298, -17.27718201193252, -17.278528131246517, -17.278759341773373, -17.278875497487665, -17.279877604254327, -17.282757798092202, -17.288489412239493, -17.298017232466403, -17.312248038195477, -17.33204152412881, -17.358201693271784, -17.39146880752339, -17.432511976421345, -17.481922458240778, -17.54020774051383, -17.607786459233953, -17.6849842076121, -17.772030276346264, -17.869055358039503, -17.97609023874934, -18.093065489767913, -18.219812162719144, -18.35606348101333, -18.501457510725427, -18.655540784156493, -18.81777283980103, -18.987531633266943, -19.164119764976462, -19.346771462297653, -19.534660246204496, -19.726907205708716, -19.922589797223345, -20.12075108076081, -20.320409300496806, -20.520567713781542, -20.720224570194553, -20.91838314073518, -21.114061696740738, -21.306303338625828, -21.4941855760417, -21.676829563541364, -21.853408899286965, -22.023157898708817, -22.185379260283845, -22.339451046685415, -22.48483291141233, -22.621071508557414, -22.747805031555522, -22.86476683546989, -22.97178810655236, -23.068799552350118, -23.155832095438708, -23.23301656383544, -23.300582381193056, -23.35885526988663, -23.408253989989994, -23.449286146789664, -23.482543108810233, -23.508694087230143, -23.52847943596286, -23.542703239480684, -23.55222526258951, -23.557952342750703, -23.560829311127215, -23.561829533249497, -23.56194516400481, -23.562177214513817, -23.56352553034146, -23.566978781377077, -23.573504563601556, -23.58403971183949, -23.599480920481753, -23.62067576608064, -23.648414221696495, -23.68342074795116, -23.726347039970197, -23.777765502828846, -23.838163520823596, -23.907938577943305, -23.987394278392294, -24.07673730700635, -24.176075359993256, -24.285416066714216, -24.40466691330137, -24.533636168875592, -24.672034805092192, -24.819479389796026, -24.97549592581637, -25.139524596468153, -25.31092537024983, -25.488984408624898, -25.672921212735144, -25.861896437494394, -26.05502029483145, -26.251361461950935, -26.449956405426345, -26.649819027774765, -26.84995053993582, -27.049349460813996, -27.2470216437732, -27.441990229700675, -27.63330542699449, -27.820054020559684, -28.00136851461306, -28.176435817761103, -28.344505383399703, -28.50489672393594, -28.65700622360283, -28.800313181658648, -28.934385025469044, -29.058881641279665, -29.173558779321645, -29.27827049915858, -29.372970630793592, -29.457713236907793, -29.532652071602875, -29.5980390410663, -29.65422168157075, -29.701639680056932, -29.74082047213481, -29.772373961574363, -29.79698641415271, -29.81541358699029, -29.82847316216295, -29.837036560342032, -29.84202021642159, -29.844376404478247, -29.845083703921105, -29.8451372022815, -29.845538532728863, -29.847285846053943, -29.851363817516344, -29.858733788604656, -29.870324142406457, -29.887021008946853, -29.90965939355057, -29.93901481704743, -29.975795551516807, -30.02063552930403, -30.07408799630146, -30.136619973035316, -30.208607579012153, -30.290332267135895, -30.38197800589543, -30.483629437533427, -30.595271030636567, -30.71678723563077, -30.847963641625046, -30.98848912302163, -31.1379589544017, -31.295878862501, -31.461669974708837, -31.63467461454724, -31.8141628861084, -31.999339981528575, -32.18935413833927, -32.38330516702838, -32.58025346343727, -32.77922941576362, -32.97924311199124, -33.17929425055839, -33.37838215504327, -33.575515792601934, -33.769723695858474, -33.960063688911745, -34.1456323200861, -34.3255739069877, -34.49908910331109, -34.66544290162733, -34.82397199203309, -34.97409140298777, -35.11530035785339, -35.247187288502914, -35.369433955803046, -35.48181863571805, -35.584218339136854, -35.676610043198885, -35.75907092179135, -35.831777572909935, -35.89500425061875, -35.94912011931012, -35.994585557754064, -36.03194754993967, -36.06183420885412, -36.08494848802517, -36.102061143785136, -36.11400301871593, -36.12165672353048, -36.125947800669046, -36.12783545807735, -36.128302965936896, -36.12834781249227, -36.128971717531904, -36.13117060350404, -36.135924624673734, -36.14418835414564, -36.156881226996845, -36.174878335199885, -36.19900166649412, -36.23001187491897, -36.26860066539966, -36.31538386862847, -36.370895275573524, -36.43558129334179, -36.50979647590025, -36.593799974399936, -36.68775294264117, -36.79171692365547, -36.905653233557366, -37.02942334883443, -37.162790293198526, -37.3054210101132, -37.4568896972446, -37.61668206945211, -37.78420050763967, -37.95877004191835, -38.13964510917976, -38.32601701742469, -38.51702204211759, -38.71175007350801, -38.9092537283457, -39.10855783476521, -39.30866919538113, -39.5085865308485, -39.70731050433744, -39.90385372655965, -40.09725064118041, -40.28656719164598, -40.47091017264617, -40.649436172587414, -40.82136001754823, -40.985962632178115, -41.14259823884009, -41.29070082292051, -41.42978979957863, -41.55947482520131, -41.67945970539315, -41.789545360375676, -41.88963181810777, -41.97971921517226, -42.059907795408535, -42.13039690630468, -42.19148300319705, -42.243556681258326, -42.28709876498918, -42.322675494363864, -42.35093285582469, -42.372590114881454, -42.388432615065376, -42.39930391533183, -42.40609734462981, -42.40974705819081, -42.4112186850785, -42.411499660633055, -42.41158934059821, -42.412488995905264, -42.41519178828286, -42.42067282705338, -42.429879406664035, -42.44372152269115, -42.463062761268326, -42.48871165315045, -42.52141357897376, -42.561843306753744, -42.6105982363332, -42.668192418414385, -42.735051408055114, -42.81150800415353, -42.89779891757679, -42.994062401290755, -43.10033686621761, -43.2165604966784, -43.34257186927109, -43.478111568987636, -43.622824786390574, -43.77626486984647, -43.93789779725308, -44.107107522490175, -44.28320214306775, -44.46542082722252, -44.652941431111714, -44.844888729842445, -45.04034317993134, -45.23835012546662, -45.4379293558045, -45.638084919110675, -45.83781509349772, -46.036122415929896, -46.23202366849026, -46.42455972202985, -46.612805138648746, -46.795877436871066, -46.972945926754996, -47.14324002648297, -47.30605697716966, -47.46076887864912, -47.60682897580174, -47.74377713248377, -47.87124443825692, -47.9889569017963, -48.096738194000245, -48.19451141333825, -48.28229985576355, -48.36022678148169, -48.42851418091065, -48.48748055218674, -48.537537712467746, -48.57918667495698, -48.61301263292644, -48.639679100957125, -48.65992127205264, -48.67453865713234, -48.684387080594945, -48.69037011209046, -48.693430020282555, -48.69453833916932, -48.69468614140931, -48.694874116033034, -48.69610254987848, -48.699361313053345, -48.705619948686056, -48.715817966183664, -48.730855435177446, -48.751583974326245, -48.778798225194876, -48.813227896568065, -48.855530458849834, -48.90628456168927, -48.96598424073354, -49.035033971507886]}],\n",
       "                        {\"template\": {\"data\": {\"bar\": [{\"error_x\": {\"color\": \"#2a3f5f\"}, \"error_y\": {\"color\": \"#2a3f5f\"}, \"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"bar\"}], \"barpolar\": [{\"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"barpolar\"}], \"carpet\": [{\"aaxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"baxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"type\": \"carpet\"}], \"choropleth\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"choropleth\"}], \"contour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"contour\"}], \"contourcarpet\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"contourcarpet\"}], \"heatmap\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmap\"}], \"heatmapgl\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmapgl\"}], \"histogram\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"histogram\"}], \"histogram2d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2d\"}], \"histogram2dcontour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2dcontour\"}], \"mesh3d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"mesh3d\"}], \"parcoords\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"parcoords\"}], \"pie\": [{\"automargin\": true, \"type\": \"pie\"}], \"scatter\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter\"}], \"scatter3d\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter3d\"}], \"scattercarpet\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattercarpet\"}], \"scattergeo\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergeo\"}], \"scattergl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergl\"}], \"scattermapbox\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattermapbox\"}], \"scatterpolar\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolar\"}], \"scatterpolargl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolargl\"}], \"scatterternary\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterternary\"}], \"surface\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"surface\"}], \"table\": [{\"cells\": {\"fill\": {\"color\": \"#EBF0F8\"}, \"line\": {\"color\": \"white\"}}, \"header\": {\"fill\": {\"color\": \"#C8D4E3\"}, \"line\": {\"color\": \"white\"}}, \"type\": \"table\"}]}, \"layout\": {\"annotationdefaults\": {\"arrowcolor\": \"#2a3f5f\", \"arrowhead\": 0, \"arrowwidth\": 1}, \"coloraxis\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"colorscale\": {\"diverging\": [[0, \"#8e0152\"], [0.1, \"#c51b7d\"], [0.2, \"#de77ae\"], [0.3, \"#f1b6da\"], [0.4, \"#fde0ef\"], [0.5, \"#f7f7f7\"], [0.6, \"#e6f5d0\"], [0.7, \"#b8e186\"], [0.8, \"#7fbc41\"], [0.9, \"#4d9221\"], [1, \"#276419\"]], \"sequential\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"sequentialminus\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]]}, \"colorway\": [\"#636efa\", \"#EF553B\", \"#00cc96\", \"#ab63fa\", \"#FFA15A\", \"#19d3f3\", \"#FF6692\", \"#B6E880\", \"#FF97FF\", \"#FECB52\"], \"font\": {\"color\": \"#2a3f5f\"}, \"geo\": {\"bgcolor\": \"white\", \"lakecolor\": \"white\", \"landcolor\": \"#E5ECF6\", \"showlakes\": true, \"showland\": true, \"subunitcolor\": \"white\"}, \"hoverlabel\": {\"align\": \"left\"}, \"hovermode\": \"closest\", \"mapbox\": {\"style\": \"light\"}, \"paper_bgcolor\": \"white\", \"plot_bgcolor\": \"#E5ECF6\", \"polar\": {\"angularaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"radialaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"scene\": {\"xaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"yaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"zaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}}, \"shapedefaults\": {\"line\": {\"color\": \"#2a3f5f\"}}, \"ternary\": {\"aaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"baxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"caxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"title\": {\"x\": 0.05}, \"xaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}, \"yaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}}}, \"title\": {\"text\": \"Transcendental Equation Inspection\"}, \"xaxis\": {\"dtick\": 5, \"range\": [-20, 20], \"showticklabels\": true, \"tick0\": 0, \"tickangle\": -90, \"ticks\": \"outside\", \"title\": {\"font\": {\"color\": \"black\", \"family\": \"Arial, serif\", \"size\": 18}, \"text\": \"x\"}}, \"yaxis\": {\"dtick\": 5, \"range\": [-20, 20], \"tick0\": 0, \"ticks\": \"outside\", \"title\": {\"font\": {\"color\": \"black\", \"family\": \"Arial, serif\", \"size\": 18}, \"text\": \"P(x)\"}}},\n",
       "                        {\"responsive\": true}\n",
       "                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('deab80a1-0f14-4227-99d9-d2fe34003e3f');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })\n",
       "                };\n",
       "                });\n",
       "            </script>\n",
       "        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "button = widgets.Button(description=\"Analyze Graph\", \n",
    "                        layout = Layout(width='30%', height='60px'),\n",
    "                        button_style = 'info'\n",
    "                       )\n",
    "display(button)\n",
    "def on_button_clicked(b):\n",
    "    x = np.linspace(-50,50,1000)\n",
    "    f = np.cos(x) -x\n",
    "    trace = go.Scatter(\n",
    "        x = x,\n",
    "        y = f,\n",
    "        name = 'P(x) = cos(x) - x',\n",
    "        line = dict(\n",
    "        color = ('black')\n",
    "        )\n",
    "    )\n",
    "    layout = go.Layout(\n",
    "        title = 'Transcendental Equation Inspection',\n",
    "        xaxis = dict(\n",
    "            title='x',\n",
    "            titlefont=dict(\n",
    "            family='Arial, serif',\n",
    "            size=18,\n",
    "            color='black'),\n",
    "            showticklabels=True,\n",
    "            tickangle= 270,\n",
    "            range = [-20,20],\n",
    "           # autotick=False,\n",
    "            ticks='outside',\n",
    "            tick0=0,\n",
    "            dtick=5\n",
    "\n",
    "        ),\n",
    "        yaxis = dict(\n",
    "            title='P(x)',\n",
    "            titlefont=dict(\n",
    "            family='Arial, serif',\n",
    "            size=18,\n",
    "            color='black'),\n",
    "            range = [-20,20],\n",
    "         #   autotick=False,\n",
    "            ticks='outside',\n",
    "            tick0=0,\n",
    "            dtick=5\n",
    "        ),\n",
    "    )\n",
    "\n",
    "    data = [trace]\n",
    "\n",
    "    fig = go.Figure(data=data, layout=layout)\n",
    "\n",
    "    iplot(fig)\n",
    "button.on_click(on_button_clicked)  \n",
    "on_button_clicked(0)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "collapsed": true,
    "hidden": false
   },
   "source": [
    "***\n",
    "We can see via inspection that the root is $x \\approx 0.75$. As we can see this method is effective for our purposes, especially when you can zoom into the root. In the next cell we will locate the value of the root using the bisection method. Please specify the initial interval and the accuracy you would like. Additionally, try to find the root beforehand, on paper, for the interval you choose. See how many iterations it takes.\n",
    "***"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 15,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'Enter a value for x0'"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "d2e6f65dbaca4efbb86f228b2bb98da9",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Text(value='', placeholder='Enter a Value')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/plain": [
       "'Enter a value for x1'"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "fd89f74522714ae5b15b339de8e1b12c",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Text(value='', placeholder='Enter a Value')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/plain": [
       "'Please specify a tolerance'"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "926e59f4010a4cd39bd0ae4aa68ceb0f",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Text(value='', placeholder='Enter a Value')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "49f59356036e44d0a75cf2ce448c69ab",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Button(button_style='info', description='Show Root', layout=Layout(height='60px', width='30%'), style=ButtonSt…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "x0_in = widgets.Text(placeholder = 'Enter a Value')\n",
    "x0_out = widgets.Text(value = None)\n",
    "x1_in = widgets.Text(placeholder = 'Enter a Value')\n",
    "x1_out = widgets.Text(value = None)\n",
    "tol_in = widgets.Text(placeholder = 'Enter a Value')\n",
    "tol_out = widgets.Text(value = None)\n",
    "\n",
    "def bisection_method(x0,x1,tol):\n",
    "    clear_output()\n",
    "    \n",
    "    if x0 == None or x1 == None or tol == None:\n",
    "        print(\"Remember to press enter after submitting an answer\")\n",
    "    \n",
    "    if tol == None:\n",
    "        display('Please specify a tolerance')\n",
    "#     if str.isdigit(x0) == False or str.isdigit(x1) == False or str.isdigit(tol) == False:  \n",
    "#         print(\"Please input a number\")\n",
    "\n",
    "    try:\n",
    "        x0 = float(x0)\n",
    "    except ValueError:\n",
    "        print(\"Please input only numbers\")\n",
    "\n",
    "    try:\n",
    "        x1 = float(x1)\n",
    "    except ValueError:\n",
    "        print(\"Please enter only a number for x1\")\n",
    "    try:\n",
    "        tol = float(tol)\n",
    "    except ValueError:\n",
    "        print(\"Please enter only a number for tol\")\n",
    "\n",
    "    else:\n",
    "        \n",
    "#         x0.replace(\" \",\"\")\n",
    "#         x1.replace(\" \",\"\")\n",
    "#         tol.replace(\" \",\"\")\n",
    "        tol = float(tol)\n",
    "        x0 = float(x0)\n",
    "        x1 = float(x1)\n",
    "\n",
    "        #Function (of your choice) we will use our function from before:\n",
    "        #Change this return statement for other functions of your choice.  \n",
    "        def f(x):\n",
    "            return np.cos(x)-x \n",
    "\n",
    "        #Bisection method algorithm\n",
    "        c = (x1+x0)/2  #First define the formula for subdiving our interval\n",
    "        n = 0\n",
    "        if f(x0) > 0 and f(x1) > 0 or f(x0) < 0 and f(x1) < 0: \n",
    "            print('Pick new initial conditions') #The Bisection method does not apply for theses two cases (as previously discussed)\n",
    "        else:\n",
    "            while f(c)>tol:\n",
    "                c = (x1+x0)/2\n",
    "                if f(c) == 0:\n",
    "                    break   # you have found the root exactly\n",
    "                if np.sign(f(c)) == np.sign(f(x0)):\n",
    "                    x0 = c #Interval [x0,c] does not necessarily have a root; x0 is set to c. Think about why this is the case.\n",
    "                if np.sign(f(c))== np.sign(f(x1)):\n",
    "                    x1 = c #Interval [c,x1] does not necessarily have a root; x1 is set to c. Think about why this is the case.\n",
    "                c = (x1+x0)/2\n",
    "                n += 1\n",
    "            display(Latex('Root = ' +str(round(c,4))))\n",
    "            display(Latex('Number of iterations ='+str(n)))\n",
    "    return \n",
    "\n",
    "def bind0(sender):\n",
    "    x0_out.value = x0_in.value\n",
    "    return x0_out.value\n",
    "\n",
    "def bind1(sender):\n",
    "    x1_out.value = x1_in.value\n",
    "    return x1_out.value\n",
    "\n",
    "def bindtol(sender):\n",
    "    tol_out.value = tol_in.value\n",
    "    return tol_out.value\n",
    "\n",
    "x0_in.on_submit(bind0)\n",
    "x1_in.on_submit(bind1)\n",
    "tol_in.on_submit(bindtol)\n",
    "\n",
    "display(\"Enter a value for x0\")\n",
    "display(x0_in)\n",
    "\n",
    "display(\"Enter a value for x1\")\n",
    "display(x1_in)\n",
    "\n",
    "display(\"Please specify a tolerance\")\n",
    "display(tol_in)\n",
    "\n",
    "show_root = widgets.Button(description=\"Show Root\", \n",
    "                           layout = Layout(width='30%', height='60px'),\n",
    "                           button_style = 'info'\n",
    "                          )\n",
    "\n",
    "display(show_root)\n",
    "\n",
    "def button_Click(b):\n",
    "    display(Javascript('IPython.notebook.execute_cell_range(IPython.notebook.get_selected_index()+1,IPython.notebook.get_selected_index()+2)'))\n",
    "    return\n",
    "\n",
    "show_root.on_click(button_Click)\n",
    "\n",
    "    "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 16,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Please input only numbers\n",
      "Please enter only a number for x1\n",
      "Please enter only a number for tol\n"
     ]
    }
   ],
   "source": [
    "\n",
    "x0 = x0_out.value\n",
    "x1 = x1_out.value\n",
    "tol = tol_out.value\n",
    "bisection_method(x0,x1,tol)\n",
    "\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hidden": false
   },
   "source": [
    "### Analysis\n",
    "---\n",
    "Our bisection algorithm gave us a reasonably precise value of the root; this value could be passed into another function. Due to this reason, and the fact that the function does not need to be plotted, the bisection method is more robust and more applicable. \n",
    "\n",
    "What do you think? Would you rather just see a graph of the function and compromise on accuracy? \n",
    "Below we will outline a clear disadvantage of the bisection method.\n",
    "\n",
    "Let's now try the same problem for $\\tan(x) = x$:\n",
    "\n",
    "- If we run the algorithm above for the function $f(x) = \\tan(x)-x$, with the initial conditions $x_0 = -1, x_1 = 1$, we obtain the     answer: $x = 0$.\n",
    "\n",
    "- If again we run the algorithm with the initial conditions $x_0 = 1, x_1 = 3$, \n",
    "  we obtain the answer: $x = 1.5708$\n",
    "\n",
    "Why is this the case?\n",
    "Let's plot the function to inspect the cause of this.\n",
    "\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 17,
   "metadata": {
    "scrolled": false,
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "8a4a780993374688994fbad856f4ef1f",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Button(button_style='info', description='Analyze Graph', layout=Layout(height='60px', width='30%'), style=Butt…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "config": {
        "linkText": "Export to plot.ly",
        "plotlyServerURL": "https://plot.ly",
        "showLink": false
       },
       "data": [
        {
         "line": {
          "color": "black"
         },
         "name": "P(x) = tan(x) - x",
         "type": "scatter",
         "x": [
          -25,
          -24.994999499949994,
          -24.98999899989999,
          -24.984998499849986,
          -24.97999799979998,
          -24.974997499749975,
          -24.96999699969997,
          -24.964996499649963,
          -24.95999599959996,
          -24.954995499549955,
          -24.94999499949995,
          -24.944994499449944,
          -24.939993999399938,
          -24.934993499349936,
          -24.92999299929993,
          -24.924992499249925,
          -24.91999199919992,
          -24.914991499149917,
          -24.90999099909991,
          -24.904990499049905,
          -24.8999899989999,
          -24.894989498949894,
          -24.88998899889989,
          -24.884988498849886,
          -24.87998799879988,
          -24.874987498749874,
          -24.86998699869987,
          -24.864986498649866,
          -24.85998599859986,
          -24.854985498549855,
          -24.84998499849985,
          -24.844984498449843,
          -24.83998399839984,
          -24.834983498349835,
          -24.82998299829983,
          -24.824982498249824,
          -24.81998199819982,
          -24.814981498149816,
          -24.80998099809981,
          -24.804980498049805,
          -24.7999799979998,
          -24.794979497949797,
          -24.78997899789979,
          -24.784978497849785,
          -24.77997799779978,
          -24.774977497749774,
          -24.76997699769977,
          -24.764976497649766,
          -24.75997599759976,
          -24.754975497549754,
          -24.74997499749975,
          -24.744974497449746,
          -24.73997399739974,
          -24.734973497349735,
          -24.72997299729973,
          -24.724972497249723,
          -24.71997199719972,
          -24.714971497149715,
          -24.70997099709971,
          -24.704970497049704,
          -24.699969996999698,
          -24.694969496949696,
          -24.68996899689969,
          -24.684968496849685,
          -24.67996799679968,
          -24.674967496749677,
          -24.66996699669967,
          -24.664966496649665,
          -24.65996599659966,
          -24.654965496549654,
          -24.64996499649965,
          -24.644964496449646,
          -24.63996399639964,
          -24.634963496349634,
          -24.62996299629963,
          -24.624962496249626,
          -24.61996199619962,
          -24.614961496149615,
          -24.60996099609961,
          -24.604960496049603,
          -24.5999599959996,
          -24.594959495949595,
          -24.58995899589959,
          -24.584958495849584,
          -24.57995799579958,
          -24.574957495749576,
          -24.56995699569957,
          -24.564956495649565,
          -24.55995599559956,
          -24.554955495549557,
          -24.54995499549955,
          -24.544954495449545,
          -24.53995399539954,
          -24.534953495349534,
          -24.52995299529953,
          -24.524952495249526,
          -24.51995199519952,
          -24.514951495149514,
          -24.50995099509951,
          -24.504950495049506,
          -24.4999499949995,
          -24.494949494949495,
          -24.48994899489949,
          -24.484948494849483,
          -24.47994799479948,
          -24.474947494749475,
          -24.46994699469947,
          -24.464946494649464,
          -24.459945994599458,
          -24.454945494549456,
          -24.44994499449945,
          -24.444944494449445,
          -24.43994399439944,
          -24.434943494349437,
          -24.42994299429943,
          -24.424942494249425,
          -24.41994199419942,
          -24.414941494149414,
          -24.40994099409941,
          -24.404940494049406,
          -24.3999399939994,
          -24.394939493949394,
          -24.38993899389939,
          -24.384938493849386,
          -24.37993799379938,
          -24.374937493749375,
          -24.36993699369937,
          -24.364936493649363,
          -24.35993599359936,
          -24.354935493549355,
          -24.34993499349935,
          -24.344934493449344,
          -24.33993399339934,
          -24.334933493349336,
          -24.32993299329933,
          -24.324932493249324,
          -24.31993199319932,
          -24.314931493149317,
          -24.30993099309931,
          -24.304930493049305,
          -24.2999299929993,
          -24.294929492949294,
          -24.28992899289929,
          -24.284928492849286,
          -24.27992799279928,
          -24.274927492749274,
          -24.26992699269927,
          -24.264926492649266,
          -24.25992599259926,
          -24.254925492549255,
          -24.24992499249925,
          -24.244924492449243,
          -24.23992399239924,
          -24.234923492349235,
          -24.22992299229923,
          -24.224922492249224,
          -24.219921992199218,
          -24.214921492149216,
          -24.20992099209921,
          -24.204920492049204,
          -24.1999199919992,
          -24.194919491949197,
          -24.18991899189919,
          -24.184918491849185,
          -24.17991799179918,
          -24.174917491749174,
          -24.16991699169917,
          -24.164916491649166,
          -24.15991599159916,
          -24.154915491549154,
          -24.14991499149915,
          -24.144914491449146,
          -24.13991399139914,
          -24.134913491349135,
          -24.12991299129913,
          -24.124912491249123,
          -24.11991199119912,
          -24.114911491149115,
          -24.10991099109911,
          -24.104910491049104,
          -24.0999099909991,
          -24.094909490949096,
          -24.08990899089909,
          -24.084908490849084,
          -24.07990799079908,
          -24.074907490749077,
          -24.06990699069907,
          -24.064906490649065,
          -24.05990599059906,
          -24.054905490549054,
          -24.04990499049905,
          -24.044904490449046,
          -24.03990399039904,
          -24.034903490349034,
          -24.02990299029903,
          -24.024902490249026,
          -24.01990199019902,
          -24.014901490149015,
          -24.00990099009901,
          -24.004900490049003,
          -23.999899989999,
          -23.994899489948995,
          -23.98989898989899,
          -23.984898489848984,
          -23.979897989798978,
          -23.974897489748976,
          -23.96989698969897,
          -23.964896489648964,
          -23.95989598959896,
          -23.954895489548953,
          -23.94989498949895,
          -23.944894489448945,
          -23.93989398939894,
          -23.934893489348934,
          -23.92989298929893,
          -23.924892489248926,
          -23.91989198919892,
          -23.914891489148914,
          -23.90989098909891,
          -23.904890489048906,
          -23.8998899889989,
          -23.894889488948895,
          -23.88988898889889,
          -23.884888488848883,
          -23.87988798879888,
          -23.874887488748875,
          -23.86988698869887,
          -23.864886488648864,
          -23.85988598859886,
          -23.854885488548856,
          -23.84988498849885,
          -23.844884488448844,
          -23.83988398839884,
          -23.834883488348837,
          -23.82988298829883,
          -23.824882488248825,
          -23.81988198819882,
          -23.814881488148814,
          -23.80988098809881,
          -23.804880488048806,
          -23.7998799879988,
          -23.794879487948794,
          -23.78987898789879,
          -23.784878487848786,
          -23.77987798779878,
          -23.774877487748775,
          -23.76987698769877,
          -23.764876487648763,
          -23.75987598759876,
          -23.754875487548755,
          -23.74987498749875,
          -23.744874487448744,
          -23.739873987398738,
          -23.734873487348736,
          -23.72987298729873,
          -23.724872487248724,
          -23.71987198719872,
          -23.714871487148713,
          -23.70987098709871,
          -23.704870487048705,
          -23.6998699869987,
          -23.694869486948694,
          -23.68986898689869,
          -23.684868486848686,
          -23.67986798679868,
          -23.674867486748674,
          -23.66986698669867,
          -23.664866486648666,
          -23.65986598659866,
          -23.654865486548655,
          -23.64986498649865,
          -23.644864486448643,
          -23.63986398639864,
          -23.634863486348635,
          -23.62986298629863,
          -23.624862486248624,
          -23.61986198619862,
          -23.614861486148616,
          -23.60986098609861,
          -23.604860486048604,
          -23.5998599859986,
          -23.594859485948597,
          -23.58985898589859,
          -23.584858485848585,
          -23.57985798579858,
          -23.574857485748574,
          -23.56985698569857,
          -23.564856485648566,
          -23.55985598559856,
          -23.554855485548554,
          -23.54985498549855,
          -23.544854485448546,
          -23.53985398539854,
          -23.534853485348535,
          -23.52985298529853,
          -23.524852485248523,
          -23.51985198519852,
          -23.514851485148515,
          -23.50985098509851,
          -23.504850485048504,
          -23.499849984998498,
          -23.494849484948496,
          -23.48984898489849,
          -23.484848484848484,
          -23.47984798479848,
          -23.474847484748473,
          -23.46984698469847,
          -23.464846484648465,
          -23.45984598459846,
          -23.454845484548454,
          -23.44984498449845,
          -23.444844484448446,
          -23.43984398439844,
          -23.434843484348434,
          -23.42984298429843,
          -23.424842484248426,
          -23.41984198419842,
          -23.414841484148415,
          -23.40984098409841,
          -23.404840484048403,
          -23.3998399839984,
          -23.394839483948395,
          -23.38983898389839,
          -23.384838483848384,
          -23.37983798379838,
          -23.374837483748376,
          -23.36983698369837,
          -23.364836483648364,
          -23.35983598359836,
          -23.354835483548356,
          -23.34983498349835,
          -23.344834483448345,
          -23.33983398339834,
          -23.334833483348334,
          -23.32983298329833,
          -23.324832483248326,
          -23.31983198319832,
          -23.314831483148314,
          -23.30983098309831,
          -23.304830483048306,
          -23.2998299829983,
          -23.294829482948295,
          -23.28982898289829,
          -23.284828482848283,
          -23.27982798279828,
          -23.274827482748275,
          -23.26982698269827,
          -23.264826482648264,
          -23.259825982598258,
          -23.254825482548256,
          -23.24982498249825,
          -23.244824482448244,
          -23.23982398239824,
          -23.234823482348233,
          -23.22982298229823,
          -23.224822482248225,
          -23.21982198219822,
          -23.214821482148214,
          -23.20982098209821,
          -23.204820482048206,
          -23.1998199819982,
          -23.194819481948194,
          -23.18981898189819,
          -23.184818481848186,
          -23.17981798179818,
          -23.174817481748175,
          -23.16981698169817,
          -23.164816481648163,
          -23.15981598159816,
          -23.154815481548155,
          -23.14981498149815,
          -23.144814481448144,
          -23.13981398139814,
          -23.134813481348136,
          -23.12981298129813,
          -23.124812481248124,
          -23.11981198119812,
          -23.114811481148116,
          -23.10981098109811,
          -23.104810481048105,
          -23.0998099809981,
          -23.094809480948093,
          -23.08980898089809,
          -23.084808480848086,
          -23.07980798079808,
          -23.074807480748074,
          -23.06980698069807,
          -23.064806480648066,
          -23.05980598059806,
          -23.054805480548055,
          -23.04980498049805,
          -23.044804480448043,
          -23.03980398039804,
          -23.034803480348035,
          -23.02980298029803,
          -23.024802480248024,
          -23.019801980198018,
          -23.014801480148016,
          -23.00980098009801,
          -23.004800480048004,
          -22.999799979998,
          -22.994799479947993,
          -22.98979897989799,
          -22.984798479847985,
          -22.97979797979798,
          -22.974797479747973,
          -22.969796979697968,
          -22.964796479647966,
          -22.95979597959796,
          -22.954795479547954,
          -22.94979497949795,
          -22.944794479447946,
          -22.93979397939794,
          -22.934793479347935,
          -22.92979297929793,
          -22.924792479247923,
          -22.91979197919792,
          -22.914791479147915,
          -22.90979097909791,
          -22.904790479047904,
          -22.8997899789979,
          -22.894789478947896,
          -22.88978897889789,
          -22.884788478847884,
          -22.87978797879788,
          -22.874787478747876,
          -22.86978697869787,
          -22.864786478647865,
          -22.85978597859786,
          -22.854785478547853,
          -22.84978497849785,
          -22.844784478447846,
          -22.83978397839784,
          -22.834783478347834,
          -22.82978297829783,
          -22.824782478247826,
          -22.81978197819782,
          -22.814781478147815,
          -22.80978097809781,
          -22.804780478047803,
          -22.7997799779978,
          -22.794779477947795,
          -22.78977897789779,
          -22.784778477847784,
          -22.779777977797778,
          -22.774777477747776,
          -22.76977697769777,
          -22.764776477647764,
          -22.75977597759776,
          -22.754775477547753,
          -22.74977497749775,
          -22.744774477447745,
          -22.73977397739774,
          -22.734773477347733,
          -22.729772977297728,
          -22.724772477247726,
          -22.71977197719772,
          -22.714771477147714,
          -22.70977097709771,
          -22.704770477047706,
          -22.6997699769977,
          -22.694769476947695,
          -22.68976897689769,
          -22.684768476847683,
          -22.67976797679768,
          -22.674767476747675,
          -22.66976697669767,
          -22.664766476647664,
          -22.65976597659766,
          -22.654765476547656,
          -22.64976497649765,
          -22.644764476447644,
          -22.63976397639764,
          -22.634763476347636,
          -22.62976297629763,
          -22.624762476247625,
          -22.61976197619762,
          -22.614761476147613,
          -22.60976097609761,
          -22.604760476047606,
          -22.5997599759976,
          -22.594759475947594,
          -22.58975897589759,
          -22.584758475847586,
          -22.57975797579758,
          -22.574757475747575,
          -22.56975697569757,
          -22.564756475647563,
          -22.55975597559756,
          -22.554755475547555,
          -22.54975497549755,
          -22.544754475447544,
          -22.539753975397538,
          -22.534753475347536,
          -22.52975297529753,
          -22.524752475247524,
          -22.51975197519752,
          -22.514751475147513,
          -22.50975097509751,
          -22.504750475047505,
          -22.4997499749975,
          -22.494749474947493,
          -22.489748974897488,
          -22.484748474847486,
          -22.47974797479748,
          -22.474747474747474,
          -22.46974697469747,
          -22.464746474647466,
          -22.45974597459746,
          -22.454745474547455,
          -22.44974497449745,
          -22.444744474447443,
          -22.43974397439744,
          -22.434743474347435,
          -22.42974297429743,
          -22.424742474247424,
          -22.41974197419742,
          -22.414741474147416,
          -22.40974097409741,
          -22.404740474047404,
          -22.3997399739974,
          -22.394739473947396,
          -22.38973897389739,
          -22.384738473847385,
          -22.37973797379738,
          -22.374737473747373,
          -22.36973697369737,
          -22.364736473647366,
          -22.35973597359736,
          -22.354735473547354,
          -22.34973497349735,
          -22.344734473447346,
          -22.33973397339734,
          -22.334733473347335,
          -22.32973297329733,
          -22.324732473247323,
          -22.31973197319732,
          -22.314731473147315,
          -22.30973097309731,
          -22.304730473047304,
          -22.299729972997298,
          -22.294729472947296,
          -22.28972897289729,
          -22.284728472847284,
          -22.27972797279728,
          -22.274727472747273,
          -22.26972697269727,
          -22.264726472647265,
          -22.25972597259726,
          -22.254725472547253,
          -22.249724972497248,
          -22.244724472447245,
          -22.23972397239724,
          -22.234723472347234,
          -22.22972297229723,
          -22.224722472247226,
          -22.21972197219722,
          -22.214721472147215,
          -22.20972097209721,
          -22.204720472047203,
          -22.1997199719972,
          -22.194719471947195,
          -22.18971897189719,
          -22.184718471847184,
          -22.17971797179718,
          -22.174717471747176,
          -22.16971697169717,
          -22.164716471647164,
          -22.15971597159716,
          -22.154715471547156,
          -22.14971497149715,
          -22.144714471447145,
          -22.13971397139714,
          -22.134713471347133,
          -22.12971297129713,
          -22.124712471247125,
          -22.11971197119712,
          -22.114711471147114,
          -22.10971097109711,
          -22.104710471047106,
          -22.0997099709971,
          -22.094709470947095,
          -22.08970897089709,
          -22.084708470847083,
          -22.07970797079708,
          -22.074707470747075,
          -22.06970697069707,
          -22.064706470647064,
          -22.059705970597058,
          -22.054705470547056,
          -22.04970497049705,
          -22.044704470447044,
          -22.03970397039704,
          -22.034703470347033,
          -22.02970297029703,
          -22.024702470247025,
          -22.01970197019702,
          -22.014701470147013,
          -22.009700970097008,
          -22.004700470047005,
          -21.999699969997,
          -21.994699469946994,
          -21.98969896989699,
          -21.984698469846986,
          -21.97969796979698,
          -21.974697469746975,
          -21.96969696969697,
          -21.964696469646963,
          -21.95969596959696,
          -21.954695469546955,
          -21.94969496949695,
          -21.944694469446944,
          -21.93969396939694,
          -21.934693469346936,
          -21.92969296929693,
          -21.924692469246924,
          -21.91969196919692,
          -21.914691469146916,
          -21.90969096909691,
          -21.904690469046905,
          -21.8996899689969,
          -21.894689468946893,
          -21.88968896889689,
          -21.884688468846885,
          -21.87968796879688,
          -21.874687468746874,
          -21.86968696869687,
          -21.864686468646866,
          -21.85968596859686,
          -21.854685468546855,
          -21.84968496849685,
          -21.844684468446843,
          -21.83968396839684,
          -21.834683468346835,
          -21.82968296829683,
          -21.824682468246824,
          -21.819681968196818,
          -21.814681468146816,
          -21.80968096809681,
          -21.804680468046804,
          -21.7996799679968,
          -21.794679467946793,
          -21.78967896789679,
          -21.784678467846785,
          -21.77967796779678,
          -21.774677467746773,
          -21.769676967696768,
          -21.764676467646765,
          -21.75967596759676,
          -21.754675467546754,
          -21.749674967496748,
          -21.744674467446746,
          -21.73967396739674,
          -21.734673467346735,
          -21.72967296729673,
          -21.724672467246723,
          -21.71967196719672,
          -21.714671467146715,
          -21.70967096709671,
          -21.704670467046704,
          -21.6996699669967,
          -21.694669466946696,
          -21.68966896689669,
          -21.684668466846684,
          -21.67966796679668,
          -21.674667466746676,
          -21.66966696669667,
          -21.664666466646665,
          -21.65966596659666,
          -21.654665466546653,
          -21.64966496649665,
          -21.644664466446645,
          -21.63966396639664,
          -21.634663466346634,
          -21.629662966296628,
          -21.624662466246626,
          -21.61966196619662,
          -21.614661466146615,
          -21.60966096609661,
          -21.604660466046603,
          -21.5996599659966,
          -21.594659465946595,
          -21.58965896589659,
          -21.584658465846584,
          -21.579657965796578,
          -21.574657465746576,
          -21.56965696569657,
          -21.564656465646564,
          -21.55965596559656,
          -21.554655465546553,
          -21.54965496549655,
          -21.544654465446545,
          -21.53965396539654,
          -21.534653465346533,
          -21.529652965296528,
          -21.524652465246525,
          -21.51965196519652,
          -21.514651465146514,
          -21.509650965096508,
          -21.504650465046506,
          -21.4996499649965,
          -21.494649464946495,
          -21.48964896489649,
          -21.484648464846483,
          -21.47964796479648,
          -21.474647464746475,
          -21.46964696469647,
          -21.464646464646464,
          -21.45964596459646,
          -21.454645464546456,
          -21.44964496449645,
          -21.444644464446444,
          -21.43964396439644,
          -21.434643464346436,
          -21.42964296429643,
          -21.424642464246425,
          -21.41964196419642,
          -21.414641464146413,
          -21.40964096409641,
          -21.404640464046405,
          -21.3996399639964,
          -21.394639463946394,
          -21.389638963896388,
          -21.384638463846386,
          -21.37963796379638,
          -21.374637463746375,
          -21.36963696369637,
          -21.364636463646363,
          -21.35963596359636,
          -21.354635463546355,
          -21.34963496349635,
          -21.344634463446344,
          -21.339633963396338,
          -21.334633463346336,
          -21.32963296329633,
          -21.324632463246324,
          -21.31963196319632,
          -21.314631463146313,
          -21.30963096309631,
          -21.304630463046305,
          -21.2996299629963,
          -21.294629462946293,
          -21.289628962896288,
          -21.284628462846285,
          -21.27962796279628,
          -21.274627462746274,
          -21.269626962696268,
          -21.264626462646266,
          -21.25962596259626,
          -21.254625462546255,
          -21.24962496249625,
          -21.244624462446243,
          -21.23962396239624,
          -21.234623462346235,
          -21.22962296229623,
          -21.224622462246224,
          -21.21962196219622,
          -21.214621462146216,
          -21.20962096209621,
          -21.204620462046204,
          -21.1996199619962,
          -21.194619461946196,
          -21.18961896189619,
          -21.184618461846185,
          -21.17961796179618,
          -21.174617461746173,
          -21.16961696169617,
          -21.164616461646165,
          -21.15961596159616,
          -21.154615461546154,
          -21.149614961496148,
          -21.144614461446146,
          -21.13961396139614,
          -21.134613461346134,
          -21.12961296129613,
          -21.124612461246123,
          -21.11961196119612,
          -21.114611461146115,
          -21.10961096109611,
          -21.104610461046104,
          -21.099609960996098,
          -21.094609460946096,
          -21.08960896089609,
          -21.084608460846084,
          -21.07960796079608,
          -21.074607460746073,
          -21.06960696069607,
          -21.064606460646065,
          -21.05960596059606,
          -21.054605460546053,
          -21.049604960496048,
          -21.044604460446045,
          -21.03960396039604,
          -21.034603460346034,
          -21.029602960296028,
          -21.024602460246022,
          -21.01960196019602,
          -21.014601460146014,
          -21.00960096009601,
          -21.004600460046003,
          -20.999599959995997,
          -20.994599459945995,
          -20.98959895989599,
          -20.984598459845984,
          -20.97959795979598,
          -20.974597459745976,
          -20.96959695969597,
          -20.964596459645964,
          -20.95959595959596,
          -20.954595459545956,
          -20.94959495949595,
          -20.944594459445945,
          -20.93959395939594,
          -20.934593459345933,
          -20.92959295929593,
          -20.924592459245925,
          -20.91959195919592,
          -20.914591459145914,
          -20.909590959095908,
          -20.904590459045906,
          -20.8995899589959,
          -20.894589458945894,
          -20.88958895889589,
          -20.884588458845883,
          -20.87958795879588,
          -20.874587458745875,
          -20.86958695869587,
          -20.864586458645864,
          -20.859585958595858,
          -20.854585458545856,
          -20.84958495849585,
          -20.844584458445844,
          -20.83958395839584,
          -20.834583458345833,
          -20.82958295829583,
          -20.824582458245825,
          -20.81958195819582,
          -20.814581458145813,
          -20.809580958095808,
          -20.804580458045805,
          -20.7995799579958,
          -20.794579457945794,
          -20.789578957895788,
          -20.784578457845782,
          -20.77957795779578,
          -20.774577457745774,
          -20.76957695769577,
          -20.764576457645767,
          -20.759575957595757,
          -20.754575457545755,
          -20.74957495749575,
          -20.744574457445744,
          -20.73957395739574,
          -20.734573457345736,
          -20.72957295729573,
          -20.724572457245724,
          -20.71957195719572,
          -20.714571457145716,
          -20.70957095709571,
          -20.704570457045705,
          -20.6995699569957,
          -20.694569456945693,
          -20.68956895689569,
          -20.684568456845685,
          -20.67956795679568,
          -20.674567456745674,
          -20.669566956695668,
          -20.664566456645666,
          -20.65956595659566,
          -20.654565456545654,
          -20.64956495649565,
          -20.644564456445643,
          -20.63956395639564,
          -20.634563456345635,
          -20.62956295629563,
          -20.624562456245624,
          -20.619561956195618,
          -20.614561456145616,
          -20.60956095609561,
          -20.604560456045604,
          -20.5995599559956,
          -20.594559455945593,
          -20.58955895589559,
          -20.584558455845585,
          -20.57955795579558,
          -20.574557455745573,
          -20.569556955695568,
          -20.564556455645565,
          -20.55955595559556,
          -20.554555455545554,
          -20.549554955495548,
          -20.544554455445542,
          -20.53955395539554,
          -20.534553455345534,
          -20.52955295529553,
          -20.524552455245527,
          -20.519551955195517,
          -20.514551455145515,
          -20.50955095509551,
          -20.504550455045504,
          -20.4995499549955,
          -20.494549454945496,
          -20.48954895489549,
          -20.484548454845484,
          -20.47954795479548,
          -20.474547454745476,
          -20.46954695469547,
          -20.464546454645465,
          -20.45954595459546,
          -20.454545454545453,
          -20.44954495449545,
          -20.444544454445445,
          -20.43954395439544,
          -20.434543454345434,
          -20.429542954295428,
          -20.424542454245426,
          -20.41954195419542,
          -20.414541454145414,
          -20.40954095409541,
          -20.404540454045403,
          -20.3995399539954,
          -20.394539453945395,
          -20.38953895389539,
          -20.384538453845384,
          -20.379537953795378,
          -20.374537453745376,
          -20.36953695369537,
          -20.364536453645364,
          -20.35953595359536,
          -20.354535453545353,
          -20.34953495349535,
          -20.344534453445345,
          -20.33953395339534,
          -20.334533453345333,
          -20.329532953295328,
          -20.324532453245325,
          -20.31953195319532,
          -20.314531453145314,
          -20.309530953095308,
          -20.304530453045302,
          -20.2995299529953,
          -20.294529452945294,
          -20.28952895289529,
          -20.284528452845286,
          -20.279527952795277,
          -20.274527452745275,
          -20.26952695269527,
          -20.264526452645264,
          -20.25952595259526,
          -20.254525452545256,
          -20.24952495249525,
          -20.244524452445244,
          -20.23952395239524,
          -20.234523452345236,
          -20.22952295229523,
          -20.224522452245225,
          -20.21952195219522,
          -20.214521452145213,
          -20.20952095209521,
          -20.204520452045205,
          -20.1995199519952,
          -20.194519451945194,
          -20.189518951895188,
          -20.184518451845186,
          -20.17951795179518,
          -20.174517451745174,
          -20.16951695169517,
          -20.164516451645163,
          -20.15951595159516,
          -20.154515451545155,
          -20.14951495149515,
          -20.144514451445144,
          -20.139513951395138,
          -20.134513451345136,
          -20.12951295129513,
          -20.124512451245124,
          -20.11951195119512,
          -20.114511451145113,
          -20.10951095109511,
          -20.104510451045105,
          -20.0995099509951,
          -20.094509450945093,
          -20.089508950895087,
          -20.084508450845085,
          -20.07950795079508,
          -20.074507450745074,
          -20.069506950695068,
          -20.064506450645062,
          -20.05950595059506,
          -20.054505450545054,
          -20.04950495049505,
          -20.044504450445046,
          -20.039503950395037,
          -20.034503450345035,
          -20.02950295029503,
          -20.024502450245024,
          -20.01950195019502,
          -20.014501450145016,
          -20.00950095009501,
          -20.004500450045004,
          -19.999499949995,
          -19.994499449944996,
          -19.98949894989499,
          -19.984498449844985,
          -19.97949794979498,
          -19.974497449744973,
          -19.96949694969497,
          -19.964496449644965,
          -19.95949594959496,
          -19.954495449544954,
          -19.949494949494948,
          -19.944494449444946,
          -19.93949394939494,
          -19.934493449344934,
          -19.92949294929493,
          -19.924492449244923,
          -19.91949194919492,
          -19.914491449144915,
          -19.90949094909491,
          -19.904490449044903,
          -19.899489948994898,
          -19.894489448944896,
          -19.88948894889489,
          -19.884488448844884,
          -19.87948794879488,
          -19.874487448744873,
          -19.86948694869487,
          -19.864486448644865,
          -19.85948594859486,
          -19.854485448544853,
          -19.849484948494847,
          -19.844484448444845,
          -19.83948394839484,
          -19.834483448344834,
          -19.829482948294828,
          -19.824482448244822,
          -19.81948194819482,
          -19.814481448144814,
          -19.80948094809481,
          -19.804480448044803,
          -19.799479947994797,
          -19.794479447944795,
          -19.78947894789479,
          -19.784478447844783,
          -19.77947794779478,
          -19.774477447744772,
          -19.76947694769477,
          -19.764476447644764,
          -19.75947594759476,
          -19.754475447544756,
          -19.74947494749475,
          -19.744474447444745,
          -19.73947394739474,
          -19.734473447344733,
          -19.72947294729473,
          -19.724472447244725,
          -19.71947194719472,
          -19.714471447144714,
          -19.709470947094708,
          -19.704470447044706,
          -19.6994699469947,
          -19.694469446944694,
          -19.68946894689469,
          -19.684468446844683,
          -19.67946794679468,
          -19.674467446744675,
          -19.66946694669467,
          -19.664466446644663,
          -19.659465946594658,
          -19.654465446544656,
          -19.64946494649465,
          -19.644464446444644,
          -19.63946394639464,
          -19.634463446344633,
          -19.62946294629463,
          -19.624462446244625,
          -19.61946194619462,
          -19.614461446144613,
          -19.609460946094607,
          -19.604460446044605,
          -19.5994599459946,
          -19.594459445944594,
          -19.589458945894588,
          -19.584458445844582,
          -19.57945794579458,
          -19.574457445744574,
          -19.56945694569457,
          -19.564456445644563,
          -19.559455945594557,
          -19.554455445544555,
          -19.54945494549455,
          -19.544454445444543,
          -19.53945394539454,
          -19.534453445344532,
          -19.52945294529453,
          -19.524452445244524,
          -19.51945194519452,
          -19.514451445144516,
          -19.50945094509451,
          -19.504450445044505,
          -19.4994499449945,
          -19.494449444944493,
          -19.48944894489449,
          -19.484448444844485,
          -19.47944794479448,
          -19.474447444744474,
          -19.469446944694468,
          -19.464446444644466,
          -19.45944594459446,
          -19.454445444544454,
          -19.44944494449445,
          -19.444444444444443,
          -19.43944394439444,
          -19.434443444344435,
          -19.42944294429443,
          -19.424442444244423,
          -19.419441944194418,
          -19.414441444144416,
          -19.40944094409441,
          -19.404440444044404,
          -19.3994399439944,
          -19.394439443944393,
          -19.38943894389439,
          -19.384438443844385,
          -19.37943794379438,
          -19.374437443744373,
          -19.369436943694367,
          -19.364436443644365,
          -19.35943594359436,
          -19.354435443544354,
          -19.349434943494348,
          -19.344434443444342,
          -19.33943394339434,
          -19.334433443344334,
          -19.32943294329433,
          -19.324432443244323,
          -19.319431943194317,
          -19.314431443144315,
          -19.30943094309431,
          -19.304430443044303,
          -19.2994299429943,
          -19.294429442944292,
          -19.28942894289429,
          -19.284428442844284,
          -19.27942794279428,
          -19.274427442744276,
          -19.26942694269427,
          -19.264426442644265,
          -19.25942594259426,
          -19.254425442544253,
          -19.24942494249425,
          -19.244424442444245,
          -19.23942394239424,
          -19.234423442344234,
          -19.229422942294228,
          -19.224422442244226,
          -19.21942194219422,
          -19.214421442144214,
          -19.20942094209421,
          -19.204420442044203,
          -19.1994199419942,
          -19.194419441944195,
          -19.18941894189419,
          -19.184418441844183,
          -19.179417941794178,
          -19.174417441744176,
          -19.16941694169417,
          -19.164416441644164,
          -19.15941594159416,
          -19.154415441544153,
          -19.14941494149415,
          -19.144414441444145,
          -19.13941394139414,
          -19.134413441344133,
          -19.129412941294127,
          -19.124412441244125,
          -19.11941194119412,
          -19.114411441144114,
          -19.109410941094108,
          -19.104410441044102,
          -19.0994099409941,
          -19.094409440944094,
          -19.08940894089409,
          -19.084408440844083,
          -19.079407940794077,
          -19.074407440744075,
          -19.06940694069407,
          -19.064406440644063,
          -19.05940594059406,
          -19.054405440544052,
          -19.04940494049405,
          -19.044404440444044,
          -19.03940394039404,
          -19.034403440344036,
          -19.02940294029403,
          -19.024402440244025,
          -19.01940194019402,
          -19.014401440144013,
          -19.00940094009401,
          -19.004400440044005,
          -18.999399939994,
          -18.994399439943994,
          -18.989398939893988,
          -18.984398439843986,
          -18.97939793979398,
          -18.974397439743974,
          -18.96939693969397,
          -18.964396439643963,
          -18.95939593959396,
          -18.954395439543955,
          -18.94939493949395,
          -18.944394439443943,
          -18.939393939393938,
          -18.934393439343935,
          -18.92939293929393,
          -18.924392439243924,
          -18.91939193919392,
          -18.914391439143913,
          -18.90939093909391,
          -18.904390439043905,
          -18.8993899389939,
          -18.894389438943893,
          -18.889388938893887,
          -18.884388438843885,
          -18.87938793879388,
          -18.874387438743874,
          -18.869386938693868,
          -18.864386438643862,
          -18.85938593859386,
          -18.854385438543854,
          -18.84938493849385,
          -18.844384438443843,
          -18.839383938393837,
          -18.834383438343835,
          -18.82938293829383,
          -18.824382438243823,
          -18.81938193819382,
          -18.814381438143812,
          -18.80938093809381,
          -18.804380438043804,
          -18.7993799379938,
          -18.794379437943796,
          -18.78937893789379,
          -18.784378437843785,
          -18.77937793779378,
          -18.774377437743773,
          -18.76937693769377,
          -18.764376437643765,
          -18.75937593759376,
          -18.754375437543754,
          -18.749374937493748,
          -18.744374437443746,
          -18.73937393739374,
          -18.734373437343734,
          -18.72937293729373,
          -18.724372437243723,
          -18.71937193719372,
          -18.714371437143715,
          -18.70937093709371,
          -18.704370437043703,
          -18.699369936993698,
          -18.694369436943695,
          -18.68936893689369,
          -18.684368436843684,
          -18.67936793679368,
          -18.674367436743672,
          -18.66936693669367,
          -18.664366436643665,
          -18.65936593659366,
          -18.654365436543653,
          -18.649364936493647,
          -18.644364436443645,
          -18.63936393639364,
          -18.634363436343634,
          -18.629362936293628,
          -18.624362436243622,
          -18.61936193619362,
          -18.614361436143614,
          -18.60936093609361,
          -18.604360436043603,
          -18.599359935993597,
          -18.594359435943595,
          -18.58935893589359,
          -18.584358435843583,
          -18.57935793579358,
          -18.574357435743572,
          -18.56935693569357,
          -18.564356435643564,
          -18.55935593559356,
          -18.554355435543556,
          -18.54935493549355,
          -18.544354435443545,
          -18.53935393539354,
          -18.534353435343533,
          -18.52935293529353,
          -18.524352435243525,
          -18.51935193519352,
          -18.514351435143514,
          -18.509350935093508,
          -18.504350435043506,
          -18.4993499349935,
          -18.494349434943494,
          -18.48934893489349,
          -18.484348434843483,
          -18.47934793479348,
          -18.474347434743475,
          -18.46934693469347,
          -18.464346434643463,
          -18.459345934593458,
          -18.454345434543455,
          -18.44934493449345,
          -18.444344434443444,
          -18.439343934393438,
          -18.434343434343432,
          -18.42934293429343,
          -18.424342434243425,
          -18.41934193419342,
          -18.414341434143413,
          -18.409340934093407,
          -18.404340434043405,
          -18.3993399339934,
          -18.394339433943394,
          -18.389338933893388,
          -18.384338433843382,
          -18.37933793379338,
          -18.374337433743374,
          -18.36933693369337,
          -18.364336433643363,
          -18.359335933593357,
          -18.354335433543355,
          -18.34933493349335,
          -18.344334433443343,
          -18.33933393339334,
          -18.334333433343332,
          -18.32933293329333,
          -18.324332433243324,
          -18.319331933193318,
          -18.314331433143316,
          -18.30933093309331,
          -18.304330433043305,
          -18.2993299329933,
          -18.294329432943293,
          -18.28932893289329,
          -18.284328432843285,
          -18.27932793279328,
          -18.274327432743274,
          -18.269326932693268,
          -18.264326432643266,
          -18.25932593259326,
          -18.254325432543254,
          -18.24932493249325,
          -18.244324432443243,
          -18.23932393239324,
          -18.234323432343235,
          -18.22932293229323,
          -18.224322432243223,
          -18.219321932193218,
          -18.214321432143215,
          -18.20932093209321,
          -18.204320432043204,
          -18.199319931993198,
          -18.194319431943192,
          -18.18931893189319,
          -18.184318431843185,
          -18.17931793179318,
          -18.174317431743173,
          -18.169316931693167,
          -18.164316431643165,
          -18.15931593159316,
          -18.154315431543154,
          -18.149314931493148,
          -18.144314431443142,
          -18.13931393139314,
          -18.134313431343134,
          -18.12931293129313,
          -18.124312431243123,
          -18.119311931193117,
          -18.114311431143115,
          -18.10931093109311,
          -18.104310431043103,
          -18.0993099309931,
          -18.094309430943092,
          -18.08930893089309,
          -18.084308430843084,
          -18.079307930793078,
          -18.074307430743076,
          -18.06930693069307,
          -18.064306430643065,
          -18.05930593059306,
          -18.054305430543053,
          -18.04930493049305,
          -18.044304430443045,
          -18.03930393039304,
          -18.034303430343034,
          -18.029302930293028,
          -18.024302430243026,
          -18.01930193019302,
          -18.014301430143014,
          -18.00930093009301,
          -18.004300430043003,
          -17.999299929993,
          -17.994299429942995,
          -17.98929892989299,
          -17.984298429842983,
          -17.979297929792978,
          -17.974297429742975,
          -17.96929692969297,
          -17.964296429642964,
          -17.959295929592958,
          -17.954295429542952,
          -17.94929492949295,
          -17.944294429442945,
          -17.93929392939294,
          -17.934293429342933,
          -17.929292929292927,
          -17.924292429242925,
          -17.91929192919292,
          -17.914291429142914,
          -17.909290929092908,
          -17.904290429042902,
          -17.8992899289929,
          -17.894289428942894,
          -17.88928892889289,
          -17.884288428842883,
          -17.879287928792877,
          -17.874287428742875,
          -17.86928692869287,
          -17.864286428642863,
          -17.85928592859286,
          -17.854285428542852,
          -17.84928492849285,
          -17.844284428442844,
          -17.839283928392838,
          -17.834283428342836,
          -17.82928292829283,
          -17.824282428242824,
          -17.81928192819282,
          -17.814281428142813,
          -17.80928092809281,
          -17.804280428042805,
          -17.7992799279928,
          -17.794279427942794,
          -17.789278927892788,
          -17.784278427842786,
          -17.77927792779278,
          -17.774277427742774,
          -17.76927692769277,
          -17.764276427642763,
          -17.75927592759276,
          -17.754275427542755,
          -17.74927492749275,
          -17.744274427442743,
          -17.739273927392738,
          -17.734273427342735,
          -17.72927292729273,
          -17.724272427242724,
          -17.719271927192718,
          -17.714271427142712,
          -17.70927092709271,
          -17.704270427042704,
          -17.6992699269927,
          -17.694269426942693,
          -17.689268926892687,
          -17.684268426842685,
          -17.67926792679268,
          -17.674267426742674,
          -17.669266926692668,
          -17.664266426642662,
          -17.65926592659266,
          -17.654265426542654,
          -17.64926492649265,
          -17.644264426442643,
          -17.639263926392637,
          -17.634263426342635,
          -17.62926292629263,
          -17.624262426242623,
          -17.61926192619262,
          -17.614261426142612,
          -17.60926092609261,
          -17.604260426042604,
          -17.599259925992598,
          -17.594259425942596,
          -17.58925892589259,
          -17.584258425842584,
          -17.57925792579258,
          -17.574257425742573,
          -17.56925692569257,
          -17.564256425642565,
          -17.55925592559256,
          -17.554255425542554,
          -17.549254925492548,
          -17.544254425442546,
          -17.53925392539254,
          -17.534253425342534,
          -17.52925292529253,
          -17.524252425242523,
          -17.51925192519252,
          -17.514251425142515,
          -17.50925092509251,
          -17.504250425042503,
          -17.499249924992498,
          -17.494249424942495,
          -17.48924892489249,
          -17.484248424842484,
          -17.479247924792478,
          -17.474247424742472,
          -17.46924692469247,
          -17.464246424642464,
          -17.45924592459246,
          -17.454245424542453,
          -17.449244924492447,
          -17.444244424442445,
          -17.43924392439244,
          -17.434243424342434,
          -17.429242924292428,
          -17.424242424242422,
          -17.41924192419242,
          -17.414241424142414,
          -17.40924092409241,
          -17.404240424042403,
          -17.399239923992397,
          -17.394239423942395,
          -17.38923892389239,
          -17.384238423842383,
          -17.37923792379238,
          -17.374237423742372,
          -17.36923692369237,
          -17.364236423642364,
          -17.359235923592358,
          -17.354235423542356,
          -17.34923492349235,
          -17.344234423442344,
          -17.33923392339234,
          -17.334233423342333,
          -17.32923292329233,
          -17.324232423242325,
          -17.31923192319232,
          -17.314231423142314,
          -17.309230923092308,
          -17.304230423042306,
          -17.2992299229923,
          -17.294229422942294,
          -17.28922892289229,
          -17.284228422842283,
          -17.27922792279228,
          -17.274227422742275,
          -17.26922692269227,
          -17.264226422642263,
          -17.259225922592258,
          -17.254225422542255,
          -17.24922492249225,
          -17.244224422442244,
          -17.239223922392238,
          -17.234223422342232,
          -17.22922292229223,
          -17.224222422242224,
          -17.21922192219222,
          -17.214221422142213,
          -17.209220922092207,
          -17.204220422042205,
          -17.1992199219922,
          -17.194219421942194,
          -17.189218921892188,
          -17.184218421842182,
          -17.17921792179218,
          -17.174217421742174,
          -17.16921692169217,
          -17.164216421642163,
          -17.159215921592157,
          -17.154215421542155,
          -17.14921492149215,
          -17.144214421442143,
          -17.139213921392138,
          -17.13421342134213,
          -17.12921292129213,
          -17.124212421242124,
          -17.119211921192118,
          -17.114211421142116,
          -17.109210921092107,
          -17.104210421042104,
          -17.0992099209921,
          -17.094209420942093,
          -17.08920892089209,
          -17.084208420842085,
          -17.07920792079208,
          -17.074207420742074,
          -17.069206920692068,
          -17.064206420642066,
          -17.05920592059206,
          -17.054205420542054,
          -17.04920492049205,
          -17.044204420442043,
          -17.03920392039204,
          -17.034203420342035,
          -17.02920292029203,
          -17.024202420242023,
          -17.019201920192017,
          -17.014201420142015,
          -17.00920092009201,
          -17.004200420042004,
          -16.999199919991998,
          -16.994199419941992,
          -16.98919891989199,
          -16.984198419841984,
          -16.97919791979198,
          -16.974197419741973,
          -16.969196919691967,
          -16.964196419641965,
          -16.95919591959196,
          -16.954195419541954,
          -16.94919491949195,
          -16.944194419441942,
          -16.93919391939194,
          -16.934193419341934,
          -16.92919291929193,
          -16.924192419241926,
          -16.919191919191917,
          -16.914191419141915,
          -16.90919091909191,
          -16.904190419041903,
          -16.8991899189919,
          -16.89418941894189,
          -16.88918891889189,
          -16.884188418841884,
          -16.879187918791878,
          -16.874187418741876,
          -16.869186918691867,
          -16.864186418641864,
          -16.85918591859186,
          -16.854185418541853,
          -16.84918491849185,
          -16.84418441844184,
          -16.83918391839184,
          -16.834183418341834,
          -16.829182918291828,
          -16.824182418241826,
          -16.819181918191816,
          -16.814181418141814,
          -16.80918091809181,
          -16.804180418041803,
          -16.7991799179918,
          -16.79417941794179,
          -16.78917891789179,
          -16.784178417841783,
          -16.779177917791777,
          -16.774177417741775,
          -16.76917691769177,
          -16.764176417641764,
          -16.759175917591758,
          -16.754175417541752,
          -16.74917491749175,
          -16.744174417441744,
          -16.73917391739174,
          -16.734173417341733,
          -16.729172917291727,
          -16.724172417241725,
          -16.71917191719172,
          -16.714171417141714,
          -16.70917091709171,
          -16.704170417041702,
          -16.6991699169917,
          -16.694169416941694,
          -16.68916891689169,
          -16.684168416841686,
          -16.679167916791677,
          -16.674167416741675,
          -16.66916691669167,
          -16.664166416641663,
          -16.65916591659166,
          -16.65416541654165,
          -16.64916491649165,
          -16.644164416441644,
          -16.639163916391638,
          -16.634163416341636,
          -16.629162916291627,
          -16.624162416241624,
          -16.61916191619162,
          -16.614161416141613,
          -16.60916091609161,
          -16.6041604160416,
          -16.5991599159916,
          -16.594159415941593,
          -16.589158915891588,
          -16.584158415841586,
          -16.579157915791576,
          -16.574157415741574,
          -16.56915691569157,
          -16.564156415641563,
          -16.55915591559156,
          -16.55415541554155,
          -16.54915491549155,
          -16.544154415441543,
          -16.539153915391537,
          -16.534153415341535,
          -16.52915291529153,
          -16.524152415241524,
          -16.519151915191518,
          -16.514151415141512,
          -16.50915091509151,
          -16.504150415041504,
          -16.4991499149915,
          -16.494149414941493,
          -16.489148914891487,
          -16.484148414841485,
          -16.47914791479148,
          -16.474147414741473,
          -16.46914691469147,
          -16.464146414641462,
          -16.45914591459146,
          -16.454145414541454,
          -16.44914491449145,
          -16.444144414441446,
          -16.439143914391437,
          -16.434143414341435,
          -16.42914291429143,
          -16.424142414241423,
          -16.41914191419142,
          -16.41414141414141,
          -16.40914091409141,
          -16.404140414041404,
          -16.399139913991398,
          -16.394139413941396,
          -16.389138913891387,
          -16.384138413841384,
          -16.37913791379138,
          -16.374137413741373,
          -16.36913691369137,
          -16.36413641364136,
          -16.35913591359136,
          -16.354135413541353,
          -16.349134913491348,
          -16.344134413441346,
          -16.339133913391336,
          -16.334133413341334,
          -16.32913291329133,
          -16.324132413241323,
          -16.31913191319132,
          -16.31413141314131,
          -16.30913091309131,
          -16.304130413041303,
          -16.299129912991297,
          -16.294129412941295,
          -16.28912891289129,
          -16.284128412841284,
          -16.279127912791278,
          -16.274127412741272,
          -16.26912691269127,
          -16.264126412641264,
          -16.25912591259126,
          -16.254125412541253,
          -16.249124912491247,
          -16.244124412441245,
          -16.23912391239124,
          -16.234123412341233,
          -16.22912291229123,
          -16.224122412241222,
          -16.21912191219122,
          -16.214121412141214,
          -16.20912091209121,
          -16.204120412041206,
          -16.199119911991197,
          -16.194119411941195,
          -16.18911891189119,
          -16.184118411841183,
          -16.17911791179118,
          -16.17411741174117,
          -16.16911691169117,
          -16.164116411641164,
          -16.159115911591158,
          -16.154115411541156,
          -16.149114911491147,
          -16.144114411441144,
          -16.13911391139114,
          -16.134113411341133,
          -16.12911291129113,
          -16.12411241124112,
          -16.11911191119112,
          -16.114111411141113,
          -16.109110911091108,
          -16.104110411041106,
          -16.099109910991096,
          -16.094109410941094,
          -16.08910891089109,
          -16.084108410841083,
          -16.07910791079108,
          -16.07410741074107,
          -16.06910691069107,
          -16.064106410641063,
          -16.059105910591057,
          -16.054105410541055,
          -16.04910491049105,
          -16.044104410441044,
          -16.039103910391038,
          -16.034103410341032,
          -16.02910291029103,
          -16.024102410241024,
          -16.01910191019102,
          -16.014101410141013,
          -16.009100910091007,
          -16.004100410041005,
          -15.999099909991,
          -15.994099409940993,
          -15.98909890989099,
          -15.984098409840984,
          -15.979097909790978,
          -15.974097409740974,
          -15.969096909690968,
          -15.964096409640964,
          -15.959095909590959,
          -15.954095409540953,
          -15.949094909490949,
          -15.944094409440943,
          -15.93909390939094,
          -15.934093409340933,
          -15.92909290929093,
          -15.924092409240924,
          -15.919091909190918,
          -15.914091409140914,
          -15.909090909090908,
          -15.904090409040904,
          -15.899089908990899,
          -15.894089408940893,
          -15.889088908890889,
          -15.884088408840883,
          -15.87908790879088,
          -15.874087408740873,
          -15.86908690869087,
          -15.864086408640864,
          -15.859085908590858,
          -15.854085408540854,
          -15.849084908490848,
          -15.844084408440844,
          -15.839083908390839,
          -15.834083408340833,
          -15.829082908290829,
          -15.824082408240823,
          -15.81908190819082,
          -15.814081408140813,
          -15.80908090809081,
          -15.804080408040804,
          -15.799079907990798,
          -15.794079407940794,
          -15.789078907890788,
          -15.784078407840784,
          -15.779077907790779,
          -15.774077407740773,
          -15.769076907690769,
          -15.764076407640763,
          -15.75907590759076,
          -15.754075407540753,
          -15.74907490749075,
          -15.744074407440744,
          -15.739073907390738,
          -15.734073407340734,
          -15.729072907290728,
          -15.724072407240724,
          -15.719071907190719,
          -15.714071407140713,
          -15.709070907090709,
          -15.704070407040703,
          -15.6990699069907,
          -15.694069406940693,
          -15.68906890689069,
          -15.684068406840684,
          -15.679067906790678,
          -15.674067406740674,
          -15.669066906690668,
          -15.664066406640664,
          -15.659065906590659,
          -15.654065406540653,
          -15.649064906490649,
          -15.644064406440643,
          -15.63906390639064,
          -15.634063406340633,
          -15.62906290629063,
          -15.624062406240624,
          -15.619061906190618,
          -15.614061406140614,
          -15.609060906090608,
          -15.604060406040604,
          -15.599059905990599,
          -15.594059405940593,
          -15.589058905890589,
          -15.584058405840583,
          -15.57905790579058,
          -15.574057405740573,
          -15.56905690569057,
          -15.564056405640564,
          -15.559055905590558,
          -15.554055405540554,
          -15.549054905490548,
          -15.544054405440544,
          -15.539053905390539,
          -15.534053405340533,
          -15.529052905290529,
          -15.524052405240523,
          -15.51905190519052,
          -15.514051405140513,
          -15.50905090509051,
          -15.504050405040504,
          -15.499049904990498,
          -15.494049404940494,
          -15.489048904890488,
          -15.484048404840484,
          -15.479047904790479,
          -15.474047404740473,
          -15.469046904690469,
          -15.464046404640463,
          -15.45904590459046,
          -15.454045404540453,
          -15.44904490449045,
          -15.444044404440444,
          -15.439043904390438,
          -15.434043404340434,
          -15.429042904290428,
          -15.424042404240424,
          -15.419041904190419,
          -15.414041404140413,
          -15.409040904090409,
          -15.404040404040403,
          -15.3990399039904,
          -15.394039403940393,
          -15.38903890389039,
          -15.384038403840384,
          -15.379037903790378,
          -15.374037403740374,
          -15.369036903690368,
          -15.364036403640364,
          -15.359035903590359,
          -15.354035403540353,
          -15.349034903490349,
          -15.344034403440343,
          -15.33903390339034,
          -15.334033403340333,
          -15.32903290329033,
          -15.324032403240324,
          -15.319031903190318,
          -15.314031403140314,
          -15.309030903090308,
          -15.304030403040304,
          -15.299029902990299,
          -15.294029402940293,
          -15.289028902890289,
          -15.284028402840283,
          -15.27902790279028,
          -15.274027402740273,
          -15.26902690269027,
          -15.264026402640264,
          -15.259025902590258,
          -15.254025402540254,
          -15.249024902490248,
          -15.244024402440244,
          -15.239023902390239,
          -15.234023402340233,
          -15.229022902290229,
          -15.224022402240223,
          -15.219021902190219,
          -15.214021402140213,
          -15.20902090209021,
          -15.204020402040204,
          -15.199019901990198,
          -15.194019401940194,
          -15.189018901890188,
          -15.184018401840184,
          -15.179017901790179,
          -15.174017401740173,
          -15.169016901690169,
          -15.164016401640163,
          -15.159015901590159,
          -15.154015401540153,
          -15.14901490149015,
          -15.144014401440144,
          -15.139013901390138,
          -15.134013401340134,
          -15.129012901290128,
          -15.124012401240124,
          -15.119011901190119,
          -15.114011401140113,
          -15.109010901090109,
          -15.104010401040103,
          -15.099009900990099,
          -15.094009400940093,
          -15.08900890089009,
          -15.084008400840084,
          -15.079007900790078,
          -15.074007400740074,
          -15.069006900690068,
          -15.064006400640064,
          -15.059005900590059,
          -15.054005400540053,
          -15.049004900490049,
          -15.044004400440043,
          -15.039003900390039,
          -15.034003400340033,
          -15.02900290029003,
          -15.024002400240024,
          -15.019001900190018,
          -15.014001400140014,
          -15.009000900090008,
          -15.004000400040004,
          -14.998999899989998,
          -14.993999399939993,
          -14.988998899889989,
          -14.983998399839983,
          -14.978997899789979,
          -14.973997399739973,
          -14.96899689968997,
          -14.963996399639964,
          -14.958995899589958,
          -14.953995399539954,
          -14.948994899489948,
          -14.943994399439944,
          -14.938993899389938,
          -14.933993399339933,
          -14.928992899289929,
          -14.923992399239923,
          -14.918991899189919,
          -14.913991399139913,
          -14.90899089908991,
          -14.903990399039904,
          -14.898989898989898,
          -14.893989398939894,
          -14.888988898889888,
          -14.883988398839884,
          -14.878987898789878,
          -14.873987398739873,
          -14.868986898689869,
          -14.863986398639863,
          -14.858985898589859,
          -14.853985398539853,
          -14.84898489848985,
          -14.843984398439844,
          -14.838983898389838,
          -14.833983398339834,
          -14.828982898289828,
          -14.823982398239824,
          -14.818981898189818,
          -14.813981398139813,
          -14.808980898089809,
          -14.803980398039803,
          -14.798979897989799,
          -14.793979397939793,
          -14.78897889788979,
          -14.783978397839784,
          -14.778977897789778,
          -14.773977397739774,
          -14.768976897689768,
          -14.763976397639764,
          -14.758975897589758,
          -14.753975397539753,
          -14.748974897489749,
          -14.743974397439743,
          -14.738973897389739,
          -14.733973397339733,
          -14.728972897289728,
          -14.723972397239724,
          -14.718971897189718,
          -14.713971397139714,
          -14.708970897089708,
          -14.703970397039704,
          -14.698969896989698,
          -14.693969396939693,
          -14.688968896889689,
          -14.683968396839683,
          -14.678967896789679,
          -14.673967396739673,
          -14.668966896689668,
          -14.663966396639664,
          -14.658965896589658,
          -14.653965396539654,
          -14.648964896489648,
          -14.643964396439644,
          -14.638963896389638,
          -14.633963396339633,
          -14.628962896289629,
          -14.623962396239623,
          -14.618961896189619,
          -14.613961396139613,
          -14.608960896089608,
          -14.603960396039604,
          -14.598959895989598,
          -14.593959395939594,
          -14.588958895889588,
          -14.583958395839584,
          -14.578957895789578,
          -14.573957395739573,
          -14.568956895689569,
          -14.563956395639563,
          -14.558955895589559,
          -14.553955395539553,
          -14.548954895489548,
          -14.543954395439544,
          -14.538953895389538,
          -14.533953395339534,
          -14.528952895289528,
          -14.523952395239524,
          -14.518951895189518,
          -14.513951395139513,
          -14.508950895089509,
          -14.503950395039503,
          -14.498949894989499,
          -14.493949394939493,
          -14.488948894889488,
          -14.483948394839484,
          -14.478947894789478,
          -14.473947394739474,
          -14.468946894689468,
          -14.463946394639464,
          -14.458945894589458,
          -14.453945394539453,
          -14.448944894489449,
          -14.443944394439443,
          -14.438943894389439,
          -14.433943394339433,
          -14.428942894289428,
          -14.423942394239424,
          -14.418941894189418,
          -14.413941394139414,
          -14.408940894089408,
          -14.403940394039404,
          -14.398939893989398,
          -14.393939393939393,
          -14.388938893889389,
          -14.383938393839383,
          -14.378937893789379,
          -14.373937393739373,
          -14.368936893689368,
          -14.363936393639364,
          -14.358935893589358,
          -14.353935393539354,
          -14.348934893489348,
          -14.343934393439344,
          -14.338933893389338,
          -14.333933393339333,
          -14.328932893289329,
          -14.323932393239323,
          -14.318931893189319,
          -14.313931393139313,
          -14.308930893089308,
          -14.303930393039304,
          -14.298929892989298,
          -14.293929392939294,
          -14.288928892889288,
          -14.283928392839284,
          -14.278927892789278,
          -14.273927392739273,
          -14.268926892689269,
          -14.263926392639263,
          -14.258925892589259,
          -14.253925392539253,
          -14.248924892489248,
          -14.243924392439244,
          -14.238923892389238,
          -14.233923392339234,
          -14.228922892289228,
          -14.223922392239224,
          -14.218921892189218,
          -14.213921392139213,
          -14.208920892089209,
          -14.203920392039203,
          -14.198919891989199,
          -14.193919391939193,
          -14.188918891889188,
          -14.183918391839184,
          -14.178917891789178,
          -14.173917391739174,
          -14.168916891689168,
          -14.163916391639164,
          -14.158915891589158,
          -14.153915391539153,
          -14.148914891489149,
          -14.143914391439143,
          -14.138913891389139,
          -14.133913391339133,
          -14.128912891289128,
          -14.123912391239124,
          -14.118911891189118,
          -14.113911391139114,
          -14.108910891089108,
          -14.103910391039104,
          -14.098909890989098,
          -14.093909390939093,
          -14.088908890889089,
          -14.083908390839083,
          -14.078907890789079,
          -14.073907390739073,
          -14.068906890689068,
          -14.063906390639064,
          -14.058905890589058,
          -14.053905390539054,
          -14.048904890489048,
          -14.043904390439044,
          -14.038903890389038,
          -14.033903390339033,
          -14.028902890289029,
          -14.023902390239023,
          -14.018901890189019,
          -14.013901390139013,
          -14.008900890089008,
          -14.003900390039004,
          -13.998899889988998,
          -13.993899389938994,
          -13.988898889888988,
          -13.983898389838984,
          -13.978897889788978,
          -13.973897389738973,
          -13.968896889688969,
          -13.963896389638963,
          -13.958895889588959,
          -13.953895389538953,
          -13.948894889488948,
          -13.943894389438944,
          -13.938893889388938,
          -13.933893389338934,
          -13.928892889288928,
          -13.923892389238924,
          -13.918891889188918,
          -13.913891389138913,
          -13.908890889088909,
          -13.903890389038903,
          -13.898889888988899,
          -13.893889388938893,
          -13.888888888888888,
          -13.883888388838884,
          -13.878887888788878,
          -13.873887388738874,
          -13.868886888688868,
          -13.863886388638864,
          -13.858885888588858,
          -13.853885388538853,
          -13.848884888488849,
          -13.843884388438843,
          -13.838883888388839,
          -13.833883388338833,
          -13.828882888288828,
          -13.823882388238824,
          -13.818881888188818,
          -13.813881388138814,
          -13.808880888088808,
          -13.803880388038804,
          -13.798879887988798,
          -13.793879387938793,
          -13.788878887888789,
          -13.783878387838783,
          -13.778877887788779,
          -13.773877387738773,
          -13.768876887688767,
          -13.763876387638764,
          -13.758875887588758,
          -13.753875387538754,
          -13.748874887488748,
          -13.743874387438744,
          -13.738873887388738,
          -13.733873387338733,
          -13.728872887288729,
          -13.723872387238723,
          -13.718871887188719,
          -13.713871387138713,
          -13.708870887088707,
          -13.703870387038704,
          -13.698869886988698,
          -13.693869386938694,
          -13.688868886888688,
          -13.683868386838684,
          -13.678867886788678,
          -13.673867386738673,
          -13.668866886688669,
          -13.663866386638663,
          -13.658865886588659,
          -13.653865386538653,
          -13.648864886488647,
          -13.643864386438644,
          -13.638863886388638,
          -13.633863386338634,
          -13.628862886288628,
          -13.623862386238624,
          -13.618861886188618,
          -13.613861386138613,
          -13.608860886088609,
          -13.603860386038603,
          -13.598859885988599,
          -13.593859385938593,
          -13.588858885888587,
          -13.583858385838584,
          -13.578857885788578,
          -13.573857385738574,
          -13.568856885688568,
          -13.563856385638564,
          -13.558855885588558,
          -13.553855385538553,
          -13.548854885488549,
          -13.543854385438543,
          -13.538853885388539,
          -13.533853385338533,
          -13.528852885288527,
          -13.523852385238524,
          -13.518851885188518,
          -13.513851385138514,
          -13.508850885088508,
          -13.503850385038504,
          -13.498849884988498,
          -13.493849384938493,
          -13.488848884888489,
          -13.483848384838483,
          -13.478847884788479,
          -13.473847384738473,
          -13.468846884688467,
          -13.463846384638464,
          -13.458845884588458,
          -13.453845384538454,
          -13.448844884488448,
          -13.443844384438444,
          -13.438843884388438,
          -13.433843384338433,
          -13.428842884288429,
          -13.423842384238423,
          -13.418841884188419,
          -13.413841384138413,
          -13.408840884088407,
          -13.403840384038403,
          -13.398839883988398,
          -13.393839383938394,
          -13.388838883888388,
          -13.383838383838384,
          -13.378837883788378,
          -13.373837383738373,
          -13.368836883688369,
          -13.363836383638363,
          -13.358835883588359,
          -13.353835383538353,
          -13.348834883488347,
          -13.343834383438343,
          -13.338833883388338,
          -13.333833383338334,
          -13.328832883288328,
          -13.323832383238324,
          -13.318831883188318,
          -13.313831383138313,
          -13.308830883088309,
          -13.303830383038303,
          -13.298829882988299,
          -13.293829382938293,
          -13.288828882888287,
          -13.283828382838283,
          -13.278827882788278,
          -13.273827382738274,
          -13.268826882688268,
          -13.263826382638264,
          -13.258825882588258,
          -13.253825382538253,
          -13.248824882488249,
          -13.243824382438243,
          -13.238823882388239,
          -13.233823382338233,
          -13.228822882288227,
          -13.223822382238223,
          -13.218821882188218,
          -13.213821382138214,
          -13.208820882088208,
          -13.203820382038204,
          -13.198819881988198,
          -13.193819381938193,
          -13.188818881888189,
          -13.183818381838183,
          -13.178817881788179,
          -13.173817381738173,
          -13.168816881688167,
          -13.163816381638163,
          -13.158815881588158,
          -13.153815381538154,
          -13.148814881488148,
          -13.143814381438144,
          -13.138813881388138,
          -13.133813381338133,
          -13.128812881288129,
          -13.123812381238123,
          -13.118811881188119,
          -13.113811381138113,
          -13.108810881088107,
          -13.103810381038103,
          -13.098809880988098,
          -13.093809380938094,
          -13.088808880888088,
          -13.083808380838084,
          -13.078807880788078,
          -13.073807380738073,
          -13.068806880688069,
          -13.063806380638063,
          -13.058805880588059,
          -13.053805380538053,
          -13.048804880488047,
          -13.043804380438043,
          -13.038803880388038,
          -13.033803380338034,
          -13.028802880288028,
          -13.023802380238024,
          -13.018801880188018,
          -13.013801380138013,
          -13.008800880088009,
          -13.003800380038003,
          -12.998799879987999,
          -12.993799379937993,
          -12.988798879887987,
          -12.983798379837983,
          -12.978797879787978,
          -12.973797379737974,
          -12.968796879687968,
          -12.963796379637964,
          -12.958795879587958,
          -12.953795379537953,
          -12.948794879487949,
          -12.943794379437943,
          -12.938793879387939,
          -12.933793379337933,
          -12.928792879287927,
          -12.923792379237923,
          -12.918791879187918,
          -12.913791379137914,
          -12.908790879087908,
          -12.903790379037904,
          -12.898789878987898,
          -12.893789378937893,
          -12.888788878887889,
          -12.883788378837883,
          -12.878787878787879,
          -12.873787378737873,
          -12.868786878687867,
          -12.863786378637863,
          -12.858785878587858,
          -12.853785378537854,
          -12.848784878487848,
          -12.843784378437844,
          -12.838783878387838,
          -12.833783378337833,
          -12.828782878287829,
          -12.823782378237823,
          -12.818781878187819,
          -12.813781378137813,
          -12.808780878087807,
          -12.803780378037803,
          -12.798779877987798,
          -12.793779377937794,
          -12.788778877887788,
          -12.783778377837784,
          -12.778777877787778,
          -12.773777377737773,
          -12.768776877687769,
          -12.763776377637763,
          -12.758775877587759,
          -12.753775377537753,
          -12.748774877487747,
          -12.743774377437743,
          -12.738773877387738,
          -12.733773377337734,
          -12.728772877287728,
          -12.723772377237724,
          -12.718771877187718,
          -12.713771377137713,
          -12.708770877087709,
          -12.703770377037703,
          -12.698769876987699,
          -12.693769376937693,
          -12.688768876887687,
          -12.683768376837683,
          -12.678767876787678,
          -12.673767376737674,
          -12.668766876687668,
          -12.663766376637664,
          -12.658765876587658,
          -12.653765376537653,
          -12.648764876487649,
          -12.643764376437643,
          -12.638763876387639,
          -12.633763376337633,
          -12.628762876287627,
          -12.623762376237623,
          -12.618761876187618,
          -12.613761376137614,
          -12.608760876087608,
          -12.603760376037604,
          -12.598759875987598,
          -12.593759375937593,
          -12.588758875887589,
          -12.583758375837583,
          -12.578757875787579,
          -12.573757375737573,
          -12.568756875687567,
          -12.563756375637563,
          -12.558755875587558,
          -12.553755375537554,
          -12.548754875487548,
          -12.543754375437544,
          -12.538753875387538,
          -12.533753375337533,
          -12.528752875287529,
          -12.523752375237523,
          -12.518751875187519,
          -12.513751375137513,
          -12.508750875087507,
          -12.503750375037503,
          -12.498749874987498,
          -12.493749374937494,
          -12.488748874887488,
          -12.483748374837484,
          -12.478747874787478,
          -12.473747374737473,
          -12.468746874687469,
          -12.463746374637463,
          -12.458745874587459,
          -12.453745374537453,
          -12.448744874487447,
          -12.443744374437443,
          -12.438743874387438,
          -12.433743374337434,
          -12.428742874287428,
          -12.423742374237424,
          -12.418741874187418,
          -12.413741374137413,
          -12.408740874087409,
          -12.403740374037403,
          -12.398739873987399,
          -12.393739373937393,
          -12.388738873887387,
          -12.383738373837383,
          -12.378737873787378,
          -12.373737373737374,
          -12.368736873687368,
          -12.363736373637364,
          -12.358735873587358,
          -12.353735373537353,
          -12.348734873487349,
          -12.343734373437343,
          -12.338733873387339,
          -12.333733373337333,
          -12.328732873287327,
          -12.323732373237323,
          -12.318731873187318,
          -12.313731373137314,
          -12.308730873087308,
          -12.303730373037304,
          -12.298729872987298,
          -12.293729372937293,
          -12.288728872887289,
          -12.283728372837283,
          -12.278727872787279,
          -12.273727372737273,
          -12.268726872687267,
          -12.263726372637263,
          -12.258725872587258,
          -12.253725372537254,
          -12.248724872487248,
          -12.243724372437244,
          -12.238723872387238,
          -12.233723372337233,
          -12.228722872287229,
          -12.223722372237223,
          -12.218721872187219,
          -12.213721372137213,
          -12.208720872087207,
          -12.203720372037203,
          -12.198719871987198,
          -12.193719371937194,
          -12.188718871887188,
          -12.183718371837182,
          -12.178717871787178,
          -12.173717371737172,
          -12.168716871687169,
          -12.163716371637163,
          -12.158715871587159,
          -12.153715371537153,
          -12.148714871487147,
          -12.143714371437143,
          -12.138713871387138,
          -12.133713371337134,
          -12.128712871287128,
          -12.123712371237122,
          -12.118711871187118,
          -12.113711371137112,
          -12.108710871087109,
          -12.103710371037103,
          -12.098709870987099,
          -12.093709370937093,
          -12.088708870887087,
          -12.083708370837083,
          -12.078707870787078,
          -12.073707370737074,
          -12.068706870687068,
          -12.063706370637062,
          -12.058705870587058,
          -12.053705370537052,
          -12.048704870487049,
          -12.043704370437043,
          -12.038703870387039,
          -12.033703370337033,
          -12.028702870287027,
          -12.023702370237023,
          -12.018701870187018,
          -12.013701370137014,
          -12.008700870087008,
          -12.003700370037002,
          -11.998699869986998,
          -11.993699369936992,
          -11.988698869886989,
          -11.983698369836983,
          -11.978697869786979,
          -11.973697369736973,
          -11.968696869686967,
          -11.963696369636963,
          -11.958695869586958,
          -11.953695369536954,
          -11.948694869486948,
          -11.943694369436942,
          -11.938693869386938,
          -11.933693369336932,
          -11.928692869286929,
          -11.923692369236923,
          -11.918691869186919,
          -11.913691369136913,
          -11.908690869086907,
          -11.903690369036903,
          -11.898689868986898,
          -11.893689368936894,
          -11.888688868886888,
          -11.883688368836882,
          -11.878687868786878,
          -11.873687368736872,
          -11.868686868686869,
          -11.863686368636863,
          -11.858685868586859,
          -11.853685368536853,
          -11.848684868486847,
          -11.843684368436843,
          -11.838683868386838,
          -11.833683368336834,
          -11.828682868286828,
          -11.823682368236822,
          -11.818681868186818,
          -11.813681368136812,
          -11.808680868086809,
          -11.803680368036803,
          -11.798679867986799,
          -11.793679367936793,
          -11.788678867886787,
          -11.783678367836783,
          -11.778677867786778,
          -11.773677367736774,
          -11.768676867686768,
          -11.763676367636762,
          -11.758675867586758,
          -11.753675367536752,
          -11.748674867486748,
          -11.743674367436743,
          -11.738673867386739,
          -11.733673367336733,
          -11.728672867286727,
          -11.723672367236723,
          -11.718671867186718,
          -11.713671367136714,
          -11.708670867086708,
          -11.703670367036702,
          -11.698669866986698,
          -11.693669366936692,
          -11.688668866886688,
          -11.683668366836683,
          -11.678667866786679,
          -11.673667366736673,
          -11.668666866686667,
          -11.663666366636663,
          -11.658665866586658,
          -11.653665366536654,
          -11.648664866486648,
          -11.643664366436642,
          -11.638663866386638,
          -11.633663366336632,
          -11.628662866286628,
          -11.623662366236623,
          -11.618661866186619,
          -11.613661366136613,
          -11.608660866086607,
          -11.603660366036603,
          -11.598659865986598,
          -11.593659365936594,
          -11.588658865886588,
          -11.583658365836582,
          -11.578657865786578,
          -11.573657365736572,
          -11.568656865686568,
          -11.563656365636563,
          -11.558655865586559,
          -11.553655365536553,
          -11.548654865486547,
          -11.543654365436543,
          -11.538653865386538,
          -11.533653365336534,
          -11.528652865286528,
          -11.523652365236522,
          -11.518651865186518,
          -11.513651365136512,
          -11.508650865086508,
          -11.503650365036503,
          -11.498649864986499,
          -11.493649364936493,
          -11.488648864886487,
          -11.483648364836483,
          -11.478647864786478,
          -11.473647364736474,
          -11.468646864686468,
          -11.463646364636462,
          -11.458645864586458,
          -11.453645364536452,
          -11.448644864486448,
          -11.443644364436443,
          -11.438643864386439,
          -11.433643364336433,
          -11.428642864286427,
          -11.423642364236423,
          -11.418641864186418,
          -11.413641364136414,
          -11.408640864086408,
          -11.403640364036402,
          -11.398639863986398,
          -11.393639363936392,
          -11.388638863886388,
          -11.383638363836383,
          -11.378637863786379,
          -11.373637363736373,
          -11.368636863686367,
          -11.363636363636363,
          -11.358635863586358,
          -11.353635363536354,
          -11.348634863486348,
          -11.343634363436342,
          -11.338633863386338,
          -11.333633363336332,
          -11.328632863286328,
          -11.323632363236323,
          -11.318631863186319,
          -11.313631363136313,
          -11.308630863086307,
          -11.303630363036303,
          -11.298629862986298,
          -11.293629362936294,
          -11.288628862886288,
          -11.283628362836282,
          -11.278627862786278,
          -11.273627362736272,
          -11.268626862686268,
          -11.263626362636263,
          -11.258625862586259,
          -11.253625362536253,
          -11.248624862486247,
          -11.243624362436243,
          -11.238623862386238,
          -11.233623362336234,
          -11.228622862286228,
          -11.223622362236222,
          -11.218621862186218,
          -11.213621362136212,
          -11.208620862086208,
          -11.203620362036203,
          -11.198619861986199,
          -11.193619361936193,
          -11.188618861886187,
          -11.183618361836183,
          -11.178617861786178,
          -11.173617361736174,
          -11.168616861686168,
          -11.163616361636162,
          -11.158615861586158,
          -11.153615361536152,
          -11.148614861486148,
          -11.143614361436143,
          -11.138613861386139,
          -11.133613361336133,
          -11.128612861286127,
          -11.123612361236123,
          -11.118611861186118,
          -11.113611361136114,
          -11.108610861086108,
          -11.103610361036102,
          -11.098609860986098,
          -11.093609360936092,
          -11.088608860886088,
          -11.083608360836083,
          -11.078607860786079,
          -11.073607360736073,
          -11.068606860686067,
          -11.063606360636063,
          -11.058605860586058,
          -11.053605360536054,
          -11.048604860486048,
          -11.043604360436042,
          -11.038603860386038,
          -11.033603360336032,
          -11.028602860286028,
          -11.023602360236023,
          -11.018601860186019,
          -11.013601360136013,
          -11.008600860086007,
          -11.003600360036003,
          -10.998599859985998,
          -10.993599359935994,
          -10.988598859885988,
          -10.983598359835982,
          -10.978597859785978,
          -10.973597359735972,
          -10.968596859685968,
          -10.963596359635963,
          -10.958595859585959,
          -10.953595359535953,
          -10.948594859485947,
          -10.943594359435943,
          -10.938593859385938,
          -10.933593359335934,
          -10.928592859285928,
          -10.923592359235922,
          -10.918591859185918,
          -10.913591359135912,
          -10.908590859085908,
          -10.903590359035903,
          -10.898589858985899,
          -10.893589358935893,
          -10.888588858885887,
          -10.883588358835883,
          -10.878587858785878,
          -10.873587358735874,
          -10.868586858685868,
          -10.863586358635862,
          -10.858585858585858,
          -10.853585358535852,
          -10.848584858485848,
          -10.843584358435843,
          -10.838583858385839,
          -10.833583358335833,
          -10.828582858285827,
          -10.823582358235823,
          -10.818581858185818,
          -10.813581358135814,
          -10.808580858085808,
          -10.803580358035802,
          -10.798579857985798,
          -10.793579357935792,
          -10.788578857885788,
          -10.783578357835783,
          -10.778577857785779,
          -10.773577357735773,
          -10.768576857685767,
          -10.763576357635763,
          -10.758575857585758,
          -10.753575357535754,
          -10.748574857485748,
          -10.743574357435742,
          -10.738573857385738,
          -10.733573357335732,
          -10.728572857285728,
          -10.723572357235723,
          -10.718571857185719,
          -10.713571357135713,
          -10.708570857085707,
          -10.703570357035703,
          -10.698569856985698,
          -10.693569356935694,
          -10.688568856885688,
          -10.683568356835682,
          -10.678567856785678,
          -10.673567356735672,
          -10.668566856685668,
          -10.663566356635663,
          -10.658565856585659,
          -10.653565356535653,
          -10.648564856485647,
          -10.643564356435643,
          -10.638563856385638,
          -10.633563356335634,
          -10.628562856285628,
          -10.623562356235622,
          -10.618561856185618,
          -10.613561356135612,
          -10.608560856085608,
          -10.603560356035603,
          -10.598559855985599,
          -10.593559355935593,
          -10.588558855885587,
          -10.583558355835583,
          -10.578557855785578,
          -10.573557355735574,
          -10.568556855685568,
          -10.563556355635562,
          -10.558555855585558,
          -10.553555355535552,
          -10.548554855485548,
          -10.543554355435543,
          -10.538553855385539,
          -10.533553355335533,
          -10.528552855285527,
          -10.523552355235523,
          -10.518551855185517,
          -10.513551355135514,
          -10.508550855085508,
          -10.503550355035502,
          -10.498549854985498,
          -10.493549354935492,
          -10.488548854885488,
          -10.483548354835483,
          -10.478547854785479,
          -10.473547354735473,
          -10.468546854685467,
          -10.463546354635463,
          -10.458545854585457,
          -10.453545354535454,
          -10.448544854485448,
          -10.443544354435442,
          -10.438543854385438,
          -10.433543354335432,
          -10.428542854285428,
          -10.423542354235423,
          -10.418541854185419,
          -10.413541354135413,
          -10.408540854085407,
          -10.403540354035403,
          -10.398539853985397,
          -10.393539353935394,
          -10.388538853885388,
          -10.383538353835382,
          -10.378537853785378,
          -10.373537353735372,
          -10.368536853685368,
          -10.363536353635363,
          -10.358535853585359,
          -10.353535353535353,
          -10.348534853485347,
          -10.343534353435343,
          -10.338533853385337,
          -10.333533353335334,
          -10.328532853285328,
          -10.323532353235322,
          -10.318531853185318,
          -10.313531353135312,
          -10.308530853085308,
          -10.303530353035303,
          -10.298529852985299,
          -10.293529352935293,
          -10.288528852885287,
          -10.283528352835283,
          -10.278527852785277,
          -10.273527352735274,
          -10.268526852685268,
          -10.263526352635262,
          -10.258525852585258,
          -10.253525352535252,
          -10.248524852485248,
          -10.243524352435243,
          -10.238523852385239,
          -10.233523352335233,
          -10.228522852285227,
          -10.223522352235223,
          -10.218521852185217,
          -10.213521352135214,
          -10.208520852085208,
          -10.203520352035202,
          -10.198519851985198,
          -10.193519351935192,
          -10.188518851885188,
          -10.183518351835183,
          -10.178517851785179,
          -10.173517351735173,
          -10.168516851685167,
          -10.163516351635163,
          -10.158515851585157,
          -10.153515351535153,
          -10.148514851485148,
          -10.143514351435142,
          -10.138513851385138,
          -10.133513351335132,
          -10.128512851285128,
          -10.123512351235123,
          -10.118511851185119,
          -10.113511351135113,
          -10.108510851085107,
          -10.103510351035103,
          -10.098509850985097,
          -10.093509350935093,
          -10.088508850885088,
          -10.083508350835082,
          -10.078507850785078,
          -10.073507350735072,
          -10.068506850685068,
          -10.063506350635063,
          -10.058505850585059,
          -10.053505350535053,
          -10.048504850485047,
          -10.043504350435043,
          -10.038503850385037,
          -10.033503350335033,
          -10.028502850285028,
          -10.023502350235022,
          -10.018501850185018,
          -10.013501350135012,
          -10.008500850085008,
          -10.003500350035003,
          -9.998499849984999,
          -9.993499349934993,
          -9.988498849884987,
          -9.983498349834983,
          -9.978497849784977,
          -9.973497349734973,
          -9.968496849684968,
          -9.963496349634962,
          -9.958495849584958,
          -9.953495349534952,
          -9.948494849484948,
          -9.943494349434943,
          -9.938493849384939,
          -9.933493349334933,
          -9.928492849284927,
          -9.923492349234923,
          -9.918491849184917,
          -9.913491349134913,
          -9.908490849084908,
          -9.903490349034902,
          -9.898489848984898,
          -9.893489348934892,
          -9.888488848884888,
          -9.883488348834883,
          -9.878487848784879,
          -9.873487348734873,
          -9.868486848684867,
          -9.863486348634863,
          -9.858485848584857,
          -9.853485348534853,
          -9.848484848484848,
          -9.843484348434842,
          -9.838483848384838,
          -9.833483348334832,
          -9.828482848284828,
          -9.823482348234823,
          -9.818481848184819,
          -9.813481348134813,
          -9.808480848084807,
          -9.803480348034803,
          -9.798479847984797,
          -9.793479347934793,
          -9.788478847884788,
          -9.783478347834782,
          -9.778477847784778,
          -9.773477347734772,
          -9.768476847684768,
          -9.763476347634763,
          -9.758475847584759,
          -9.753475347534753,
          -9.748474847484747,
          -9.743474347434743,
          -9.738473847384737,
          -9.733473347334733,
          -9.728472847284728,
          -9.723472347234722,
          -9.718471847184718,
          -9.713471347134712,
          -9.708470847084708,
          -9.703470347034703,
          -9.698469846984699,
          -9.693469346934693,
          -9.688468846884687,
          -9.683468346834683,
          -9.678467846784677,
          -9.673467346734673,
          -9.668466846684668,
          -9.663466346634662,
          -9.658465846584658,
          -9.653465346534652,
          -9.648464846484648,
          -9.643464346434643,
          -9.638463846384639,
          -9.633463346334633,
          -9.628462846284627,
          -9.623462346234623,
          -9.618461846184617,
          -9.613461346134613,
          -9.608460846084608,
          -9.603460346034602,
          -9.598459845984598,
          -9.593459345934592,
          -9.588458845884588,
          -9.583458345834583,
          -9.578457845784577,
          -9.573457345734573,
          -9.568456845684567,
          -9.563456345634563,
          -9.558455845584557,
          -9.553455345534553,
          -9.548454845484548,
          -9.543454345434542,
          -9.538453845384538,
          -9.533453345334532,
          -9.528452845284528,
          -9.523452345234523,
          -9.518451845184517,
          -9.513451345134513,
          -9.508450845084507,
          -9.503450345034503,
          -9.498449844984497,
          -9.493449344934493,
          -9.488448844884488,
          -9.483448344834482,
          -9.478447844784478,
          -9.473447344734472,
          -9.468446844684468,
          -9.463446344634463,
          -9.458445844584457,
          -9.453445344534453,
          -9.448444844484447,
          -9.443444344434443,
          -9.438443844384437,
          -9.433443344334433,
          -9.428442844284428,
          -9.423442344234422,
          -9.418441844184418,
          -9.413441344134412,
          -9.408440844084408,
          -9.403440344034403,
          -9.398439843984397,
          -9.393439343934393,
          -9.388438843884387,
          -9.383438343834383,
          -9.378437843784377,
          -9.373437343734373,
          -9.368436843684368,
          -9.363436343634362,
          -9.358435843584358,
          -9.353435343534352,
          -9.348434843484348,
          -9.343434343434343,
          -9.338433843384337,
          -9.333433343334333,
          -9.328432843284327,
          -9.323432343234323,
          -9.318431843184317,
          -9.313431343134313,
          -9.308430843084308,
          -9.303430343034302,
          -9.298429842984298,
          -9.293429342934292,
          -9.288428842884288,
          -9.283428342834283,
          -9.278427842784277,
          -9.273427342734273,
          -9.268426842684267,
          -9.263426342634263,
          -9.258425842584257,
          -9.253425342534253,
          -9.248424842484248,
          -9.243424342434242,
          -9.238423842384238,
          -9.233423342334232,
          -9.228422842284228,
          -9.223422342234223,
          -9.218421842184217,
          -9.213421342134213,
          -9.208420842084207,
          -9.203420342034203,
          -9.198419841984197,
          -9.193419341934193,
          -9.188418841884188,
          -9.183418341834182,
          -9.178417841784178,
          -9.173417341734172,
          -9.168416841684168,
          -9.163416341634163,
          -9.158415841584157,
          -9.153415341534153,
          -9.148414841484147,
          -9.143414341434143,
          -9.138413841384137,
          -9.133413341334133,
          -9.128412841284128,
          -9.123412341234122,
          -9.118411841184118,
          -9.113411341134112,
          -9.108410841084108,
          -9.103410341034103,
          -9.098409840984097,
          -9.093409340934093,
          -9.088408840884087,
          -9.083408340834083,
          -9.078407840784077,
          -9.073407340734073,
          -9.068406840684068,
          -9.063406340634062,
          -9.058405840584058,
          -9.053405340534052,
          -9.048404840484048,
          -9.043404340434043,
          -9.038403840384037,
          -9.033403340334033,
          -9.028402840284027,
          -9.023402340234023,
          -9.018401840184017,
          -9.013401340134013,
          -9.008400840084008,
          -9.003400340034002,
          -8.998399839983996,
          -8.993399339933994,
          -8.988398839883988,
          -8.983398339833983,
          -8.978397839783977,
          -8.973397339733971,
          -8.968396839683969,
          -8.963396339633963,
          -8.958395839583957,
          -8.953395339533952,
          -8.948394839483946,
          -8.943394339433944,
          -8.938393839383938,
          -8.933393339333932,
          -8.928392839283926,
          -8.923392339233924,
          -8.918391839183919,
          -8.913391339133913,
          -8.908390839083907,
          -8.903390339033901,
          -8.8983898389839,
          -8.893389338933893,
          -8.888388838883888,
          -8.883388338833882,
          -8.878387838783876,
          -8.873387338733874,
          -8.868386838683868,
          -8.863386338633862,
          -8.858385838583857,
          -8.853385338533851,
          -8.848384838483849,
          -8.843384338433843,
          -8.838383838383837,
          -8.833383338333832,
          -8.828382838283826,
          -8.823382338233824,
          -8.818381838183818,
          -8.813381338133812,
          -8.808380838083806,
          -8.803380338033804,
          -8.798379837983799,
          -8.793379337933793,
          -8.788378837883787,
          -8.783378337833781,
          -8.77837783778378,
          -8.773377337733773,
          -8.768376837683768,
          -8.763376337633762,
          -8.758375837583756,
          -8.753375337533754,
          -8.748374837483748,
          -8.743374337433742,
          -8.738373837383737,
          -8.733373337333731,
          -8.728372837283729,
          -8.723372337233723,
          -8.718371837183717,
          -8.713371337133712,
          -8.708370837083706,
          -8.703370337033704,
          -8.698369836983698,
          -8.693369336933692,
          -8.688368836883686,
          -8.683368336833684,
          -8.678367836783679,
          -8.673367336733673,
          -8.668366836683667,
          -8.663366336633661,
          -8.658365836583659,
          -8.653365336533653,
          -8.648364836483648,
          -8.643364336433642,
          -8.638363836383636,
          -8.633363336333634,
          -8.628362836283628,
          -8.623362336233622,
          -8.618361836183617,
          -8.613361336133611,
          -8.608360836083609,
          -8.603360336033603,
          -8.598359835983597,
          -8.593359335933592,
          -8.588358835883586,
          -8.583358335833584,
          -8.578357835783578,
          -8.573357335733572,
          -8.568356835683566,
          -8.563356335633564,
          -8.558355835583559,
          -8.553355335533553,
          -8.548354835483547,
          -8.543354335433541,
          -8.538353835383539,
          -8.533353335333533,
          -8.528352835283528,
          -8.523352335233522,
          -8.518351835183516,
          -8.513351335133514,
          -8.508350835083508,
          -8.503350335033502,
          -8.498349834983497,
          -8.493349334933491,
          -8.488348834883489,
          -8.483348334833483,
          -8.478347834783477,
          -8.473347334733472,
          -8.468346834683466,
          -8.463346334633464,
          -8.458345834583458,
          -8.453345334533452,
          -8.448344834483446,
          -8.443344334433444,
          -8.438343834383438,
          -8.433343334333433,
          -8.428342834283427,
          -8.423342334233421,
          -8.418341834183419,
          -8.413341334133413,
          -8.408340834083408,
          -8.403340334033402,
          -8.398339833983396,
          -8.393339333933394,
          -8.388338833883388,
          -8.383338333833382,
          -8.378337833783377,
          -8.373337333733371,
          -8.368336833683369,
          -8.363336333633363,
          -8.358335833583357,
          -8.353335333533352,
          -8.348334833483346,
          -8.343334333433344,
          -8.338333833383338,
          -8.333333333333332,
          -8.328332833283326,
          -8.323332333233324,
          -8.318331833183318,
          -8.313331333133313,
          -8.308330833083307,
          -8.303330333033301,
          -8.298329832983299,
          -8.293329332933293,
          -8.288328832883288,
          -8.283328332833282,
          -8.278327832783276,
          -8.273327332733274,
          -8.268326832683268,
          -8.263326332633262,
          -8.258325832583257,
          -8.253325332533251,
          -8.248324832483249,
          -8.243324332433243,
          -8.238323832383237,
          -8.233323332333232,
          -8.228322832283226,
          -8.223322332233224,
          -8.218321832183218,
          -8.213321332133212,
          -8.208320832083206,
          -8.203320332033204,
          -8.198319831983198,
          -8.193319331933193,
          -8.188318831883187,
          -8.183318331833181,
          -8.178317831783179,
          -8.173317331733173,
          -8.168316831683168,
          -8.163316331633162,
          -8.158315831583156,
          -8.153315331533154,
          -8.148314831483148,
          -8.143314331433142,
          -8.138313831383137,
          -8.133313331333131,
          -8.128312831283129,
          -8.123312331233123,
          -8.118311831183117,
          -8.113311331133112,
          -8.108310831083106,
          -8.103310331033104,
          -8.098309830983098,
          -8.093309330933092,
          -8.088308830883086,
          -8.083308330833084,
          -8.078307830783078,
          -8.073307330733073,
          -8.068306830683067,
          -8.063306330633061,
          -8.058305830583059,
          -8.053305330533053,
          -8.048304830483048,
          -8.043304330433042,
          -8.038303830383036,
          -8.033303330333034,
          -8.028302830283028,
          -8.023302330233022,
          -8.018301830183017,
          -8.013301330133011,
          -8.008300830083009,
          -8.003300330033003,
          -7.998299829982997,
          -7.9932993299329915,
          -7.988298829882986,
          -7.983298329832984,
          -7.978297829782978,
          -7.973297329732972,
          -7.968296829682966,
          -7.963296329632964,
          -7.9582958295829584,
          -7.953295329532953,
          -7.948294829482947,
          -7.943294329432941,
          -7.938293829382939,
          -7.933293329332933,
          -7.928292829282928,
          -7.923292329232922,
          -7.918291829182916,
          -7.913291329132914,
          -7.908290829082908,
          -7.903290329032902,
          -7.898289828982897,
          -7.893289328932891,
          -7.888288828882889,
          -7.883288328832883,
          -7.878287828782877,
          -7.8732873287328715,
          -7.868286828682866,
          -7.863286328632864,
          -7.858285828582858,
          -7.853285328532852,
          -7.848284828482846,
          -7.843284328432844,
          -7.838283828382838,
          -7.833283328332833,
          -7.828282828282827,
          -7.823282328232821,
          -7.818281828182819,
          -7.813281328132813,
          -7.8082808280828075,
          -7.803280328032802,
          -7.798279827982796,
          -7.793279327932794,
          -7.788278827882788,
          -7.783278327832782,
          -7.778277827782777,
          -7.773277327732771,
          -7.768276827682769,
          -7.763276327632763,
          -7.758275827582757,
          -7.7532753275327515,
          -7.748274827482746,
          -7.743274327432744,
          -7.738273827382738,
          -7.733273327332732,
          -7.728272827282726,
          -7.723272327232724,
          -7.718271827182718,
          -7.713271327132713,
          -7.708270827082707,
          -7.703270327032701,
          -7.698269826982699,
          -7.693269326932693,
          -7.6882688268826875,
          -7.683268326832682,
          -7.678267826782676,
          -7.673267326732674,
          -7.668266826682668,
          -7.663266326632662,
          -7.658265826582657,
          -7.653265326532651,
          -7.648264826482649,
          -7.643264326432643,
          -7.638263826382637,
          -7.6332633263326315,
          -7.628262826282626,
          -7.623262326232624,
          -7.618261826182618,
          -7.613261326132612,
          -7.608260826082606,
          -7.603260326032604,
          -7.598259825982598,
          -7.593259325932593,
          -7.588258825882587,
          -7.583258325832581,
          -7.578257825782579,
          -7.573257325732573,
          -7.5682568256825675,
          -7.563256325632562,
          -7.558255825582556,
          -7.553255325532554,
          -7.548254825482548,
          -7.543254325432542,
          -7.538253825382537,
          -7.533253325332531,
          -7.528252825282529,
          -7.523252325232523,
          -7.518251825182517,
          -7.5132513251325115,
          -7.508250825082506,
          -7.5032503250325036,
          -7.498249824982498,
          -7.493249324932492,
          -7.488248824882486,
          -7.483248324832484,
          -7.478247824782478,
          -7.473247324732473,
          -7.468246824682467,
          -7.463246324632461,
          -7.458245824582459,
          -7.453245324532453,
          -7.4482448244824475,
          -7.443244324432442,
          -7.438243824382436,
          -7.433243324332434,
          -7.428242824282428,
          -7.423242324232422,
          -7.418241824182417,
          -7.413241324132411,
          -7.408240824082409,
          -7.403240324032403,
          -7.398239823982397,
          -7.3932393239323915,
          -7.388238823882386,
          -7.3832383238323835,
          -7.378237823782378,
          -7.373237323732372,
          -7.368236823682366,
          -7.363236323632364,
          -7.358235823582358,
          -7.353235323532353,
          -7.348234823482347,
          -7.343234323432341,
          -7.338233823382339,
          -7.333233323332333,
          -7.3282328232823275,
          -7.323232323232322,
          -7.318231823182316,
          -7.313231323132314,
          -7.308230823082308,
          -7.303230323032302,
          -7.298229822982297,
          -7.293229322932291,
          -7.288228822882289,
          -7.283228322832283,
          -7.278227822782277,
          -7.2732273227322715,
          -7.268226822682266,
          -7.2632263226322635,
          -7.258225822582258,
          -7.253225322532252,
          -7.248224822482246,
          -7.243224322432244,
          -7.238223822382238,
          -7.233223322332233,
          -7.228222822282227,
          -7.223222322232221,
          -7.218221822182219,
          -7.213221322132213,
          -7.2082208220822075,
          -7.203220322032202,
          -7.198219821982196,
          -7.193219321932194,
          -7.188218821882188,
          -7.183218321832182,
          -7.178217821782177,
          -7.173217321732171,
          -7.168216821682169,
          -7.163216321632163,
          -7.158215821582157,
          -7.1532153215321514,
          -7.148214821482146,
          -7.1432143214321435,
          -7.138213821382138,
          -7.133213321332132,
          -7.128212821282126,
          -7.123212321232124,
          -7.118211821182118,
          -7.113211321132113,
          -7.108210821082107,
          -7.103210321032101,
          -7.098209820982099,
          -7.093209320932093,
          -7.0882088208820875,
          -7.083208320832082,
          -7.078207820782076,
          -7.073207320732074,
          -7.068206820682068,
          -7.063206320632062,
          -7.058205820582057,
          -7.053205320532051,
          -7.048204820482049,
          -7.043204320432043,
          -7.038203820382037,
          -7.033203320332031,
          -7.028202820282026,
          -7.0232023202320235,
          -7.018201820182018,
          -7.013201320132012,
          -7.008200820082006,
          -7.0032003200320005,
          -6.998199819981998,
          -6.993199319931993,
          -6.988198819881987,
          -6.983198319831981,
          -6.978197819781979,
          -6.973197319731973,
          -6.9681968196819675,
          -6.963196319631962,
          -6.958195819581956,
          -6.953195319531954,
          -6.948194819481948,
          -6.943194319431942,
          -6.938193819381937,
          -6.933193319331931,
          -6.928192819281929,
          -6.923192319231923,
          -6.918191819181917,
          -6.913191319131911,
          -6.908190819081906,
          -6.9031903190319035,
          -6.898189818981898,
          -6.893189318931892,
          -6.888188818881886,
          -6.8831883188318805,
          -6.878187818781878,
          -6.873187318731873,
          -6.868186818681867,
          -6.863186318631861,
          -6.858185818581859,
          -6.853185318531853,
          -6.8481848184818475,
          -6.843184318431842,
          -6.838183818381836,
          -6.833183318331834,
          -6.828182818281828,
          -6.823182318231822,
          -6.818181818181817,
          -6.813181318131811,
          -6.808180818081809,
          -6.803180318031803,
          -6.798179817981797,
          -6.793179317931791,
          -6.788178817881786,
          -6.7831783178317835,
          -6.778177817781778,
          -6.773177317731772,
          -6.768176817681766,
          -6.7631763176317605,
          -6.758175817581758,
          -6.753175317531753,
          -6.748174817481747,
          -6.743174317431741,
          -6.738173817381739,
          -6.733173317331733,
          -6.7281728172817274,
          -6.723172317231722,
          -6.718171817181716,
          -6.713171317131714,
          -6.708170817081708,
          -6.703170317031702,
          -6.698169816981697,
          -6.693169316931691,
          -6.688168816881689,
          -6.683168316831683,
          -6.678167816781677,
          -6.673167316731671,
          -6.668166816681666,
          -6.6631663166316635,
          -6.658165816581658,
          -6.653165316531652,
          -6.648164816481646,
          -6.6431643164316405,
          -6.638163816381638,
          -6.633163316331633,
          -6.628162816281627,
          -6.623162316231621,
          -6.618161816181619,
          -6.613161316131613,
          -6.608160816081607,
          -6.603160316031602,
          -6.598159815981596,
          -6.593159315931594,
          -6.588158815881588,
          -6.583158315831582,
          -6.5781578157815765,
          -6.573157315731571,
          -6.568156815681569,
          -6.563156315631563,
          -6.558155815581557,
          -6.553155315531551,
          -6.548154815481546,
          -6.5431543154315435,
          -6.538153815381538,
          -6.533153315331532,
          -6.528152815281526,
          -6.5231523152315205,
          -6.518151815181518,
          -6.513151315131513,
          -6.508150815081507,
          -6.503150315031501,
          -6.498149814981499,
          -6.493149314931493,
          -6.488148814881487,
          -6.483148314831482,
          -6.478147814781476,
          -6.473147314731474,
          -6.468146814681468,
          -6.463146314631462,
          -6.4581458145814565,
          -6.453145314531451,
          -6.448144814481449,
          -6.443144314431443,
          -6.438143814381437,
          -6.433143314331431,
          -6.428142814281426,
          -6.4231423142314235,
          -6.418141814181418,
          -6.413141314131412,
          -6.408140814081406,
          -6.4031403140314005,
          -6.398139813981398,
          -6.393139313931393,
          -6.388138813881387,
          -6.383138313831381,
          -6.378137813781379,
          -6.373137313731373,
          -6.368136813681367,
          -6.363136313631362,
          -6.358135813581356,
          -6.353135313531354,
          -6.348134813481348,
          -6.343134313431342,
          -6.3381338133813365,
          -6.333133313331331,
          -6.328132813281329,
          -6.323132313231323,
          -6.318131813181317,
          -6.313131313131311,
          -6.308130813081306,
          -6.3031303130313034,
          -6.298129812981298,
          -6.293129312931292,
          -6.288128812881286,
          -6.2831283128312805,
          -6.278127812781278,
          -6.2731273127312726,
          -6.268126812681267,
          -6.263126312631261,
          -6.258125812581259,
          -6.253125312531253,
          -6.248124812481247,
          -6.243124312431242,
          -6.238123812381236,
          -6.233123312331234,
          -6.228122812281228,
          -6.223122312231222,
          -6.2181218121812165,
          -6.213121312131211,
          -6.208120812081209,
          -6.203120312031203,
          -6.198119811981197,
          -6.193119311931191,
          -6.188118811881186,
          -6.183118311831183,
          -6.178117811781178,
          -6.173117311731172,
          -6.168116811681166,
          -6.1631163116311605,
          -6.158115811581158,
          -6.1531153115311525,
          -6.148114811481147,
          -6.143114311431141,
          -6.138113811381139,
          -6.133113311331133,
          -6.128112811281127,
          -6.123112311231122,
          -6.118111811181116,
          -6.113111311131114,
          -6.108110811081108,
          -6.103110311031102,
          -6.0981098109810965,
          -6.093109310931091,
          -6.088108810881089,
          -6.083108310831083,
          -6.078107810781077,
          -6.073107310731071,
          -6.068106810681066,
          -6.063106310631063,
          -6.058105810581058,
          -6.053105310531052,
          -6.048104810481046,
          -6.0431043104310405,
          -6.038103810381038,
          -6.0331033103310325,
          -6.028102810281027,
          -6.023102310231021,
          -6.018101810181019,
          -6.013101310131013,
          -6.008100810081007,
          -6.003100310031002,
          -5.998099809980996,
          -5.993099309930994,
          -5.988098809880988,
          -5.983098309830982,
          -5.9780978097809765,
          -5.973097309730971,
          -5.968096809680969,
          -5.963096309630963,
          -5.958095809580957,
          -5.953095309530951,
          -5.948094809480946,
          -5.943094309430943,
          -5.938093809380938,
          -5.933093309330932,
          -5.928092809280926,
          -5.9230923092309204,
          -5.918091809180918,
          -5.9130913091309125,
          -5.908090809080907,
          -5.903090309030901,
          -5.898089808980899,
          -5.893089308930893,
          -5.888088808880887,
          -5.883088308830882,
          -5.878087808780876,
          -5.873087308730874,
          -5.868086808680868,
          -5.863086308630862,
          -5.8580858085808565,
          -5.853085308530851,
          -5.8480848084808486,
          -5.843084308430843,
          -5.838083808380837,
          -5.833083308330831,
          -5.828082808280826,
          -5.823082308230823,
          -5.818081808180818,
          -5.813081308130812,
          -5.808080808080806,
          -5.8030803080308,
          -5.798079807980798,
          -5.7930793079307925,
          -5.788078807880787,
          -5.783078307830781,
          -5.778077807780779,
          -5.773077307730773,
          -5.768076807680767,
          -5.763076307630762,
          -5.758075807580756,
          -5.753075307530754,
          -5.748074807480748,
          -5.743074307430742,
          -5.7380738073807365,
          -5.733073307330731,
          -5.7280728072807285,
          -5.723072307230723,
          -5.718071807180717,
          -5.713071307130711,
          -5.708070807080706,
          -5.703070307030703,
          -5.698069806980698,
          -5.693069306930692,
          -5.688068806880686,
          -5.68306830683068,
          -5.678067806780678,
          -5.6730673067306725,
          -5.668066806680667,
          -5.663066306630661,
          -5.658065806580659,
          -5.653065306530653,
          -5.648064806480647,
          -5.643064306430642,
          -5.638063806380636,
          -5.633063306330634,
          -5.628062806280628,
          -5.623062306230622,
          -5.6180618061806165,
          -5.613061306130611,
          -5.6080608060806085,
          -5.603060306030603,
          -5.598059805980597,
          -5.593059305930591,
          -5.588058805880586,
          -5.583058305830583,
          -5.578057805780578,
          -5.573057305730572,
          -5.568056805680566,
          -5.56305630563056,
          -5.558055805580558,
          -5.5530553055305525,
          -5.548054805480547,
          -5.543054305430541,
          -5.538053805380539,
          -5.533053305330533,
          -5.528052805280527,
          -5.523052305230522,
          -5.518051805180516,
          -5.513051305130514,
          -5.508050805080508,
          -5.503050305030502,
          -5.4980498049804964,
          -5.493049304930491,
          -5.4880488048804885,
          -5.483048304830483,
          -5.478047804780477,
          -5.473047304730471,
          -5.4680468046804656,
          -5.463046304630463,
          -5.458045804580458,
          -5.453045304530452,
          -5.448044804480446,
          -5.44304430443044,
          -5.438043804380438,
          -5.4330433043304325,
          -5.428042804280427,
          -5.423042304230421,
          -5.418041804180419,
          -5.413041304130413,
          -5.408040804080407,
          -5.403040304030402,
          -5.398039803980396,
          -5.393039303930394,
          -5.388038803880388,
          -5.383038303830382,
          -5.378037803780376,
          -5.373037303730371,
          -5.3680368036803685,
          -5.363036303630363,
          -5.358035803580357,
          -5.353035303530351,
          -5.3480348034803455,
          -5.343034303430343,
          -5.338033803380338,
          -5.333033303330332,
          -5.328032803280326,
          -5.32303230323032,
          -5.318031803180318,
          -5.3130313031303125,
          -5.308030803080307,
          -5.303030303030301,
          -5.298029802980299,
          -5.293029302930293,
          -5.288028802880287,
          -5.283028302830282,
          -5.278027802780276,
          -5.273027302730274,
          -5.268026802680268,
          -5.263026302630262,
          -5.258025802580256,
          -5.253025302530251,
          -5.2480248024802485,
          -5.243024302430243,
          -5.238023802380237,
          -5.233023302330231,
          -5.2280228022802255,
          -5.223022302230223,
          -5.218021802180218,
          -5.213021302130212,
          -5.208020802080206,
          -5.2030203020302,
          -5.198019801980198,
          -5.1930193019301925,
          -5.188018801880187,
          -5.183018301830181,
          -5.178017801780179,
          -5.173017301730173,
          -5.168016801680167,
          -5.163016301630162,
          -5.158015801580156,
          -5.153015301530154,
          -5.148014801480148,
          -5.143014301430142,
          -5.138013801380136,
          -5.133013301330131,
          -5.1280128012801285,
          -5.123012301230123,
          -5.118011801180117,
          -5.113011301130111,
          -5.1080108010801055,
          -5.103010301030103,
          -5.098009800980098,
          -5.093009300930092,
          -5.088008800880086,
          -5.08300830083008,
          -5.078007800780078,
          -5.0730073007300724,
          -5.068006800680067,
          -5.063006300630061,
          -5.058005800580059,
          -5.053005300530053,
          -5.048004800480047,
          -5.0430043004300416,
          -5.038003800380036,
          -5.033003300330034,
          -5.028002800280028,
          -5.023002300230022,
          -5.018001800180016,
          -5.013001300130011,
          -5.0080008000800085,
          -5.003000300030003,
          -4.997999799979997,
          -4.992999299929991,
          -4.9879987998799855,
          -4.982998299829983,
          -4.977997799779978,
          -4.972997299729972,
          -4.967996799679966,
          -4.96299629962996,
          -4.957995799579958,
          -4.952995299529952,
          -4.947994799479947,
          -4.942994299429941,
          -4.937993799379939,
          -4.932993299329933,
          -4.927992799279927,
          -4.9229922992299215,
          -4.917991799179916,
          -4.912991299129914,
          -4.907990799079908,
          -4.902990299029902,
          -4.897989798979896,
          -4.892989298929891,
          -4.8879887988798885,
          -4.882988298829883,
          -4.877987798779877,
          -4.872987298729871,
          -4.8679867986798655,
          -4.862986298629863,
          -4.857985798579858,
          -4.852985298529852,
          -4.847984798479846,
          -4.84298429842984,
          -4.837983798379838,
          -4.832983298329832,
          -4.827982798279827,
          -4.822982298229821,
          -4.817981798179819,
          -4.812981298129813,
          -4.807980798079807,
          -4.8029802980298015,
          -4.797979797979796,
          -4.792979297929794,
          -4.787978797879788,
          -4.782978297829782,
          -4.777977797779776,
          -4.772977297729771,
          -4.7679767976797685,
          -4.762976297629763,
          -4.757975797579757,
          -4.752975297529751,
          -4.7479747974797455,
          -4.742974297429743,
          -4.737973797379738,
          -4.732973297329732,
          -4.727972797279726,
          -4.72297229722972,
          -4.717971797179718,
          -4.712971297129712,
          -4.707970797079707,
          -4.702970297029701,
          -4.697969796979699,
          -4.692969296929693,
          -4.687968796879687,
          -4.6829682968296815,
          -4.677967796779676,
          -4.672967296729674,
          -4.667966796679668,
          -4.662966296629662,
          -4.657965796579656,
          -4.652965296529651,
          -4.647964796479648,
          -4.642964296429643,
          -4.637963796379637,
          -4.632963296329631,
          -4.6279627962796255,
          -4.622962296229623,
          -4.6179617961796176,
          -4.612961296129612,
          -4.607960796079606,
          -4.6029602960296,
          -4.597959795979598,
          -4.592959295929592,
          -4.587958795879587,
          -4.582958295829581,
          -4.577957795779579,
          -4.572957295729573,
          -4.567956795679567,
          -4.5629562956295615,
          -4.557955795579556,
          -4.552955295529554,
          -4.547954795479548,
          -4.542954295429542,
          -4.537953795379536,
          -4.532953295329531,
          -4.527952795279528,
          -4.522952295229523,
          -4.517951795179517,
          -4.512951295129511,
          -4.5079507950795055,
          -4.502950295029503,
          -4.4979497949794975,
          -4.492949294929492,
          -4.487948794879486,
          -4.48294829482948,
          -4.477947794779478,
          -4.472947294729472,
          -4.467946794679467,
          -4.462946294629461,
          -4.457945794579455,
          -4.452945294529453,
          -4.447944794479447,
          -4.4429442944294415,
          -4.437943794379436,
          -4.432943294329434,
          -4.427942794279428,
          -4.422942294229422,
          -4.417941794179416,
          -4.412941294129411,
          -4.407940794079408,
          -4.402940294029403,
          -4.397939793979397,
          -4.392939293929391,
          -4.3879387938793855,
          -4.382938293829383,
          -4.3779377937793775,
          -4.372937293729372,
          -4.367936793679366,
          -4.36293629362936,
          -4.357935793579358,
          -4.352935293529352,
          -4.347934793479347,
          -4.342934293429341,
          -4.337933793379335,
          -4.332933293329333,
          -4.327932793279327,
          -4.3229322932293215,
          -4.317931793179316,
          -4.312931293129314,
          -4.307930793079308,
          -4.302930293029302,
          -4.297929792979296,
          -4.292929292929291,
          -4.287928792879288,
          -4.282928292829283,
          -4.277927792779277,
          -4.272927292729271,
          -4.2679267926792654,
          -4.262926292629263,
          -4.2579257925792575,
          -4.252925292529252,
          -4.247924792479246,
          -4.24292429242924,
          -4.237923792379238,
          -4.232923292329232,
          -4.227922792279227,
          -4.222922292229221,
          -4.217921792179215,
          -4.212921292129213,
          -4.207920792079207,
          -4.2029202920292015,
          -4.197919791979196,
          -4.1929192919291935,
          -4.187918791879188,
          -4.182918291829182,
          -4.177917791779176,
          -4.172917291729171,
          -4.167916791679168,
          -4.162916291629163,
          -4.157915791579157,
          -4.152915291529151,
          -4.147914791479145,
          -4.142914291429143,
          -4.1379137913791375,
          -4.132913291329132,
          -4.127912791279126,
          -4.12291229122912,
          -4.117911791179118,
          -4.112911291129112,
          -4.107910791079107,
          -4.102910291029101,
          -4.097909790979095,
          -4.092909290929093,
          -4.087908790879087,
          -4.0829082908290815,
          -4.077907790779076,
          -4.0729072907290735,
          -4.067906790679068,
          -4.062906290629062,
          -4.057905790579056,
          -4.052905290529051,
          -4.047904790479048,
          -4.042904290429043,
          -4.037903790379037,
          -4.032903290329031,
          -4.027902790279025,
          -4.022902290229023,
          -4.0179017901790175,
          -4.012901290129012,
          -4.007900790079006,
          -4.002900290029,
          -3.997899789978998,
          -3.9928992899289923,
          -3.9878987898789866,
          -3.982898289828981,
          -3.977897789778975,
          -3.972897289728973,
          -3.967896789678967,
          -3.9628962896289615,
          -3.9578957895789557,
          -3.9528952895289535,
          -3.947894789478948,
          -3.942894289428942,
          -3.9378937893789363,
          -3.9328932893289306,
          -3.9278927892789284,
          -3.9228922892289226,
          -3.917891789178917,
          -3.912891289128911,
          -3.9078907890789054,
          -3.9028902890289032,
          -3.8978897889788975,
          -3.8928892889288917,
          -3.887888788878886,
          -3.8828882888288803,
          -3.877887788778878,
          -3.8728872887288723,
          -3.8678867886788666,
          -3.862886288628861,
          -3.857885788578855,
          -3.852885288528853,
          -3.847884788478847,
          -3.8428842884288414,
          -3.8378837883788357,
          -3.8328832883288335,
          -3.8278827882788278,
          -3.822882288228822,
          -3.8178817881788163,
          -3.8128812881288106,
          -3.8078807880788084,
          -3.8028802880288026,
          -3.797879787978797,
          -3.792879287928791,
          -3.7878787878787854,
          -3.782878287828783,
          -3.7778777877787775,
          -3.7728772877287717,
          -3.767876787678766,
          -3.7628762876287603,
          -3.757875787578758,
          -3.7528752875287523,
          -3.7478747874787466,
          -3.742874287428741,
          -3.737873787378735,
          -3.732873287328733,
          -3.727872787278727,
          -3.7228722872287214,
          -3.7178717871787157,
          -3.7128712871287135,
          -3.7078707870787078,
          -3.702870287028702,
          -3.6978697869786963,
          -3.6928692869286905,
          -3.6878687868786884,
          -3.6828682868286826,
          -3.677867786778677,
          -3.672867286728671,
          -3.6678667866786654,
          -3.662866286628663,
          -3.6578657865786575,
          -3.6528652865286517,
          -3.647864786478646,
          -3.6428642864286402,
          -3.637863786378638,
          -3.6328632863286323,
          -3.6278627862786266,
          -3.622862286228621,
          -3.617861786178615,
          -3.612861286128613,
          -3.607860786078607,
          -3.6028602860286014,
          -3.5978597859785957,
          -3.5928592859285935,
          -3.5878587858785878,
          -3.582858285828582,
          -3.5778577857785763,
          -3.5728572857285705,
          -3.5678567856785683,
          -3.5628562856285626,
          -3.557855785578557,
          -3.552855285528551,
          -3.5478547854785454,
          -3.542854285428543,
          -3.5378537853785375,
          -3.5328532853285317,
          -3.527852785278526,
          -3.5228522852285202,
          -3.517851785178518,
          -3.5128512851285123,
          -3.5078507850785066,
          -3.502850285028501,
          -3.497849784978495,
          -3.492849284928493,
          -3.487848784878487,
          -3.4828482848284814,
          -3.4778477847784757,
          -3.4728472847284735,
          -3.4678467846784677,
          -3.462846284628462,
          -3.4578457845784563,
          -3.4528452845284505,
          -3.4478447844784483,
          -3.4428442844284426,
          -3.437843784378437,
          -3.432843284328431,
          -3.4278427842784254,
          -3.422842284228423,
          -3.4178417841784174,
          -3.4128412841284117,
          -3.407840784078406,
          -3.4028402840284,
          -3.397839783978398,
          -3.3928392839283923,
          -3.3878387838783866,
          -3.382838283828381,
          -3.377837783778375,
          -3.372837283728373,
          -3.367836783678367,
          -3.3628362836283614,
          -3.3578357835783557,
          -3.3528352835283535,
          -3.3478347834783477,
          -3.342834283428342,
          -3.3378337833783362,
          -3.3328332833283305,
          -3.3278327832783283,
          -3.3228322832283226,
          -3.317831783178317,
          -3.312831283128311,
          -3.3078307830783054,
          -3.302830283028303,
          -3.2978297829782974,
          -3.2928292829282917,
          -3.287828782878286,
          -3.28282828282828,
          -3.277827782778278,
          -3.2728272827282723,
          -3.2678267826782665,
          -3.262826282628261,
          -3.257825782578255,
          -3.252825282528253,
          -3.247824782478247,
          -3.2428242824282414,
          -3.2378237823782356,
          -3.2328232823282335,
          -3.2278227822782277,
          -3.222822282228222,
          -3.2178217821782162,
          -3.2128212821282105,
          -3.2078207820782083,
          -3.2028202820282026,
          -3.197819781978197,
          -3.192819281928191,
          -3.1878187818781853,
          -3.182818281828183,
          -3.1778177817781774,
          -3.1728172817281717,
          -3.167816781678166,
          -3.16281628162816,
          -3.157815781578158,
          -3.1528152815281523,
          -3.1478147814781465,
          -3.142814281428141,
          -3.137813781378135,
          -3.132813281328133,
          -3.127812781278127,
          -3.1228122812281214,
          -3.1178117811781156,
          -3.1128112811281134,
          -3.1078107810781077,
          -3.102810281028102,
          -3.0978097809780962,
          -3.0928092809280905,
          -3.0878087808780883,
          -3.0828082808280826,
          -3.077807780778077,
          -3.072807280728071,
          -3.0678067806780653,
          -3.062806280628063,
          -3.0578057805780574,
          -3.0528052805280517,
          -3.047804780478046,
          -3.04280428042804,
          -3.037803780378038,
          -3.0328032803280323,
          -3.0278027802780265,
          -3.0228022802280208,
          -3.017801780178015,
          -3.012801280128013,
          -3.007800780078007,
          -3.0028002800280014,
          -2.9977997799779956,
          -2.9927992799279934,
          -2.9877987798779877,
          -2.982798279827982,
          -2.977797779777976,
          -2.9727972797279705,
          -2.9677967796779683,
          -2.9627962796279625,
          -2.957795779577957,
          -2.952795279527951,
          -2.9477947794779453,
          -2.942794279427943,
          -2.9377937793779374,
          -2.9327932793279317,
          -2.927792779277926,
          -2.92279227922792,
          -2.917791779177918,
          -2.9127912791279122,
          -2.9077907790779065,
          -2.9027902790279008,
          -2.897789778977895,
          -2.892789278927893,
          -2.887788778877887,
          -2.8827882788278814,
          -2.8777877787778756,
          -2.8727872787278734,
          -2.8677867786778677,
          -2.862786278627862,
          -2.857785778577856,
          -2.8527852785278505,
          -2.8477847784778483,
          -2.8427842784278425,
          -2.837783778377837,
          -2.832783278327831,
          -2.8277827782778253,
          -2.822782278227823,
          -2.8177817781778174,
          -2.8127812781278116,
          -2.807780778077806,
          -2.8027802780278,
          -2.797779777977798,
          -2.7927792779277922,
          -2.7877787778777865,
          -2.7827782778277808,
          -2.777777777777775,
          -2.772777277727773,
          -2.767776777677767,
          -2.7627762776277613,
          -2.7577757775777556,
          -2.7527752775277534,
          -2.7477747774777477,
          -2.742774277427742,
          -2.737773777377736,
          -2.7327732773277305,
          -2.7277727772777283,
          -2.7227722772277225,
          -2.717771777177717,
          -2.712771277127711,
          -2.7077707770777053,
          -2.702770277027703,
          -2.6977697769776974,
          -2.6927692769276916,
          -2.687768776877686,
          -2.68276827682768,
          -2.677767776777678,
          -2.6727672767276722,
          -2.6677667766776665,
          -2.6627662766276607,
          -2.657765776577655,
          -2.652765276527653,
          -2.647764776477647,
          -2.6427642764276413,
          -2.6377637763776356,
          -2.6327632763276334,
          -2.6277627762776277,
          -2.622762276227622,
          -2.617761776177616,
          -2.6127612761276104,
          -2.6077607760776083,
          -2.6027602760276025,
          -2.5977597759775968,
          -2.592759275927591,
          -2.5877587758775853,
          -2.582758275827583,
          -2.5777577757775774,
          -2.5727572757275716,
          -2.567756775677566,
          -2.56275627562756,
          -2.557755775577558,
          -2.552755275527552,
          -2.5477547754775465,
          -2.5427542754275407,
          -2.537753775377535,
          -2.532753275327533,
          -2.527752775277527,
          -2.5227522752275213,
          -2.5177517751775156,
          -2.5127512751275134,
          -2.5077507750775077,
          -2.502750275027502,
          -2.497749774977496,
          -2.4927492749274904,
          -2.4877487748774882,
          -2.4827482748274825,
          -2.4777477747774768,
          -2.472747274727471,
          -2.4677467746774653,
          -2.462746274627463,
          -2.4577457745774574,
          -2.4527452745274516,
          -2.447744774477446,
          -2.44274427442744,
          -2.437743774377438,
          -2.432743274327432,
          -2.4277427742774265,
          -2.4227422742274207,
          -2.417741774177415,
          -2.412741274127413,
          -2.407740774077407,
          -2.4027402740274013,
          -2.3977397739773956,
          -2.3927392739273934,
          -2.3877387738773876,
          -2.382738273827382,
          -2.377737773777376,
          -2.3727372737273704,
          -2.3677367736773682,
          -2.3627362736273625,
          -2.3577357735773568,
          -2.352735273527351,
          -2.3477347734773453,
          -2.342734273427343,
          -2.3377337733773373,
          -2.3327332733273316,
          -2.327732773277326,
          -2.32273227322732,
          -2.317731773177318,
          -2.312731273127312,
          -2.3077307730773065,
          -2.3027302730273007,
          -2.297729772977295,
          -2.292729272927293,
          -2.287728772877287,
          -2.2827282728272813,
          -2.2777277727772756,
          -2.2727272727272734,
          -2.2677267726772676,
          -2.262726272627262,
          -2.257725772577256,
          -2.2527252725272504,
          -2.2477247724772482,
          -2.2427242724272425,
          -2.2377237723772367,
          -2.232723272327231,
          -2.2277227722772253,
          -2.222722272227223,
          -2.2177217721772173,
          -2.2127212721272116,
          -2.207720772077206,
          -2.2027202720272,
          -2.197719771977198,
          -2.192719271927192,
          -2.1877187718771864,
          -2.1827182718271807,
          -2.177717771777175,
          -2.1727172717271728,
          -2.167716771677167,
          -2.1627162716271613,
          -2.1577157715771556,
          -2.1527152715271534,
          -2.1477147714771476,
          -2.142714271427142,
          -2.137713771377136,
          -2.1327132713271304,
          -2.127712771277128,
          -2.1227122712271225,
          -2.1177117711771167,
          -2.112711271127111,
          -2.1077107710771052,
          -2.102710271027103,
          -2.0977097709770973,
          -2.0927092709270916,
          -2.087708770877086,
          -2.08270827082708,
          -2.077707770777078,
          -2.072707270727072,
          -2.0677067706770664,
          -2.0627062706270607,
          -2.057705770577055,
          -2.0527052705270528,
          -2.047704770477047,
          -2.0427042704270413,
          -2.0377037703770355,
          -2.0327032703270334,
          -2.0277027702770276,
          -2.022702270227022,
          -2.017701770177016,
          -2.0127012701270104,
          -2.007700770077008,
          -2.0027002700270025,
          -1.9976997699769967,
          -1.992699269926991,
          -1.9876987698769852,
          -1.982698269826983,
          -1.9776977697769773,
          -1.9726972697269716,
          -1.9676967696769658,
          -1.96269626962696,
          -1.957695769576958,
          -1.9526952695269522,
          -1.9476947694769464,
          -1.9426942694269407,
          -1.937693769376935,
          -1.9326932693269328,
          -1.927692769276927,
          -1.9226922692269213,
          -1.9176917691769155,
          -1.9126912691269098,
          -1.9076907690769076,
          -1.9026902690269019,
          -1.8976897689768961,
          -1.8926892689268904,
          -1.8876887688768882,
          -1.8826882688268824,
          -1.8776877687768767,
          -1.872687268726871,
          -1.8676867686768652,
          -1.862686268626863,
          -1.8576857685768573,
          -1.8526852685268516,
          -1.8476847684768458,
          -1.84268426842684,
          -1.837683768376838,
          -1.8326832683268321,
          -1.8276827682768264,
          -1.8226822682268207,
          -1.817681768176815,
          -1.8126812681268127,
          -1.807680768076807,
          -1.8026802680268013,
          -1.7976797679767955,
          -1.7926792679267898,
          -1.7876787678767876,
          -1.7826782678267818,
          -1.777677767776776,
          -1.7726772677267704,
          -1.7676767676767682,
          -1.7626762676267624,
          -1.7576757675767567,
          -1.752675267526751,
          -1.7476747674767452,
          -1.742674267426743,
          -1.7376737673767373,
          -1.7326732673267315,
          -1.7276727672767258,
          -1.72267226722672,
          -1.7176717671767179,
          -1.7126712671267121,
          -1.7076707670767064,
          -1.7026702670267007,
          -1.697669766976695,
          -1.6926692669266927,
          -1.687668766876687,
          -1.6826682668266812,
          -1.6776677667766755,
          -1.6726672667266698,
          -1.6676667666766676,
          -1.6626662666266618,
          -1.657665766576656,
          -1.6526652665266504,
          -1.6476647664766482,
          -1.6426642664266424,
          -1.6376637663766367,
          -1.632663266326631,
          -1.6276627662766252,
          -1.622662266226623,
          -1.6176617661766173,
          -1.6126612661266115,
          -1.6076607660766058,
          -1.6026602660266,
          -1.5976597659765979,
          -1.5926592659265921,
          -1.5876587658765864,
          -1.5826582658265806,
          -1.577657765776575,
          -1.5726572657265727,
          -1.567656765676567,
          -1.5626562656265612,
          -1.5576557655765555,
          -1.5526552655265498,
          -1.5476547654765476,
          -1.5426542654265418,
          -1.537653765376536,
          -1.5326532653265303,
          -1.5276527652765282,
          -1.5226522652265224,
          -1.5176517651765167,
          -1.512651265126511,
          -1.5076507650765052,
          -1.502650265026503,
          -1.4976497649764973,
          -1.4926492649264915,
          -1.4876487648764858,
          -1.48264826482648,
          -1.4776477647764779,
          -1.4726472647264721,
          -1.4676467646764664,
          -1.4626462646264606,
          -1.457645764576455,
          -1.4526452645264527,
          -1.447644764476447,
          -1.4426442644264412,
          -1.4376437643764355,
          -1.4326432643264297,
          -1.4276427642764276,
          -1.4226422642264218,
          -1.417641764176416,
          -1.4126412641264103,
          -1.4076407640764081,
          -1.4026402640264024,
          -1.3976397639763967,
          -1.392639263926391,
          -1.3876387638763852,
          -1.382638263826383,
          -1.3776377637763773,
          -1.3726372637263715,
          -1.3676367636763658,
          -1.36263626362636,
          -1.3576357635763578,
          -1.352635263526352,
          -1.3476347634763464,
          -1.3426342634263406,
          -1.3376337633763349,
          -1.3326332633263327,
          -1.327632763276327,
          -1.3226322632263212,
          -1.3176317631763155,
          -1.3126312631263097,
          -1.3076307630763075,
          -1.3026302630263018,
          -1.297629762976296,
          -1.2926292629262903,
          -1.2876287628762881,
          -1.2826282628262824,
          -1.2776277627762767,
          -1.272627262726271,
          -1.2676267626762652,
          -1.262626262626263,
          -1.2576257625762572,
          -1.2526252625262515,
          -1.2476247624762458,
          -1.24262426242624,
          -1.2376237623762378,
          -1.232623262326232,
          -1.2276227622762264,
          -1.2226222622262206,
          -1.2176217621762149,
          -1.2126212621262127,
          -1.207620762076207,
          -1.2026202620262012,
          -1.1976197619761955,
          -1.1926192619261897,
          -1.1876187618761875,
          -1.1826182618261818,
          -1.177617761776176,
          -1.1726172617261703,
          -1.1676167616761681,
          -1.1626162616261624,
          -1.1576157615761566,
          -1.152615261526151,
          -1.1476147614761452,
          -1.142614261426143,
          -1.1376137613761372,
          -1.1326132613261315,
          -1.1276127612761258,
          -1.12261226122612,
          -1.1176117611761178,
          -1.112611261126112,
          -1.1076107610761063,
          -1.1026102610261006,
          -1.0976097609760949,
          -1.0926092609260927,
          -1.087608760876087,
          -1.0826082608260812,
          -1.0776077607760755,
          -1.0726072607260697,
          -1.0676067606760675,
          -1.0626062606260618,
          -1.057605760576056,
          -1.0526052605260503,
          -1.0476047604760481,
          -1.0426042604260424,
          -1.0376037603760366,
          -1.032603260326031,
          -1.0276027602760252,
          -1.022602260226023,
          -1.0176017601760172,
          -1.0126012601260115,
          -1.0076007600760057,
          -1.002600260026,
          -0.9975997599759978,
          -0.9925992599259921,
          -0.9875987598759863,
          -0.9825982598259806,
          -0.9775977597759749,
          -0.9725972597259727,
          -0.9675967596759669,
          -0.9625962596259612,
          -0.9575957595759554,
          -0.9525952595259497,
          -0.9475947594759475,
          -0.9425942594259418,
          -0.937593759375936,
          -0.9325932593259303,
          -0.9275927592759281,
          -0.9225922592259224,
          -0.9175917591759166,
          -0.9125912591259109,
          -0.9075907590759051,
          -0.902590259025903,
          -0.8975897589758972,
          -0.8925892589258915,
          -0.8875887588758857,
          -0.88258825882588,
          -0.8775877587758778,
          -0.8725872587258721,
          -0.8675867586758663,
          -0.8625862586258606,
          -0.8575857585758548,
          -0.8525852585258527,
          -0.8475847584758469,
          -0.8425842584258412,
          -0.8375837583758354,
          -0.8325832583258297,
          -0.8275827582758275,
          -0.8225822582258218,
          -0.817581758175816,
          -0.8125812581258103,
          -0.8075807580758081,
          -0.8025802580258024,
          -0.7975797579757966,
          -0.7925792579257909,
          -0.7875787578757851,
          -0.7825782578257829,
          -0.7775777577757772,
          -0.7725772577257715,
          -0.7675767576757657,
          -0.76257625762576,
          -0.7575757575757578,
          -0.752575257525752,
          -0.7475747574757463,
          -0.7425742574257406,
          -0.7375737573757348,
          -0.7325732573257326,
          -0.7275727572757269,
          -0.7225722572257212,
          -0.7175717571757154,
          -0.7125712571257097,
          -0.7075707570757075,
          -0.7025702570257017,
          -0.697569756975696,
          -0.6925692569256903,
          -0.6875687568756881,
          -0.6825682568256823,
          -0.6775677567756766,
          -0.6725672567256709,
          -0.6675667566756651,
          -0.6625662566256629,
          -0.6575657565756572,
          -0.6525652565256514,
          -0.6475647564756457,
          -0.64256425642564,
          -0.6375637563756378,
          -0.632563256325632,
          -0.6275627562756263,
          -0.6225622562256206,
          -0.6175617561756148,
          -0.6125612561256126,
          -0.6075607560756069,
          -0.6025602560256011,
          -0.5975597559755954,
          -0.5925592559255897,
          -0.5875587558755875,
          -0.5825582558255817,
          -0.577557755775576,
          -0.5725572557255703,
          -0.5675567556755681,
          -0.5625562556255623,
          -0.5575557555755566,
          -0.5525552555255508,
          -0.5475547554755451,
          -0.5425542554255429,
          -0.5375537553755372,
          -0.5325532553255314,
          -0.5275527552755257,
          -0.52255225522552,
          -0.5175517551755178,
          -0.512551255125512,
          -0.5075507550755063,
          -0.5025502550255005,
          -0.4975497549754948,
          -0.4925492549254926,
          -0.4875487548754869,
          -0.48254825482548114,
          -0.4775477547754754,
          -0.47254725472546966,
          -0.46754675467546747,
          -0.46254625462546173,
          -0.457545754575456,
          -0.45254525452545025,
          -0.44754475447544806,
          -0.4425442544254423,
          -0.4375437543754366,
          -0.43254325432543084,
          -0.4275427542754251,
          -0.4225422542254229,
          -0.41754175417541717,
          -0.4125412541254114,
          -0.4075407540754057,
          -0.40254025402539995,
          -0.39753975397539776,
          -0.392539253925392,
          -0.3875387538753863,
          -0.38253825382538054,
          -0.3775377537753748,
          -0.3725372537253726,
          -0.36753675367536687,
          -0.3625362536253611,
          -0.3575357535753554,
          -0.35253525352534965,
          -0.34753475347534746,
          -0.3425342534253417,
          -0.337533753375336,
          -0.33253325332533024,
          -0.32753275327532805,
          -0.3225322532253223,
          -0.31753175317531657,
          -0.3125312531253108,
          -0.3075307530753051,
          -0.3025302530253029,
          -0.29752975297529716,
          -0.2925292529252914,
          -0.2875287528752857,
          -0.28252825282527994,
          -0.27752775277527775,
          -0.272527252725272,
          -0.26752675267526627,
          -0.2625262526252605,
          -0.2575257525752548,
          -0.2525252525252526,
          -0.24752475247524686,
          -0.24252425242524112,
          -0.23752375237523538,
          -0.23252325232522963,
          -0.22752275227522745,
          -0.2225222522252217,
          -0.21752175217521597,
          -0.21252125212521022,
          -0.20752075207520804,
          -0.2025202520252023,
          -0.19751975197519656,
          -0.19251925192519082,
          -0.18751875187518507,
          -0.1825182518251829,
          -0.17751775177517715,
          -0.1725172517251714,
          -0.16751675167516566,
          -0.16251625162515992,
          -0.15751575157515774,
          -0.152515251525152,
          -0.14751475147514626,
          -0.14251425142514051,
          -0.13751375137513477,
          -0.13251325132513259,
          -0.12751275127512685,
          -0.1225122512251211,
          -0.11751175117511536,
          -0.11251125112510962,
          -0.10751075107510744,
          -0.1025102510251017,
          -0.09750975097509595,
          -0.09250925092509021,
          -0.08750875087508803,
          -0.08250825082508229,
          -0.07750775077507654,
          -0.0725072507250708,
          -0.06750675067506506,
          -0.06250625062506288,
          -0.057505750575057135,
          -0.052505250525051395,
          -0.047504750475045654,
          -0.04250425042503991,
          -0.037503750375037725,
          -0.032503250325031985,
          -0.027502750275026244,
          -0.022502250225020504,
          -0.017501750175014763,
          -0.012501250125012575,
          -0.0075007500750068345,
          -0.002500250025001094,
          0.0025002500250046467,
          0.007500750075010387,
          0.012501250125012575,
          0.017501750175018316,
          0.022502250225024056,
          0.027502750275029797,
          0.032503250325031985,
          0.037503750375037725,
          0.042504250425043466,
          0.04750475047504921,
          0.05250525052505495,
          0.057505750575057135,
          0.06250625062506288,
          0.06750675067506862,
          0.07250725072507436,
          0.0775077507750801,
          0.08250825082508229,
          0.08750875087508803,
          0.09250925092509377,
          0.09750975097509951,
          0.10251025102510525,
          0.10751075107510744,
          0.11251125112511318,
          0.11751175117511892,
          0.12251225122512466,
          0.1275127512751304,
          0.13251325132513259,
          0.13751375137513833,
          0.14251425142514407,
          0.1475147514751498,
          0.152515251525152,
          0.15751575157515774,
          0.16251625162516348,
          0.16751675167516922,
          0.17251725172517496,
          0.17751775177517715,
          0.1825182518251829,
          0.18751875187518863,
          0.19251925192519437,
          0.1975197519752001,
          0.2025202520252023,
          0.20752075207520804,
          0.21252125212521378,
          0.21752175217521952,
          0.22252225222522526,
          0.22752275227522745,
          0.2325232523252332,
          0.23752375237523893,
          0.24252425242524467,
          0.2475247524752504,
          0.2525252525252526,
          0.25752575257525834,
          0.2625262526252641,
          0.2675267526752698,
          0.272527252725272,
          0.27752775277527775,
          0.2825282528252835,
          0.28752875287528923,
          0.29252925292529497,
          0.29752975297529716,
          0.3025302530253029,
          0.30753075307530864,
          0.3125312531253144,
          0.3175317531753201,
          0.3225322532253223,
          0.32753275327532805,
          0.3325332533253338,
          0.33753375337533953,
          0.34253425342534527,
          0.34753475347534746,
          0.3525352535253532,
          0.35753575357535894,
          0.3625362536253647,
          0.3675367536753704,
          0.3725372537253726,
          0.37753775377537835,
          0.3825382538253841,
          0.38753875387538983,
          0.392539253925392,
          0.39753975397539776,
          0.4025402540254035,
          0.40754075407540924,
          0.412541254125415,
          0.41754175417541717,
          0.4225422542254229,
          0.42754275427542865,
          0.4325432543254344,
          0.43754375437544013,
          0.4425442544254423,
          0.44754475447544806,
          0.4525452545254538,
          0.45754575457545954,
          0.4625462546254653,
          0.46754675467546747,
          0.4725472547254732,
          0.47754775477547895,
          0.4825482548254847,
          0.48754875487549043,
          0.4925492549254926,
          0.49754975497549836,
          0.5025502550255041,
          0.5075507550755098,
          0.512551255125512,
          0.5175517551755178,
          0.5225522552255235,
          0.5275527552755293,
          0.532553255325535,
          0.5375537553755372,
          0.5425542554255429,
          0.5475547554755487,
          0.5525552555255544,
          0.5575557555755601,
          0.5625562556255623,
          0.5675567556755681,
          0.5725572557255738,
          0.5775577557755796,
          0.5825582558255853,
          0.5875587558755875,
          0.5925592559255932,
          0.597559755975599,
          0.6025602560256047,
          0.6075607560756104,
          0.6125612561256126,
          0.6175617561756184,
          0.6225622562256241,
          0.6275627562756299,
          0.6325632563256356,
          0.6375637563756378,
          0.6425642564256435,
          0.6475647564756493,
          0.652565256525655,
          0.6575657565756572,
          0.6625662566256629,
          0.6675667566756687,
          0.6725672567256744,
          0.6775677567756802,
          0.6825682568256823,
          0.6875687568756881,
          0.6925692569256938,
          0.6975697569756996,
          0.7025702570257053,
          0.7075707570757075,
          0.7125712571257132,
          0.717571757175719,
          0.7225722572257247,
          0.7275727572757305,
          0.7325732573257326,
          0.7375737573757384,
          0.7425742574257441,
          0.7475747574757499,
          0.7525752575257556,
          0.7575757575757578,
          0.7625762576257635,
          0.7675767576757693,
          0.772577257725775,
          0.7775777577757772,
          0.7825782578257829,
          0.7875787578757887,
          0.7925792579257944,
          0.7975797579758002,
          0.8025802580258024,
          0.8075807580758081,
          0.8125812581258138,
          0.8175817581758196,
          0.8225822582258253,
          0.8275827582758275,
          0.8325832583258332,
          0.837583758375839,
          0.8425842584258447,
          0.8475847584758505,
          0.8525852585258527,
          0.8575857585758584,
          0.8625862586258641,
          0.8675867586758699,
          0.8725872587258756,
          0.8775877587758778,
          0.8825882588258835,
          0.8875887588758893,
          0.892589258925895,
          0.8975897589758972,
          0.902590259025903,
          0.9075907590759087,
          0.9125912591259144,
          0.9175917591759202,
          0.9225922592259224,
          0.9275927592759281,
          0.9325932593259338,
          0.9375937593759396,
          0.9425942594259453,
          0.9475947594759475,
          0.9525952595259533,
          0.957595759575959,
          0.9625962596259647,
          0.9675967596759705,
          0.9725972597259727,
          0.9775977597759784,
          0.9825982598259841,
          0.9875987598759899,
          0.9925992599259956,
          0.9975997599759978,
          1.0026002600260036,
          1.0076007600760093,
          1.012601260126015,
          1.0176017601760172,
          1.022602260226023,
          1.0276027602760287,
          1.0326032603260344,
          1.0376037603760402,
          1.0426042604260424,
          1.0476047604760481,
          1.0526052605260539,
          1.0576057605760596,
          1.0626062606260653,
          1.0676067606760675,
          1.0726072607260733,
          1.077607760776079,
          1.0826082608260847,
          1.0876087608760905,
          1.0926092609260927,
          1.0976097609760984,
          1.1026102610261042,
          1.10761076107611,
          1.1126112611261156,
          1.1176117611761178,
          1.1226122612261236,
          1.1276127612761293,
          1.132613261326135,
          1.1376137613761372,
          1.142614261426143,
          1.1476147614761487,
          1.1526152615261545,
          1.1576157615761602,
          1.1626162616261624,
          1.1676167616761681,
          1.1726172617261739,
          1.1776177617761796,
          1.1826182618261853,
          1.1876187618761875,
          1.1926192619261933,
          1.197619761976199,
          1.2026202620262048,
          1.2076207620762105,
          1.2126212621262127,
          1.2176217621762184,
          1.2226222622262242,
          1.22762276227623,
          1.2326232623262356,
          1.2376237623762378,
          1.2426242624262436,
          1.2476247624762493,
          1.252625262526255,
          1.2576257625762572,
          1.262626262626263,
          1.2676267626762687,
          1.2726272627262745,
          1.2776277627762802,
          1.2826282628262824,
          1.2876287628762881,
          1.2926292629262939,
          1.2976297629762996,
          1.3026302630263054,
          1.3076307630763075,
          1.3126312631263133,
          1.317631763176319,
          1.3226322632263248,
          1.3276327632763305,
          1.3326332633263327,
          1.3376337633763384,
          1.3426342634263442,
          1.34763476347635,
          1.3526352635263557,
          1.3576357635763578,
          1.3626362636263636,
          1.3676367636763693,
          1.372637263726375,
          1.3776377637763773,
          1.382638263826383,
          1.3876387638763887,
          1.3926392639263945,
          1.3976397639764002,
          1.4026402640264024,
          1.4076407640764081,
          1.4126412641264139,
          1.4176417641764196,
          1.4226422642264254,
          1.4276427642764276,
          1.4326432643264333,
          1.437643764376439,
          1.4426442644264448,
          1.4476447644764505,
          1.4526452645264527,
          1.4576457645764584,
          1.4626462646264642,
          1.46764676467647,
          1.4726472647264757,
          1.4776477647764779,
          1.4826482648264836,
          1.4876487648764893,
          1.492649264926495,
          1.4976497649764973,
          1.502650265026503,
          1.5076507650765087,
          1.5126512651265145,
          1.5176517651765202,
          1.5226522652265224,
          1.5276527652765282,
          1.532653265326534,
          1.5376537653765396,
          1.5426542654265454,
          1.5476547654765476,
          1.5526552655265533,
          1.557655765576559,
          1.5626562656265648,
          1.5676567656765705,
          1.5726572657265727,
          1.5776577657765785,
          1.5826582658265842,
          1.58765876587659,
          1.5926592659265957,
          1.5976597659765979,
          1.6026602660266036,
          1.6076607660766093,
          1.612661266126615,
          1.6176617661766173,
          1.622662266226623,
          1.6276627662766288,
          1.6326632663266345,
          1.6376637663766402,
          1.6426642664266424,
          1.6476647664766482,
          1.652665266526654,
          1.6576657665766596,
          1.6626662666266654,
          1.6676667666766676,
          1.6726672667266733,
          1.677667766776679,
          1.6826682668266848,
          1.6876687668766905,
          1.6926692669266927,
          1.6976697669766985,
          1.7026702670267042,
          1.70767076707671,
          1.7126712671267157,
          1.7176717671767179,
          1.7226722672267236,
          1.7276727672767294,
          1.732673267326735,
          1.7376737673767373,
          1.742674267426743,
          1.7476747674767488,
          1.7526752675267545,
          1.7576757675767603,
          1.7626762676267624,
          1.7676767676767682,
          1.772677267726774,
          1.7776777677767797,
          1.7826782678267854,
          1.7876787678767876,
          1.7926792679267933,
          1.797679767976799,
          1.8026802680268048,
          1.8076807680768106,
          1.8126812681268127,
          1.8176817681768185,
          1.8226822682268242,
          1.82768276827683,
          1.8326832683268357,
          1.837683768376838,
          1.8426842684268436,
          1.8476847684768494,
          1.8526852685268551,
          1.8576857685768573,
          1.862686268626863,
          1.8676867686768688,
          1.8726872687268745,
          1.8776877687768803,
          1.8826882688268824,
          1.8876887688768882,
          1.892689268926894,
          1.8976897689768997,
          1.9026902690269054,
          1.9076907690769076,
          1.9126912691269133,
          1.917691769176919,
          1.9226922692269248,
          1.9276927692769306,
          1.9326932693269328,
          1.9376937693769385,
          1.9426942694269442,
          1.94769476947695,
          1.9526952695269557,
          1.957695769576958,
          1.9626962696269636,
          1.9676967696769694,
          1.9726972697269751,
          1.9776977697769773,
          1.982698269826983,
          1.9876987698769888,
          1.9926992699269945,
          1.9976997699770003,
          2.0027002700270025,
          2.007700770077008,
          2.012701270127014,
          2.0177017701770197,
          2.0227022702270254,
          2.0277027702770276,
          2.0327032703270334,
          2.037703770377039,
          2.042704270427045,
          2.0477047704770506,
          2.0527052705270528,
          2.0577057705770585,
          2.0627062706270642,
          2.06770677067707,
          2.0727072707270757,
          2.077707770777078,
          2.0827082708270837,
          2.0877087708770894,
          2.092709270927095,
          2.0977097709770973,
          2.102710271027103,
          2.107710771077109,
          2.1127112711271145,
          2.1177117711771203,
          2.1227122712271225,
          2.127712771277128,
          2.132713271327134,
          2.1377137713771397,
          2.1427142714271454,
          2.1477147714771476,
          2.1527152715271534,
          2.157715771577159,
          2.162716271627165,
          2.1677167716771706,
          2.1727172717271728,
          2.1777177717771785,
          2.1827182718271843,
          2.18771877187719,
          2.1927192719271957,
          2.197719771977198,
          2.2027202720272037,
          2.2077207720772094,
          2.212721272127215,
          2.2177217721772173,
          2.222722272227223,
          2.227722772277229,
          2.2327232723272346,
          2.2377237723772403,
          2.2427242724272425,
          2.2477247724772482,
          2.252725272527254,
          2.2577257725772597,
          2.2627262726272654,
          2.2677267726772676,
          2.2727272727272734,
          2.277727772777279,
          2.282728272827285,
          2.2877287728772906,
          2.292729272927293,
          2.2977297729772985,
          2.3027302730273043,
          2.30773077307731,
          2.3127312731273157,
          2.317731773177318,
          2.3227322732273237,
          2.3277327732773294,
          2.332733273327335,
          2.3377337733773373,
          2.342734273427343,
          2.347734773477349,
          2.3527352735273546,
          2.3577357735773603,
          2.3627362736273625,
          2.3677367736773682,
          2.372737273727374,
          2.3777377737773797,
          2.3827382738273855,
          2.3877387738773876,
          2.3927392739273934,
          2.397739773977399,
          2.402740274027405,
          2.4077407740774106,
          2.412741274127413,
          2.4177417741774185,
          2.4227422742274243,
          2.42774277427743,
          2.4327432743274358,
          2.437743774377438,
          2.4427442744274437,
          2.4477447744774494,
          2.452745274527455,
          2.4577457745774574,
          2.462746274627463,
          2.467746774677469,
          2.4727472747274746,
          2.4777477747774803,
          2.4827482748274825,
          2.4877487748774882,
          2.492749274927494,
          2.4977497749774997,
          2.5027502750275055,
          2.5077507750775077,
          2.5127512751275134,
          2.517751775177519,
          2.522752275227525,
          2.5277527752775306,
          2.532753275327533,
          2.5377537753775385,
          2.5427542754275443,
          2.54775477547755,
          2.5527552755275558,
          2.557755775577558,
          2.5627562756275637,
          2.5677567756775694,
          2.572757275727575,
          2.5777577757775774,
          2.582758275827583,
          2.587758775877589,
          2.5927592759275946,
          2.5977597759776003,
          2.6027602760276025,
          2.6077607760776083,
          2.612761276127614,
          2.6177617761776197,
          2.6227622762276255,
          2.6277627762776277,
          2.6327632763276334,
          2.637763776377639,
          2.642764276427645,
          2.6477647764776506,
          2.652765276527653,
          2.6577657765776586,
          2.6627662766276643,
          2.66776677667767,
          2.672767276727676,
          2.677767776777678,
          2.6827682768276837,
          2.6877687768776894,
          2.692769276927695,
          2.6977697769776974,
          2.702770277027703,
          2.707770777077709,
          2.7127712771277146,
          2.7177717771777203,
          2.7227722772277225,
          2.7277727772777283,
          2.732773277327734,
          2.7377737773777397,
          2.7427742774277455,
          2.7477747774777477,
          2.7527752775277534,
          2.757775777577759,
          2.762776277627765,
          2.7677767776777706,
          2.772777277727773,
          2.7777777777777786,
          2.7827782778277843,
          2.78777877787779,
          2.792779277927796,
          2.797779777977798,
          2.8027802780278037,
          2.8077807780778095,
          2.812781278127815,
          2.8177817781778174,
          2.822782278227823,
          2.827782778277829,
          2.8327832783278346,
          2.8377837783778403,
          2.8427842784278425,
          2.8477847784778483,
          2.852785278527854,
          2.8577857785778598,
          2.8627862786278655,
          2.8677867786778677,
          2.8727872787278734,
          2.877787778777879,
          2.882788278827885,
          2.8877887788778906,
          2.892789278927893,
          2.8977897789778986,
          2.9027902790279043,
          2.90779077907791,
          2.912791279127916,
          2.917791779177918,
          2.9227922792279237,
          2.9277927792779295,
          2.932793279327935,
          2.9377937793779374,
          2.942794279427943,
          2.947794779477949,
          2.9527952795279546,
          2.9577957795779604,
          2.9627962796279625,
          2.9677967796779683,
          2.972797279727974,
          2.9777977797779798,
          2.9827982798279855,
          2.9877987798779877,
          2.9927992799279934,
          2.997799779977999,
          3.002800280028005,
          3.0078007800780107,
          3.012801280128013,
          3.0178017801780186,
          3.0228022802280243,
          3.02780278027803,
          3.032803280328036,
          3.037803780378038,
          3.0428042804280437,
          3.0478047804780495,
          3.052805280528055,
          3.0578057805780574,
          3.062806280628063,
          3.067806780678069,
          3.0728072807280746,
          3.0778077807780804,
          3.0828082808280826,
          3.0878087808780883,
          3.092809280928094,
          3.0978097809781,
          3.1028102810281055,
          3.1078107810781077,
          3.1128112811281134,
          3.117811781178119,
          3.122812281228125,
          3.1278127812781307,
          3.132813281328133,
          3.1378137813781386,
          3.1428142814281443,
          3.14781478147815,
          3.152815281528156,
          3.157815781578158,
          3.1628162816281638,
          3.1678167816781695,
          3.1728172817281752,
          3.177817781778181,
          3.182818281828183,
          3.187818781878189,
          3.1928192819281946,
          3.1978197819782004,
          3.2028202820282026,
          3.2078207820782083,
          3.212821282128214,
          3.21782178217822,
          3.2228222822282255,
          3.2278227822782277,
          3.2328232823282335,
          3.237823782378239,
          3.242824282428245,
          3.2478247824782507,
          3.252825282528253,
          3.2578257825782586,
          3.2628262826282644,
          3.26782678267827,
          3.272827282728276,
          3.277827782778278,
          3.2828282828282838,
          3.2878287828782895,
          3.2928292829282952,
          3.297829782978301,
          3.302830283028303,
          3.307830783078309,
          3.3128312831283147,
          3.3178317831783204,
          3.3228322832283226,
          3.3278327832783283,
          3.332833283328334,
          3.33783378337834,
          3.3428342834283455,
          3.3478347834783477,
          3.3528352835283535,
          3.357835783578359,
          3.362836283628365,
          3.3678367836783707,
          3.372837283728373,
          3.3778377837783786,
          3.3828382838283844,
          3.38783878387839,
          3.392839283928396,
          3.397839783978398,
          3.4028402840284038,
          3.4078407840784095,
          3.4128412841284153,
          3.417841784178421,
          3.422842284228423,
          3.427842784278429,
          3.4328432843284347,
          3.4378437843784404,
          3.4428442844284426,
          3.4478447844784483,
          3.452845284528454,
          3.45784578457846,
          3.4628462846284656,
          3.4678467846784677,
          3.4728472847284735,
          3.4778477847784792,
          3.482848284828485,
          3.4878487848784907,
          3.492849284928493,
          3.4978497849784986,
          3.5028502850285044,
          3.50785078507851,
          3.512851285128516,
          3.517851785178518,
          3.522852285228524,
          3.5278527852785295,
          3.5328532853285353,
          3.537853785378541,
          3.542854285428543,
          3.547854785478549,
          3.5528552855285547,
          3.5578557855785604,
          3.5628562856285626,
          3.5678567856785683,
          3.572857285728574,
          3.57785778577858,
          3.5828582858285856,
          3.5878587858785878,
          3.5928592859285935,
          3.5978597859785992,
          3.602860286028605,
          3.6078607860786107,
          3.612861286128613,
          3.6178617861786186,
          3.6228622862286244,
          3.62786278627863,
          3.632863286328636,
          3.637863786378638,
          3.642864286428644,
          3.6478647864786495,
          3.6528652865286553,
          3.657865786578661,
          3.662866286628663,
          3.667866786678669,
          3.6728672867286747,
          3.6778677867786804,
          3.6828682868286826,
          3.6878687868786884,
          3.692869286928694,
          3.6978697869787,
          3.7028702870287056,
          3.7078707870787078,
          3.7128712871287135,
          3.7178717871787192,
          3.722872287228725,
          3.7278727872787307,
          3.732873287328733,
          3.7378737873787387,
          3.7428742874287444,
          3.74787478747875,
          3.752875287528756,
          3.757875787578758,
          3.762876287628764,
          3.7678767876787695,
          3.7728772877287753,
          3.777877787778781,
          3.782878287828783,
          3.787878787878789,
          3.7928792879287947,
          3.7978797879788004,
          3.8028802880288026,
          3.8078807880788084,
          3.812881288128814,
          3.81788178817882,
          3.8228822882288256,
          3.8278827882788278,
          3.8328832883288335,
          3.8378837883788393,
          3.842884288428845,
          3.8478847884788507,
          3.852885288528853,
          3.8578857885788587,
          3.8628862886288644,
          3.86788678867887,
          3.872887288728876,
          3.877887788778878,
          3.882888288828884,
          3.8878887888788896,
          3.8928892889288953,
          3.897889788978901,
          3.9028902890289032,
          3.907890789078909,
          3.9128912891289147,
          3.9178917891789204,
          3.9228922892289226,
          3.9278927892789284,
          3.932893289328934,
          3.93789378937894,
          3.9428942894289456,
          3.947894789478948,
          3.9528952895289535,
          3.9578957895789593,
          3.962896289628965,
          3.9678967896789707,
          3.972897289728973,
          3.9778977897789787,
          3.9828982898289844,
          3.98789878987899,
          3.992899289928996,
          3.997899789978998,
          4.002900290029004,
          4.00790079007901,
          4.012901290129015,
          4.017901790179021,
          4.022902290229023,
          4.027902790279029,
          4.032903290329035,
          4.0379037903790405,
          4.042904290429043,
          4.047904790479048,
          4.052905290529054,
          4.05790579057906,
          4.062906290629066,
          4.067906790679068,
          4.0729072907290735,
          4.077907790779079,
          4.082908290829085,
          4.087908790879091,
          4.092909290929093,
          4.097909790979099,
          4.102910291029104,
          4.10791079107911,
          4.112911291129116,
          4.117911791179118,
          4.122912291229124,
          4.12791279127913,
          4.132913291329135,
          4.137913791379141,
          4.142914291429143,
          4.147914791479149,
          4.152915291529155,
          4.1579157915791605,
          4.162916291629163,
          4.167916791679168,
          4.172917291729174,
          4.17791779177918,
          4.182918291829186,
          4.187918791879188,
          4.1929192919291935,
          4.197919791979199,
          4.202920292029205,
          4.207920792079211,
          4.212921292129213,
          4.217921792179219,
          4.222922292229224,
          4.22792279227923,
          4.232923292329236,
          4.237923792379238,
          4.242924292429244,
          4.24792479247925,
          4.252925292529255,
          4.257925792579261,
          4.262926292629263,
          4.267926792679269,
          4.272927292729275,
          4.2779277927792805,
          4.282928292829283,
          4.287928792879288,
          4.292929292929294,
          4.2979297929793,
          4.302930293029306,
          4.307930793079308,
          4.312931293129314,
          4.317931793179319,
          4.322932293229325,
          4.327932793279331,
          4.332933293329333,
          4.337933793379339,
          4.3429342934293445,
          4.34793479347935,
          4.352935293529356,
          4.357935793579358,
          4.362936293629364,
          4.36793679367937,
          4.372937293729375,
          4.377937793779381,
          4.382938293829383,
          4.387938793879389,
          4.392939293929395,
          4.3979397939794005,
          4.402940294029403,
          4.407940794079408,
          4.412941294129414,
          4.41794179417942,
          4.422942294229426,
          4.427942794279428,
          4.432943294329434,
          4.437943794379439,
          4.442944294429445,
          4.447944794479451,
          4.452945294529453,
          4.457945794579459,
          4.4629462946294645,
          4.46794679467947,
          4.472947294729476,
          4.477947794779478,
          4.482948294829484,
          4.48794879487949,
          4.492949294929495,
          4.497949794979501,
          4.502950295029503,
          4.507950795079509,
          4.512951295129515,
          4.5179517951795205,
          4.522952295229523,
          4.527952795279528,
          4.532953295329534,
          4.53795379537954,
          4.542954295429546,
          4.547954795479548,
          4.552955295529554,
          4.557955795579559,
          4.562956295629565,
          4.567956795679571,
          4.572957295729573,
          4.577957795779579,
          4.5829582958295845,
          4.58795879587959,
          4.592959295929596,
          4.597959795979598,
          4.602960296029604,
          4.60796079607961,
          4.612961296129615,
          4.617961796179621,
          4.622962296229623,
          4.627962796279629,
          4.632963296329635,
          4.6379637963796405,
          4.642964296429643,
          4.647964796479648,
          4.652965296529654,
          4.65796579657966,
          4.662966296629666,
          4.667966796679668,
          4.672967296729674,
          4.677967796779679,
          4.682968296829685,
          4.687968796879691,
          4.692969296929693,
          4.697969796979699,
          4.7029702970297045,
          4.70797079707971,
          4.712971297129716,
          4.717971797179718,
          4.722972297229724,
          4.72797279727973,
          4.732973297329735,
          4.737973797379741,
          4.742974297429743,
          4.747974797479749,
          4.752975297529755,
          4.7579757975797605,
          4.762976297629763,
          4.7679767976797685,
          4.772977297729774,
          4.77797779777978,
          4.782978297829786,
          4.787978797879788,
          4.792979297929794,
          4.797979797979799,
          4.802980298029805,
          4.807980798079811,
          4.812981298129813,
          4.817981798179819,
          4.8229822982298245,
          4.82798279827983,
          4.832983298329836,
          4.837983798379838,
          4.842984298429844,
          4.84798479847985,
          4.852985298529855,
          4.857985798579861,
          4.862986298629863,
          4.867986798679869,
          4.872987298729875,
          4.8779877987798805,
          4.882988298829883,
          4.8879887988798885,
          4.892989298929894,
          4.8979897989799,
          4.902990299029906,
          4.907990799079908,
          4.912991299129914,
          4.917991799179919,
          4.922992299229925,
          4.927992799279931,
          4.932993299329933,
          4.937993799379939,
          4.9429942994299445,
          4.94799479947995,
          4.952995299529956,
          4.957995799579958,
          4.962996299629964,
          4.96799679967997,
          4.972997299729975,
          4.977997799779981,
          4.982998299829983,
          4.987998799879989,
          4.992999299929995,
          4.9979997999800005,
          5.003000300030003,
          5.0080008000800085,
          5.013001300130014,
          5.01800180018002,
          5.023002300230026,
          5.028002800280028,
          5.033003300330034,
          5.038003800380039,
          5.043004300430045,
          5.048004800480051,
          5.053005300530053,
          5.058005800580059,
          5.0630063006300645,
          5.06800680068007,
          5.073007300730076,
          5.078007800780078,
          5.083008300830084,
          5.08800880088009,
          5.093009300930095,
          5.098009800980101,
          5.103010301030103,
          5.108010801080109,
          5.113011301130115,
          5.118011801180121,
          5.123012301230123,
          5.1280128012801285,
          5.133013301330134,
          5.13801380138014,
          5.143014301430146,
          5.148014801480148,
          5.153015301530154,
          5.158015801580159,
          5.163016301630165,
          5.168016801680171,
          5.173017301730173,
          5.178017801780179,
          5.1830183018301845,
          5.18801880188019,
          5.193019301930196,
          5.198019801980198,
          5.203020302030204,
          5.20802080208021,
          5.213021302130215,
          5.218021802180221,
          5.223022302230223,
          5.228022802280229,
          5.233023302330235,
          5.238023802380241,
          5.243024302430243,
          5.2480248024802485,
          5.253025302530254,
          5.25802580258026,
          5.263026302630266,
          5.268026802680268,
          5.273027302730274,
          5.278027802780279,
          5.283028302830285,
          5.288028802880291,
          5.293029302930293,
          5.298029802980299,
          5.3030303030303045,
          5.30803080308031,
          5.313031303130316,
          5.318031803180318,
          5.323032303230324,
          5.32803280328033,
          5.333033303330335,
          5.338033803380341,
          5.343034303430343,
          5.348034803480349,
          5.353035303530355,
          5.358035803580361,
          5.363036303630363,
          5.3680368036803685,
          5.373037303730374,
          5.37803780378038,
          5.383038303830386,
          5.388038803880388,
          5.393039303930394,
          5.398039803980399,
          5.403040304030405,
          5.408040804080411,
          5.413041304130413,
          5.418041804180419,
          5.4230423042304245,
          5.42804280428043,
          5.433043304330436,
          5.438043804380438,
          5.443044304430444,
          5.44804480448045,
          5.453045304530455,
          5.458045804580461,
          5.463046304630463,
          5.468046804680469,
          5.473047304730475,
          5.478047804780481,
          5.483048304830483,
          5.4880488048804885,
          5.493049304930494,
          5.4980498049805,
          5.503050305030506,
          5.508050805080508,
          5.513051305130514,
          5.518051805180519,
          5.523052305230525,
          5.528052805280531,
          5.533053305330533,
          5.538053805380539,
          5.543054305430545,
          5.54805480548055,
          5.553055305530556,
          5.558055805580558,
          5.563056305630564,
          5.56805680568057,
          5.5730573057305755,
          5.578057805780581,
          5.583058305830583,
          5.588058805880589,
          5.593059305930595,
          5.598059805980601,
          5.603060306030603,
          5.6080608060806085,
          5.613061306130614,
          5.61806180618062,
          5.623062306230626,
          5.628062806280628,
          5.633063306330634,
          5.638063806380639,
          5.643064306430645,
          5.648064806480651,
          5.653065306530653,
          5.658065806580659,
          5.663066306630665,
          5.66806680668067,
          5.673067306730676,
          5.678067806780678,
          5.683068306830684,
          5.68806880688069,
          5.6930693069306955,
          5.698069806980701,
          5.703070307030703,
          5.708070807080709,
          5.713071307130715,
          5.718071807180721,
          5.723072307230723,
          5.7280728072807285,
          5.733073307330734,
          5.73807380738074,
          5.743074307430746,
          5.748074807480748,
          5.753075307530754,
          5.758075807580759,
          5.763076307630765,
          5.768076807680771,
          5.773077307730773,
          5.778077807780779,
          5.783078307830785,
          5.78807880788079,
          5.793079307930796,
          5.798079807980798,
          5.803080308030804,
          5.80808080808081,
          5.8130813081308155,
          5.818081808180821,
          5.823082308230823,
          5.828082808280829,
          5.833083308330835,
          5.838083808380841,
          5.843084308430846,
          5.8480848084808486,
          5.853085308530854,
          5.85808580858086,
          5.863086308630866,
          5.868086808680868,
          5.873087308730874,
          5.878087808780879,
          5.883088308830885,
          5.888088808880891,
          5.893089308930893,
          5.898089808980899,
          5.903090309030905,
          5.90809080908091,
          5.913091309130916,
          5.918091809180918,
          5.923092309230924,
          5.92809280928093,
          5.9330933093309355,
          5.938093809380941,
          5.943094309430943,
          5.948094809480949,
          5.953095309530955,
          5.958095809580961,
          5.963096309630966,
          5.968096809680969,
          5.973097309730974,
          5.97809780978098,
          5.983098309830986,
          5.988098809880988,
          5.993099309930994,
          5.9980998099809995,
          6.003100310031005,
          6.008100810081011,
          6.013101310131013,
          6.018101810181019,
          6.023102310231025,
          6.02810281028103,
          6.033103310331036,
          6.038103810381038,
          6.043104310431044,
          6.04810481048105,
          6.0531053105310555,
          6.058105810581061,
          6.063106310631063,
          6.068106810681069,
          6.073107310731075,
          6.078107810781081,
          6.083108310831086,
          6.088108810881089,
          6.093109310931094,
          6.0981098109811,
          6.103110311031106,
          6.108110811081108,
          6.113111311131114,
          6.1181118111811195,
          6.123112311231125,
          6.128112811281131,
          6.133113311331133,
          6.138113811381139,
          6.143114311431145,
          6.14811481148115,
          6.153115311531156,
          6.158115811581158,
          6.163116311631164,
          6.16811681168117,
          6.1731173117311755,
          6.178117811781181,
          6.183118311831183,
          6.188118811881189,
          6.193119311931195,
          6.198119811981201,
          6.203120312031206,
          6.208120812081209,
          6.213121312131214,
          6.21812181218122,
          6.223122312231226,
          6.228122812281228,
          6.233123312331234,
          6.2381238123812395,
          6.243124312431245,
          6.248124812481251,
          6.253125312531253,
          6.258125812581259,
          6.263126312631265,
          6.26812681268127,
          6.273127312731276,
          6.278127812781278,
          6.283128312831284,
          6.28812881288129,
          6.2931293129312955,
          6.298129812981301,
          6.3031303130313034,
          6.308130813081309,
          6.313131313131315,
          6.318131813181321,
          6.323132313231326,
          6.328132813281329,
          6.333133313331334,
          6.33813381338134,
          6.343134313431346,
          6.348134813481348,
          6.353135313531354,
          6.3581358135813595,
          6.363136313631365,
          6.368136813681371,
          6.373137313731373,
          6.378137813781379,
          6.383138313831385,
          6.38813881388139,
          6.393139313931396,
          6.398139813981398,
          6.403140314031404,
          6.40814081408141,
          6.4131413141314155,
          6.418141814181421,
          6.4231423142314235,
          6.428142814281429,
          6.433143314331435,
          6.438143814381441,
          6.443144314431446,
          6.448144814481449,
          6.453145314531454,
          6.45814581458146,
          6.463146314631466,
          6.468146814681468,
          6.473147314731474,
          6.4781478147814795,
          6.483148314831485,
          6.488148814881491,
          6.493149314931493,
          6.498149814981499,
          6.503150315031505,
          6.50815081508151,
          6.513151315131516,
          6.518151815181518,
          6.523152315231524,
          6.52815281528153,
          6.5331533153315355,
          6.538153815381541,
          6.5431543154315435,
          6.548154815481549,
          6.553155315531555,
          6.558155815581561,
          6.563156315631566,
          6.568156815681569,
          6.573157315731574,
          6.57815781578158,
          6.583158315831586,
          6.588158815881588,
          6.593159315931594,
          6.5981598159815995,
          6.603160316031605,
          6.608160816081611,
          6.613161316131613,
          6.618161816181619,
          6.623162316231625,
          6.62816281628163,
          6.633163316331636,
          6.638163816381638,
          6.643164316431644,
          6.64816481648165,
          6.6531653165316555,
          6.658165816581661,
          6.6631663166316635,
          6.668166816681669,
          6.673167316731675,
          6.678167816781681,
          6.683168316831686,
          6.688168816881689,
          6.693169316931694,
          6.6981698169817,
          6.703170317031706,
          6.708170817081708,
          6.713171317131714,
          6.7181718171817195,
          6.723172317231725,
          6.728172817281731,
          6.733173317331733,
          6.738173817381739,
          6.743174317431745,
          6.74817481748175,
          6.753175317531756,
          6.758175817581758,
          6.763176317631764,
          6.76817681768177,
          6.773177317731776,
          6.778177817781781,
          6.7831783178317835,
          6.788178817881789,
          6.793179317931795,
          6.798179817981801,
          6.8031803180318065,
          6.808180818081809,
          6.813181318131814,
          6.81818181818182,
          6.823182318231826,
          6.828182818281828,
          6.833183318331834,
          6.8381838183818395,
          6.843184318431845,
          6.848184818481851,
          6.853185318531853,
          6.858185818581859,
          6.863186318631865,
          6.86818681868187,
          6.873187318731876,
          6.878187818781878,
          6.883188318831884,
          6.88818881888189,
          6.893189318931896,
          6.898189818981901,
          6.9031903190319035,
          6.908190819081909,
          6.913191319131915,
          6.918191819181921,
          6.9231923192319265,
          6.928192819281929,
          6.933193319331934,
          6.93819381938194,
          6.943194319431946,
          6.948194819481948,
          6.953195319531954,
          6.9581958195819595,
          6.963196319631965,
          6.968196819681971,
          6.973197319731973,
          6.978197819781979,
          6.983198319831985,
          6.98819881988199,
          6.993199319931996,
          6.998199819981998,
          7.003200320032008,
          7.00820082008201,
          7.013201320132012,
          7.018201820182021,
          7.0232023202320235,
          7.028202820282033,
          7.033203320332035,
          7.038203820382037,
          7.0432043204320465,
          7.048204820482049,
          7.053205320532058,
          7.05820582058206,
          7.063206320632062,
          7.068206820682072,
          7.073207320732074,
          7.078207820782083,
          7.083208320832085,
          7.0882088208820875,
          7.093209320932097,
          7.098209820982099,
          7.103210321032108,
          7.10821082108211,
          7.113211321132113,
          7.118211821182122,
          7.123212321232124,
          7.128212821282126,
          7.133213321332136,
          7.138213821382138,
          7.143214321432147,
          7.148214821482149,
          7.1532153215321514,
          7.158215821582161,
          7.163216321632163,
          7.168216821682172,
          7.173217321732174,
          7.178217821782177,
          7.183218321832186,
          7.188218821882188,
          7.193219321932197,
          7.1982198219822,
          7.203220322032202,
          7.208220822082211,
          7.213221322132213,
          7.2182218221822225,
          7.223222322232225,
          7.228222822282227,
          7.233223322332236,
          7.238223822382238,
          7.243224322432248,
          7.24822482248225,
          7.253225322532252,
          7.258225822582261,
          7.2632263226322635,
          7.268226822682273,
          7.273227322732275,
          7.278227822782277,
          7.2832283228322865,
          7.288228822882289,
          7.293229322932298,
          7.2982298229823,
          7.303230323032302,
          7.308230823082312,
          7.313231323132314,
          7.318231823182323,
          7.323232323232325,
          7.3282328232823275,
          7.333233323332337,
          7.338233823382339,
          7.343234323432348,
          7.3482348234823505,
          7.353235323532353,
          7.358235823582362,
          7.363236323632364,
          7.368236823682366,
          7.373237323732376,
          7.378237823782378,
          7.383238323832387,
          7.388238823882389,
          7.3932393239323915,
          7.398239823982401,
          7.403240324032403,
          7.408240824082412,
          7.413241324132414,
          7.418241824182417,
          7.423242324232426,
          7.428242824282428,
          7.433243324332437,
          7.43824382438244,
          7.443244324432442,
          7.448244824482451,
          7.453245324532453,
          7.4582458245824625,
          7.463246324632465,
          7.468246824682467,
          7.473247324732476,
          7.478247824782478,
          7.483248324832488,
          7.48824882488249,
          7.493249324932492,
          7.498249824982501,
          7.5032503250325036,
          7.508250825082513,
          7.513251325132515,
          7.518251825182517,
          7.5232523252325265,
          7.528252825282529,
          7.533253325332538,
          7.53825382538254,
          7.543254325432542,
          7.548254825482552,
          7.553255325532554,
          7.558255825582563,
          7.563256325632565,
          7.5682568256825675,
          7.573257325732577,
          7.578257825782579,
          7.583258325832588,
          7.5882588258825905,
          7.593259325932593,
          7.598259825982602,
          7.603260326032604,
          7.608260826082606,
          7.613261326132616,
          7.618261826182618,
          7.623262326232627,
          7.628262826282629,
          7.6332633263326315,
          7.638263826382641,
          7.643264326432643,
          7.648264826482652,
          7.6532653265326545,
          7.658265826582657,
          7.663266326632666,
          7.668266826682668,
          7.673267326732677,
          7.67826782678268,
          7.683268326832682,
          7.688268826882691,
          7.693269326932693,
          7.698269826982703,
          7.703270327032705,
          7.708270827082707,
          7.713271327132716,
          7.718271827182718,
          7.723272327232728,
          7.72827282728273,
          7.733273327332732,
          7.738273827382741,
          7.743274327432744,
          7.748274827482753,
          7.753275327532755,
          7.758275827582757,
          7.7632763276327665,
          7.768276827682769,
          7.773277327732778,
          7.77827782778278,
          7.783278327832782,
          7.788278827882792,
          7.793279327932794,
          7.798279827982803,
          7.803280328032805,
          7.8082808280828075,
          7.813281328132817,
          7.818281828182819,
          7.823282328232828,
          7.8282828282828305,
          7.833283328332833,
          7.838283828382842,
          7.843284328432844,
          7.848284828482846,
          7.853285328532856,
          7.858285828582858,
          7.863286328632867,
          7.868286828682869,
          7.8732873287328715,
          7.878287828782881,
          7.883288328832883,
          7.888288828882892,
          7.8932893289328945,
          7.898289828982897,
          7.903290329032906,
          7.908290829082908,
          7.913291329132917,
          7.91829182918292,
          7.923292329232922,
          7.928292829282931,
          7.933293329332933,
          7.938293829382943,
          7.943294329432945,
          7.948294829482947,
          7.953295329532956,
          7.9582958295829584,
          7.963296329632968,
          7.96829682968297,
          7.973297329732972,
          7.978297829782981,
          7.983298329832984,
          7.988298829882993,
          7.993299329932995,
          7.998299829982997,
          8.003300330033007,
          8.008300830083009,
          8.013301330133018,
          8.01830183018302,
          8.023302330233022,
          8.028302830283032,
          8.033303330333034,
          8.038303830383043,
          8.043304330433045,
          8.048304830483048,
          8.053305330533057,
          8.058305830583059,
          8.063306330633068,
          8.06830683068307,
          8.073307330733073,
          8.078307830783082,
          8.083308330833084,
          8.088308830883086,
          8.093309330933096,
          8.098309830983098,
          8.103310331033107,
          8.10831083108311,
          8.113311331133112,
          8.11831183118312,
          8.123312331233123,
          8.128312831283132,
          8.133313331333134,
          8.138313831383137,
          8.143314331433146,
          8.148314831483148,
          8.153315331533157,
          8.15831583158316,
          8.163316331633162,
          8.168316831683171,
          8.173317331733173,
          8.178317831783183,
          8.183318331833185,
          8.188318831883187,
          8.193319331933196,
          8.198319831983198,
          8.203320332033208,
          8.20832083208321,
          8.213321332133212,
          8.218321832183221,
          8.223322332233224,
          8.228322832283233,
          8.233323332333235,
          8.238323832383237,
          8.243324332433247,
          8.248324832483249,
          8.253325332533258,
          8.25832583258326,
          8.263326332633262,
          8.268326832683272,
          8.273327332733274,
          8.278327832783283,
          8.283328332833285,
          8.288328832883288,
          8.293329332933297,
          8.298329832983299,
          8.303330333033308,
          8.30833083308331,
          8.313331333133313,
          8.318331833183322,
          8.323332333233324,
          8.328332833283334,
          8.333333333333336,
          8.338333833383338,
          8.343334333433347,
          8.34833483348335,
          8.353335333533352,
          8.35833583358336,
          8.363336333633363,
          8.368336833683372,
          8.373337333733375,
          8.378337833783377,
          8.383338333833386,
          8.388338833883388,
          8.393339333933397,
          8.3983398339834,
          8.403340334033402,
          8.408340834083411,
          8.413341334133413,
          8.418341834183423,
          8.423342334233425,
          8.428342834283427,
          8.433343334333436,
          8.438343834383438,
          8.443344334433448,
          8.44834483448345,
          8.453345334533452,
          8.458345834583461,
          8.463346334633464,
          8.468346834683473,
          8.473347334733475,
          8.478347834783477,
          8.483348334833487,
          8.488348834883489,
          8.493349334933498,
          8.4983498349835,
          8.503350335033502,
          8.508350835083512,
          8.513351335133514,
          8.518351835183523,
          8.523352335233525,
          8.528352835283528,
          8.533353335333537,
          8.538353835383539,
          8.543354335433548,
          8.54835483548355,
          8.553355335533553,
          8.558355835583562,
          8.563356335633564,
          8.568356835683574,
          8.573357335733576,
          8.578357835783578,
          8.583358335833587,
          8.58835883588359,
          8.593359335933592,
          8.5983598359836,
          8.603360336033603,
          8.608360836083612,
          8.613361336133615,
          8.618361836183617,
          8.623362336233626,
          8.628362836283628,
          8.633363336333638,
          8.63836383638364,
          8.643364336433642,
          8.648364836483651,
          8.653365336533653,
          8.658365836583663,
          8.663366336633665,
          8.668366836683667,
          8.673367336733676,
          8.678367836783679,
          8.683368336833688,
          8.68836883688369,
          8.693369336933692,
          8.698369836983701,
          8.703370337033704,
          8.708370837083713,
          8.713371337133715,
          8.718371837183717,
          8.723372337233727,
          8.728372837283729,
          8.733373337333738,
          8.73837383738374,
          8.743374337433742,
          8.748374837483752,
          8.753375337533754,
          8.758375837583763,
          8.763376337633765,
          8.768376837683768,
          8.773377337733777,
          8.77837783778378,
          8.783378337833788,
          8.78837883788379,
          8.793379337933793,
          8.798379837983802,
          8.803380338033804,
          8.808380838083814,
          8.813381338133816,
          8.818381838183818,
          8.823382338233827,
          8.82838283828383,
          8.833383338333832,
          8.838383838383841,
          8.843384338433843,
          8.848384838483852,
          8.853385338533855,
          8.858385838583857,
          8.863386338633866,
          8.868386838683868,
          8.873387338733878,
          8.87838783878388,
          8.883388338833882,
          8.888388838883891,
          8.893389338933893,
          8.898389838983903,
          8.903390339033905,
          8.908390839083907,
          8.913391339133916,
          8.918391839183919,
          8.923392339233928,
          8.92839283928393,
          8.933393339333932,
          8.938393839383941,
          8.943394339433944,
          8.948394839483953,
          8.953395339533955,
          8.958395839583957,
          8.963396339633967,
          8.968396839683969,
          8.973397339733978,
          8.97839783978398,
          8.983398339833983,
          8.988398839883992,
          8.993399339933994,
          8.998399839984003,
          9.003400340034005,
          9.008400840084008,
          9.013401340134017,
          9.01840184018402,
          9.023402340234028,
          9.02840284028403,
          9.033403340334033,
          9.038403840384042,
          9.043404340434044,
          9.048404840484054,
          9.053405340534056,
          9.058405840584058,
          9.063406340634067,
          9.06840684068407,
          9.073407340734072,
          9.078407840784081,
          9.083408340834083,
          9.088408840884092,
          9.093409340934095,
          9.098409840984097,
          9.103410341034106,
          9.108410841084108,
          9.113411341134118,
          9.11841184118412,
          9.123412341234122,
          9.128412841284131,
          9.133413341334133,
          9.138413841384143,
          9.143414341434145,
          9.148414841484147,
          9.153415341534156,
          9.158415841584159,
          9.163416341634168,
          9.16841684168417,
          9.173417341734172,
          9.178417841784182,
          9.183418341834184,
          9.188418841884193,
          9.193419341934195,
          9.198419841984197,
          9.203420342034207,
          9.208420842084209,
          9.213421342134218,
          9.21842184218422,
          9.223422342234223,
          9.228422842284232,
          9.233423342334234,
          9.238423842384243,
          9.243424342434245,
          9.248424842484248,
          9.253425342534257,
          9.25842584258426,
          9.263426342634268,
          9.26842684268427,
          9.273427342734273,
          9.278427842784282,
          9.283428342834284,
          9.288428842884294,
          9.293429342934296,
          9.298429842984298,
          9.303430343034307,
          9.30843084308431,
          9.313431343134312,
          9.318431843184321,
          9.323432343234323,
          9.328432843284332,
          9.333433343334335,
          9.338433843384337,
          9.343434343434346,
          9.348434843484348,
          9.353435343534358,
          9.35843584358436,
          9.363436343634362,
          9.368436843684371,
          9.373437343734373,
          9.378437843784383,
          9.383438343834385,
          9.388438843884387,
          9.393439343934396,
          9.398439843984399,
          9.403440344034408,
          9.40844084408441,
          9.413441344134412,
          9.418441844184422,
          9.423442344234424,
          9.428442844284433,
          9.433443344334435,
          9.438443844384437,
          9.443444344434447,
          9.448444844484449,
          9.453445344534458,
          9.45844584458446,
          9.463446344634463,
          9.468446844684472,
          9.473447344734474,
          9.478447844784483,
          9.483448344834486,
          9.488448844884488,
          9.493449344934497,
          9.4984498449845,
          9.503450345034508,
          9.50845084508451,
          9.513451345134513,
          9.518451845184522,
          9.523452345234524,
          9.528452845284534,
          9.533453345334536,
          9.538453845384538,
          9.543454345434547,
          9.54845484548455,
          9.553455345534552,
          9.558455845584561,
          9.563456345634563,
          9.568456845684572,
          9.573457345734575,
          9.578457845784577,
          9.583458345834586,
          9.588458845884588,
          9.593459345934598,
          9.5984598459846,
          9.603460346034602,
          9.608460846084611,
          9.613461346134613,
          9.618461846184623,
          9.623462346234625,
          9.628462846284627,
          9.633463346334636,
          9.638463846384639,
          9.643464346434648,
          9.64846484648465,
          9.653465346534652,
          9.658465846584662,
          9.663466346634664,
          9.668466846684673,
          9.673467346734675,
          9.678467846784677,
          9.683468346834687,
          9.688468846884689,
          9.693469346934698,
          9.6984698469847,
          9.703470347034703,
          9.708470847084712,
          9.713471347134714,
          9.718471847184723,
          9.723472347234726,
          9.728472847284728,
          9.733473347334737,
          9.73847384738474,
          9.743474347434748,
          9.74847484748475,
          9.753475347534753,
          9.758475847584762,
          9.763476347634764,
          9.768476847684774,
          9.773477347734776,
          9.778477847784778,
          9.783478347834787,
          9.78847884788479,
          9.793479347934792,
          9.798479847984801,
          9.803480348034803,
          9.808480848084812,
          9.813481348134815,
          9.818481848184817,
          9.823482348234826,
          9.828482848284828,
          9.833483348334838,
          9.83848384838484,
          9.843484348434842,
          9.848484848484851,
          9.853485348534853,
          9.858485848584863,
          9.863486348634865,
          9.868486848684867,
          9.873487348734876,
          9.878487848784879,
          9.883488348834888,
          9.88848884888489,
          9.893489348934892,
          9.898489848984902,
          9.903490349034904,
          9.908490849084913,
          9.913491349134915,
          9.918491849184917,
          9.923492349234927,
          9.928492849284929,
          9.933493349334938,
          9.93849384938494,
          9.943494349434943,
          9.948494849484952,
          9.953495349534954,
          9.958495849584963,
          9.963496349634966,
          9.968496849684968,
          9.973497349734977,
          9.97849784978498,
          9.983498349834989,
          9.98849884988499,
          9.993499349934993,
          9.998499849985002,
          10.003500350035004,
          10.008500850085014,
          10.013501350135016,
          10.018501850185018,
          10.023502350235027,
          10.02850285028503,
          10.033503350335032,
          10.038503850385041,
          10.043504350435043,
          10.048504850485052,
          10.053505350535055,
          10.058505850585057,
          10.063506350635066,
          10.068506850685068,
          10.073507350735078,
          10.07850785078508,
          10.083508350835082,
          10.088508850885091,
          10.093509350935093,
          10.098509850985103,
          10.103510351035105,
          10.108510851085107,
          10.113511351135116,
          10.118511851185119,
          10.123512351235128,
          10.12851285128513,
          10.133513351335132,
          10.138513851385142,
          10.143514351435144,
          10.148514851485153,
          10.153515351535155,
          10.158515851585157,
          10.163516351635167,
          10.168516851685169,
          10.173517351735178,
          10.17851785178518,
          10.183518351835183,
          10.188518851885192,
          10.193519351935194,
          10.198519851985203,
          10.203520352035206,
          10.208520852085208,
          10.213521352135217,
          10.21852185218522,
          10.223522352235229,
          10.22852285228523,
          10.233523352335233,
          10.238523852385242,
          10.243524352435244,
          10.248524852485254,
          10.253525352535256,
          10.258525852585258,
          10.263526352635267,
          10.26852685268527,
          10.273527352735272,
          10.278527852785281,
          10.283528352835283,
          10.288528852885293,
          10.293529352935295,
          10.298529852985297,
          10.303530353035306,
          10.308530853085308,
          10.313531353135318,
          10.31853185318532,
          10.323532353235322,
          10.328532853285331,
          10.333533353335334,
          10.338533853385343,
          10.343534353435345,
          10.348534853485347,
          10.353535353535356,
          10.358535853585359,
          10.363536353635368,
          10.36853685368537,
          10.373537353735372,
          10.378537853785382,
          10.383538353835384,
          10.388538853885393,
          10.393539353935395,
          10.398539853985397,
          10.403540354035407,
          10.408540854085409,
          10.413541354135418,
          10.41854185418542,
          10.423542354235423,
          10.428542854285432,
          10.433543354335434,
          10.438543854385443,
          10.443544354435446,
          10.448544854485448,
          10.453545354535457,
          10.45854585458546,
          10.463546354635469,
          10.46854685468547,
          10.473547354735473,
          10.478547854785482,
          10.483548354835484,
          10.488548854885494,
          10.493549354935496,
          10.498549854985498,
          10.503550355035507,
          10.50855085508551,
          10.513551355135512,
          10.518551855185521,
          10.523552355235523,
          10.528552855285533,
          10.533553355335535,
          10.538553855385537,
          10.543554355435546,
          10.548554855485548,
          10.553555355535558,
          10.55855585558556,
          10.563556355635562,
          10.568556855685571,
          10.573557355735574,
          10.578557855785583,
          10.583558355835585,
          10.588558855885587,
          10.593559355935596,
          10.598559855985599,
          10.603560356035608,
          10.60856085608561,
          10.613561356135612,
          10.618561856185622,
          10.623562356235624,
          10.628562856285633,
          10.633563356335635,
          10.638563856385638,
          10.643564356435647,
          10.648564856485649,
          10.653565356535658,
          10.65856585658566,
          10.663566356635663,
          10.668566856685672,
          10.673567356735674,
          10.678567856785683,
          10.683568356835686,
          10.688568856885688,
          10.693569356935697,
          10.6985698569857,
          10.703570357035709,
          10.70857085708571,
          10.713571357135713,
          10.718571857185722,
          10.723572357235724,
          10.728572857285734,
          10.733573357335736,
          10.738573857385738,
          10.743574357435747,
          10.74857485748575,
          10.753575357535752,
          10.758575857585761,
          10.763576357635763,
          10.768576857685773,
          10.773577357735775,
          10.778577857785777,
          10.783578357835786,
          10.788578857885788,
          10.793579357935798,
          10.7985798579858,
          10.803580358035802,
          10.808580858085811,
          10.813581358135814,
          10.818581858185823,
          10.823582358235825,
          10.828582858285827,
          10.833583358335837,
          10.838583858385839,
          10.843584358435848,
          10.84858485848585,
          10.853585358535852,
          10.858585858585862,
          10.863586358635864,
          10.868586858685873,
          10.873587358735875,
          10.878587858785878,
          10.883588358835887,
          10.888588858885889,
          10.893589358935898,
          10.8985898589859,
          10.903590359035903,
          10.908590859085912,
          10.913591359135914,
          10.918591859185923,
          10.923592359235926,
          10.928592859285928,
          10.933593359335937,
          10.93859385938594,
          10.943594359435949,
          10.94859485948595,
          10.953595359535953,
          10.958595859585962,
          10.963596359635964,
          10.968596859685974,
          10.973597359735976,
          10.978597859785978,
          10.983598359835987,
          10.98859885988599,
          10.993599359935999,
          10.998599859986001,
          11.003600360036003,
          11.008600860086013,
          11.013601360136015,
          11.018601860186017,
          11.023602360236026,
          11.028602860286028,
          11.033603360336038,
          11.03860386038604,
          11.043604360436042,
          11.048604860486051,
          11.053605360536054,
          11.058605860586063,
          11.063606360636065,
          11.068606860686067,
          11.073607360736077,
          11.078607860786079,
          11.083608360836088,
          11.08860886088609,
          11.093609360936092,
          11.098609860986102,
          11.103610361036104,
          11.108610861086113,
          11.113611361136115,
          11.118611861186118,
          11.123612361236127,
          11.128612861286129,
          11.133613361336138,
          11.13861386138614,
          11.143614361436143,
          11.148614861486152,
          11.153615361536154,
          11.158615861586163,
          11.163616361636166,
          11.168616861686168,
          11.173617361736177,
          11.17861786178618,
          11.183618361836189,
          11.18861886188619,
          11.193619361936193,
          11.198619861986202,
          11.203620362036204,
          11.208620862086214,
          11.213621362136216,
          11.218621862186218,
          11.223622362236227,
          11.22862286228623,
          11.233623362336239,
          11.238623862386241,
          11.243624362436243,
          11.248624862486253,
          11.253625362536255,
          11.258625862586257,
          11.263626362636266,
          11.268626862686268,
          11.273627362736278,
          11.27862786278628,
          11.283628362836282,
          11.288628862886291,
          11.293629362936294,
          11.298629862986303,
          11.303630363036305,
          11.308630863086307,
          11.313631363136317,
          11.318631863186319,
          11.323632363236328,
          11.32863286328633,
          11.333633363336332,
          11.338633863386342,
          11.343634363436344,
          11.348634863486353,
          11.353635363536355,
          11.358635863586358,
          11.363636363636367,
          11.368636863686369,
          11.373637363736378,
          11.37863786378638,
          11.383638363836383,
          11.388638863886392,
          11.393639363936394,
          11.398639863986403,
          11.403640364036406,
          11.408640864086408,
          11.413641364136417,
          11.41864186418642,
          11.423642364236429,
          11.42864286428643,
          11.433643364336433,
          11.438643864386442,
          11.443644364436445,
          11.448644864486454,
          11.453645364536456,
          11.458645864586458,
          11.463646364636467,
          11.46864686468647,
          11.473647364736479,
          11.478647864786481,
          11.483648364836483,
          11.488648864886493,
          11.493649364936495,
          11.498649864986497,
          11.503650365036506,
          11.508650865086508,
          11.513651365136518,
          11.51865186518652,
          11.523652365236522,
          11.528652865286531,
          11.533653365336534,
          11.538653865386543,
          11.543654365436545,
          11.548654865486547,
          11.553655365536557,
          11.558655865586559,
          11.563656365636568,
          11.56865686568657,
          11.573657365736572,
          11.578657865786582,
          11.583658365836584,
          11.588658865886593,
          11.593659365936595,
          11.598659865986598,
          11.603660366036607,
          11.608660866086609,
          11.613661366136618,
          11.61866186618662,
          11.623662366236623,
          11.628662866286632,
          11.633663366336634,
          11.638663866386644,
          11.643664366436646,
          11.648664866486648,
          11.653665366536657,
          11.65866586658666,
          11.663666366636669,
          11.66866686668667,
          11.673667366736673,
          11.678667866786682,
          11.683668366836685,
          11.688668866886694,
          11.693669366936696,
          11.698669866986698,
          11.703670367036707,
          11.70867086708671,
          11.713671367136719,
          11.718671867186721,
          11.723672367236723,
          11.728672867286733,
          11.733673367336735,
          11.738673867386737,
          11.743674367436746,
          11.748674867486748,
          11.753675367536758,
          11.75867586758676,
          11.763676367636762,
          11.768676867686771,
          11.773677367736774,
          11.778677867786783,
          11.783678367836785,
          11.788678867886787,
          11.793679367936797,
          11.798679867986799,
          11.803680368036808,
          11.80868086808681,
          11.813681368136812,
          11.818681868186822,
          11.823682368236824,
          11.828682868286833,
          11.833683368336835,
          11.838683868386838,
          11.843684368436847,
          11.848684868486849,
          11.853685368536858,
          11.85868586858686,
          11.863686368636863,
          11.868686868686872,
          11.873687368736874,
          11.878687868786884,
          11.883688368836886,
          11.888688868886888,
          11.893689368936897,
          11.8986898689869,
          11.903690369036909,
          11.90869086908691,
          11.913691369136913,
          11.918691869186922,
          11.923692369236925,
          11.928692869286934,
          11.933693369336936,
          11.938693869386938,
          11.943694369436948,
          11.94869486948695,
          11.953695369536959,
          11.958695869586961,
          11.963696369636963,
          11.968696869686973,
          11.973697369736975,
          11.978697869786977,
          11.983698369836986,
          11.988698869886989,
          11.993699369936998,
          11.998699869987,
          12.003700370037002,
          12.008700870087011,
          12.013701370137014,
          12.018701870187023,
          12.023702370237025,
          12.028702870287027,
          12.033703370337037,
          12.038703870387039,
          12.043704370437048,
          12.04870487048705,
          12.053705370537052,
          12.058705870587062,
          12.063706370637064,
          12.068706870687073,
          12.073707370737075,
          12.078707870787078,
          12.083708370837087,
          12.08870887088709,
          12.093709370937098,
          12.0987098709871,
          12.103710371037103,
          12.108710871087112,
          12.113711371137114,
          12.118711871187124,
          12.123712371237126,
          12.128712871287128,
          12.133713371337137,
          12.13871387138714,
          12.143714371437149,
          12.148714871487151,
          12.153715371537153,
          12.158715871587162,
          12.163716371637165,
          12.168716871687174,
          12.173717371737176,
          12.178717871787178,
          12.183718371837188,
          12.18871887188719,
          12.193719371937199,
          12.198719871987201,
          12.203720372037203,
          12.208720872087213,
          12.213721372137215,
          12.218721872187217,
          12.223722372237226,
          12.228722872287229,
          12.233723372337238,
          12.23872387238724,
          12.243724372437242,
          12.248724872487252,
          12.253725372537254,
          12.258725872587263,
          12.263726372637265,
          12.268726872687267,
          12.273727372737277,
          12.278727872787279,
          12.283728372837288,
          12.28872887288729,
          12.293729372937293,
          12.298729872987302,
          12.303730373037304,
          12.308730873087313,
          12.313731373137315,
          12.318731873187318,
          12.323732373237327,
          12.32873287328733,
          12.333733373337338,
          12.33873387338734,
          12.343734373437343,
          12.348734873487352,
          12.353735373537354,
          12.358735873587364,
          12.363736373637366,
          12.368736873687368,
          12.373737373737377,
          12.37873787378738,
          12.383738373837389,
          12.388738873887391,
          12.393739373937393,
          12.398739873987402,
          12.403740374037405,
          12.408740874087414,
          12.413741374137416,
          12.418741874187418,
          12.423742374237428,
          12.42874287428743,
          12.433743374337439,
          12.438743874387441,
          12.443744374437443,
          12.448744874487453,
          12.453745374537455,
          12.458745874587457,
          12.463746374637466,
          12.468746874687469,
          12.473747374737478,
          12.47874787478748,
          12.483748374837482,
          12.488748874887492,
          12.493749374937494,
          12.498749874987503,
          12.503750375037505,
          12.508750875087507,
          12.513751375137517,
          12.518751875187519,
          12.523752375237528,
          12.52875287528753,
          12.533753375337533,
          12.538753875387542,
          12.543754375437544,
          12.548754875487553,
          12.553755375537555,
          12.558755875587558,
          12.563756375637567,
          12.56875687568757,
          12.573757375737578,
          12.57875787578758,
          12.583758375837583,
          12.588758875887592,
          12.593759375937594,
          12.598759875987604,
          12.603760376037606,
          12.608760876087608,
          12.613761376137617,
          12.61876187618762,
          12.623762376237629,
          12.628762876287631,
          12.633763376337633,
          12.638763876387642,
          12.643764376437645,
          12.648764876487654,
          12.653765376537656,
          12.658765876587658,
          12.663766376637668,
          12.66876687668767,
          12.673767376737679,
          12.678767876787681,
          12.683768376837683,
          12.688768876887693,
          12.693769376937695,
          12.698769876987697,
          12.703770377037706,
          12.708770877087709,
          12.713771377137718,
          12.71877187718772,
          12.723772377237722,
          12.728772877287732,
          12.733773377337734,
          12.738773877387743,
          12.743774377437745,
          12.748774877487747,
          12.753775377537757,
          12.758775877587759,
          12.763776377637768,
          12.76877687768777,
          12.773777377737773,
          12.778777877787782,
          12.783778377837784,
          12.788778877887793,
          12.793779377937796,
          12.798779877987798,
          12.803780378037807,
          12.80878087808781,
          12.813781378137818,
          12.81878187818782,
          12.823782378237823,
          12.828782878287832,
          12.833783378337834,
          12.838783878387844,
          12.843784378437846,
          12.848784878487848,
          12.853785378537857,
          12.85878587858786,
          12.863786378637869,
          12.868786878687871,
          12.873787378737873,
          12.878787878787882,
          12.883788378837885,
          12.888788878887894,
          12.893789378937896,
          12.898789878987898,
          12.903790379037908,
          12.90879087908791,
          12.913791379137919,
          12.918791879187921,
          12.923792379237923,
          12.928792879287933,
          12.933793379337935,
          12.938793879387937,
          12.943794379437946,
          12.948794879487949,
          12.953795379537958,
          12.95879587958796,
          12.963796379637962,
          12.968796879687972,
          12.973797379737974,
          12.978797879787983,
          12.983798379837985,
          12.988798879887987,
          12.993799379937997,
          12.998799879987999,
          13.003800380038008,
          13.00880088008801,
          13.013801380138013,
          13.018801880188022,
          13.023802380238024,
          13.028802880288033,
          13.033803380338036,
          13.038803880388038,
          13.043804380438047,
          13.04880488048805,
          13.053805380538059,
          13.05880588058806,
          13.063806380638063,
          13.068806880688072,
          13.073807380738074,
          13.078807880788084,
          13.083808380838086,
          13.088808880888088,
          13.093809380938097,
          13.0988098809881,
          13.103810381038109,
          13.108810881088111,
          13.113811381138113,
          13.118811881188122,
          13.123812381238125,
          13.128812881288134,
          13.133813381338136,
          13.138813881388138,
          13.143814381438148,
          13.14881488148815,
          13.153815381538159,
          13.158815881588161,
          13.163816381638163,
          13.168816881688173,
          13.173817381738175,
          13.178817881788177,
          13.183818381838186,
          13.188818881888189,
          13.193819381938198,
          13.1988198819882,
          13.203820382038202,
          13.208820882088212,
          13.213821382138214,
          13.218821882188223,
          13.223822382238225,
          13.228822882288227,
          13.233823382338237,
          13.238823882388239,
          13.243824382438248,
          13.24882488248825,
          13.253825382538253,
          13.258825882588262,
          13.263826382638264,
          13.268826882688273,
          13.273827382738276,
          13.278827882788278,
          13.283828382838287,
          13.28882888288829,
          13.293829382938299,
          13.2988298829883,
          13.303830383038303,
          13.308830883088312,
          13.313831383138314,
          13.318831883188324,
          13.323832383238326,
          13.328832883288328,
          13.333833383338337,
          13.33883388338834,
          13.343834383438349,
          13.348834883488351,
          13.353835383538353,
          13.358835883588362,
          13.363836383638365,
          13.368836883688374,
          13.373837383738376,
          13.378837883788378,
          13.383838383838388,
          13.38883888388839,
          13.3938393839384,
          13.398839883988401,
          13.403840384038403,
          13.408840884088413,
          13.413841384138415,
          13.418841884188424,
          13.423842384238426,
          13.428842884288429,
          13.433843384338438,
          13.43884388438844,
          13.443844384438442,
          13.448844884488452,
          13.453845384538454,
          13.458845884588463,
          13.463846384638465,
          13.468846884688467,
          13.473847384738477,
          13.478847884788479,
          13.483848384838488,
          13.48884888488849,
          13.493849384938493,
          13.498849884988502,
          13.503850385038504,
          13.508850885088513,
          13.513851385138516,
          13.518851885188518,
          13.523852385238527,
          13.52885288528853,
          13.533853385338539,
          13.53885388538854,
          13.543854385438543,
          13.548854885488552,
          13.553855385538554,
          13.558855885588564,
          13.563856385638566,
          13.568856885688568,
          13.573857385738577,
          13.57885788578858,
          13.583858385838589,
          13.588858885888591,
          13.593859385938593,
          13.598859885988603,
          13.603860386038605,
          13.608860886088614,
          13.613861386138616,
          13.618861886188618,
          13.623862386238628,
          13.62886288628863,
          13.63386338633864,
          13.638863886388641,
          13.643864386438644,
          13.648864886488653,
          13.653865386538655,
          13.658865886588664,
          13.663866386638666,
          13.668866886688669,
          13.673867386738678,
          13.67886788678868,
          13.683868386838682,
          13.688868886888692,
          13.693869386938694,
          13.698869886988703,
          13.703870387038705,
          13.708870887088707,
          13.713871387138717,
          13.718871887188719,
          13.723872387238728,
          13.72887288728873,
          13.733873387338733,
          13.738873887388742,
          13.743874387438744,
          13.748874887488753,
          13.753875387538756,
          13.758875887588758,
          13.763876387638767,
          13.76887688768877,
          13.773877387738779,
          13.77887788778878,
          13.783878387838783,
          13.788878887888792,
          13.793879387938794,
          13.798879887988804,
          13.803880388038806,
          13.808880888088808,
          13.813881388138817,
          13.81888188818882,
          13.823882388238829,
          13.828882888288831,
          13.833883388338833,
          13.838883888388843,
          13.843884388438845,
          13.848884888488854,
          13.853885388538856,
          13.858885888588858,
          13.863886388638868,
          13.86888688868887,
          13.87388738873888,
          13.878887888788881,
          13.883888388838884,
          13.888888888888893,
          13.893889388938895,
          13.898889888988904,
          13.903890389038907,
          13.908890889088909,
          13.913891389138918,
          13.91889188918892,
          13.923892389238922,
          13.928892889288932,
          13.933893389338934,
          13.938893889388943,
          13.943894389438945,
          13.948894889488948,
          13.953895389538957,
          13.958895889588959,
          13.963896389638968,
          13.96889688968897,
          13.973897389738973,
          13.978897889788982,
          13.983898389838984,
          13.988898889888993,
          13.993899389938996,
          13.998899889988998,
          14.003900390039007,
          14.00890089008901,
          14.013901390139019,
          14.01890189018902,
          14.023902390239023,
          14.028902890289032,
          14.033903390339034,
          14.038903890389044,
          14.043904390439046,
          14.048904890489048,
          14.053905390539057,
          14.05890589058906,
          14.063906390639069,
          14.068906890689071,
          14.073907390739073,
          14.078907890789083,
          14.083908390839085,
          14.088908890889094,
          14.093909390939096,
          14.098909890989098,
          14.103910391039108,
          14.10891089108911,
          14.11391139113912,
          14.118911891189121,
          14.123912391239124,
          14.128912891289133,
          14.133913391339135,
          14.138913891389144,
          14.143914391439147,
          14.148914891489149,
          14.153915391539158,
          14.15891589158916,
          14.163916391639162,
          14.168916891689172,
          14.173917391739174,
          14.178917891789183,
          14.183918391839185,
          14.188918891889188,
          14.193919391939197,
          14.198919891989199,
          14.203920392039208,
          14.20892089208921,
          14.213921392139213,
          14.218921892189222,
          14.223922392239224,
          14.228922892289233,
          14.233923392339236,
          14.238923892389238,
          14.243924392439247,
          14.24892489248925,
          14.253925392539259,
          14.25892589258926,
          14.263926392639263,
          14.268926892689272,
          14.273927392739274,
          14.278927892789284,
          14.283928392839286,
          14.288928892889288,
          14.293929392939297,
          14.2989298929893,
          14.303930393039309,
          14.308930893089311,
          14.313931393139313,
          14.318931893189323,
          14.323932393239325,
          14.328932893289334,
          14.333933393339336,
          14.338933893389338,
          14.343934393439348,
          14.34893489348935,
          14.35393539353936,
          14.358935893589361,
          14.363936393639364,
          14.368936893689373,
          14.373937393739375,
          14.378937893789384,
          14.383938393839387,
          14.388938893889389,
          14.393939393939398,
          14.3989398939894,
          14.403940394039402,
          14.408940894089412,
          14.413941394139414,
          14.418941894189423,
          14.423942394239425,
          14.428942894289428,
          14.433943394339437,
          14.438943894389439,
          14.443944394439448,
          14.44894489448945,
          14.453945394539453,
          14.458945894589462,
          14.463946394639464,
          14.468946894689473,
          14.473947394739476,
          14.478947894789478,
          14.483948394839487,
          14.48894889488949,
          14.493949394939499,
          14.4989498949895,
          14.503950395039503,
          14.508950895089512,
          14.513951395139514,
          14.518951895189524,
          14.523952395239526,
          14.528952895289528,
          14.533953395339537,
          14.53895389538954,
          14.543954395439549,
          14.548954895489551,
          14.553955395539553,
          14.558955895589563,
          14.563956395639565,
          14.568956895689574,
          14.573957395739576,
          14.578957895789578,
          14.583958395839588,
          14.58895889588959,
          14.5939593959396,
          14.598959895989601,
          14.603960396039604,
          14.608960896089613,
          14.613961396139615,
          14.618961896189624,
          14.623962396239627,
          14.628962896289629,
          14.633963396339638,
          14.63896389638964,
          14.643964396439642,
          14.648964896489652,
          14.653965396539654,
          14.658965896589663,
          14.663966396639665,
          14.668966896689668,
          14.673967396739677,
          14.678967896789679,
          14.683968396839688,
          14.68896889688969,
          14.693969396939693,
          14.698969896989702,
          14.703970397039704,
          14.708970897089714,
          14.713971397139716,
          14.718971897189718,
          14.723972397239727,
          14.72897289728973,
          14.733973397339739,
          14.73897389738974,
          14.743974397439743,
          14.748974897489752,
          14.753975397539755,
          14.758975897589764,
          14.763976397639766,
          14.768976897689768,
          14.773977397739777,
          14.77897789778978,
          14.783978397839789,
          14.788978897889791,
          14.793979397939793,
          14.798979897989803,
          14.803980398039805,
          14.808980898089814,
          14.813981398139816,
          14.818981898189818,
          14.823982398239828,
          14.82898289828983,
          14.83398339833984,
          14.838983898389841,
          14.843984398439844,
          14.848984898489853,
          14.853985398539855,
          14.858985898589864,
          14.863986398639867,
          14.868986898689869,
          14.873987398739878,
          14.87898789878988,
          14.883988398839882,
          14.888988898889892,
          14.893989398939894,
          14.898989898989903,
          14.903990399039905,
          14.908990899089908,
          14.913991399139917,
          14.918991899189919,
          14.923992399239928,
          14.92899289928993,
          14.933993399339933,
          14.938993899389942,
          14.943994399439944,
          14.948994899489954,
          14.953995399539956,
          14.958995899589958,
          14.963996399639967,
          14.96899689968997,
          14.973997399739979,
          14.97899789978998,
          14.983998399839983,
          14.988998899889992,
          14.993999399939995,
          14.998999899990004,
          15.004000400040006,
          15.009000900090008,
          15.014001400140017,
          15.01900190019002,
          15.024002400240029,
          15.029002900290031,
          15.034003400340033,
          15.039003900390043,
          15.044004400440045,
          15.049004900490054,
          15.054005400540056,
          15.059005900590059,
          15.064006400640068,
          15.06900690069007,
          15.07400740074008,
          15.079007900790081,
          15.084008400840084,
          15.089008900890093,
          15.094009400940095,
          15.099009900990104,
          15.104010401040107,
          15.109010901090109,
          15.114011401140118,
          15.11901190119012,
          15.124012401240122,
          15.129012901290132,
          15.134013401340134,
          15.139013901390143,
          15.144014401440145,
          15.149014901490148,
          15.154015401540157,
          15.159015901590159,
          15.164016401640168,
          15.16901690169017,
          15.174017401740173,
          15.179017901790182,
          15.184018401840184,
          15.189018901890194,
          15.194019401940196,
          15.199019901990198,
          15.204020402040207,
          15.20902090209021,
          15.214021402140219,
          15.21902190219022,
          15.224022402240223,
          15.229022902290232,
          15.234023402340235,
          15.239023902390244,
          15.244024402440246,
          15.249024902490248,
          15.254025402540258,
          15.25902590259026,
          15.264026402640269,
          15.269026902690271,
          15.274027402740273,
          15.279027902790283,
          15.284028402840285,
          15.289028902890294,
          15.294029402940296,
          15.299029902990299,
          15.304030403040308,
          15.30903090309031,
          15.31403140314032,
          15.319031903190321,
          15.324032403240324,
          15.329032903290333,
          15.334033403340335,
          15.339033903390344,
          15.344034403440347,
          15.349034903490349,
          15.354035403540358,
          15.35903590359036,
          15.364036403640362,
          15.369036903690372,
          15.374037403740374,
          15.379037903790383,
          15.384038403840385,
          15.389038903890388,
          15.394039403940397,
          15.3990399039904,
          15.404040404040408,
          15.40904090409041,
          15.414041404140413,
          15.419041904190422,
          15.424042404240424,
          15.429042904290434,
          15.434043404340436,
          15.439043904390438,
          15.444044404440447,
          15.44904490449045,
          15.454045404540459,
          15.459045904590461,
          15.464046404640463,
          15.469046904690472,
          15.474047404740475,
          15.479047904790484,
          15.484048404840486,
          15.489048904890488,
          15.494049404940498,
          15.4990499049905,
          15.504050405040509,
          15.509050905090511,
          15.514051405140513,
          15.519051905190523,
          15.524052405240525,
          15.529052905290534,
          15.534053405340536,
          15.539053905390539,
          15.544054405440548,
          15.54905490549055,
          15.55405540554056,
          15.559055905590562,
          15.564056405640564,
          15.569056905690573,
          15.574057405740575,
          15.579057905790584,
          15.584058405840587,
          15.589058905890589,
          15.594059405940598,
          15.5990599059906,
          15.604060406040603,
          15.609060906090612,
          15.614061406140614,
          15.619061906190623,
          15.624062406240625,
          15.629062906290628,
          15.634063406340637,
          15.63906390639064,
          15.644064406440648,
          15.64906490649065,
          15.654065406540653,
          15.659065906590662,
          15.664066406640664,
          15.669066906690674,
          15.674067406740676,
          15.679067906790678,
          15.684068406840687,
          15.68906890689069,
          15.694069406940699,
          15.699069906990701,
          15.704070407040703,
          15.709070907090712,
          15.714071407140715,
          15.719071907190724,
          15.724072407240726,
          15.729072907290728,
          15.734073407340738,
          15.73907390739074,
          15.744074407440749,
          15.749074907490751,
          15.754075407540753,
          15.759075907590763,
          15.764076407640765,
          15.769076907690774,
          15.774077407740776,
          15.779077907790779,
          15.784078407840788,
          15.78907890789079,
          15.7940794079408,
          15.799079907990802,
          15.804080408040804,
          15.809080908090813,
          15.814081408140815,
          15.819081908190824,
          15.824082408240827,
          15.829082908290829,
          15.834083408340838,
          15.83908390839084,
          15.844084408440843,
          15.849084908490852,
          15.854085408540854,
          15.859085908590863,
          15.864086408640865,
          15.869086908690868,
          15.874087408740877,
          15.87908790879088,
          15.884088408840888,
          15.88908890889089,
          15.894089408940893,
          15.899089908990902,
          15.904090409040904,
          15.909090909090914,
          15.914091409140916,
          15.919091909190918,
          15.924092409240927,
          15.92909290929093,
          15.934093409340939,
          15.939093909390941,
          15.944094409440943,
          15.949094909490952,
          15.954095409540955,
          15.959095909590964,
          15.964096409640966,
          15.969096909690968,
          15.974097409740978,
          15.97909790979098,
          15.984098409840989,
          15.989098909890991,
          15.994099409940993,
          15.999099909991003,
          16.004100410041005,
          16.009100910091014,
          16.014101410141016,
          16.01910191019102,
          16.024102410241028,
          16.02910291029103,
          16.03410341034104,
          16.03910391039104,
          16.044104410441044,
          16.049104910491053,
          16.054105410541055,
          16.059105910591065,
          16.064106410641067,
          16.06910691069107,
          16.074107410741078,
          16.07910791079108,
          16.08410841084109,
          16.089108910891092,
          16.094109410941094,
          16.099109910991103,
          16.104110411041106,
          16.109110911091108,
          16.114111411141117,
          16.11911191119112,
          16.12411241124113,
          16.12911291129113,
          16.134113411341133,
          16.139113911391142,
          16.144114411441144,
          16.149114911491154,
          16.154115411541156,
          16.159115911591158,
          16.164116411641167,
          16.16911691169117,
          16.17411741174118,
          16.17911791179118,
          16.184118411841183,
          16.189118911891192,
          16.194119411941195,
          16.199119911991204,
          16.204120412041206,
          16.20912091209121,
          16.214121412141218,
          16.21912191219122,
          16.22412241224123,
          16.22912291229123,
          16.234123412341233,
          16.239123912391243,
          16.244124412441245,
          16.249124912491254,
          16.254125412541256,
          16.25912591259126,
          16.264126412641268,
          16.26912691269127,
          16.27412741274128,
          16.27912791279128,
          16.284128412841284,
          16.289128912891293,
          16.294129412941295,
          16.299129912991305,
          16.304130413041307,
          16.30913091309131,
          16.314131413141318,
          16.31913191319132,
          16.32413241324133,
          16.329132913291332,
          16.334133413341334,
          16.339133913391343,
          16.344134413441346,
          16.349134913491348,
          16.354135413541357,
          16.35913591359136,
          16.36413641364137,
          16.36913691369137,
          16.374137413741373,
          16.379137913791382,
          16.384138413841384,
          16.389138913891394,
          16.394139413941396,
          16.399139913991398,
          16.404140414041407,
          16.40914091409141,
          16.41414141414142,
          16.41914191419142,
          16.424142414241423,
          16.429142914291432,
          16.434143414341435,
          16.439143914391444,
          16.444144414441446,
          16.44914491449145,
          16.454145414541458,
          16.45914591459146,
          16.46414641464147,
          16.46914691469147,
          16.474147414741473,
          16.479147914791483,
          16.484148414841485,
          16.489148914891494,
          16.494149414941496,
          16.4991499149915,
          16.504150415041508,
          16.50915091509151,
          16.51415141514152,
          16.51915191519152,
          16.524152415241524,
          16.529152915291533,
          16.534153415341535,
          16.539153915391545,
          16.544154415441547,
          16.54915491549155,
          16.55415541554156,
          16.55915591559156,
          16.56415641564157,
          16.569156915691572,
          16.574157415741574,
          16.579157915791583,
          16.584158415841586,
          16.589158915891588,
          16.594159415941597,
          16.5991599159916,
          16.60416041604161,
          16.60916091609161,
          16.614161416141613,
          16.619161916191622,
          16.624162416241624,
          16.629162916291634,
          16.634163416341636,
          16.639163916391638,
          16.644164416441647,
          16.64916491649165,
          16.65416541654166,
          16.65916591659166,
          16.664166416641663,
          16.669166916691672,
          16.674167416741675,
          16.679167916791684,
          16.684168416841686,
          16.68916891689169,
          16.694169416941698,
          16.6991699169917,
          16.70417041704171,
          16.70917091709171,
          16.714171417141714,
          16.719171917191723,
          16.724172417241725,
          16.729172917291734,
          16.734173417341736,
          16.73917391739174,
          16.744174417441748,
          16.74917491749175,
          16.75417541754176,
          16.75917591759176,
          16.764176417641764,
          16.769176917691773,
          16.774177417741775,
          16.779177917791785,
          16.784178417841787,
          16.78917891789179,
          16.7941794179418,
          16.7991799179918,
          16.80418041804181,
          16.809180918091812,
          16.814181418141814,
          16.819181918191823,
          16.824182418241826,
          16.829182918291828,
          16.834183418341837,
          16.83918391839184,
          16.84418441844185,
          16.84918491849185,
          16.854185418541853,
          16.859185918591862,
          16.864186418641864,
          16.869186918691874,
          16.874187418741876,
          16.879187918791878,
          16.884188418841887,
          16.88918891889189,
          16.8941894189419,
          16.8991899189919,
          16.904190419041903,
          16.909190919091913,
          16.914191419141915,
          16.919191919191924,
          16.924192419241926,
          16.92919291929193,
          16.934193419341938,
          16.93919391939194,
          16.94419441944195,
          16.94919491949195,
          16.954195419541954,
          16.959195919591963,
          16.964196419641965,
          16.969196919691974,
          16.974197419741976,
          16.97919791979198,
          16.984198419841988,
          16.98919891989199,
          16.994199419942,
          16.999199919992,
          17.004200420042004,
          17.009200920092013,
          17.014201420142015,
          17.019201920192025,
          17.024202420242027,
          17.02920292029203,
          17.03420342034204,
          17.03920392039204,
          17.04420442044205,
          17.049204920492052,
          17.054205420542054,
          17.059205920592063,
          17.064206420642066,
          17.069206920692068,
          17.074207420742077,
          17.07920792079208,
          17.08420842084209,
          17.08920892089209,
          17.094209420942093,
          17.099209920992102,
          17.104210421042104,
          17.109210921092114,
          17.114211421142116,
          17.119211921192118,
          17.124212421242127,
          17.12921292129213,
          17.13421342134214,
          17.13921392139214,
          17.144214421442143,
          17.149214921492153,
          17.154215421542155,
          17.159215921592164,
          17.164216421642166,
          17.16921692169217,
          17.174217421742178,
          17.17921792179218,
          17.18421842184219,
          17.18921892189219,
          17.194219421942194,
          17.199219921992203,
          17.204220422042205,
          17.209220922092214,
          17.214221422142217,
          17.21922192219222,
          17.224222422242228,
          17.22922292229223,
          17.23422342234224,
          17.23922392239224,
          17.244224422442244,
          17.249224922492253,
          17.254225422542255,
          17.259225922592265,
          17.264226422642267,
          17.26922692269227,
          17.27422742274228,
          17.27922792279228,
          17.28422842284229,
          17.289228922892292,
          17.294229422942294,
          17.299229922992303,
          17.304230423042306,
          17.309230923092308,
          17.314231423142317,
          17.31923192319232,
          17.32423242324233,
          17.32923292329233,
          17.334233423342333,
          17.339233923392342,
          17.344234423442344,
          17.349234923492354,
          17.354235423542356,
          17.359235923592358,
          17.364236423642367,
          17.36923692369237,
          17.37423742374238,
          17.37923792379238,
          17.384238423842383,
          17.389238923892393,
          17.394239423942395,
          17.399239923992404,
          17.404240424042406,
          17.40924092409241,
          17.414241424142418,
          17.41924192419242,
          17.42424242424243,
          17.42924292429243,
          17.434243424342434,
          17.439243924392443,
          17.444244424442445,
          17.449244924492454,
          17.454245424542457,
          17.45924592459246,
          17.464246424642468,
          17.46924692469247,
          17.47424742474248,
          17.47924792479248,
          17.484248424842484,
          17.489248924892493,
          17.494249424942495,
          17.499249924992505,
          17.504250425042507,
          17.50925092509251,
          17.51425142514252,
          17.51925192519252,
          17.52425242524253,
          17.529252925292532,
          17.534253425342534,
          17.539253925392543,
          17.544254425442546,
          17.549254925492548,
          17.554255425542557,
          17.55925592559256,
          17.56425642564257,
          17.56925692569257,
          17.574257425742573,
          17.579257925792582,
          17.584258425842584,
          17.589258925892594,
          17.594259425942596,
          17.599259925992598,
          17.604260426042607,
          17.60926092609261,
          17.61426142614262,
          17.61926192619262,
          17.624262426242623,
          17.629262926292633,
          17.634263426342635,
          17.639263926392644,
          17.644264426442646,
          17.64926492649265,
          17.654265426542658,
          17.65926592659266,
          17.66426642664267,
          17.66926692669267,
          17.674267426742674,
          17.679267926792683,
          17.684268426842685,
          17.689268926892694,
          17.694269426942697,
          17.6992699269927,
          17.704270427042708,
          17.70927092709271,
          17.71427142714272,
          17.71927192719272,
          17.724272427242724,
          17.729272927292733,
          17.734273427342735,
          17.739273927392745,
          17.744274427442747,
          17.74927492749275,
          17.75427542754276,
          17.75927592759276,
          17.76427642764277,
          17.769276927692772,
          17.774277427742774,
          17.779277927792783,
          17.784278427842786,
          17.789278927892788,
          17.794279427942797,
          17.7992799279928,
          17.80428042804281,
          17.80928092809281,
          17.814281428142813,
          17.819281928192822,
          17.824282428242824,
          17.829282928292834,
          17.834283428342836,
          17.839283928392838,
          17.844284428442847,
          17.84928492849285,
          17.85428542854286,
          17.85928592859286,
          17.864286428642863,
          17.869286928692873,
          17.874287428742875,
          17.879287928792884,
          17.884288428842886,
          17.88928892889289,
          17.894289428942898,
          17.8992899289929,
          17.90429042904291,
          17.90929092909291,
          17.914291429142914,
          17.919291929192923,
          17.924292429242925,
          17.929292929292934,
          17.934293429342937,
          17.93929392939294,
          17.944294429442948,
          17.94929492949295,
          17.95429542954296,
          17.95929592959296,
          17.964296429642964,
          17.969296929692973,
          17.974297429742975,
          17.979297929792985,
          17.984298429842987,
          17.98929892989299,
          17.994299429943,
          17.999299929993,
          18.00430043004301,
          18.009300930093012,
          18.014301430143014,
          18.019301930193024,
          18.024302430243026,
          18.029302930293028,
          18.034303430343037,
          18.03930393039304,
          18.04430443044305,
          18.04930493049305,
          18.054305430543053,
          18.059305930593062,
          18.064306430643065,
          18.069306930693074,
          18.074307430743076,
          18.079307930793078,
          18.084308430843087,
          18.08930893089309,
          18.0943094309431,
          18.0993099309931,
          18.104310431043103,
          18.109310931093113,
          18.114311431143115,
          18.119311931193124,
          18.124312431243126,
          18.12931293129313,
          18.134313431343138,
          18.13931393139314,
          18.14431443144315,
          18.14931493149315,
          18.154315431543154,
          18.159315931593163,
          18.164316431643165,
          18.169316931693174,
          18.174317431743177,
          18.17931793179318,
          18.184318431843188,
          18.18931893189319,
          18.1943194319432,
          18.1993199319932,
          18.204320432043204,
          18.209320932093213,
          18.214321432143215,
          18.219321932193225,
          18.224322432243227,
          18.22932293229323,
          18.23432343234324,
          18.23932393239324,
          18.24432443244325,
          18.249324932493252,
          18.254325432543254,
          18.259325932593264,
          18.264326432643266,
          18.269326932693268,
          18.274327432743277,
          18.27932793279328,
          18.28432843284329,
          18.28932893289329,
          18.294329432943293,
          18.299329932993302,
          18.304330433043305,
          18.309330933093314,
          18.314331433143316,
          18.319331933193318,
          18.324332433243328,
          18.32933293329333,
          18.33433343334334,
          18.33933393339334,
          18.344334433443343,
          18.349334933493353,
          18.354335433543355,
          18.359335933593364,
          18.364336433643366,
          18.36933693369337,
          18.374337433743378,
          18.37933793379338,
          18.38433843384339,
          18.38933893389339,
          18.394339433943394,
          18.399339933993403,
          18.404340434043405,
          18.409340934093414,
          18.414341434143417,
          18.41934193419342,
          18.424342434243428,
          18.42934293429343,
          18.43434343434344,
          18.43934393439344,
          18.444344434443444,
          18.449344934493453,
          18.454345434543455,
          18.459345934593465,
          18.464346434643467,
          18.46934693469347,
          18.47434743474348,
          18.47934793479348,
          18.48434843484349,
          18.489348934893492,
          18.494349434943494,
          18.499349934993504,
          18.504350435043506,
          18.509350935093508,
          18.514351435143517,
          18.51935193519352,
          18.52435243524353,
          18.52935293529353,
          18.534353435343533,
          18.539353935393542,
          18.544354435443545,
          18.549354935493554,
          18.554355435543556,
          18.55935593559356,
          18.564356435643568,
          18.56935693569357,
          18.57435743574358,
          18.57935793579358,
          18.584358435843583,
          18.589358935893593,
          18.594359435943595,
          18.599359935993604,
          18.604360436043606,
          18.60936093609361,
          18.614361436143618,
          18.61936193619362,
          18.62436243624363,
          18.62936293629363,
          18.634363436343634,
          18.639363936393643,
          18.644364436443645,
          18.649364936493654,
          18.654365436543657,
          18.65936593659366,
          18.664366436643668,
          18.66936693669367,
          18.67436743674368,
          18.679367936793682,
          18.684368436843684,
          18.689368936893693,
          18.694369436943695,
          18.699369936993705,
          18.704370437043707,
          18.70937093709371,
          18.71437143714372,
          18.71937193719372,
          18.72437243724373,
          18.729372937293732,
          18.734373437343734,
          18.739373937393744,
          18.744374437443746,
          18.749374937493755,
          18.754375437543757,
          18.75937593759376,
          18.76437643764377,
          18.76937693769377,
          18.774377437743773,
          18.779377937793782,
          18.784378437843785,
          18.789378937893794,
          18.794379437943796,
          18.7993799379938,
          18.804380438043808,
          18.80938093809381,
          18.81438143814382,
          18.81938193819382,
          18.824382438243823,
          18.829382938293833,
          18.834383438343835,
          18.839383938393844,
          18.844384438443846,
          18.84938493849385,
          18.854385438543858,
          18.85938593859386,
          18.86438643864387,
          18.86938693869387,
          18.874387438743874,
          18.879387938793883,
          18.884388438843885,
          18.889388938893894,
          18.894389438943897,
          18.8993899389939,
          18.904390439043908,
          18.90939093909391,
          18.91439143914392,
          18.919391939193922,
          18.924392439243924,
          18.929392939293933,
          18.934393439343935,
          18.939393939393945,
          18.944394439443947,
          18.94939493949395,
          18.95439543954396,
          18.95939593959396,
          18.96439643964397,
          18.969396939693972,
          18.974397439743974,
          18.979397939793984,
          18.984398439843986,
          18.989398939893995,
          18.994399439943997,
          18.999399939994,
          19.00440044004401,
          19.00940094009401,
          19.014401440144013,
          19.019401940194022,
          19.024402440244025,
          19.029402940294034,
          19.034403440344036,
          19.03940394039404,
          19.044404440444048,
          19.04940494049405,
          19.05440544054406,
          19.05940594059406,
          19.064406440644063,
          19.069406940694073,
          19.074407440744075,
          19.079407940794084,
          19.084408440844086,
          19.08940894089409,
          19.094409440944098,
          19.0994099409941,
          19.10441044104411,
          19.10941094109411,
          19.114411441144114,
          19.119411941194123,
          19.124412441244125,
          19.129412941294134,
          19.134413441344137,
          19.13941394139414,
          19.144414441444148,
          19.14941494149415,
          19.15441544154416,
          19.159415941594162,
          19.164416441644164,
          19.169416941694173,
          19.174417441744176,
          19.179417941794185,
          19.184418441844187,
          19.18941894189419,
          19.1944194419442,
          19.1994199419942,
          19.20442044204421,
          19.209420942094212,
          19.214421442144214,
          19.219421942194224,
          19.224422442244226,
          19.229422942294235,
          19.234423442344237,
          19.23942394239424,
          19.24442444244425,
          19.24942494249425,
          19.254425442544253,
          19.259425942594262,
          19.264426442644265,
          19.269426942694274,
          19.274427442744276,
          19.27942794279428,
          19.284428442844288,
          19.28942894289429,
          19.2944294429443,
          19.2994299429943,
          19.304430443044303,
          19.309430943094313,
          19.314431443144315,
          19.319431943194324,
          19.324432443244326,
          19.32943294329433,
          19.334433443344338,
          19.33943394339434,
          19.34443444344435,
          19.34943494349435,
          19.354435443544354,
          19.359435943594363,
          19.364436443644365,
          19.369436943694375,
          19.374437443744377,
          19.37943794379438,
          19.384438443844388,
          19.38943894389439,
          19.3944394439444,
          19.399439943994402,
          19.404440444044404,
          19.409440944094413,
          19.414441444144416,
          19.419441944194425,
          19.424442444244427,
          19.42944294429443,
          19.43444344434444,
          19.43944394439444,
          19.44444444444445,
          19.449444944494452,
          19.454445444544454,
          19.459445944594464,
          19.464446444644466,
          19.469446944694475,
          19.474447444744477,
          19.47944794479448,
          19.48444844484449,
          19.48944894489449,
          19.494449444944493,
          19.499449944994502,
          19.504450445044505,
          19.509450945094514,
          19.514451445144516,
          19.51945194519452,
          19.524452445244528,
          19.52945294529453,
          19.53445344534454,
          19.53945394539454,
          19.544454445444543,
          19.549454945494553,
          19.554455445544555,
          19.559455945594564,
          19.564456445644566,
          19.56945694569457,
          19.574457445744578,
          19.57945794579458,
          19.58445844584459,
          19.58945894589459,
          19.594459445944594,
          19.599459945994603,
          19.604460446044605,
          19.609460946094615,
          19.614461446144617,
          19.61946194619462,
          19.624462446244628,
          19.62946294629463,
          19.63446344634464,
          19.639463946394642,
          19.644464446444644,
          19.649464946494653,
          19.654465446544656,
          19.659465946594665,
          19.664466446644667,
          19.66946694669467,
          19.67446744674468,
          19.67946794679468,
          19.68446844684469,
          19.689468946894692,
          19.694469446944694,
          19.699469946994704,
          19.704470447044706,
          19.709470947094715,
          19.714471447144717,
          19.71947194719472,
          19.72447244724473,
          19.72947294729473,
          19.734473447344733,
          19.739473947394742,
          19.744474447444745,
          19.749474947494754,
          19.754475447544756,
          19.75947594759476,
          19.764476447644768,
          19.76947694769477,
          19.77447744774478,
          19.77947794779478,
          19.784478447844783,
          19.789478947894793,
          19.794479447944795,
          19.799479947994804,
          19.804480448044806,
          19.80948094809481,
          19.814481448144818,
          19.81948194819482,
          19.82448244824483,
          19.82948294829483,
          19.834483448344834,
          19.839483948394843,
          19.844484448444845,
          19.849484948494855,
          19.854485448544857,
          19.85948594859486,
          19.86448644864487,
          19.86948694869487,
          19.87448744874488,
          19.879487948794882,
          19.884488448844884,
          19.889488948894893,
          19.894489448944896,
          19.899489948994905,
          19.904490449044907,
          19.90949094909491,
          19.91449144914492,
          19.91949194919492,
          19.92449244924493,
          19.929492949294932,
          19.934493449344934,
          19.939493949394944,
          19.944494449444946,
          19.949494949494955,
          19.954495449544957,
          19.95949594959496,
          19.96449644964497,
          19.96949694969497,
          19.974497449744973,
          19.979497949794983,
          19.984498449844985,
          19.989498949894994,
          19.994499449944996,
          19.999499949995,
          20.004500450045008,
          20.00950095009501,
          20.01450145014502,
          20.01950195019502,
          20.024502450245024,
          20.029502950295033,
          20.034503450345035,
          20.039503950395044,
          20.044504450445046,
          20.04950495049505,
          20.054505450545058,
          20.05950595059506,
          20.06450645064507,
          20.06950695069507,
          20.074507450745074,
          20.079507950795083,
          20.084508450845085,
          20.089508950895095,
          20.094509450945097,
          20.0995099509951,
          20.10451045104511,
          20.10951095109511,
          20.11451145114512,
          20.119511951195122,
          20.124512451245124,
          20.129512951295133,
          20.134513451345136,
          20.139513951395145,
          20.144514451445147,
          20.14951495149515,
          20.15451545154516,
          20.15951595159516,
          20.16451645164517,
          20.169516951695172,
          20.174517451745174,
          20.179517951795184,
          20.184518451845186,
          20.189518951895195,
          20.194519451945197,
          20.1995199519952,
          20.20452045204521,
          20.20952095209521,
          20.214521452145213,
          20.219521952195223,
          20.224522452245225,
          20.229522952295234,
          20.234523452345236,
          20.23952395239524,
          20.244524452445248,
          20.24952495249525,
          20.25452545254526,
          20.25952595259526,
          20.264526452645264,
          20.269526952695273,
          20.274527452745275,
          20.279527952795284,
          20.284528452845286,
          20.28952895289529,
          20.294529452945298,
          20.2995299529953,
          20.30453045304531,
          20.30953095309531,
          20.314531453145314,
          20.319531953195323,
          20.324532453245325,
          20.329532953295335,
          20.334533453345337,
          20.33953395339534,
          20.34453445344535,
          20.34953495349535,
          20.35453545354536,
          20.359535953595362,
          20.364536453645364,
          20.369536953695373,
          20.374537453745376,
          20.379537953795385,
          20.384538453845387,
          20.38953895389539,
          20.3945394539454,
          20.3995399539954,
          20.40454045404541,
          20.409540954095412,
          20.414541454145414,
          20.419541954195424,
          20.424542454245426,
          20.429542954295435,
          20.434543454345437,
          20.43954395439544,
          20.44454445444545,
          20.44954495449545,
          20.454545454545453,
          20.459545954595463,
          20.464546454645465,
          20.469546954695474,
          20.474547454745476,
          20.47954795479548,
          20.484548454845488,
          20.48954895489549,
          20.4945494549455,
          20.4995499549955,
          20.504550455045504,
          20.509550955095513,
          20.514551455145515,
          20.519551955195524,
          20.524552455245527,
          20.52955295529553,
          20.534553455345538,
          20.53955395539554,
          20.54455445544555,
          20.54955495549555,
          20.554555455545554,
          20.559555955595563,
          20.564556455645565,
          20.569556955695575,
          20.574557455745577,
          20.57955795579558,
          20.58455845584559,
          20.58955895589559,
          20.5945594559456,
          20.599559955995602,
          20.604560456045604,
          20.609560956095613,
          20.614561456145616,
          20.619561956195625,
          20.624562456245627,
          20.62956295629563,
          20.63456345634564,
          20.63956395639564,
          20.64456445644565,
          20.649564956495652,
          20.654565456545654,
          20.659565956595664,
          20.664566456645666,
          20.669566956695675,
          20.674567456745677,
          20.67956795679568,
          20.68456845684569,
          20.68956895689569,
          20.694569456945693,
          20.699569956995703,
          20.704570457045705,
          20.709570957095714,
          20.714571457145716,
          20.71957195719572,
          20.724572457245728,
          20.72957295729573,
          20.73457345734574,
          20.73957395739574,
          20.744574457445744,
          20.749574957495753,
          20.754575457545755,
          20.759575957595764,
          20.764576457645767,
          20.76957695769577,
          20.774577457745778,
          20.77957795779578,
          20.78457845784579,
          20.78957895789579,
          20.794579457945794,
          20.799579957995803,
          20.804580458045805,
          20.809580958095815,
          20.814581458145817,
          20.81958195819582,
          20.82458245824583,
          20.82958295829583,
          20.83458345834584,
          20.839583958395842,
          20.844584458445844,
          20.849584958495853,
          20.854585458545856,
          20.859585958595865,
          20.864586458645867,
          20.86958695869587,
          20.87458745874588,
          20.87958795879588,
          20.88458845884589,
          20.889588958895892,
          20.894589458945894,
          20.899589958995904,
          20.904590459045906,
          20.909590959095915,
          20.914591459145917,
          20.91959195919592,
          20.92459245924593,
          20.92959295929593,
          20.934593459345933,
          20.939593959395943,
          20.944594459445945,
          20.949594959495954,
          20.954595459545956,
          20.95959595959596,
          20.964596459645968,
          20.96959695969597,
          20.97459745974598,
          20.97959795979598,
          20.984598459845984,
          20.989598959895993,
          20.994599459945995,
          20.999599959996004,
          21.004600460046007,
          21.00960096009601,
          21.014601460146018,
          21.01960196019602,
          21.02460246024603,
          21.02960296029603,
          21.034603460346034,
          21.039603960396043,
          21.044604460446045,
          21.049604960496055,
          21.054605460546057,
          21.05960596059606,
          21.06460646064607,
          21.06960696069607,
          21.07460746074608,
          21.079607960796082,
          21.084608460846084,
          21.089608960896093,
          21.094609460946096,
          21.099609960996105,
          21.104610461046107,
          21.10961096109611,
          21.11461146114612,
          21.11961196119612,
          21.12461246124613,
          21.129612961296132,
          21.134613461346134,
          21.139613961396144,
          21.144614461446146,
          21.149614961496155,
          21.154615461546157,
          21.15961596159616,
          21.16461646164617,
          21.16961696169617,
          21.17461746174618,
          21.179617961796183,
          21.184618461846185,
          21.189618961896194,
          21.194619461946196,
          21.1996199619962,
          21.204620462046208,
          21.20962096209621,
          21.21462146214622,
          21.21962196219622,
          21.224622462246224,
          21.229622962296233,
          21.234623462346235,
          21.239623962396244,
          21.244624462446247,
          21.24962496249625,
          21.254625462546258,
          21.25962596259626,
          21.26462646264627,
          21.26962696269627,
          21.274627462746274,
          21.279627962796283,
          21.284628462846285,
          21.289628962896295,
          21.294629462946297,
          21.2996299629963,
          21.30463046304631,
          21.30963096309631,
          21.31463146314632,
          21.319631963196322,
          21.324632463246324,
          21.329632963296334,
          21.334633463346336,
          21.339633963396345,
          21.344634463446347,
          21.34963496349635,
          21.35463546354636,
          21.35963596359636,
          21.36463646364637,
          21.369636963696372,
          21.374637463746375,
          21.379637963796384,
          21.384638463846386,
          21.389638963896395,
          21.394639463946397,
          21.3996399639964,
          21.40464046404641,
          21.40964096409641,
          21.41464146414642,
          21.419641964196423,
          21.424642464246425,
          21.429642964296434,
          21.434643464346436,
          21.43964396439644,
          21.444644464446448,
          21.44964496449645,
          21.45464546454646,
          21.45964596459646,
          21.464646464646464,
          21.469646964696473,
          21.474647464746475,
          21.479647964796484,
          21.484648464846487,
          21.48964896489649,
          21.494649464946498,
          21.4996499649965,
          21.50465046504651,
          21.50965096509651,
          21.514651465146514,
          21.519651965196523,
          21.524652465246525,
          21.529652965296535,
          21.534653465346537,
          21.53965396539654,
          21.54465446544655,
          21.54965496549655,
          21.55465546554656,
          21.559655965596562,
          21.564656465646564,
          21.569656965696574,
          21.574657465746576,
          21.579657965796585,
          21.584658465846587,
          21.58965896589659,
          21.5946594659466,
          21.5996599659966,
          21.60466046604661,
          21.609660966096612,
          21.614661466146615,
          21.619661966196624,
          21.624662466246626,
          21.629662966296635,
          21.634663466346638,
          21.63966396639664,
          21.64466446644665,
          21.64966496649665,
          21.65466546654666,
          21.659665966596663,
          21.664666466646665,
          21.669666966696674,
          21.674667466746676,
          21.67966796679668,
          21.684668466846688,
          21.68966896689669,
          21.6946694669467,
          21.6996699669967,
          21.704670467046704,
          21.709670967096713,
          21.714671467146715,
          21.719671967196724,
          21.724672467246727,
          21.72967296729673,
          21.734673467346738,
          21.73967396739674,
          21.74467446744675,
          21.74967496749675,
          21.754675467546754,
          21.759675967596763,
          21.764676467646765,
          21.769676967696775,
          21.774677467746777,
          21.77967796779678,
          21.78467846784679,
          21.78967896789679,
          21.7946794679468,
          21.799679967996802,
          21.804680468046804,
          21.809680968096814,
          21.814681468146816,
          21.819681968196825,
          21.824682468246827,
          21.82968296829683,
          21.83468346834684,
          21.83968396839684,
          21.84468446844685,
          21.849684968496852,
          21.854685468546855,
          21.859685968596864,
          21.864686468646866,
          21.869686968696875,
          21.874687468746878,
          21.87968796879688,
          21.88468846884689,
          21.88968896889689,
          21.8946894689469,
          21.899689968996903,
          21.904690469046905,
          21.909690969096914,
          21.914691469146916,
          21.91969196919692,
          21.924692469246928,
          21.92969296929693,
          21.93469346934694,
          21.93969396939694,
          21.944694469446944,
          21.949694969496953,
          21.954695469546955,
          21.959695969596964,
          21.964696469646967,
          21.96969696969697,
          21.974697469746978,
          21.97969796979698,
          21.98469846984699,
          21.989698969896992,
          21.994699469946994,
          21.999699969997003,
          22.004700470047005,
          22.009700970097015,
          22.014701470147017,
          22.01970197019702,
          22.02470247024703,
          22.02970297029703,
          22.03470347034704,
          22.039703970397042,
          22.044704470447044,
          22.049704970497054,
          22.054705470547056,
          22.059705970597065,
          22.064706470647067,
          22.06970697069707,
          22.07470747074708,
          22.07970797079708,
          22.08470847084709,
          22.089708970897092,
          22.094709470947095,
          22.099709970997104,
          22.104710471047106,
          22.109710971097115,
          22.114711471147118,
          22.11971197119712,
          22.12471247124713,
          22.12971297129713,
          22.13471347134714,
          22.139713971397143,
          22.144714471447145,
          22.149714971497154,
          22.154715471547156,
          22.15971597159716,
          22.164716471647168,
          22.16971697169717,
          22.17471747174718,
          22.17971797179718,
          22.184718471847184,
          22.189718971897193,
          22.194719471947195,
          22.199719971997204,
          22.204720472047207,
          22.20972097209721,
          22.214721472147218,
          22.21972197219722,
          22.22472247224723,
          22.229722972297232,
          22.234723472347234,
          22.239723972397243,
          22.244724472447245,
          22.249724972497255,
          22.254725472547257,
          22.25972597259726,
          22.26472647264727,
          22.26972697269727,
          22.27472747274728,
          22.279727972797282,
          22.284728472847284,
          22.289728972897294,
          22.294729472947296,
          22.299729972997305,
          22.304730473047307,
          22.30973097309731,
          22.31473147314732,
          22.31973197319732,
          22.32473247324733,
          22.329732973297332,
          22.334733473347335,
          22.339733973397344,
          22.344734473447346,
          22.349734973497355,
          22.354735473547358,
          22.35973597359736,
          22.36473647364737,
          22.36973697369737,
          22.37473747374738,
          22.379737973797383,
          22.384738473847385,
          22.389738973897394,
          22.394739473947396,
          22.3997399739974,
          22.404740474047408,
          22.40974097409741,
          22.41474147414742,
          22.41974197419742,
          22.424742474247424,
          22.429742974297433,
          22.434743474347435,
          22.439743974397445,
          22.444744474447447,
          22.44974497449745,
          22.454745474547458,
          22.45974597459746,
          22.46474647464747,
          22.469746974697472,
          22.474747474747474,
          22.479747974797483,
          22.484748474847486,
          22.489748974897495,
          22.494749474947497,
          22.4997499749975,
          22.50475047504751,
          22.50975097509751,
          22.51475147514752,
          22.519751975197522,
          22.524752475247524,
          22.529752975297534,
          22.534753475347536,
          22.539753975397545,
          22.544754475447547,
          22.54975497549755,
          22.55475547554756,
          22.55975597559756,
          22.56475647564757,
          22.569756975697572,
          22.574757475747575,
          22.579757975797584,
          22.584758475847586,
          22.589758975897595,
          22.594759475947598,
          22.5997599759976,
          22.60476047604761,
          22.60976097609761,
          22.61476147614762,
          22.619761976197623,
          22.624762476247625,
          22.629762976297634,
          22.634763476347636,
          22.63976397639764,
          22.644764476447648,
          22.64976497649765,
          22.65476547654766,
          22.65976597659766,
          22.664766476647664,
          22.669766976697673,
          22.674767476747675,
          22.679767976797685,
          22.684768476847687,
          22.68976897689769,
          22.694769476947698,
          22.6997699769977,
          22.70477047704771,
          22.709770977097712,
          22.714771477147714,
          22.719771977197723,
          22.724772477247726,
          22.729772977297735,
          22.734773477347737,
          22.73977397739774,
          22.74477447744775,
          22.74977497749775,
          22.75477547754776,
          22.759775977597762,
          22.764776477647764,
          22.769776977697774,
          22.774777477747776,
          22.779777977797785,
          22.784778477847787,
          22.78977897789779,
          22.7947794779478,
          22.7997799779978,
          22.80478047804781,
          22.809780978097812,
          22.814781478147815,
          22.819781978197824,
          22.824782478247826,
          22.829782978297835,
          22.834783478347838,
          22.83978397839784,
          22.84478447844785,
          22.84978497849785,
          22.85478547854786,
          22.859785978597863,
          22.864786478647865,
          22.869786978697874,
          22.874787478747876,
          22.87978797879788,
          22.884788478847888,
          22.88978897889789,
          22.8947894789479,
          22.8997899789979,
          22.904790479047904,
          22.909790979097913,
          22.914791479147915,
          22.919791979197925,
          22.924792479247927,
          22.92979297929793,
          22.934793479347938,
          22.93979397939794,
          22.94479447944795,
          22.949794979497952,
          22.954795479547954,
          22.959795979597963,
          22.964796479647966,
          22.969796979697975,
          22.974797479747977,
          22.97979797979798,
          22.98479847984799,
          22.98979897989799,
          22.994799479948,
          22.999799979998002,
          23.004800480048004,
          23.009800980098014,
          23.014801480148016,
          23.019801980198025,
          23.024802480248027,
          23.02980298029803,
          23.03480348034804,
          23.03980398039804,
          23.04480448044805,
          23.049804980498052,
          23.054805480548055,
          23.059805980598064,
          23.064806480648066,
          23.069806980698075,
          23.074807480748078,
          23.07980798079808,
          23.08480848084809,
          23.08980898089809,
          23.0948094809481,
          23.099809980998103,
          23.104810481048105,
          23.109810981098114,
          23.114811481148116,
          23.11981198119812,
          23.124812481248128,
          23.12981298129813,
          23.13481348134814,
          23.13981398139814,
          23.144814481448144,
          23.149814981498153,
          23.154815481548155,
          23.159815981598165,
          23.164816481648167,
          23.16981698169817,
          23.17481748174818,
          23.17981798179818,
          23.18481848184819,
          23.189818981898192,
          23.194819481948194,
          23.199819981998203,
          23.204820482048206,
          23.209820982098215,
          23.214821482148217,
          23.21982198219822,
          23.22482248224823,
          23.22982298229823,
          23.23482348234824,
          23.239823982398242,
          23.244824482448244,
          23.249824982498254,
          23.254825482548256,
          23.259825982598265,
          23.264826482648267,
          23.26982698269827,
          23.27482748274828,
          23.27982798279828,
          23.28482848284829,
          23.289828982898293,
          23.294829482948295,
          23.299829982998304,
          23.304830483048306,
          23.309830983098315,
          23.314831483148318,
          23.31983198319832,
          23.32483248324833,
          23.32983298329833,
          23.33483348334834,
          23.339833983398343,
          23.344834483448345,
          23.349834983498354,
          23.354835483548356,
          23.35983598359836,
          23.364836483648368,
          23.36983698369837,
          23.37483748374838,
          23.37983798379838,
          23.384838483848384,
          23.389838983898393,
          23.394839483948395,
          23.399839983998405,
          23.404840484048407,
          23.40984098409841,
          23.41484148414842,
          23.41984198419842,
          23.42484248424843,
          23.429842984298432,
          23.434843484348434,
          23.439843984398443,
          23.444844484448446,
          23.449844984498455,
          23.454845484548457,
          23.45984598459846,
          23.46484648464847,
          23.46984698469847,
          23.47484748474848,
          23.479847984798482,
          23.484848484848484,
          23.489848984898494,
          23.494849484948496,
          23.499849984998505,
          23.504850485048507,
          23.50985098509851,
          23.51485148514852,
          23.51985198519852,
          23.52485248524853,
          23.529852985298533,
          23.534853485348535,
          23.539853985398544,
          23.544854485448546,
          23.549854985498555,
          23.554855485548558,
          23.55985598559856,
          23.56485648564857,
          23.56985698569857,
          23.57485748574858,
          23.579857985798583,
          23.584858485848585,
          23.589858985898594,
          23.594859485948597,
          23.5998599859986,
          23.604860486048608,
          23.60986098609861,
          23.61486148614862,
          23.61986198619862,
          23.624862486248624,
          23.629862986298633,
          23.634863486348635,
          23.639863986398645,
          23.644864486448647,
          23.64986498649865,
          23.65486548654866,
          23.65986598659866,
          23.66486648664867,
          23.669866986698672,
          23.674867486748674,
          23.679867986798683,
          23.684868486848686,
          23.689868986898695,
          23.694869486948697,
          23.6998699869987,
          23.70487048704871,
          23.70987098709871,
          23.71487148714872,
          23.719871987198722,
          23.724872487248724,
          23.729872987298734,
          23.734873487348736,
          23.739873987398745,
          23.744874487448747,
          23.74987498749875,
          23.75487548754876,
          23.75987598759876,
          23.76487648764877,
          23.769876987698773,
          23.774877487748775,
          23.779877987798784,
          23.784878487848786,
          23.789878987898796,
          23.794879487948798,
          23.7998799879988,
          23.80488048804881,
          23.80988098809881,
          23.81488148814882,
          23.819881988198823,
          23.824882488248825,
          23.829882988298834,
          23.834883488348837,
          23.839883988398846,
          23.844884488448848,
          23.84988498849885,
          23.85488548854886,
          23.85988598859886,
          23.864886488648864,
          23.869886988698873,
          23.874887488748875,
          23.879887988798885,
          23.884888488848887,
          23.88988898889889,
          23.8948894889489,
          23.8998899889989,
          23.90489048904891,
          23.909890989098912,
          23.914891489148914,
          23.919891989198923,
          23.924892489248926,
          23.929892989298935,
          23.934893489348937,
          23.93989398939894,
          23.94489448944895,
          23.94989498949895,
          23.95489548954896,
          23.959895989598962,
          23.964896489648964,
          23.969896989698974,
          23.974897489748976,
          23.979897989798985,
          23.984898489848987,
          23.98989898989899,
          23.994899489949,
          23.999899989999,
          24.00490049004901,
          24.009900990099013,
          24.014901490149015,
          24.019901990199024,
          24.024902490249026,
          24.029902990299036,
          24.034903490349038,
          24.03990399039904,
          24.04490449044905,
          24.04990499049905,
          24.05490549054906,
          24.059905990599063,
          24.064906490649065,
          24.069906990699074,
          24.074907490749077,
          24.079907990799086,
          24.084908490849088,
          24.08990899089909,
          24.0949094909491,
          24.0999099909991,
          24.104910491049104,
          24.109910991099113,
          24.114911491149115,
          24.119911991199125,
          24.124912491249127,
          24.12991299129913,
          24.13491349134914,
          24.13991399139914,
          24.14491449144915,
          24.149914991499152,
          24.154915491549154,
          24.159915991599163,
          24.164916491649166,
          24.169916991699175,
          24.174917491749177,
          24.17991799179918,
          24.18491849184919,
          24.18991899189919,
          24.1949194919492,
          24.199919991999202,
          24.204920492049204,
          24.209920992099214,
          24.214921492149216,
          24.219921992199225,
          24.224922492249227,
          24.22992299229923,
          24.23492349234924,
          24.23992399239924,
          24.24492449244925,
          24.249924992499253,
          24.254925492549255,
          24.259925992599264,
          24.264926492649266,
          24.269926992699276,
          24.274927492749278,
          24.27992799279928,
          24.28492849284929,
          24.28992899289929,
          24.2949294929493,
          24.299929992999303,
          24.304930493049305,
          24.309930993099314,
          24.314931493149317,
          24.319931993199326,
          24.324932493249328,
          24.32993299329933,
          24.33493349334934,
          24.33993399339934,
          24.344934493449344,
          24.349934993499353,
          24.354935493549355,
          24.359935993599365,
          24.364936493649367,
          24.36993699369937,
          24.37493749374938,
          24.37993799379938,
          24.38493849384939,
          24.389938993899392,
          24.394939493949394,
          24.399939993999403,
          24.404940494049406,
          24.409940994099415,
          24.414941494149417,
          24.41994199419942,
          24.42494249424943,
          24.42994299429943,
          24.43494349434944,
          24.439943994399442,
          24.444944494449445,
          24.449944994499454,
          24.454945494549456,
          24.459945994599465,
          24.464946494649467,
          24.46994699469947,
          24.47494749474948,
          24.47994799479948,
          24.48494849484949,
          24.489948994899493,
          24.494949494949495,
          24.499949994999504,
          24.504950495049506,
          24.509950995099516,
          24.514951495149518,
          24.51995199519952,
          24.52495249524953,
          24.52995299529953,
          24.53495349534954,
          24.539953995399543,
          24.544954495449545,
          24.549954995499554,
          24.554955495549557,
          24.559955995599566,
          24.564956495649568,
          24.56995699569957,
          24.57495749574958,
          24.57995799579958,
          24.584958495849584,
          24.589958995899593,
          24.594959495949595,
          24.599959995999605,
          24.604960496049607,
          24.60996099609961,
          24.61496149614962,
          24.61996199619962,
          24.62496249624963,
          24.629962996299632,
          24.634963496349634,
          24.639963996399644,
          24.644964496449646,
          24.649964996499655,
          24.654965496549657,
          24.65996599659966,
          24.66496649664967,
          24.66996699669967,
          24.67496749674968,
          24.679967996799682,
          24.684968496849685,
          24.689968996899694,
          24.694969496949696,
          24.699969996999705,
          24.704970497049707,
          24.70997099709971,
          24.71497149714972,
          24.71997199719972,
          24.72497249724973,
          24.729972997299733,
          24.734973497349735,
          24.739973997399744,
          24.744974497449746,
          24.749974997499756,
          24.754975497549758,
          24.75997599759976,
          24.76497649764977,
          24.76997699769977,
          24.77497749774978,
          24.779977997799783,
          24.784978497849785,
          24.789978997899794,
          24.794979497949797,
          24.799979997999806,
          24.804980498049808,
          24.80998099809981,
          24.81498149814982,
          24.81998199819982,
          24.824982498249824,
          24.829982998299833,
          24.834983498349835,
          24.839983998399845,
          24.844984498449847,
          24.84998499849985,
          24.85498549854986,
          24.85998599859986,
          24.86498649864987,
          24.869986998699872,
          24.874987498749874,
          24.879987998799884,
          24.884988498849886,
          24.889988998899895,
          24.894989498949897,
          24.8999899989999,
          24.90499049904991,
          24.90999099909991,
          24.91499149914992,
          24.919991999199922,
          24.924992499249925,
          24.929992999299934,
          24.934993499349936,
          24.939993999399945,
          24.944994499449948,
          24.94999499949995,
          24.95499549954996,
          24.95999599959996,
          24.96499649964997,
          24.969996999699973,
          24.974997499749975,
          24.979997999799984,
          24.984998499849986,
          24.989998999899996,
          24.994999499949998,
          25
         ],
         "y": [
          25.133526407021535,
          25.133619005550823,
          25.133718669770847,
          25.133825669996508,
          25.13394027805574,
          25.13406276734902,
          25.134193412909497,
          25.134332491463944,
          25.13448028149438,
          25.134637063300527,
          25.134803119063072,
          25.134978732907786,
          25.1351641909705,
          25.135359781463027,
          25.135565794740007,
          25.13578252336674,
          25.136010262188034,
          25.13624930839811,
          25.136499961611595,
          25.13676252393562,
          25.13703730004312,
          25.137324597247293,
          25.137624725577354,
          25.137937997855513,
          25.138264729775344,
          25.13860523998147,
          25.138959850150705,
          25.139328885074622,
          25.139712672743673,
          25.140111544432816,
          25.140525834788786,
          25.140955881919012,
          25.141402027482247,
          25.14186461678095,
          25.14234399885551,
          25.142840526580326,
          25.14335455676184,
          25.143886450238558,
          25.144436571983135,
          25.145005291206587,
          25.145592981464674,
          25.146200020766575,
          25.146826791685857,
          25.147473681473873,
          25.148141082175623,
          25.148829390748173,
          25.149539009181687,
          25.150270344623227,
          25.151023809503293,
          25.151799821665282,
          25.15259880449793,
          25.153421187070798,
          25.15426740427296,
          25.15513789695494,
          25.156033112074006,
          25.156953502842974,
          25.157899528882567,
          25.158871656377496,
          25.159870358236336,
          25.16089611425538,
          25.161949411286496,
          25.163030743409244,
          25.164140612107282,
          25.16527952644924,
          25.166448003274237,
          25.167646567382125,
          25.168875751728663,
          25.170136097625782,
          25.17142815494706,
          25.17275248233863,
          25.1741096474357,
          25.17550022708479,
          25.17692480757201,
          25.17838398485744,
          25.179878364815924,
          25.18140856348443,
          25.18297520731621,
          25.184578933442026,
          25.186220389938615,
          25.18790023610469,
          25.18961914274472,
          25.19137779246079,
          25.19317687995269,
          25.195017112326727,
          25.196899209413367,
          25.198823904094144,
          25.20079194263808,
          25.20280408504802,
          25.204861105417145,
          25.20696379229615,
          25.209112949071336,
          25.21130939435408,
          25.213553962382093,
          25.215847503432872,
          25.218190884249793,
          25.22058498848132,
          25.22303071713379,
          25.225528989038292,
          25.22808074133218,
          25.230686929955713,
          25.23334853016444,
          25.236066537057905,
          25.238841966125264,
          25.241675853808527,
          25.244569258084024,
          25.24752325906283,
          25.250538959610893,
          25.25361748598959,
          25.256759988517583,
          25.259967642254722,
          25.26324164770893,
          25.266583231566976,
          25.269993647450043,
          25.273474176695164,
          25.277026129163502,
          25.280650844076597,
          25.284349690881736,
          25.288124070147603,
          25.29197541449149,
          25.295905189539404,
          25.29991489492036,
          25.304006065296413,
          25.308180271429855,
          25.312439121289188,
          25.316784261195554,
          25.321217377011326,
          25.32574019537272,
          25.330354484968353,
          25.33506205786571,
          25.33986477088772,
          25.34476452704159,
          25.349763277002303,
          25.354863020653163,
          25.360065808686066,
          25.365373744264144,
          25.37078898474966,
          25.376313743500216,
          25.381950291736395,
          25.387700960484217,
          25.393568142595882,
          25.399554294852624,
          25.405661940153458,
          25.41189366979407,
          25.41825214584016,
          25.424740103599824,
          25.4313603541999,
          25.438115787271386,
          25.445009373749336,
          25.452044168793037,
          25.459223314832485,
          25.466550044747628,
          25.474027685187167,
          25.481659660034108,
          25.48944949402575,
          25.497400816536096,
          25.505517365529425,
          25.513802991693954,
          25.522261662765402,
          25.530897468050618,
          25.539714623162155,
          25.548717474975483,
          25.557910506821013,
          25.567298343924126,
          25.576885759107046,
          25.5866776787675,
          25.5966791891499,
          25.606895542925884,
          25.617332166102248,
          25.62799466527532,
          25.63888883525234,
          25.650020667061657,
          25.661396356375015,
          25.67302231236708,
          25.68490516703863,
          25.697051785032293,
          25.709469273971237,
          25.722164995353726,
          25.735146576038712,
          25.74842192036015,
          25.761999222910724,
          25.775886982038347,
          25.79009401410245,
          25.804629468540227,
          25.819502843797228,
          25.83472400418061,
          25.850303197698054,
          25.866251074950256,
          25.882578709150263,
          25.899297617348992,
          25.91641978295246,
          25.933957679623415,
          25.951924296667826,
          25.970333166014683,
          25.98919839090741,
          26.008534676434625,
          26.028357362039426,
          26.048682456158517,
          26.06952667315552,
          26.09090747272804,
          26.11284310198377,
          26.135352640398963,
          26.158456047892514,
          26.182174216270084,
          26.20652902431766,
          26.23154339684979,
          26.25724136804791,
          26.283648149456916,
          26.310790203044313,
          26.338695319767705,
          26.36739270414093,
          26.396913065340243,
          26.42728871544841,
          26.458553675497456,
          26.490743790042515,
          26.523896851077907,
          26.558052732196828,
          26.59325353399585,
          26.629543741840063,
          26.666970397231868,
          26.70558328417209,
          26.74543513206639,
          26.78658183691604,
          26.829082702745204,
          26.87300070545774,
          26.918402781592977,
          26.965360144765683,
          27.013948632936554,
          27.064249090076224,
          27.11634778626295,
          27.17033688080685,
          27.226314933630658,
          27.284387470877693,
          27.34466761157585,
          27.407276763188047,
          27.472345395048684,
          27.54001390005399,
          27.610433556583732,
          27.683767604524462,
          27.760192451503293,
          27.839899028093996,
          27.923094313910365,
          28.01000306026764,
          28.10086973959765,
          28.195960757221386,
          28.295566967618072,
          28.40000654524512,
          28.509628269595936,
          28.624815295945986,
          28.745989497679943,
          28.873616483902644,
          29.008211418109596,
          29.150345791201254,
          29.300655336585137,
          29.459849318542954,
          29.628721480111455,
          29.808163007006414,
          29.999177954435066,
          30.20290170052768,
          30.420623142572726,
          30.65381155269595,
          30.90414927548387,
          31.17357180593517,
          31.46431726719485,
          31.778987964739144,
          32.12062760170024,
          32.49281900994228,
          32.89980905097334,
          33.346669927121326,
          33.83950991842272,
          34.38575216405271,
          34.994508578782636,
          35.67708906456045,
          36.447706795688205,
          37.32447369986329,
          38.330835695696635,
          39.49769234036157,
          40.866614526109174,
          42.49488656796933,
          44.46370543087155,
          46.892112173146785,
          49.96194763310965,
          53.96555625279971,
          59.40476358277171,
          67.21945473078841,
          79.39900365370033,
          101.01438737773742,
          149.95617458687494,
          null,
          null,
          -117.49811612578634,
          -59.15967271969695,
          -34.96177341294294,
          -21.720256614771994,
          -13.368175818417114,
          -7.619943739939764,
          -3.422470761362117,
          -0.22308158745820705,
          2.296161149951782,
          4.3311194721457476,
          6.009038676235129,
          7.41617583920722,
          8.61307370741442,
          9.643478296698609,
          10.53978610089579,
          11.326500572752606,
          12.022497928912413,
          12.642554817170556,
          13.198403941010627,
          13.699479476114305,
          14.153453664714192,
          14.566629793063557,
          14.944234481793483,
          15.290638153812452,
          15.609523459528216,
          15.904015449315958,
          16.176783259511637,
          16.430120328862095,
          16.66600825414244,
          16.886168050043835,
          17.092101619708707,
          17.28512554974037,
          17.46639883747668,
          17.63694578460312,
          17.79767501243757,
          17.94939534435388,
          18.092829141431938,
          18.228623555373797,
          18.357360068550168,
          18.47956261782989,
          18.595704541547306,
          18.706214543819854,
          18.811481834641977,
          18.911860575650024,
          19.00767373857039,
          19.09921646492123,
          19.186759000595046,
          19.270549266782787,
          19.350815118752852,
          19.427766335822202,
          19.50159637911544,
          19.572483948122226,
          19.640594362418295,
          19.706080791041067,
          19.76908534876236,
          19.82974007577313,
          19.88816781499411,
          19.94448299927881,
          19.99879235912539,
          20.051195560106468,
          20.101785778027565,
          20.15065021879778,
          20.19787058911487,
          20.24352352331024,
          20.287680971044328,
          20.330410549978755,
          20.371775867061857,
          20.411836811638338,
          20.450649823224914,
          20.48826813646985,
          20.52474200553298,
          20.560118909875158,
          20.594443743230016,
          20.627758987339718,
          20.660104871868892,
          20.69151952176303,
          20.7220390931862,
          20.751697899058055,
          20.78052852510649,
          20.80856193726169,
          20.83582758113601,
          20.86235347426168,
          20.88816629169437,
          20.913291445532415,
          20.937753158850644,
          20.96157453450079,
          20.984777619190037,
          21.00738346321119,
          21.029412176165,
          21.05088297898499,
          21.071814252547686,
          21.092223583127165,
          21.112127804930207,
          21.131543039928495,
          21.150484735186293,
          21.168967697865206,
          21.18700612807317,
          21.20461364971086,
          21.22180333945657,
          21.238587754019342,
          21.254978955779766,
          21.270988536928844,
          21.28662764220641,
          21.30190699033304,
          21.31683689422232,
          21.331427280053425,
          21.345687705278632,
          21.35962737563423,
          21.373255161218786,
          21.386579611697808,
          21.399608970689634,
          21.412351189383706,
          21.424813939438415,
          21.437004625202714,
          21.44893039530251,
          21.460598153629917,
          21.472014569771105,
          21.483186088905885,
          21.494118941209972,
          21.50481915078887,
          21.515292544170318,
          21.52554475838067,
          21.53558124862866,
          21.545407295618784,
          21.55502801251479,
          21.56444835157288,
          21.57367311046258,
          21.582706938292386,
          21.59155434135618,
          21.600219688615308,
          21.608707216930526,
          21.617021036056922,
          21.62516513341437,
          21.633143378645045,
          21.640959527969194,
          21.648617228349377,
          21.65612002147299,
          21.663471347562286,
          21.67067454902046,
          21.67773287392211,
          21.684649479355652,
          21.69142743462506,
          21.698069724317726,
          21.704579251244986,
          21.710958839261405,
          21.717211235968655,
          21.723339115309418,
          21.729345080056564,
          21.73523166420244,
          21.74100133525301,
          21.74665649643112,
          21.75219948879323,
          21.7576325932634,
          21.762958032588354,
          21.768177973217252,
          21.773294527109357,
          21.778309753473003,
          21.783225660438774,
          21.788044206669817,
          21.792767302912058,
          21.79739681348689,
          21.80193455772887,
          21.8063823113707,
          21.810741807877807,
          21.81501473973465,
          21.819202759684728,
          21.82330748192632,
          21.827330483265705,
          21.831273304229683,
          21.835137450139037,
          21.838924392144577,
          21.842635568227216,
          21.846272384163598,
          21.849836214458623,
          21.853328403246216,
          21.85675026515959,
          21.860103086172202,
          21.863388124410555,
          21.866606610939982,
          21.8697597505244,
          21.872848722361095,
          21.87587468079147,
          21.878838755988674,
          21.881742054623018,
          21.884585660505984,
          21.88737063521367,
          21.89009801869038,
          21.892768829833198,
          21.895384067058135,
          21.89794470884864,
          21.90045171428703,
          21.9029060235695,
          21.905308558505347,
          21.90766022300092,
          21.90996190352885,
          21.912214469583155,
          21.91441877412062,
          21.91657565398902,
          21.918685930342647,
          21.920750409045503,
          21.922769881062703,
          21.924745122840427,
          21.92667689667483,
          21.928565951070315,
          21.930413021087503,
          21.932218828681272,
          21.933984083029184,
          21.935709480850676,
          21.937395706717243,
          21.93904343335399,
          21.940653321932814,
          21.942226022357485,
          21.943762173540907,
          21.945262403674832,
          21.946727330492227,
          21.948157561522596,
          21.94955369434045,
          21.950916316807152,
          21.95224600730635,
          21.953543334973237,
          21.954808859917765,
          21.956043133442115,
          21.957246698252483,
          21.958420088665463,
          21.959563830809145,
          21.960678442819116,
          21.961764435029515,
          21.962822310159304,
          21.963852563493898,
          21.964855683062307,
          21.965832149809934,
          21.966782437767137,
          21.96770701421372,
          21.968606339839475,
          21.969480868900856,
          21.970331049373954,
          21.971157323103878,
          21.971960125950616,
          21.97273988793153,
          21.973497033360548,
          21.97423198098419,
          21.97494514411449,
          21.97563693075895,
          21.976307743747554,
          21.976957980857016,
          21.977588034932236,
          21.978198294005175,
          21.978789141411124,
          21.979360955902482,
          21.979914111760156,
          21.98044897890256,
          21.980965922992425,
          21.981465305541313,
          21.981947484012085,
          21.982412811919243,
          21.982861638927275,
          21.983294310947073,
          21.983711170230443,
          21.984112555462787,
          21.984498801854034,
          21.984870241227817,
          21.98522720210901,
          21.98557000980964,
          21.985898986513238,
          21.986214451357657,
          21.986516720516452,
          21.986806107278806,
          21.9870829221281,
          21.98734747281912,
          21.987600064454025,
          21.987840999556997,
          21.98807057814773,
          21.988289097813738,
          21.988496853781513,
          21.988694138986617,
          21.988881244142693,
          21.989058457809456,
          21.98922606645973,
          21.989384354545475,
          21.98953360456295,
          21.98967409711696,
          21.98980611098426,
          21.989929923176117,
          21.990045809000122,
          21.990154042121183,
          21.990254894621856,
          21.990348637061885,
          21.990435538537167,
          21.99051586673798,
          21.990589888006642,
          21.99065786739459,
          21.990720068718822,
          21.990776754617894,
          21.990828186607327,
          21.990874625134563,
          21.990916329633443,
          21.99095355857826,
          21.990986569537366,
          21.99101561922644,
          21.991040963561325,
          21.99106285771057,
          21.991081556147634,
          21.99109731270278,
          21.991110380614717,
          21.991121012581967,
          21.991129460814008,
          21.991135977082227,
          21.991140812770645,
          21.99114421892652,
          21.991146446310786,
          21.99114774544835,
          21.991148366678345,
          21.991148560204238,
          21.99114857614393,
          21.991148664579796,
          21.991149075608707,
          21.99115005939208,
          21.991151866205932,
          21.99115474649099,
          21.991158950902893,
          21.991164730362435,
          21.991172336105972,
          21.99118201973594,
          21.991194033271533,
          21.991208629199555,
          21.991226060525467,
          21.991246580824686,
          21.991270444294077,
          21.99129790580376,
          21.991329220949176,
          21.99136464610348,
          21.991404438470255,
          21.99144885613659,
          21.991498158126554,
          21.99155260445504,
          21.99161245618209,
          21.991677975467606,
          21.991749425626608,
          21.991827071184954,
          21.99191117793559,
          21.992002012995382,
          21.99209984486249,
          21.992204943474395,
          21.992317580266523,
          21.992438028231543,
          21.992566561979384,
          21.992703457797912,
          21.99284899371442,
          21.993003449557865,
          21.993167107021907,
          21.993340249728806,
          21.993523163294196,
          21.993716135392734,
          21.99391945582473,
          21.99413341658371,
          21.994358311925005,
          21.994594438435385,
          21.994842095103756,
          21.995101583393,
          21.99537320731294,
          21.99565727349451,
          21.995954091265155,
          21.996263972725526,
          21.996587232827462,
          21.996924189453342,
          21.99727516349685,
          21.997640478945186,
          21.998020462962756,
          21.998415445976438,
          21.998825761762415,
          21.999251747534665,
          21.99969374403515,
          22.00015209562574,
          22.00062715038198,
          22.001119260188666,
          22.00162878083738,
          22.002156072126006,
          22.00270149796027,
          22.003265426457407,
          22.003848230051982,
          22.004450285603976,
          22.005071974509153,
          22.005713682811834,
          22.006375801320125,
          22.007058725723667,
          22.007762856714002,
          22.00848860010765,
          22.009236366971937,
          22.010006573753707,
          22.010799642410984,
          22.011616000547686,
          22.012456081551473,
          22.013320324734835,
          22.014209175479536,
          22.015123085384502,
          22.01606251241726,
          22.01702792106905,
          22.018019782513743,
          22.01903857477063,
          22.020084782871272,
          22.021158899030507,
          22.02226142282173,
          22.02339286135665,
          22.024553729469567,
          22.025744549906403,
          22.02696585351861,
          22.02821817946212,
          22.029502075401442,
          22.03081809771922,
          22.032166811731237,
          22.03354879190721,
          22.03496462209751,
          22.036414895765933,
          22.037900216228856,
          22.039421196900893,
          22.04097846154729,
          22.042572644543334,
          22.04420439114092,
          22.04587435774263,
          22.047583212183483,
          22.049331634020696,
          22.051120314831657,
          22.052949958520472,
          22.054821281633323,
          22.05673501368297,
          22.058691897482717,
          22.060692689490164,
          22.062738160161107,
          22.064829094313936,
          22.066966291504897,
          22.069150566414628,
          22.071382749246354,
          22.073663686136186,
          22.075994239575923,
          22.078375288848882,
          22.080807730479155,
          22.08329247869484,
          22.085830465905747,
          22.088422643196132,
          22.091069980832998,
          22.093773468790562,
          22.0965341172915,
          22.09935295736561,
          22.102231041426553,
          22.105169443867354,
          22.108169261675442,
          22.111231615067897,
          22.114357648147767,
          22.117548529582276,
          22.120805453303735,
          22.124129639234113,
          22.127522334034182,
          22.130984811878243,
          22.134518375255418,
          22.138124355798674,
          22.1418041151426,
          22.145559045811233,
          22.149390572137033,
          22.153300151212488,
          22.15728927387552,
          22.16135946573023,
          22.165512288204443,
          22.169749339645634,
          22.174072256456814,
          22.178482714274203,
          22.1829824291884,
          22.18757315901098,
          22.192256704588544,
          22.197034911166263,
          22.201909669803126,
          22.206882918841238,
          22.211956645431542,
          22.217132887118545,
          22.22241373348678,
          22.227801327871692,
          22.23329786913813,
          22.238905613529376,
          22.244626876590146,
          22.250464035167003,
          22.256419529489804,
          22.26249586533813,
          22.268695616296725,
          22.275021426104217,
          22.281476011099787,
          22.288062162772395,
          22.29478275041784,
          22.301640723908836,
          22.308639116583866,
          22.315781048260778,
          22.323069728381444,
          22.33050845929419,
          22.33810063968115,
          22.34584976813796,
          22.35375944691391,
          22.36183338582084,
          22.37007540631991,
          22.37848944579561,
          22.38707956202724,
          22.395849937868498,
          22.404804886146586,
          22.413948854792984,
          22.423286432218784,
          22.43282235294823,
          22.442561503525162,
          22.452508928707804,
          22.462669837968555,
          22.473049612316434,
          22.483653811460965,
          22.494488181337736,
          22.50555866201695,
          22.516871396018082,
          22.528432737055102,
          22.54024925923848,
          22.552327766762176,
          22.56467530410552,
          22.57729916678243,
          22.59020691267237,
          22.603406373970177,
          22.61690566979457,
          22.630713219498098,
          22.644837756724485,
          22.659288344262816,
          22.674074389751667,
          22.68920566229067,
          22.704692310021148,
          22.720544878742388,
          22.736774331635655,
          22.753392070173312,
          22.770409956297286,
          22.787840335957473,
          22.805696064108496,
          22.823990531271374,
          22.84273769177539,
          22.86195209380583,
          22.881648911393455,
          22.901843978493886,
          22.922553825317944,
          22.943795717088143,
          22.965587695412808,
          22.987948622486208,
          23.010898228342537,
          23.03445716141294,
          23.058647042657796,
          23.083490523573154,
          23.109011348398433,
          23.135234420884824,
          23.16218587601942,
          23.18989315713928,
          23.2183850989144,
          23.247692016727083,
          23.27784580303055,
          23.30888003133106,
          23.340830068506282,
          23.37373319625071,
          23.407628742524878,
          23.442558223983273,
          23.478565500465997,
          23.515696942762936,
          23.554001615000573,
          23.59353147316017,
          23.63434158141625,
          23.67649034819124,
          23.720039784053412,
          23.76505578385446,
          23.811608435806498,
          23.859772360547716,
          23.909627083647816,
          23.961257445464597,
          24.014754052795535,
          24.070213777382975,
          24.12774030704259,
          24.18744475601303,
          24.249446342085577,
          24.31387313919678,
          24.380862915481636,
          24.450564068326955,
          24.523136669781948,
          24.59875363782565,
          24.67760205153058,
          24.75988463117888,
          24.845821407982438,
          24.935651612363,
          25.029635814912414,
          25.128058360381022,
          25.23123014257728,
          25.33949177721609,
          25.453217240929394,
          25.572818058348155,
          25.698748136038244,
          25.831509362958364,
          25.97165812309416,
          26.119812898440003,
          26.276663181410857,
          26.442979967564185,
          26.619628165504064,
          26.80758134548367,
          27.007939357576852,
          27.221949492619196,
          27.451032045875607,
          27.696811390523994,
          27.96115399804794,
          28.246215287593554,
          28.55449779252553,
          28.888923967471268,
          29.252928123270426,
          29.650573621138264,
          30.086703811260538,
          30.56713862284122,
          31.09893376922868,
          31.690727139645738,
          32.353208623361915,
          33.09976792052555,
          33.94740430717802,
          34.91803086527833,
          36.040388262985445,
          37.35292852336676,
          38.90829527587897,
          40.78053643572093,
          43.077213498335745,
          45.96078056627114,
          49.688722510383755,
          54.694945396451644,
          61.77210673444492,
          72.53898836573654,
          90.89598754580994,
          129.23204927340163,
          null,
          null,
          -151.67703716147375,
          -72.08271911202871,
          -42.834118155428314,
          -27.642045260732026,
          -18.33733416568528,
          -12.053713603759903,
          -7.525724479592057,
          -4.108075534381278,
          -1.437199255326309,
          0.707363832114531,
          2.4670699356785626,
          3.9368514363418328,
          5.182790371115416,
          6.2523042320663045,
          7.18030098956525,
          7.993049123442368,
          8.710694657454866,
          9.348946667963924,
          9.9202350277875,
          10.434523618340513,
          10.899892974575113,
          11.32296518861433,
          11.709218744430355,
          12.06322517171286,
          12.388829268580377,
          12.689287992032662,
          12.967378667991177,
          13.225484146895502,
          13.46566043879692,
          13.689690894110274,
          13.899129952295112,
          14.09533872899032,
          14.279514164377405,
          14.452713052112943,
          14.615871968000242,
          14.769823892098676,
          14.915312147109457,
          15.053002145309225,
          15.183491335740108,
          15.30731766534243,
          15.424966806747058,
          15.536878357494496,
          15.643451177494663,
          15.745048001321244,
          15.841999437740858,
          15.934607449395497,
          16.023148389796592,
          16.10787566197248,
          16.189022052639764,
          16.266801787179638,
          16.34141234361782,
          16.413036057949448,
          16.481841548283384,
          16.54798498122128,
          16.611611200492607,
          16.67285473501332,
          16.731840701133923,
          16.788685611811925,
          16.843498103720634,
          16.896379591843417,
          16.947424859852106,
          16.99672259350108,
          17.044355863352454,
          17.0904025623599,
          17.134935803160918,
          17.178024279340065,
          17.21973259441839,
          17.260121561883622,
          17.299248479191736,
          17.337167378337263,
          17.373929255296826,
          17.4095822803954,
          17.444171991420717,
          17.477741471113784,
          17.5103315104911,
          17.541980759300532,
          17.572725864777752,
          17.602601599751846,
          17.63164098104087,
          17.659875378986072,
          17.687334618888748,
          17.71404707503941,
          17.740039757963245,
          17.765338395445667,
          17.789967507849465,
          17.813950478187266,
          17.837309617370334,
          17.86006622501703,
          17.882240646169254,
          17.903852324234695,
          17.92491985044472,
          17.9454610100924,
          17.965492825792808,
          17.985031597986833,
          18.004092942891255,
          18.02269182808113,
          18.040842605874797,
          18.05855904467852,
          18.07585435843455,
          18.092741234305276,
          18.109231858715525,
          18.12533794186539,
          18.141070740817554,
          18.156441081254748,
          18.17145937799593,
          18.186135654353105,
          18.200479560404304,
          18.214500390253125,
          18.22820709833967,
          18.241608314863154,
          18.254712360372235,
          18.267527259574834,
          18.280060754415935,
          18.29232031646805,
          18.304313158676305,
          18.316046246496903,
          18.327526308465266,
          18.338759846227664,
          18.34975314406781,
          18.360512277957852,
          18.371043124161265,
          18.381351367413277,
          18.39144250870287,
          18.401321872678835,
          18.41099461470087,
          18.42046572755544,
          18.429740047854843,
          18.43882226213678,
          18.44771691268074,
          18.456428403056226,
          18.464961003417457,
          18.473318855557615,
          18.481505977735562,
          18.489526269286774,
          18.497383515029632,
          18.505081389477724,
          18.512623460867907,
          18.520013195013615,
          18.52725395899206,
          18.53434902467373,
          18.54130157210195,
          18.548114692729932,
          18.55479139252221,
          18.56133459492717,
          18.567747143726738,
          18.57403180576924,
          18.580191273590934,
          18.586228167931463,
          18.592145040148267,
          18.597944374534592,
          18.603628590545608,
          18.60920004493687,
          18.614661033819086,
          18.62001379463307,
          18.62526050804836,
          18.630403299789066,
          18.635444242390093,
          18.64038535688685,
          18.645228614441393,
          18.649975937907733,
          18.654629203339017,
          18.659190241439024,
          18.66366083896043,
          18.668042740052076,
          18.672337647557395,
          18.676547224266095,
          18.68067309412102,
          18.684716843382077,
          18.68868002174902,
          18.692564143444717,
          18.69637068826063,
          18.700101102565938,
          18.703756800281845,
          18.70733916382245,
          18.710849545003494,
          18.71428926592031,
          18.717659619796187,
          18.720961871802217,
          18.72419725984994,
          18.72736699535761,
          18.730472263991295,
          18.733514226381686,
          18.736494018817535,
          18.73941275391668,
          18.742271521275452,
          18.745071388097287,
          18.747813399801352,
          18.75049858061188,
          18.753127934128987,
          18.755702443881617,
          18.758223073863274,
          18.760690769051195,
          18.76310645590954,
          18.765471042877188,
          18.767785420840692,
          18.77005046359294,
          18.77226702827801,
          18.774435955822693,
          18.77655807135523,
          18.77863418461163,
          18.78066509033003,
          18.782651568633543,
          18.78459438540197,
          18.786494292632728,
          18.788352028791437,
          18.79016831915247,
          18.791943876129803,
          18.79367939959853,
          18.795375577207324,
          18.79703308468217,
          18.798652586121666,
          18.800234734284135,
          18.801780170866877,
          18.80328952677777,
          18.804763422399507,
          18.806202467846695,
          18.807607263216056,
          18.808978398829936,
          18.810316455473362,
          18.81162200462487,
          18.812895608681234,
          18.814137821176402,
          18.8153491869947,
          18.816530242578587,
          18.817681516131092,
          18.818803527813106,
          18.819896789935676,
          18.820961807147487,
          18.821999076617672,
          18.823009088214082,
          18.823992324677185,
          18.82494926178969,
          18.825880368542087,
          18.826786107294158,
          18.82766693393265,
          18.82852329802519,
          18.829355642970548,
          18.830164406145407,
          18.83095001904771,
          18.831712907436675,
          18.832453491469632,
          18.83317218583573,
          18.833869399886623,
          18.834545537764257,
          18.835200998525785,
          18.835836176265758,
          18.836451460235637,
          18.837047234960714,
          18.837623880354542,
          18.838181771830907,
          18.838721280413466,
          18.839242772843082,
          18.83974661168294,
          18.84023315542152,
          18.840702758573467,
          18.84115577177847,
          18.841592541898144,
          18.842013412111026,
          18.842418722005718,
          18.842808807672274,
          18.843184001791805,
          18.843544633724427,
          18.84389102959561,
          18.844223512380893,
          18.844542401989102,
          18.844848015344102,
          18.845140666465074,
          18.845420666545436,
          18.845688324030405,
          18.845943944693246,
          18.846187831710296,
          18.846420285734713,
          18.846641604969104,
          18.846852085236954,
          18.84705202005301,
          18.847241700692543,
          18.84742141625961,
          18.84759145375433,
          18.847752098139157,
          18.847903632404275,
          18.848046337632066,
          18.84818049306072,
          18.848306376147036,
          18.84842426262839,
          18.848534426583964,
          18.84863714049521,
          18.848732675305634,
          18.848821300479855,
          18.848903284062065,
          18.8489788927338,
          18.849048391871168,
          18.84911204560148,
          18.849170116859312,
          18.8492228674421,
          18.849270558065196,
          18.84931344841645,
          18.84935179721039,
          18.84938586224194,
          18.849415900439762,
          18.8494421679192,
          18.849464920034908,
          18.849484411433128,
          18.849500896103663,
          18.849514627431585,
          18.84952585824866,
          18.84953484088457,
          18.849541827217873,
          18.849547068726828,
          18.849550816539995,
          18.849553321486727,
          18.8495548341475,
          18.84955560490418,
          18.849555883990146,
          18.849555921540425,
          18.84955596764171,
          18.849556272382404,
          18.849557085902664,
          18.849558658444426,
          18.849561240401542,
          18.849565082369907,
          18.84957043519773,
          18.849577550035878,
          18.849586678388363,
          18.849598072162983,
          18.849611983722124,
          18.849628665933757,
          18.84964837222267,
          18.849671356621908,
          18.8496978738245,
          18.849728179235445,
          18.849762529024034,
          18.849801180176478,
          18.84984439054888,
          18.849892418920618,
          18.849945525048085,
          18.850003969718884,
          18.85006801480645,
          18.850137923325157,
          18.850213959485924,
          18.850296388752316,
          18.850385477897234,
          18.850481495060155,
          18.85058470980497,
          18.850695393178466,
          18.85081381776945,
          18.85094025776856,
          18.851074989028806,
          18.851218289126823,
          18.851370437424908,
          18.85153171513388,
          18.85170240537673,
          18.85188279325317,
          18.85207316590508,
          18.852273812582837,
          18.852485024712685,
          18.852707095965027,
          18.852940322323807,
          18.853185002156916,
          18.853441436287746,
          18.853709928067858,
          18.853990783450847,
          18.854284311067417,
          18.85459082230175,
          18.854910631369133,
          18.85524405539499,
          18.85559141449525,
          18.855953031858203,
          18.856329233827793,
          18.85672034998849,
          18.857126713251702,
          18.857548659943866,
          18.85798652989616,
          18.858440666536,
          18.858911416980323,
          18.859399132130704,
          18.859904166770374,
          18.86042687966323,
          18.86096763365485,
          18.861526795775607,
          18.862104737345934,
          18.862701834083833,
          18.86331846621463,
          18.863955018583155,
          18.86461188076832,
          18.865289447200205,
          18.86598811727978,
          18.866708295501248,
          18.867450391577172,
          18.868214820566454,
          18.869002003005225,
          18.869812365040758,
          18.87064633856852,
          18.87150436137242,
          18.872386877268386,
          18.87329433625135,
          18.874227194645787,
          18.875185915259866,
          18.87617096754337,
          18.87718282774952,
          18.878221979100744,
          18.879288911958607,
          18.880384123998017,
          18.881508120385785,
          18.882661413963756,
          18.883844525436608,
          18.88505798356449,
          18.88630232536067,
          18.887578096294313,
          18.888885850498596,
          18.89022615098433,
          18.89159956985926,
          18.893006688553214,
          18.894448098049352,
          18.895924399121647,
          18.897436202578856,
          18.898984129515185,
          18.900568811567858,
          18.902190891181863,
          18.903851021882065,
          18.90554986855297,
          18.907288107726416,
          18.909066427877427,
          18.910885529728528,
          18.912746126562826,
          18.914648944546148,
          18.916594723058537,
          18.918584215035512,
          18.92061818731929,
          18.922697421020484,
          18.92482271189057,
          18.92699487070547,
          18.929214723660753,
          18.931483112778775,
          18.933800896328265,
          18.93616894925676,
          18.938588163636382,
          18.941059449123472,
          18.94358373343251,
          18.946161962824988,
          18.94879510261364,
          18.95148413768275,
          18.95423007302503,
          18.95703393429577,
          18.959896768384887,
          18.962819644007585,
          18.96580365231429,
          18.96884990752069,
          18.971959547558566,
          18.97513373474833,
          18.978373656494053,
          18.981680526001877,
          18.98505558302282,
          18.98850009462082,
          18.992015355967176,
          18.995602691162343,
          18.99926345408626,
          19.002999029278385,
          19.006810832848572,
          19.010700313420205,
          19.01466895310684,
          19.018718268523752,
          19.022849811835968,
          19.02706517184417,
          19.031365975110244,
          19.03575388712409,
          19.040230613513472,
          19.044797901298846,
          19.049457540195068,
          19.054211363962057,
          19.059061251806654,
          19.06400912983782,
          19.069056972577734,
          19.074206804531162,
          19.079460701815858,
          19.08482079385674,
          19.09028926514676,
          19.095868357077624,
          19.10156036984352,
          19.107367664421417,
          19.113292664631448,
          19.119337859281202,
          19.125505804397996,
          19.131799125553364,
          19.138220520284186,
          19.14477276061526,
          19.15145869568827,
          19.15828125450243,
          19.165243448772433,
          19.172348375909536,
          19.17959922213211,
          19.186999265712174,
          19.19455188036497,
          19.202260538788995,
          19.210128816364318,
          19.218160395017524,
          19.22635906726208,
          19.234728740423567,
          19.24327344105965,
          19.251997319585385,
          19.260904655115116,
          19.269999860532778,
          19.279287487803433,
          19.28877223353945,
          19.298458944835698,
          19.3083526253891,
          19.318458441918793,
          19.3287817309043,
          19.33932800566029,
          19.350102963767608,
          19.361112494881855,
          19.37236268894187,
          19.383859844802426,
          19.39561047931692,
          19.407621336897435,
          19.41989939958214,
          19.43245189764124,
          19.44528632075581,
          19.458410429805717,
          19.471832269305718,
          19.485560180531845,
          19.49960281538306,
          19.51396915102676,
          19.528668505380367,
          19.543710553485102,
          19.55910534483271,
          19.574863321710314,
          19.590995338633984,
          19.60751268294719,
          19.62442709666623,
          19.64175079966193,
          19.659496514273695,
          19.67767749146035,
          19.696307538600994,
          19.71540104906833,
          19.734973033708137,
          19.755039154369456,
          19.77561575964322,
          19.79671992298097,
          19.818369483380387,
          19.840583088842017,
          19.863380242819556,
          19.88678135390729,
          19.91080778903095,
          19.93548193043351,
          19.96082723677579,
          19.986868308702597,
          20.013630959259938,
          20.041142289587295,
          20.069430770351634,
          20.09852632943813,
          20.128460446465464,
          20.159266254753565,
          20.1909786514386,
          20.223634416504638,
          20.257272341586294,
          20.291933369490803,
          20.327660745495052,
          20.36450018159362,
          20.40250003500957,
          20.441711502434632,
          20.48218883163972,
          20.523989552294957,
          20.567174728066128,
          20.61180923230984,
          20.657962049986708,
          20.705706608747736,
          20.755121142536304,
          20.80628909149386,
          20.859299542469305,
          20.91424771502469,
          20.97123549851564,
          21.03037204661946,
          21.09177443661094,
          21.155568401763876,
          21.22188914651957,
          21.290882255544297,
          21.362704709538054,
          21.43752602271282,
          21.515529519287824,
          21.59691376923585,
          21.68189420695196,
          21.770704960623235,
          21.86360092500837,
          21.9608601162682,
          22.06278635466304,
          22.16971232963999,
          22.282003112446453,
          22.40006019440556,
          22.52432614497577,
          22.65529000348519,
          22.793493542994014,
          22.939538575423864,
          23.094095505653886,
          23.25791339101572,
          23.43183182461126,
          23.616795040250835,
          23.813868739155026,
          24.024260271524554,
          24.249342980165043,
          24.490685743212307,
          24.750089059214627,
          25.02962942965089,
          25.33171435349946,
          25.659151017004675,
          26.01523282984185,
          26.40384946201076,
          26.829628180248122,
          27.298117387736156,
          27.81602783942047,
          28.39155384623549,
          29.034807224403142,
          29.75841302870201,
          30.578342100439333,
          31.515098050620168,
          32.59544816291965,
          33.85501304587973,
          35.342256897563104,
          37.124849714261664,
          39.30022728844329,
          42.01397955839009,
          45.49379230496486,
          50.11680887937424,
          56.55633972105906,
          66.14360143722647,
          81.93103172221785,
          112.80285214166373,
          200.13693701479804,
          null,
          -203.3690210636809,
          -87.62997697231184,
          -51.53903192002832,
          -33.92791394995034,
          -23.49707206831257,
          -16.599439757150176,
          -11.700249931998915,
          -8.041209243894645,
          -5.204587588663038,
          -2.941326613371505,
          -1.0937123575820955,
          0.4429842944454023,
          1.7410342809948158,
          2.8519206401539527,
          3.813311346529291,
          4.653401938223322,
          5.393716961263406,
          6.0509727150590376,
          6.638348848510914,
          7.166376682489245,
          7.64357258888959,
          8.076897891428477,
          8.47209830178848,
          8.833958164279274,
          9.166493452329359,
          9.473100066315268,
          9.756669061604843,
          10.019677102011542,
          10.264258138105308,
          10.492260704967176,
          10.705294096450857,
          10.904765856355656,
          11.091912433623012,
          11.267824412849844,
          11.433467407964482,
          11.589699464543338,
          11.73728563296632,
          11.876910234864244,
          12.009187237877716,
          12.134669070549197,
          12.253854144278444,
          12.367193298311024,
          12.475095343463257,
          12.577931848272609,
          12.676041285663166,
          12.769732637639077,
          12.859288538885309,
          12.944968026650235,
          13.027008953263465,
          13.105630108607798,
          13.181033092429864,
          13.25340397022495,
          13.322914741331443,
          13.389724643620596,
          13.453981315613362,
          13.515821833876693,
          13.575373641040366,
          13.632755377656931,
          13.688077629331495,
          13.741443599021459,
          13.792949713107195,
          13.842686168721903,
          13.890737428877301,
          13.937182671103523,
          13.98209619461611,
          14.025547790415608,
          14.067603078197632,
          14.108323813494238,
          14.147768168071842,
          14.185990986262244,
          14.223044019603739,
          14.258976141903442,
          14.293833546600258,
          14.327659928105861,
          14.360496648619764,
          14.392382891758954,
          14.423355804201911,
          14.453450626423573,
          14.482700813489917,
          14.511138146781885,
          14.538792837434288,
          14.565693622197415,
          14.59186785236089,
          14.617341576319268,
          14.642139616302675,
          14.66628563974867,
          14.689802225746694,
          14.712710926947203,
          14.735032327293277,
          14.756786095899106,
          14.777991037372725,
          14.798665138853575,
          14.818825614012162,
          14.8384889442389,
          14.857670917228704,
          14.87638666315199,
          14.894650688586204,
          14.912476908367829,
          14.929878675512533,
          14.946868809338199,
          14.963459621916,
          14.979662942964172,
          14.99549014329033,
          15.010952156880302,
          15.026059501723685,
          15.040822299459597,
          15.05525029392001,
          15.069352868641948,
          15.083139063415114,
          15.096617589926145,
          15.109796846556632,
          15.122684932387843,
          15.135289660461227,
          15.147618570340576,
          15.159678940018338,
          15.171477797205556,
          15.183021930042653,
          15.194317897265064,
          15.205372037856126,
          15.216190480217016,
          15.226779150881622,
          15.237143782802756,
          15.247289923233756,
          15.257222941228639,
          15.266948034782056,
          15.276470237629,
          15.28579442572328,
          15.294925323412016,
          15.303867509322952,
          15.31262542197992,
          15.321203365160935,
          15.329605513012813,
          15.337835914934843,
          15.345898500243795,
          15.35379708263158,
          15.361535364426091,
          15.369116940665574,
          15.37654530299567,
          15.383823843398318,
          15.39095585776084,
          15.39794454929306,
          15.404793031800176,
          15.411504332818204,
          15.418081396618842,
          15.424527087090043,
          15.430844190498151,
          15.437035418137441,
          15.44310340887218,
          15.44905073157641,
          15.454879887476205,
          15.46059331239884,
          15.466193378933298,
          15.471682398506063,
          15.47706262337611,
          15.482336248552755,
          15.487505413639749,
          15.49257220460903,
          15.497538655507144,
          15.502406750097379,
          15.507178423440369,
          15.511855563415889,
          15.51644001218836,
          15.520933567618522,
          15.525337984623487,
          15.529654976487507,
          15.533886216125381,
          15.53803333730062,
          15.542097935800173,
          15.546081570567539,
          15.549985764796032,
          15.553812006983735,
          15.557561751951788,
          15.561236421827477,
          15.564837406993483,
          15.568366067004773,
          15.571823731474272,
          15.575211700928671,
          15.578531247635505,
          15.581783616402586,
          15.584970025350968,
          15.58809166666237,
          15.591149707302087,
          15.594145289718353,
          15.597079532518986,
          15.599953531126259,
          15.60276835841075,
          15.605525065304995,
          15.608224681397715,
          15.610868215509262,
          15.613456656249106,
          15.615990972555888,
          15.618472114220774,
          15.620901012394677,
          15.623278580079926,
          15.625605712606987,
          15.627883288096703,
          15.63011216790864,
          15.632293197075994,
          15.634427204727523,
          15.636515004497012,
          15.638557394920657,
          15.640555159822812,
          15.6425090686905,
          15.644419877037087,
          15.646288326755458,
          15.648115146461109,
          15.64990105182544,
          15.651646745899637,
          15.653352919429407,
          15.655020251160927,
          15.65664940813826,
          15.658241045992542,
          15.659795809223217,
          15.661314331471575,
          15.662797235786838,
          15.66424513488508,
          15.66565863140114,
          15.667038318133852,
          15.66838477828472,
          15.669698585690307,
          15.670980305048534,
          15.67223049213904,
          15.673449694037867,
          15.674638449326578,
          15.675797288296042,
          15.676926733145022,
          15.678027298173724,
          15.679099489972517,
          15.680143807605903,
          15.681160742791942,
          15.68215078007726,
          15.683114397007738,
          15.68405206429511,
          15.684964245979458,
          15.685851399587891,
          15.686713976289383,
          15.687552421045964,
          15.688367172760394,
          15.68915866442034,
          15.68992732323926,
          15.690673570794038,
          15.691397823159472,
          15.692100491039735,
          15.692781979896893,
          15.693442690076536,
          15.694083016930671,
          15.694703350937903,
          15.695304077821014,
          15.695885578662018,
          15.696448230014767,
          15.696992404015162,
          15.697518468489084,
          15.698026787058058,
          15.698517719242782,
          15.69899162056452,
          15.699448842644488,
          15.69988973330123,
          15.700314636646107,
          15.700723893176903,
          15.701117839869648,
          15.701496810268676,
          15.701861134575006,
          15.702211139733077,
          15.702547149515876,
          15.702869484608556,
          15.70317846269053,
          15.703474398516144,
          15.703757603993926,
          15.704028388264495,
          15.70428705777715,
          15.704533916365182,
          15.704769265319978,
          15.704993403463895,
          15.705206627222024,
          15.705409230692819,
          15.705601505717642,
          15.705783741949293,
          15.705956226919515,
          15.706119246105535,
          15.706273082995674,
          15.706418019154048,
          15.7065543342844,
          15.706682306293096,
          15.706802211351315,
          15.706914323956449,
          15.707018916992777,
          15.707116261791404,
          15.707206628189516,
          15.707290284588977,
          15.70736749801429,
          15.707438534169949,
          15.707503657497217,
          15.707563131230348,
          15.707617217452285,
          15.707666177149845,
          15.707710270268446,
          15.707749755766365,
          15.707784891668577,
          15.707815935120188,
          15.707843142439486,
          15.707866769170652,
          15.707887070136104,
          15.707904299488566,
          15.707918710762836,
          15.707930556927279,
          15.707940090435095,
          15.707947563275356,
          15.707953227023854,
          15.707957332893757,
          15.707960131786129,
          15.707961874340299,
          15.70796281098414,
          15.707963191984236,
          15.707963267495991,
          15.707963287613698,
          15.707963502420565,
          15.707964162038747,
          15.707965516679398,
          15.707967816692749,
          15.707971312618257,
          15.70797625523483,
          15.70798289561114,
          15.707991485156096,
          15.708002275669418,
          15.70801551939241,
          15.7080314690589,
          15.70805037794641,
          15.708072499927546,
          15.708098089521641,
          15.708127401946683,
          15.708160693171541,
          15.708198219968507,
          15.708240239966194,
          15.7082870117028,
          15.70833879467976,
          15.708395849415812,
          15.708458437501525,
          15.708526821654266,
          15.708601265773677,
          15.708682034997654,
          15.70876939575888,
          15.708863615841919,
          15.7089649644409,
          15.709073712217837,
          15.709190131361575,
          15.709314495647446,
          15.709447080497586,
          15.709588163042028,
          15.709738022180533,
          15.709896938645228,
          15.710065195064056,
          15.710243076025098,
          15.710430868141769,
          15.710628860118945,
          15.710837342820039,
          15.711056609335069,
          15.711286955049747,
          15.71152867771563,
          15.711782077521375,
          15.71204745716511,
          15.712325121927993,
          15.712615379748986,
          15.71291854130087,
          15.71323492006756,
          15.713564832422769,
          15.713908597710025,
          15.71426653832415,
          15.71463897979418,
          15.715026250867824,
          15.715428683597489,
          15.715846613427912,
          15.716280379285477,
          15.716730323669248,
          15.71719679274378,
          15.717680136433756,
          15.718180708520537,
          15.718698866740635,
          15.71923497288622,
          15.719789392907687,
          15.72036249701837,
          15.720954659801453,
          15.721566260319179,
          15.722197682224367,
          15.722849313874384,
          15.723521548447595,
          15.724214784062374,
          15.724929423898796,
          15.725665876323038,
          15.726424555014608,
          15.727205879096495,
          15.728010273268293,
          15.728838167942449,
          15.729689999383673,
          15.730566209851665,
          15.73146724774721,
          15.732393567761804,
          15.733345631030863,
          15.734323905290685,
          15.735328865039238,
          15.736360991700925,
          15.737420773795447,
          15.738508707110881,
          15.73962529488112,
          15.740771047967833,
          15.741946485047043,
          15.74315213280052,
          15.74438852611213,
          15.745656208269283,
          15.746955731169678,
          15.748287655533483,
          15.749652551121178,
          15.75105099695719,
          15.752483581559552,
          15.753950903175786,
          15.755453570025182,
          15.756992200547737,
          15.758567423659938,
          15.760179879017644,
          15.761830217286288,
          15.763519100418678,
          15.765247201940623,
          15.767015207244665,
          15.768823813892222,
          15.770673731924388,
          15.772565684181723,
          15.774500406633337,
          15.776478648715603,
          15.778501173680818,
          15.780568758956178,
          15.782682196513454,
          15.784842293249698,
          15.787049871379429,
          15.789305768838691,
          15.791610839701402,
          15.793965954608469,
          15.7963720012101,
          15.79882988462185,
          15.801340527894837,
          15.803904872500745,
          15.806523878832067,
          15.809198526718243,
          15.811929815958251,
          15.814718766870271,
          15.817566420859105,
          15.820473841001988,
          15.823442112653549,
          15.82647234407062,
          15.829565667057688,
          15.832723237633799,
          15.835946236721734,
          15.83923587086039,
          15.84259337294122,
          15.84602000296975,
          15.849517048853171,
          15.853085827215022,
          15.85672768423813,
          15.860443996536914,
          15.864236172060272,
          15.86810565102635,
          15.872053906890448,
          15.876082447347557,
          15.880192815370862,
          15.884386590287859,
          15.888665388895578,
          15.893030866616686,
          15.897484718698163,
          15.90202868145443,
          15.906664533556894,
          15.911394097371884,
          15.9162192403492,
          15.921141876463464,
          15.926163967710671,
          15.931287525662436,
          15.9365146130805,
          15.941847345594352,
          15.947287893444738,
          15.952838483296217,
          15.958501400121929,
          15.964278989163947,
          15.97017365797284,
          15.976187878530126,
          15.982324189457676,
          15.988585198318185,
          15.994973584011156,
          16.001492099269072,
          16.008143573258653,
          16.014930914292457,
          16.021857112656257,
          16.02892524355807,
          16.03613847020499,
          16.043500047014284,
          16.051013322965748,
          16.058681745102486,
          16.066508862188012,
          16.074498328527756,
          16.08265390796371,
          16.090979478051462,
          16.099479034429397,
          16.108156695390473,
          16.11701670666759,
          16.126063446444345,
          16.13530143060364,
          16.14473531822739,
          16.154369917361535,
          16.16421019106137,
          16.1742612637332,
          16.18452842778955,
          16.195017150635955,
          16.205733082008983,
          16.216682061686157,
          16.227870127589963,
          16.23930352430973,
          16.25098871206661,
          16.262932376148964,
          16.275141436846987,
          16.287623059917923,
          16.30038466761498,
          16.31343395031591,
          16.326778878789526,
          16.340427717141374,
          16.354389036482953,
          16.368671729371936,
          16.383285025074777,
          16.398238505706832,
          16.413542123309327,
          16.429206217927437,
          16.445241536758413,
          16.461659254444626,
          16.47847099459195,
          16.495688852600914,
          16.51332541990491,
          16.53139380971767,
          16.549907684400925,
          16.568881284572278,
          16.58832946008398,
          16.608267703014278,
          16.628712182825588,
          16.649679783857476,
          16.671188145337148,
          16.69325570410721,
          16.715901740288146,
          16.739146426113656,
          16.763010878199008,
          16.787517213527178,
          16.812688609465283,
          16.838549368153597,
          16.865124985643618,
          16.89244222619888,
          16.92052920221383,
          16.949415460252936,
          16.97913207376361,
          17.009711743075165,
          17.041188903360347,
          17.073599841309345,
          17.10698282134775,
          17.1413782223216,
          17.17682868567686,
          17.21337927627662,
          17.251077657131958,
          17.289974279471394,
          17.330122589742896,
          17.371579255335327,
          17.414404411023963,
          17.458661928395017,
          17.50441971078777,
          17.55175001661964,
          17.60072981433252,
          17.65144117262798,
          17.70397169015397,
          17.758414969375373,
          17.814871140021864,
          17.873447438271686,
          17.93425884871996,
          17.997428817218534,
          18.06309004388576,
          18.131385367007027,
          18.202468750215626,
          18.27650638731349,
          18.353677941418294,
          18.434177937884353,
          18.518217333731506,
          18.606025290238573,
          18.697851180062084,
          18.79396686589687,
          18.894669294526437,
          19.000283458395312,
          19.111165786919766,
          19.227708042091216,
          19.350341808081474,
          19.479543683275544,
          19.615841306380197,
          19.759820377230422,
          19.91213286926861,
          20.073506676543865,
          20.24475699633735,
          20.426799822981145,
          20.62066802427842,
          20.827530596197043,
          21.04871585387184,
          21.285739530868252,
          21.540339042962167,
          21.814515554110578,
          22.110585999118165,
          22.43124792536896,
          22.779660996706653,
          23.159550378180448,
          23.575339175930836,
          24.0323199269276,
          24.536879265590734,
          25.09679605347108,
          25.72164261236122,
          26.423333204725978,
          27.216886912881286,
          28.121509506383305,
          29.16216156544138,
          30.371888485444714,
          31.795382271938518,
          33.49460827293693,
          35.558042897612445,
          38.116549729379244,
          41.37221686850193,
          45.654444925017884,
          51.53894501680889,
          60.13089627427864,
          73.8553487618664,
          99.26623036156215,
          162.34579535047897,
          null,
          null,
          -107.0209840053114,
          -61.31746017135638,
          -40.65436548513689,
          -28.878824507236516,
          -21.272320694590306,
          -15.954267721744863,
          -12.027309479940346,
          -9.009021280339752,
          -6.616933847460631,
          -4.674663222390501,
          -3.06638310421015,
          -1.7128902369634815,
          -0.5581900086331384,
          0.43842423908360395,
          1.3072553397788944,
          2.0713264530157875,
          2.7484432195910227,
          3.3525925117672593,
          3.894914098217944,
          4.384389993831153,
          4.828342771380454,
          5.232801873862508,
          5.602776996004971,
          5.942464924351192,
          6.255407994914152,
          6.544616876425849,
          6.8126667104651135,
          7.0617731179796985,
          7.293852825397932,
          7.510572422908318,
          7.713387879653129,
          7.903576797466879,
          8.08226491368781,
          8.25044801482347,
          8.40901016214811,
          8.558738933626866,
          8.700338236888932,
          8.834439133157293,
          8.961609023283888,
          9.082359477933664,
          9.197152939789133,
          9.306408482902839,
          9.41050678039871,
          9.509794404630348,
          9.6045875621572,
          9.695175348344716,
          9.781822592156573,
          9.864772350104198,
          9.94424809881622,
          10.02045566787981,
          10.093584948153518,
          10.163811405402793,
          10.23129742465914,
          10.296193506984109,
          10.3586393372041,
          10.41876473855869,
          10.476690527994096,
          10.53252928395965,
          10.586386036974858,
          10.638358891880937,
          10.688539589533088,
          10.737014014700197,
          10.783862656087724,
          10.829161023667394,
          10.872980027866266,
          10.915386324620428,
          10.956442629825904,
          10.996208006306695,
          11.034738126062452,
          11.07208551024485,
          11.108299749038409,
          11.143427703382262,
          11.177513690258465,
          11.210599653088053,
          11.242725318612745,
          11.273928341496376,
          11.304244437753333,
          11.333707507998094,
          11.362349751410768,
          11.390201771224103,
          11.417292672459098,
          11.443650152565608,
          11.46930058556158,
          11.494269100208747,
          11.518579652711935,
          11.542255094384553,
          11.565317234682242,
          11.587786899970324,
          11.609683988358347,
          11.631027520905198,
          11.651835689472234,
          11.672125901477443,
          11.691914821782454,
          11.711218411924381,
          11.730051966886727,
          11.748430149587772,
          11.766367023249858,
          11.783876081800091,
          11.800970278440717,
          11.817662052516345,
          11.833963354795518,
          11.849885671274539,
          11.865440045603547,
          11.880637100226831,
          11.895487056322706,
          11.909999752621676,
          11.924184663175813,
          11.938050914146988,
          11.951607299676501,
          11.964862296894308,
          11.977824080121756,
          11.990500534317897,
          12.002899267816069,
          12.015027624393964,
          12.026892694717652,
          12.038501327196993,
          12.049860138287574,
          12.060975522271773,
          12.071853660549413,
          12.082500530466506,
          12.0929219137086,
          12.103123404283664,
          12.113110416117674,
          12.122888190284684,
          12.13246180189175,
          12.141836166637772,
          12.151016047064141,
          12.16000605851396,
          12.168810674815578,
          12.177434233705215,
          12.185880942002523,
          12.194154880552167,
          12.20226000894364,
          12.210200170020862,
          12.217979094192433,
          12.225600403552686,
          12.233067615823256,
          12.240384148124123,
          12.247553320582803,
          12.254578359789596,
          12.261462402106638,
          12.268208496837852,
          12.274819609266574,
          12.281298623567325,
          12.287648345597699,
          12.293871505576151,
          12.29997076065106,
          12.305948697366208,
          12.311807834027512,
          12.317550622975597,
          12.323179452768573,
          12.328696650279108,
          12.334104482709737,
          12.339405159530084,
          12.344600834339506,
          12.349693606658526,
          12.354685523652183,
          12.359578581788323,
          12.364374728433688,
          12.369075863390485,
          12.373683840376069,
          12.378200468448137,
          12.382627513377788,
          12.38696669897267,
          12.391219708352319,
          12.395388185177705,
          12.39947373483688,
          12.40347792558859,
          12.40740228966554,
          12.411248324339013,
          12.41501749294638,
          12.418711225883046,
          12.422330921560249,
          12.42587794733006,
          12.429353640378944,
          12.432759308591084,
          12.43609623138269,
          12.439365660508408,
          12.44256882084094,
          12.445706911124912,
          12.448781104705962,
          12.451792550236023,
          12.45474237235572,
          12.457631672354696,
          12.460461528810791,
          12.463232998208767,
          12.465947115539436,
          12.46860489487985,
          12.471207329955302,
          12.473755394683788,
          12.47625004370356,
          12.478692212884429,
          12.481082819823344,
          12.483422764324894,
          12.485712928867194,
          12.487954179053741,
          12.4901473640517,
          12.492293317017124,
          12.494392855507563,
          12.496446781882481,
          12.498455883691953,
          12.500420934054016,
          12.502342692021058,
          12.504221902935665,
          12.506059298776245,
          12.507855598492801,
          12.509611508333183,
          12.51132772216014,
          12.513004921759475,
          12.514643777139627,
          12.516244946822933,
          12.517809078128865,
          12.519336807449514,
          12.520828760517572,
          12.52228555266703,
          12.523707789086895,
          12.525096065068087,
          12.526450966243772,
          12.52777306882335,
          12.529062939820275,
          12.53032113727393,
          12.53154821046574,
          12.532744700129696,
          12.533911138657487,
          12.535048050298396,
          12.536155951354143,
          12.537235350368794,
          12.538286748313956,
          12.53931063876934,
          12.540307508098882,
          12.541277835622543,
          12.542222093783904,
          12.543140748313741,
          12.544034258389633,
          12.544903076791789,
          12.545747650055164,
          12.546568418618003,
          12.547365816966924,
          12.548140273778618,
          12.54889221205831,
          12.54962204927505,
          12.55033019749393,
          12.551017063505343,
          12.551683048951359,
          12.552328550449294,
          12.552953959712584,
          12.553559663669024,
          12.554146044576456,
          12.554713480135995,
          12.555262343602847,
          12.555793003894815,
          12.556305825698539,
          12.55680116957356,
          12.55727939205426,
          12.557740845749747,
          12.558185879441739,
          12.55861483818054,
          12.559028063379117,
          12.559425892905363,
          12.559808661172623,
          12.560176699228478,
          12.560530334841904,
          12.560869892588812,
          12.561195693936035,
          12.561508057323824,
          12.56180729824686,
          12.562093729333876,
          12.562367660425902,
          12.56262939865319,
          12.562879248510844,
          12.563117511933225,
          12.56334448836715,
          12.563560474843921,
          12.56376576605025,
          12.563960654398073,
          12.564145430093342,
          12.56432038120378,
          12.56448579372567,
          12.564641951649705,
          12.564789137025908,
          12.564927630027688,
          12.565057709015054,
          12.56517965059699,
          12.565293729693076,
          12.565400219594329,
          12.565499392023332,
          12.565591517193665,
          12.56567686386866,
          12.565755699419528,
          12.565828289882862,
          12.565894900017563,
          12.565955793361194,
          12.566011232285815,
          12.566061478053296,
          12.566106790870158,
          12.56614742994195,
          12.566183653527188,
          12.5662157189909,
          12.566243882857762,
          12.566268400864892,
          12.566289528014304,
          12.56630751862502,
          12.566322626384931,
          12.566335104402352,
          12.566345205257344,
          12.566353181052811,
          12.566359283465392,
          12.566363763796165,
          12.566366873021199,
          12.566368861841964,
          12.56636998073562,
          12.566370480005224,
          12.566370609829844,
          12.566370620314638,
          12.566370761540883,
          12.566371283616018,
          12.566372436723675,
          12.566374471173756,
          12.566377637452556,
          12.566382186272968,
          12.566388368624782,
          12.566396435825096,
          12.566406639568878,
          12.56641923197968,
          12.566434465660532,
          12.566452593745053,
          12.566473869948783,
          12.566498548620757,
          12.566526884795362,
          12.566559134244478,
          12.566595553529947,
          12.566636400056366,
          12.566681932124265,
          12.56673240898365,
          12.566788090887968,
          12.566849239148508,
          12.566916116189262,
          12.566988985602253,
          12.567068112203401,
          12.567153762088907,
          12.567246202692191,
          12.567345702841438,
          12.567452532817738,
          12.567566964413883,
          12.567689270993824,
          12.567819727552832,
          12.567958610778382,
          12.568106199111785,
          12.568262772810629,
          12.568428614012017,
          12.568604006796654,
          12.568789237253824,
          12.568984593547277,
          12.569190365982053,
          12.569406847072292,
          12.569634331610072,
          12.56987311673527,
          12.570123502006535,
          12.570385789473374,
          12.570660283749403,
          12.570947292086805,
          12.571247124452018,
          12.571560093602725,
          12.57188651516616,
          12.572226707718778,
          12.572580992867357,
          12.572949695331543,
          12.57333314302791,
          12.573731667155585,
          12.574145602283457,
          12.574575286439067,
          12.575021061199186,
          12.575483271782176,
          12.575962267142147,
          12.576458400065023,
          12.576972027266505,
          12.57750350949206,
          12.578053211618947,
          12.57862150276039,
          12.579208756371909,
          12.579815350359935,
          12.580441667192739,
          12.581088094013758,
          12.581755022757408,
          12.582442850267443,
          12.583151978417934,
          12.583882814236985,
          12.584635770033227,
          12.585411263525206,
          12.586209717973748,
          12.587031562317389,
          12.587877231310978,
          12.588747165667533,
          12.589641812203476,
          12.590561623987341,
          12.591507060492058,
          12.59247858775094,
          12.593476678517481,
          12.594501812429106,
          12.595554476174954,
          12.596635163667877,
          12.59774437622075,
          12.598882622727258,
          12.600050419847285,
          12.60124829219706,
          12.602476772544215,
          12.603736402007925,
          12.605027730264275,
          12.606351315757042,
          12.607707725914057,
          12.609097537369356,
          12.610521336191276,
          12.61197971811672,
          12.613473288791788,
          12.615002664018993,
          12.616568470011266,
          12.618171343653003,
          12.619811932768377,
          12.621490896397162,
          12.623208905078338,
          12.624966641141727,
          12.626764799007956,
          12.62860408549701,
          12.6304852201457,
          12.632408935534341,
          12.634375977622966,
          12.636387106097411,
          12.638443094725625,
          12.640544731724564,
          12.642692820138047,
          12.644888178225965,
          12.647131639865265,
          12.649424054963113,
          12.651766289882694,
          12.654159227882122,
          12.656603769566907,
          12.659100833356513,
          12.661651355965521,
          12.664256292899918,
          12.666916618969129,
          12.669633328814328,
          12.672407437453684,
          12.675239980845168,
          12.678132016467615,
          12.681084623920691,
          12.684098905544579,
          12.687175987060066,
          12.690317018229877,
          12.693523173542095,
          12.696795652916501,
          12.700135682434773,
          12.703544515095519,
          12.707023431595074,
          12.710573741135173,
          12.71419678225855,
          12.717893923713623,
          12.721666565349441,
          12.725516139042174,
          12.729444109654434,
          12.733451976028785,
          12.737541272016955,
          12.741713567546137,
          12.745970469724092,
          12.75031362398462,
          12.754744715275177,
          12.75926546928846,
          12.763877653739886,
          12.76858307969297,
          12.773383602934704,
          12.778281125403195,
          12.783277596669874,
          12.788375015478733,
          12.79357543134519,
          12.798880946217267,
          12.804293716201997,
          12.809815953360024,
          12.815449927571573,
          12.82119796847716,
          12.827062467496534,
          12.833045879929589,
          12.839150727143126,
          12.845379598847632,
          12.851735155468415,
          12.858220130615685,
          12.864837333658478,
          12.871589652407511,
          12.878480055912416,
          12.885511597379109,
          12.892687417213319,
          12.900010746196724,
          12.907484908802493,
          12.915113326657425,
          12.922899522158286,
          12.93084712225048,
          12.938959862377576,
          12.947241590610789,
          12.955696271968083,
          12.964327992933113,
          12.973140966184898,
          12.982139535549802,
          12.991328181188058,
          13.000711525027992,
          13.010294336461781,
          13.020081538317633,
          13.030078213124087,
          13.04028960968334,
          13.050721149971482,
          13.06137843638476,
          13.072267259352381,
          13.08339360533753,
          13.094763665250058,
          13.106383843295692,
          13.118260766288387,
          13.130401293454497,
          13.142812526759162,
          13.155501821787846,
          13.168476799217995,
          13.181745356918643,
          13.19531568271836,
          13.209196267885018,
          13.223395921364187,
          13.237923784826355,
          13.25278934857717,
          13.268002468389003,
          13.283573383316606,
          13.299512734564825,
          13.315831585481392,
          13.332541442754026,
          13.349654278897182,
          13.367182556121074,
          13.385139251683094,
          13.403537884830069,
          13.42239254544924,
          13.441717924555583,
          13.461529346754382,
          13.481842804829988,
          13.502674996624929,
          13.524043364388477,
          13.54596613678955,
          13.568462373807064,
          13.591552014730095,
          13.615255929522313,
          13.639595973828996,
          13.664595047931469,
          13.690277159983763,
          13.716667493898482,
          13.743792482285908,
          13.771679884890585,
          13.800358873014847,
          13.829860120469583,
          13.860215901648333,
          13.891460197384632,
          13.923628809322473,
          13.956759483609865,
          13.990892044814167,
          14.026068541058383,
          14.062333401491186,
          14.09973360733068,
          14.138318877867174,
          14.178141872973773,
          14.219258413859507,
          14.261727724011894,
          14.305612692515956,
          14.350980162212835,
          14.397901245474877,
          14.446451670735552,
          14.496712163326336,
          14.548768864649313,
          14.602713794264954,
          14.658645360109439,
          14.716668922793863,
          14.776897420793404,
          14.839452064331919,
          14.904463106933095,
          14.972070704972284,
          15.042425877166718,
          15.115691577827425,
          15.1920438999269,
          15.27167342667811,
          15.354786753462099,
          15.44160820569102,
          15.53238178268013,
          15.627373362997792,
          15.726873213268735,
          15.83119885028746,
          15.940698315886749,
          16.055753935715906,
          16.176786647458684,
          16.304261001742354,
          16.438690960957217,
          16.58064664857089,
          16.73076223580535,
          16.88974519574673,
          17.058387209725215,
          17.237577080693384,
          17.428316098119627,
          17.63173641510736,
          17.849123149971,
          18.081941123685553,
          18.331867408762232,
          18.600831218579494,
          18.89106314393148,
          19.20515639602384,
          19.546143616387702,
          19.917594074248644,
          20.32373785684676,
          20.769626222823586,
          21.261341030726115,
          21.806271706738915,
          22.41348660613083,
          23.09423856087306,
          23.86266480567902,
          24.7367744453422,
          25.739871407598116,
          26.90265472090625,
          28.266404669700805,
          29.887971574279508,
          31.84788091749583,
          34.26408988983344,
          37.31659714745562,
          41.294407958842534,
          46.692773778991636,
          54.437126852270914,
          66.47971592526793,
          87.77042242351747,
          135.59486599054873,
          null,
          null,
          -132.36946134854296,
          -72.5132475308933,
          -47.920950669835904,
          -34.52134203799305,
          -26.090436301925102,
          -20.297313239522197,
          -16.07187059645461,
          -12.853885388213797,
          -10.321655624960396,
          -8.277271002655278,
          -6.592294222866771,
          -5.179736261781393,
          -3.978584760779192,
          -2.9447811842684057,
          -2.045714524627776,
          -1.2567301263382689,
          -0.5588427136356042,
          0.06280462509501916,
          0.6200047259622536,
          1.1222375345743423,
          1.5772106286724288,
          1.9912549252437763,
          2.369618902353743,
          2.7166904563569663,
          3.0361663414655498,
          3.331183092949412,
          3.6044192757349096,
          3.858176127342084,
          4.094441740249274,
          4.314942574580875,
          4.521185126020685,
          4.7144898762425145,
          4.896019143537157,
          5.066800075058896,
          5.227743741524749,
          5.379661083998337,
          5.52327630202135,
          5.659238149573497,
          5.788129510615441,
          5.91047555234359,
          6.0267506966691915,
          6.137384605050502,
          6.242767335831942,
          6.343253804566901,
          6.439167654804518,
          6.5308046282896415,
          6.618435508509803,
          6.70230869930137,
          6.782652490233194,
          6.8596770522743515,
          6.9335762004820465,
          7.004528954835648,
          7.072700925679378,
          7.138245546345088,
          7.201305172265535,
          7.262012063150699,
          7.320489262488316,
          7.376851386677265,
          7.4312053344438205,
          7.483650925780102,
          7.534281478440777,
          7.58318432900273,
          7.630441304609427,
          7.676129150760584,
          7.720319919851978,
          7.763081324603901,
          7.804477060024615,
          7.844567097129664,
          7.883407951265587,
          7.921052927563741,
          7.957552345766373,
          7.9929537464193565,
          8.02730208020906,
          8.060639882028974,
          8.09300743119417,
          8.124442899072717,
          8.15498248527204,
          8.184660543402435,
          8.21350969733634,
          8.24156094879127,
          8.268843776982228,
          8.295386231017638,
          8.321215015647734,
          8.34635557091677,
          8.370832146218898,
          8.39466786921096,
          8.417884809994309,
          8.440504040940247,
          8.462545692500097,
          8.484029005311065,
          8.504972378881366,
          8.52539341711401,
          8.545308970905955,
          8.56473517803971,
          8.58368750056598,
          8.602180759859477,
          8.620229169515326,
          8.637846366239465,
          8.655045438874481,
          8.671838955690852,
          8.688238990063253,
          8.704257144642487,
          8.71990457412473,
          8.735192006712294,
          8.750129764352675,
          8.764727781836369,
          8.778995624827829,
          8.792942506898363,
          8.80657730562501,
          8.819908577814434,
          8.832944573906968,
          8.845693251611797,
          8.858162288820736,
          8.870359095844814,
          8.882290827014637,
          8.893964391682935,
          8.90538646466479,
          8.916563496148902,
          8.927501721110877,
          8.93820716825745,
          8.948685668528766,
          8.958942863183914,
          8.968984211493426,
          8.978814998060841,
          8.988440339793984,
          8.997865192545467,
          9.00709435744048,
          9.016132486909012,
          9.024984090438421,
          9.03365354006142,
          9.04214507559355,
          9.050462809633373,
          9.058610732337891,
          9.066592715984822,
          9.074412519332824,
          9.082073791790013,
          9.089580077400507,
          9.09693481865828,
          9.104141360156907,
          9.111202952083477,
          9.1181227535643,
          9.12490383586976,
          9.13154918548519,
          9.138061707054188,
          9.144444226200644,
          9.150699492235143,
          9.156830180751346,
          9.16283889611749,
          9.168728173867903,
          9.174500482999253,
          9.180158228175863,
          9.185703751848337,
          9.191139336289408,
          9.196467205550775,
          9.201689527344513,
          9.206808414852388,
          9.211825928466341,
          9.216744077463122,
          9.22156482161602,
          9.226290072746421,
          9.230921696217772,
          9.2354615123745,
          9.239911297928176,
          9.24427278729323,
          9.248547673874311,
          9.252737611307355,
          9.256844214656292,
          9.260869061567222,
          9.264813693381855,
          9.26867961621184,
          9.272468301975621,
          9.27618118939936,
          9.279819684983297,
          9.283385163935039,
          9.286878971071024,
          9.290302421687475,
          9.293656802401994,
          9.296943371967023,
          9.300163362056207,
          9.303317978024738,
          9.3064083996447,
          9.309435781816351,
          9.312401255256272,
          9.315305927163283,
          9.318150881862922,
          9.32093718143135,
          9.323665866299404,
          9.326337955837568,
          9.328954448922563,
          9.331516324486218,
          9.33402454204731,
          9.336480042226937,
          9.338883747248088,
          9.341236561419931,
          9.343539371607394,
          9.345793047686554,
          9.347998442986352,
          9.350156394717109,
          9.35226772438631,
          9.354333238202107,
          9.356353727464967,
          9.358329968947885,
          9.360262725265544,
          9.362152745232823,
          9.364000764212996,
          9.365807504455995,
          9.367573675427066,
          9.36929997412614,
          9.370987085398237,
          9.372635682235217,
          9.374246426069124,
          9.37581996705748,
          9.377356944360695,
          9.378857986411962,
          9.380323711179795,
          9.381754726423498,
          9.383151629941793,
          9.384515009814807,
          9.385845444639665,
          9.38714350375987,
          9.388409747488671,
          9.389644727326642,
          9.390848986173609,
          9.392023058535152,
          9.393167470723819,
          9.394282741055246,
          9.395369380039318,
          9.396427890566542,
          9.397458768089798,
          9.398462500801571,
          9.39943956980684,
          9.400390449291748,
          9.401315606688184,
          9.402215502834396,
          9.40309059213177,
          9.403941322697891,
          9.404768136515985,
          9.405571469580876,
          9.406351752041543,
          9.407109408340402,
          9.407844857349392,
          9.408558512502974,
          9.409250781928142,
          9.409922068571511,
          9.410572770323617,
          9.411203280140455,
          9.411813986162395,
          9.41240527183051,
          9.412977516000424,
          9.413531093053741,
          9.414066373007136,
          9.414583721619163,
          9.415083500494873,
          9.415566067188292,
          9.416031775302821,
          9.416480974589632,
          9.41691401104412,
          9.417331227000464,
          9.417732961224345,
          9.418119549003915,
          9.41849132223902,
          9.418848609528768,
          9.41919173625748,
          9.419521024679067,
          9.419836793999908,
          9.42013936046023,
          9.420429037414085,
          9.420706135407949,
          9.420970962257963,
          9.421223823125908,
          9.421465020593915,
          9.421694854737959,
          9.421913623200197,
          9.42212162126016,
          9.42231914190486,
          9.422506475897823,
          9.422683911847123,
          9.422851736272408,
          9.423010233670981,
          9.423159686582963,
          9.423300375655565,
          9.423432579706507,
          9.42355657578662,
          9.42367263924164,
          9.423781043773257,
          9.423882061499418,
          9.423975963013934,
          9.424063017445409,
          9.424143492515524,
          9.42421765459669,
          9.42428576876913,
          9.424348098877365,
          9.42440490758619,
          9.424456456436113,
          9.424503005898316,
          9.424544815429142,
          9.424582143524153,
          9.42461524777177,
          9.424644384906507,
          9.42466981086186,
          9.424691780822828,
          9.424710549278133,
          9.42472637007213,
          9.424739496456436,
          9.424750181141313,
          9.424758676346828,
          9.424765233853778,
          9.42477010505446,
          9.424773541003242,
          9.424775792467019,
          9.424777109975528,
          9.424777743871571,
          9.424777944361155,
          9.424777961563569,
          9.424778045561442,
          9.424778446450759,
          9.424779414390908,
          9.424781199654733,
          9.424784052678655,
          9.424788224112843,
          9.424793964871492,
          9.424801526183206,
          9.424811159641509,
          9.424823117255528,
          9.42483765150084,
          9.424855015370515,
          9.4248754624264,
          9.424899246850623,
          9.424926623497377,
          9.424957847944988,
          9.424993176548291,
          9.425032866491353,
          9.425077175840531,
          9.425126363597931,
          9.425180689755267,
          9.425240415348135,
          9.425305802510763,
          9.425377114531218,
          9.425454615907128,
          9.425538572401926,
          9.425629251101661,
          9.425726920472368,
          9.42583185041806,
          9.42594431233936,
          9.42606457919278,
          9.4261929255507,
          9.42632962766206,
          9.426474963513815,
          9.426629212893147,
          9.426792657450502,
          9.426965580763463,
          9.427148268401488,
          9.42734100799157,
          9.427544089284808,
          9.427757804223972,
          9.427982447012065,
          9.428218314181926,
          9.428465704666912,
          9.428724919872698,
          9.428996263750223,
          9.429280042869838,
          9.429576566496676,
          9.429886146667306,
          9.43020909826769,
          9.430545739112516,
          9.43089639002591,
          9.431261374923626,
          9.431641020896704,
          9.432035658296689,
          9.432445620822437,
          9.432871245608561,
          9.433312873315586,
          9.43377084822183,
          9.434245518317116,
          9.434737235398332,
          9.435246355166907,
          9.435773237328268,
          9.436318245693364,
          9.43688174828225,
          9.437464117429883,
          9.43806572989414,
          9.438686966966145,
          9.439328214582982,
          9.439989863442861,
          9.440672309122814,
          9.441375952199005,
          9.442101198369732,
          9.442848458581206,
          9.44361814915619,
          9.44441069192559,
          9.4452265143631,
          9.44606604972297,
          9.446929737181042,
          9.447818021979094,
          9.448731355572656,
          9.449670195782362,
          9.450635006948994,
          9.451626260092283,
          9.452644433073635,
          9.453690010762877,
          9.45476348520916,
          9.455865355816162,
          9.456996129521709,
          9.458156320981972,
          9.459346452760387,
          9.460567055521448,
          9.461818668229515,
          9.463101838352843,
          9.464417122072952,
          9.46576508449956,
          9.46714629989122,
          9.468561351881888,
          9.47001083371358,
          9.471495348475372,
          9.473015509348896,
          9.474571939860592,
          9.476165274140941,
          9.477796157190879,
          9.47946524515569,
          9.481173205606597,
          9.482920717830309,
          9.484708473126833,
          9.486537175115803,
          9.488407540051636,
          9.490320297147832,
          9.492276188910713,
          9.494275971482947,
          9.496320414997221,
          9.498410303940378,
          9.500546437528454,
          9.502729630092924,
          9.504960711478647,
          9.507240527453874,
          9.509569940132769,
          9.511949828410925,
          9.514381088414316,
          9.516864633962202,
          9.519401397044504,
          9.521992328314191,
          9.5246383975952,
          9.527340594406553,
          9.530099928503194,
          9.532917430434262,
          9.535794152119403,
          9.53873116744384,
          9.541729572872955,
          9.544790488087061,
          9.547915056637253,
          9.551104446623082,
          9.554359851392952,
          9.557682490268137,
          9.561073609291357,
          9.5645344820009,
          9.568066410231324,
          9.571670724941802,
          9.57534878707325,
          9.57910198843544,
          9.582931752625289,
          9.586839535977653,
          9.590826828549979,
          9.594895155142222,
          9.59904607635353,
          9.60328118967728,
          9.607602130636039,
          9.612010573958255,
          9.616508234798415,
          9.621096870002592,
          9.6257782794214,
          9.63055430727235,
          9.635426843553937,
          9.640397825513645,
          9.645469239172375,
          9.650643120907803,
          9.655921559099363,
          9.661306695837693,
          9.666800728701492,
          9.672405912604942,
          9.67812456171899,
          9.683959051469913,
          9.68991182061892,
          9.695985373426591,
          9.702182281906204,
          9.70850518817035,
          9.714956806875232,
          9.721539927767575,
          9.72825741833911,
          9.735112226594062,
          9.74210738393519,
          9.749246008174488,
          9.756531306674782,
          9.763966579628944,
          9.771555223483858,
          9.779300734516562,
          9.787206712570619,
          9.795276864961117,
          9.803515010557229,
          9.811925084051905,
          9.820511140428678,
          9.829277359636398,
          9.838228051483217,
          9.847367660761936,
          9.856700772619622,
          9.86623211818508,
          9.87596658046891,
          9.885909200551568,
          9.896065184075985,
          9.906439908062476,
          9.917038928064605,
          9.927867985686243,
          9.938933016481185,
          9.950240158258282,
          9.961795759816509,
          9.97360639013631,
          9.985678848055153,
          9.998020172457377,
          10.010637653010543,
          10.02353884148268,
          10.036731563677627,
          10.050223932028043,
          10.064024358888869,
          10.078141570577118,
          10.092584622207244,
          10.107362913375372,
          10.122486204749459,
          10.13796463562709,
          10.153808742527463,
          10.170029478889163,
          10.186638235951483,
          10.2036468649029,
          10.22106770038744,
          10.238913585467076,
          10.257197898146357,
          10.27593457957475,
          10.295138164051648,
          10.31482381097006,
          10.335007338846541,
          10.355705261598315,
          10.376934827242476,
          10.398714059208114,
          10.421061800469626,
          10.443997760728337,
          10.467542566891275,
          10.49171781711881,
          10.516546138739178,
          10.542051250356621,
          10.568258028511472,
          10.595192579286637,
          10.622882315293733,
          10.6513560385165,
          10.6806440295382,
          10.710778143734082,
          10.741791915072069,
          10.773720668232711,
          10.80660163983702,
          10.840474109657283,
          10.875379542782976,
          10.911361743824434,
          10.948467024360102,
          10.986744384973907,
          11.02624571338734,
          11.067026000371857,
          11.109143575330918,
          11.15266036367466,
          11.197642168376106,
          11.244158978401249,
          11.29228530705458,
          11.342100563680432,
          11.39368946262077,
          11.447142473860403,
          11.502556320402373,
          11.56003452812713,
          11.619688034711743,
          11.681635865145179,
          11.746005882494957,
          11.812935623889615,
          11.882573233220006,
          11.955078503870256,
          12.03062404692574,
          12.109396602834765,
          12.191598517504314,
          12.277449407393917,
          12.367188042454666,
          12.461074480906307,
          12.559392496043683,
          12.662452342768034,
          12.770593920651232,
          12.88419040146477,
          13.003652402739231,
          13.129432805709554,
          13.262032336787115,
          13.402006057553962,
          13.549970940622682,
          13.706614749403109,
          13.8727064913295,
          14.049108779729199,
          14.236792523671063,
          14.43685447383898,
          14.650538293944741,
          14.879260012775983,
          15.124638957514836,
          15.38853559676179,
          15.673098163587667,
          15.980820530792506,
          16.314614639414124,
          16.67790193672002,
          17.074729910677764,
          17.50992214224042,
          17.98927368892685,
          18.51980862400898,
          19.110124091374036,
          19.770856794372158,
          20.515325953785663,
          21.36043585881971,
          22.32796911159155,
          23.44648321630646,
          24.754166596153116,
          26.303272410714527,
          28.167250230711208,
          30.45270687899598,
          33.3204968100788,
          37.025256861592574,
          41.99541507375927,
          49.01196053057818,
          59.665039597155676,
          77.76819428105885,
          115.33281407058332,
          240.18835349860052,
          null,
          -167.68679067661765,
          -85.63463417182864,
          -55.8596548705128,
          -40.472950361167904,
          -31.07546466221223,
          -24.740510467227203,
          -20.181174089189295,
          -16.742990343824804,
          -14.057935656752555,
          -11.903174178784802,
          -10.135888334579793,
          -8.6603203233281,
          -7.4098640247914425,
          -6.336756218278762,
          -5.40585338694588,
          -4.590722085663806,
          -3.8710979683478897,
          -3.231185304191653,
          -2.658489581884165,
          -2.142997911068745,
          -1.6765920522982576,
          -1.2526205228720197,
          -0.8655816555020674,
          -0.5108854352465926,
          -0.1846721789701018,
          0.11632716489777906,
          0.3948998313912897,
          0.6534368519162967,
          0.8940010387895683,
          1.118381435688879,
          1.3281372764334707,
          1.5246337372046614,
          1.7090712156754195,
          1.8825094643109699,
          2.0458876029259905,
          2.2000408086674064,
          2.345714309661642,
          2.4835751772047567,
          2.6142223102249913,
          2.7381949272711523,
          2.855979819977491,
          2.9680175737439436,
          3.0747079232155983,
          3.176414379774272,
          3.2734682439342953,
          3.36617209596192,
          3.4548028422004933,
          3.53961438170594,
          3.620839947281474,
          3.698694166368069,
          3.773374880137865,
          3.845064753252319,
          3.9139327018617465,
          3.98013516334619,
          4.043817227889022,
          4.105113649111557,
          4.164149748584002,
          4.221042226990937,
          4.27589989299951,
          4.328824319409683,
          4.379910434912375,
          4.429247058708764,
          4.476917384326187,
          4.522999418174717,
          4.567566377708205,
          4.610687053465344,
          4.6524261387561445,
          4.692844530318305,
          4.731999602882112,
          4.769945460248048,
          4.806733165188316,
          4.8424109502267125,
          4.877024411127467,
          4.910616684725189,
          4.943228612555027,
          4.974898891588127,
          5.0056642132430085,
          5.03555939172276,
          5.064617482622377,
          5.092869892656171,
          5.120346481271069,
          5.147075654837678,
          5.1730844540437575,
          5.198398635055707,
          5.22304274496056,
          5.247040191953007,
          5.270413310689914,
          5.293183423195902,
          5.3153708956694325,
          5.33699519150783,
          5.358074920841422,
          5.378627886842315,
          5.3986711290499825,
          5.418220963935564,
          5.437293022908117,
          5.455902287948861,
          5.47406312504463,
          5.491789315577279,
          5.509094085813543,
          5.525990134627923,
          5.542489659581142,
          5.558604381466696,
          5.574345567429516,
          5.589724052752797,
          5.604750261401479,
          5.61943422540462,
          5.633785603152343,
          5.647813696677687,
          5.661527467988515,
          5.674935554509694,
          5.6880462836918095,
          5.700867686838269,
          5.713407512199213,
          5.72567323737726,
          5.7376720810867585,
          5.749411014305721,
          5.760896770856586,
          5.7721358574496895,
          5.783134563221078,
          5.7938989687939815,
          5.804434954891652,
          5.814748210527134,
          5.824844240794139,
          5.83472837428136,
          5.844405770131479,
          5.853881424764449,
          5.863160178283575,
          5.872246720581779,
          5.8811455971641635,
          5.889861214702311,
          5.898397846334498,
          5.906759636725358,
          5.914950606897636,
          5.92297465884787,
          5.930835579957284,
          5.938537047208363,
          5.946082631217033,
          5.953475800089837,
          5.960719923114825,
          5.967818274294567,
          5.9747740357290535,
          5.981590300855891,
          5.988270077554804,
          5.994816291122962,
          6.001231787127456,
          6.007519334140734,
          6.013681626364628,
          6.019721286148152,
          6.025640866404167,
          6.0314428529295405,
          6.037129666633312,
          6.042703665677115,
          6.048167147531792,
          6.053522350954125,
          6.058771457887177,
          6.063916595287742,
          6.068959836884137,
          6.073903204867378,
          6.07874867151874,
          6.083498160776442,
          6.088153549744094,
          6.092716670143476,
          6.0971893097139525,
          6.10157321356089,
          6.105870085455184,
          6.110081589085972,
          6.114209349268516,
          6.118254953109065,
          6.122219951128557,
          6.1261058583467936,
          6.129914155328735,
          6.1336462891944645,
          6.1373036745942455,
          6.140887694650151,
          6.144399701865532,
          6.147841019003664,
          6.151212939936733,
          6.15451673046638,
          6.157753629116895,
          6.1609248479021135,
          6.16403157306707,
          6.167074965805326,
          6.170056162952967,
          6.172976277660108,
          6.175836400040783,
          6.178637597802039,
          6.181380916852982,
          6.18406738189457,
          6.186697996990829,
          6.189273746122201,
          6.191795593721671,
          6.194264485194292,
          6.196681347420749,
          6.19904708924549,
          6.201362601950024,
          6.203628759711891,
          6.205846420049821,
          6.208016424255584,
          6.210139597812982,
          6.2122167508044575,
          6.214248678305726,
          6.2162361607688785,
          6.218179964394329,
          6.2200808414920115,
          6.221939530832184,
          6.223756757986193,
          6.225533235657559,
          6.227269664003689,
          6.228966730948549,
          6.2306251124865915,
          6.2322454729782315,
          6.233828465437162,
          6.2353747318097685,
          6.2368849032469065,
          6.2383596003683115,
          6.239799433519843,
          6.241205003023842,
          6.242576899422803,
          6.24391570371657,
          6.245221987593296,
          6.246496313654325,
          6.247739235633232,
          6.24895129860918,
          6.250133039214796,
          6.251284985838715,
          6.252407658822986,
          6.253501570655493,
          6.2545672261575325,
          6.255605122666738,
          6.256615750215443,
          6.257599591704679,
          6.258557123073906,
          6.2594888134666276,
          6.26039512539201,
          6.261276514882625,
          6.262133431648456,
          6.262966319227252,
          6.263775615131364,
          6.2645617509911675,
          6.265325152695163,
          6.266066240526876,
          6.266785429298638,
          6.267483128482344,
          6.268159742337293,
          6.268815670035176,
          6.269451305782329,
          6.270067038939299,
          6.270663254137833,
          6.271240331395351,
          6.271798646226987,
          6.272338569755267,
          6.272860468817504,
          6.273364706070957,
          6.2738516400958595,
          6.2743216254963405,
          6.274775012999329,
          6.2752121495514945,
          6.275633378414288,
          6.276039039257129,
          6.276429468248811,
          6.276804998147164,
          6.277165958387052,
          6.2775126751667205,
          6.277845471532581,
          6.278164667462456,
          6.278470579947349,
          6.278763523071774,
          6.279043808092693,
          6.2793117435171135,
          6.279567635178376,
          6.279811786311178,
          6.280044497625393,
          6.28026606737868,
          6.2804767914479775,
          6.28067696339988,
          6.280866874559943,
          6.281046814080972,
          6.281217069010296,
          6.281377924356093,
          6.2815296631527815,
          6.281672566525518,
          6.2818069137538375,
          6.281932982334445,
          6.282051048043232,
          6.282161384996499,
          6.282264265711457,
          6.282359961166002,
          6.28244874085782,
          6.282530872862828,
          6.28260662389299,
          6.28267625935354,
          6.282740043399623,
          6.282798238992391,
          6.282851107954583,
          6.282898911025601,
          6.282941907916122,
          6.282980357362259,
          6.283014517179304,
          6.28304464431507,
          6.283070994902858,
          6.283093824314079,
          6.283113387210541,
          6.283129937596436,
          6.283143728870044,
          6.283155013875178,
          6.28316404495239,
          6.283171073989962,
          6.283176352474708,
          6.2831801315426,
          6.283182662029247,
          6.283184194520244,
          6.283184979401418,
          6.283185266908986,
          6.283185307179648,
          6.283185350300646,
          6.283185646359788,
          6.283186445495488,
          6.283187997946815,
          6.28319055410359,
          6.283194364556547,
          6.283199680147581,
          6.283206752020099,
          6.2832158316695015,
          6.283227170993815,
          6.283241022344494,
          6.283257638577419,
          6.28327727310411,
          6.28330017994317,
          6.283326613772006,
          6.2833568299788105,
          6.283391084714866,
          6.283429634947167,
          6.283472738511401,
          6.283520654165297,
          6.283573641642377,
          6.283631961706129,
          6.283695876204626,
          6.283765648125617,
          6.283841541652118,
          6.283923822218514,
          6.2840127565672255,
          6.284108612805932,
          6.284211660465407,
          6.284322170557975,
          6.284440415636631,
          6.284566669854831,
          6.2847012090270065,
          6.284844310689812,
          6.284996254164149,
          6.285157320617986,
          6.285327793130012,
          6.285507956754158,
          6.285698098585004,
          6.285898507824132,
          6.286109475847419,
          6.286331296273348,
          6.2865642650323394,
          6.2868086804371535,
          6.2870648432544005,
          6.287333056777193,
          6.287613626898976,
          6.287906862188589,
          6.288213073966582,
          6.288532576382837,
          6.288865686495544,
          6.28921272435156,
          6.2895740130682105,
          6.2899498789165715,
          6.290340651406286,
          6.290746663371954,
          6.291168251061162,
          6.291605754224186,
          6.292059516205438,
          6.292529884036695,
          6.293017208532184,
          6.293521844385559,
          6.294044150268858,
          6.294584488933475,
          6.295143227313225,
          6.2957207366295584,
          6.296317392499014,
          6.296933575042939,
          6.29756966899959,
          6.2982260638386665,
          6.298903153878346,
          6.299601338404925,
          6.300321021795123,
          6.301062613641138,
          6.301826528878551,
          6.302613187917154,
          6.3034230167748,
          6.304256447214374,
          6.305113916883969,
          6.305995869460384,
          6.306902754796038,
          6.307835029069413,
          6.3087931549391385,
          6.309777601701816,
          6.3107888454537395,
          6.311827369256595,
          6.312893663307291,
          6.313988225112047,
          6.315111559664873,
          6.316264179630581,
          6.317446605532487,
          6.318659365944931,
          6.319902997690808,
          6.321178046044227,
          6.322485064938509,
          6.323824617179678,
          6.3251972746656175,
          6.32660361861111,
          6.328044239778918,
          6.329519738717136,
          6.331030726003005,
          6.332577822493431,
          6.334161659582387,
          6.335782879465487,
          6.337442135411934,
          6.3391400920441185,
          6.3408774256251075,
          6.342654824354317,
          6.344472988671631,
          6.346332631570282,
          6.348234478918766,
          6.350179269792152,
          6.352167756813068,
          6.354200706502738,
          6.356278899642421,
          6.358403131645607,
          6.360574212941382,
          6.3627929693693215,
          6.36506024258638,
          6.3673768904861765,
          6.369743787631131,
          6.372161825697944,
          6.374631913936882,
          6.377154979645405,
          6.37973196865665,
          6.382363845843346,
          6.385051595637714,
          6.387796222567979,
          6.390598751812117,
          6.393460229769488,
          6.396381724651057,
          6.399364327088892,
          6.402409150765723,
          6.40551733306531,
          6.408690035744461,
          6.411928445627539,
          6.415233775324345,
          6.418607263972328,
          6.422050178004074,
          6.42556381194111,
          6.429149489215083,
          6.432808563017413,
          6.436542417178621,
          6.440352467078526,
          6.444240160588604,
          6.448206979047855,
          6.452254438273547,
          6.456384089608375,
          6.460597521005513,
          6.464896358153236,
          6.469282265640746,
          6.473756948167047,
          6.478322151794715,
          6.482979665250504,
          6.487731321274907,
          6.492578998022767,
          6.497524620517282,
          6.502570162159772,
          6.507717646297705,
          6.512969147853679,
          6.5183267950180905,
          6.523792771008474,
          6.529369315898573,
          6.535058728520395,
          6.540863368442709,
          6.546785658029539,
          6.552828084582535,
          6.558993202571183,
          6.565283635955128,
          6.571702080603075,
          6.5782513068129616,
          6.584934161938463,
          6.591753573127029,
          6.598712550175099,
          6.605814188506297,
          6.61306167227896,
          6.620458277629497,
          6.628007376058639,
          6.6357124379679515,
          6.6435770363544275,
          6.651604850671548,
          6.659799670865567,
          6.66816540159639,
          6.67670606665303,
          6.685425813574076,
          6.694328918484516,
          6.703419791160733,
          6.712702980336363,
          6.722183179262544,
          6.731865231536771,
          6.741754137215815,
          6.751855059228835,
          6.762173330108106,
          6.772714459055892,
          6.783484139367117,
          6.794488256229066,
          6.805732894920532,
          6.8172243494345865,
          6.828969131550596,
          6.840973980383225,
          6.8532458724378,
          6.8657920322037,
          6.878619943319725,
          6.89173736034764,
          6.905152321193126,
          6.9188731602158935,
          6.932908522074058,
          6.947267376351244,
          6.961959033018421,
          6.976993158786773,
          6.99237979441194,
          7.008129373014909,
          7.024252739489986,
          7.0407611710756886,
          7.057666399170907,
          7.074980632485031,
          7.092716581618223,
          7.110887485176076,
          7.129507137531373,
          7.148589918355729,
          7.168150824053938,
          7.188205501245795,
          7.2087702824524555,
          7.229862224158854,
          7.251499147438629,
          7.273699681345163,
          7.296483309291098,
          7.319870418659013,
          7.343882353909297,
          7.368541473476034,
          7.393871210769968,
          7.4198961396387855,
          7.446642044669064,
          7.474135996753294,
          7.502406434387539,
          7.53148325121334,
          7.561397890370781,
          7.592183446288781,
          7.623874774606097,
          7.656508610990647,
          7.6901236997091384,
          7.724760932893577,
          7.760463501557146,
          7.797277059532963,
          7.835249901644124,
          7.874433157567806,
          7.914881003029842,
          7.956650890165179,
          7.999803799104087,
          8.044404513101663,
          8.090521919821832,
          8.138229341722798,
          8.187604898877717,
          8.23873190800689,
          8.29169932200947,
          8.346602214872911,
          8.403542317521001,
          8.462628610955283,
          8.52397798396582,
          8.58771596376355,
          8.653977529144534,
          8.7229080172706,
          8.79466413688739,
          8.869415102845714,
          8.947343909214371,
          9.028648761147108,
          9.113544689088597,
          9.20226537299785,
          9.295065209173092,
          9.392221658172737,
          9.494037919467548,
          9.600845987130073,
          9.713010151431135,
          9.83093102415097,
          9.955050181325689,
          10.085855536818265,
          10.223887584546281,
          10.36974667772579,
          10.524101551847288,
          10.687699346572803,
          10.861377443387228,
          11.046077514762404,
          11.24286228233701,
          11.452935613772425,
          11.677666760949517,
          11.91861977055102,
          12.177589402262864,
          12.456645298830795,
          12.758186707779974,
          13.085010817506395,
          13.440398830367632,
          13.828225386652882,
          14.253099080129882,
          14.720544884229337,
          15.237243835562081,
          15.811352098387136,
          16.45293187391797,
          17.1745427330196,
          17.992067659821352,
          18.92589019358654,
          20.00261004329238,
          21.257608265075863,
          22.738996970020516,
          24.51391157728164,
          26.67894431863874,
          29.378290599567425,
          32.83719486221428,
          37.42820553239433,
          43.815126328284634,
          53.306786100787136,
          68.89190988927808,
          99.20778068307507,
          183.8371597289453,
          null,
          -221.62792886611885,
          -101.46584243446526,
          -64.6492787032293,
          -46.79470253465951,
          -36.25362405005467,
          -29.29691717863086,
          -24.362434793033344,
          -20.680640936284004,
          -17.828499007071102,
          -15.554180788720132,
          -13.698411777030024,
          -12.155529228693304,
          -10.852675874214276,
          -9.737985404382275,
          -8.7735307377601,
          -7.930936075517508,
          -7.188548324626714,
          -6.529557519575169,
          -5.940714455444599,
          -5.411435284196347,
          -4.933163367153073,
          -4.498906093856748,
          -4.102893145678525,
          -3.740320610085284,
          -3.407156794887208,
          -3.099993056191889,
          -2.8159279192964455,
          -2.5524761345198606,
          -2.3074966249335116,
          -2.0791349006990156,
          -1.8657766610452482,
          -1.6660101276490744,
          -1.47859525074424,
          -1.3024383681239282,
          -1.1365712228150242,
          -0.9801334891560272,
          -0.8323581414302836,
          -0.6925591398158533,
          -0.5601210164791901,
          -0.43449002831464245,
          -0.31516660809319585,
          -0.2016988970167759,
          -0.09367718215690513,
          0.00927090556202792,
          0.1074845514502707,
          0.20127337314268967,
          0.29092057391375636,
          0.3766857008699791,
          0.45880706459943,
          0.5375038677862003,
          0.6129780828263196,
          0.6854161123095373,
          0.7549902611084551,
          0.8218600445483184,
          0.886173353565165,
          0.948067494765279,
          1.0076701207809395,
          1.0651000641885227,
          1.1204680864541743,
          1.173877551839165,
          1.2254250348927913,
          1.275200869045284,
          1.323289642856769,
          1.3697706496585171,
          1.4147182956142834,
          1.4582024706196868,
          1.5002888859291317,
          1.5410393819408132,
          1.5805122091729449,
          1.6187622851161247,
          1.6558414293443033,
          1.691798579001647,
          1.726679986549693,
          1.7605294014560164,
          1.793388237325169,
          1.8252957258149105,
          1.8562890585409995,
          1.8864035180497818,
          1.9156725988291106,
          1.9441281192301787,
          1.9718003250871132,
          1.9987179857437618,
          2.0249084831293045,
          2.0503978944624848,
          2.0752110691099697,
          2.0993717000754026,
          2.1229023905514826,
          2.1458247159286423,
          2.168159281617895,
          2.1899257770139107,
          2.2111430258956957,
          2.231829033536038,
          2.2520010307680542,
          2.2716755152355077,
          2.290868290034725,
          2.3095944999386133,
          2.327868665377282,
          2.3457047143359504,
          2.3631160123173975,
          2.380115390504656,
          2.3967151722488866,
          2.412927197997326,
          2.428762848767686,
          2.4442330682667555,
          2.45934838374383,
          2.4741189256624407,
          2.4885544462679845,
          2.5026643371227415,
          2.5164576456747136,
          2.529943090921889,
          2.543129078228888,
          2.5560237133492203,
          2.568634815702265,
          2.580969930950838,
          2.593036342922003,
          2.6048410849106762,
          2.616390950403149,
          2.6276925032548544,
          2.638752087354564,
          2.649575835805022,
          2.6601696796479244,
          2.670539356159554,
          2.6806904167414176,
          2.6906282344288126,
          2.700358011038773,
          2.7098847839773414,
          2.7192134327251067,
          2.7283486850185037,
          2.737295122743485,
          2.7460571875569606,
          2.7546391862506976,
          2.763045295871251,
          2.771279568608815,
          2.7793459364671027,
          2.787248215725536,
          2.794990111204556,
          2.802575220344047,
          2.810007037104378,
          2.8172889556990404,
          2.824424274167233,
          2.8314161977944385,
          2.838267842388433,
          2.844982237417819,
          2.851562329019818,
          2.858010982883545,
          2.8643309870148532,
          2.8705250543883176,
          2.8765958254917243,
          2.8825458707681415,
          2.8883776929602973,
          2.8940937293618774,
          2.89969635397997,
          2.9051878796127744,
          2.910570559846372,
          2.915846590974285,
          2.921018113843251,
          2.926087215628508,
          2.931055931541747,
          2.9359262464746467,
          2.940700096580872,
          2.945379370799174,
          2.949965912320156,
          2.9544615199991364,
          2.9588679497173733,
          2.9631869156939032,
          2.967420091750035,
          2.9715691125284986,
          2.975635574669164,
          2.9796210379430748,
          2.9835270263465876,
          2.987355029157202,
          2.99110650195266,
          2.9947828675948176,
          2.9983855171796643,
          3.00191581095491,
          3.005375079206379,
          3.0087646231144864,
          3.012085715581929,
          3.015339602033778,
          3.0185275011910004,
          3.0216506058184667,
          3.0247100834484244,
          3.0277070770803554,
          3.030642705858161,
          3.0335180657254996,
          3.036334230060113,
          3.0390922502879416,
          3.0417931564777585,
          3.0444379579170744,
          3.0470276436699897,
          3.0495631831176593,
          3.0520455264820194,
          3.0544756053333564,
          3.056854333082345,
          3.059182605457082,
          3.061461300965668,
          3.06369128134486,
          3.0658733919952654,
          3.06800846240359,
          3.07009730655236,
          3.072140723317591,
          3.0741394968547846,
          3.076094396973701,
          3.0780061795022644,
          3.0798755866399894,
          3.081703347301287,
          3.0834901774489833,
          3.0852367804184055,
          3.0869438472323316,
          3.088612056907126,
          3.090242076750357,
          3.0918345626501607,
          3.093390159356659,
          3.094909500755664,
          3.096393210134943,
          3.0978419004432816,
          3.0992561745425746,
          3.100636625453184,
          3.1019838365927797,
          3.103298382008862,
          3.10458082660519,
          3.1058317263622914,
          3.1070516285522567,
          3.108241071947998,
          3.1094005870271437,
          3.1105306961707404,
          3.111631913856931,
          3.112704746849764,
          3.113749694383281,
          3.114767248341046,
          3.1157578934312364,
          3.116722107357458,
          3.1176603609853952,
          3.1185731185054424,
          3.1194608375914306,
          3.1203239695555696,
          3.1211629594997303,
          3.1219782464631702,
          3.1227702635668146,
          3.1235394381542045,
          3.124286191929198,
          3.1250109410905424,
          3.1257140964633967,
          3.126396063627907,
          3.127057243044923,
          3.127698030178931,
          3.128318815618307,
          3.128919985192954,
          3.1295019200894143,
          3.1300649969635206,
          3.130609588050676,
          3.131136061273821,
          3.131644780349163,
          3.1321361048897414,
          3.132610390506877,
          3.1330679889095934,
          3.133509248002051,
          3.1339345119790654,
          3.134344121419767,
          3.1347384133794534,
          3.135117721479697,
          3.135482375996758,
          3.135832703948352,
          3.136169029178828,
          3.1364916724428062,
          3.136800951487315,
          3.1370971811324875,
          3.137380673350852,
          3.137651737345264,
          3.137910679625529,
          3.138157804083745,
          3.1383934120684205,
          3.138617802457397,
          3.1388312717296203,
          3.139034114035799,
          3.1392266212679836,
          3.139409083128106,
          3.1395817871955147,
          3.1397450189935374,
          3.139899062055108,
          3.1400441979874913,
          3.140180706536134,
          3.1403088656476794,
          3.1404289515321713,
          3.140541238724481,
          3.1406460001449874,
          3.1407435071595375,
          3.140834029638719,
          3.140917836016465,
          3.140995193348035,
          3.141066367367379,
          3.1411316225439285,
          3.14119122213883,
          3.141245428260652,
          3.14129450192059,
          3.141338703087193,
          3.14137829074064,
          3.1414135229265834,
          3.141444656809594,
          3.1414719487262235,
          3.1414956542377075,
          3.14151602818234,
          3.141533324727535,
          3.1415477974215973,
          3.141559699245235,
          3.141569282662822,
          3.141576799673445,
          3.1415825018617483,
          3.1415866404486055,
          3.1415894663416313,
          3.141591230185564,
          3.1415921824125355,
          3.1415925732922476,
          3.141592652982084,
          3.1415926715771705,
          3.1415928791604104,
          3.141593525852516,
          3.1415948618620533,
          3.1415971375355256,
          3.1416006034075172,
          3.141605510250914,
          3.141612109127229,
          3.1416206514370457,
          3.1416313889706133,
          3.1416445739586005,
          3.141660459123043,
          3.141679297728496,
          3.141701343633425,
          3.141726851341844,
          3.1417560760552345,
          3.1417892737247635,
          3.1418267011038226,
          3.141868615800914,
          3.141915276332903,
          3.1419669421786636,
          3.142023873833145,
          3.1420863328618687,
          3.142154581955902,
          3.142228884987312,
          3.1423095070651432,
          3.1423967145919294,
          3.142490775320775,
          3.1425919584130337,
          3.1427005344966013,
          3.142816775724861,
          3.142940955836304,
          3.1430733502148542,
          3.143214235950925,
          3.1433638919032423,
          3.1435225987614572,
          3.1436906391095865,
          3.1438682974903043,
          3.144055860470125,
          3.1442536167055057,
          3.1444618570099,
          3.1446808744218036,
          3.1449109642738193,
          3.145152424262787,
          3.145405554521003,
          3.145670657688577,
          3.14594803898696,
          3.146238006293685,
          3.1465408702183577,
          3.1468569441799437,
          3.147186544485391,
          3.1475299904096317,
          3.1478876042770105,
          3.1482597115441844,
          3.148646640884541,
          3.149048724274182,
          3.1494662970795293,
          3.149899698146593,
          3.1503492698919686,
          3.1508153583956067,
          3.151298313495412,
          3.151798488883738,
          3.1523162422058277,
          3.1528519351602644,
          3.1534059336014972,
          3.1539786076445004,
          3.1545703317716427,
          3.155181484941826,
          3.1558124507019683,
          3.1564636173009077,
          3.157135377805792,
          3.1578281302210454,
          3.158542277609982,
          3.1592782282191507,
          3.1600363956055064,
          3.1608171987664755,
          3.1616210622730287,
          3.162448416405842,
          3.163299697294648,
          3.164175347060869,
          3.165075813963653,
          3.1660015525493987,
          3.1669530238048997,
          3.167930695314207,
          3.1689350414193327,
          3.169966543384926,
          3.1710256895670335,
          3.172112975586084,
          3.1732289045042377,
          3.1743739870072187,
          3.1755487415908066,
          3.1767536947521107,
          3.1779893811858,
          3.179256343985442,
          3.1805551348501138,
          3.1818863142964724,
          3.183250451876448,
          3.184648126400755,
          3.186079926168418,
          3.1875464492024905,
          3.189048303492209,
          3.1905861072417587,
          3.1921604891259134,
          3.193772088552739,
          3.1954215559336383,
          3.197109552960966,
          3.198836752893475,
          3.2006038408498743,
          3.202411514110754,
          3.2042604824292016,
          3.2061514683503773,
          3.208085207540386,
          3.2100624491247634,
          3.212083956036905,
          3.2141505053768125,
          3.216262888780504,
          3.2184219128004785,
          3.2206283992976372,
          3.2228831858450517,
          3.2251871261440415,
          3.2275410904529824,
          3.229945966029324,
          3.232402657585306,
          3.234912087757858,
          3.2374751975932394,
          3.240092947046948,
          3.2427663154994866,
          3.2454963022885575,
          3.2482839272583472,
          3.251130231326522,
          3.2540362770696207,
          3.257003149327571,
          3.260031955828026,
          3.2631238278313495,
          3.266279920797012,
          3.2695014150722614,
          3.2727895166039542,
          3.2761454576744384,
          3.2795704976624953,
          3.2830659238303093,
          3.2866330521375393,
          3.290273228083598,
          3.293987827579259,
          3.2977782578488535,
          3.3016459583642765,
          3.3055924018121448,
          3.3096190950955107,
          3.3137275803715407,
          3.317919436126741,
          3.3221962782912904,
          3.326559761394185,
          3.331011579760913,
          3.3355534687555677,
          3.3401872060692877,
          3.344914613057088,
          3.349737556125226,
          3.3546579481713126,
          3.3596777500795882,
          3.3647989722738134,
          3.370023676330393,
          3.375353976654506,
          3.3807920422220903,
          3.3863400983907876,
          3.3920004287830237,
          3.3977753772446047,
          3.403667349882433,
          3.409678817185023,
          3.4158123162298812,
          3.4220704529818464,
          3.4284559046868512,
          3.434971422365764,
          3.4416198334131813,
          3.4484040443064483,
          3.4553270434303425,
          3.4623919040232813,
          3.4696017872511273,
          3.4769599454151887,
          3.4844697253012393,
          3.492134571676866,
          3.4999580309449074,
          3.5079437549610883,
          3.5160955050246514,
          3.5244171560511197,
          3.5329127009369916,
          3.5415862551267967,
          3.550442061393449,
          3.559484494843743,
          3.568718068161381,
          3.578147437100812,
          3.5877774062460484,
          3.5976129350493853,
          3.607659144166172,
          3.6179213221026147,
          3.628404932194841,
          3.639115619938698,
          3.6500592206909026,
          3.661241767763861,
          3.672669500937699,
          3.684348875414919,
          3.6962865712446513,
          3.708489503245646,
          3.7209648314589656,
          3.7337199721637018,
          3.746762609491477,
          3.7601007076779167,
          3.7737425239924227,
          3.7876966223903263,
          3.8019718879350095,
          3.816577542041199,
          3.8315231585943454,
          3.846818681005629,
          3.862474440266415,
          3.8785011740712143,
          3.8949100470837372,
          3.911712672426388,
          3.928921134480488,
          3.9465480130912844,
          3.9646064092798365,
          3.9831099725724495,
          4.00207293006744,
          4.02151011736974,
          4.041437011534682,
          4.061869766175045,
          4.082825248898694,
          4.104321081259661,
          4.126375681421515,
          4.149008309750418,
          4.172239117575371,
          4.19608919937511,
          4.220580648676254,
          4.245736617974083,
          4.27158138301786,
          4.298140411836249,
          4.325440438915381,
          4.353509544984398,
          4.382377242908998,
          4.412074570245701,
          4.442634189067443,
          4.474090493735471,
          4.506479727365899,
          4.539840107820106,
          4.574211964140236,
          4.609637884454386,
          4.646162876491967,
          4.683834541982227,
          4.722703266356881,
          4.762822425347098,
          4.804248610256775,
          4.8470418739114915,
          4.891265999532074,
          4.93698879506451,
          4.984282415823543,
          5.033223718678833,
          5.083894651441629,
          5.136382681601616,
          5.1907812691329624,
          5.247190388746693,
          5.305717107728762,
          5.366476226391637,
          5.429590989199797,
          5.495193875838549,
          5.563427482911534,
          5.634445508615313,
          5.708413854702318,
          5.785511862360578,
          5.865933701389762,
          5.94988993532584,
          6.037609289073379,
          6.129340650289512,
          6.225355341394505,
          6.3259497058867264,
          6.431448060886365,
          6.542206077871192,
          6.658614665848786,
          6.781104446292431,
          6.910150927793626,
          7.046280511490293,
          7.190077487159503,
          7.342192216021569,
          7.503350741933661,
          7.674366130586398,
          7.856151910356769,
          8.049738083757916,
          8.256290301940329,
          8.47713295606665,
          8.713777151935178,
          8.967954816664069,
          9.241660565081995,
          9.537203466671585,
          9.857271556634608,
          10.205012907966982,
          10.584138446297702,
          10.999053628883615,
          11.455028905662736,
          11.958422976010844,
          12.51697895697165,
          13.140222842179067,
          13.840007986409374,
          14.631272111292954,
          15.533110341274739,
          16.570329704065735,
          17.77575750187411,
          19.19376759012488,
          20.885846510129923,
          22.939723029733653,
          25.485040476434406,
          28.721784371416987,
          32.97547744805289,
          38.814020394364846,
          47.324875759359294,
          60.88543963506136,
          85.8819532650027,
          147.31739392111953,
          null,
          null,
          -121.28383006386758,
          -74.53821446448183,
          -53.564864235374756,
          -41.65692720944922,
          -33.981964244293,
          -28.623980920633684,
          -24.671719170927446,
          -21.636393785083616,
          -19.232290943689613,
          -17.281230832034673,
          -15.666327789245916,
          -14.307720873428627,
          -13.148989649729401,
          -12.14914190282608,
          -11.277677506848695,
          -10.51143345049316,
          -9.832502722530759,
          -9.226823520909173,
          -8.683199723840715,
          -8.192606275397162,
          -7.747687271093584,
          -7.342387131087982,
          -6.971675432382844,
          -6.631338779229118,
          -6.317821400897482,
          -6.028101667232168,
          -5.759595421590811,
          -5.510079573858527,
          -5.277631166805298,
          -5.060578379353955,
          -4.8574608248316125,
          -4.666997150055199,
          -4.488058415501968,
          -4.319646087923975,
          -4.16087373917178,
          -4.010951742930298,
          -3.8691744116573235,
          -3.7349091315195206,
          -3.60758714239412,
          -3.486695679496883,
          -3.3717712476711634,
          -3.2623938423412016,
          -3.158181965238904,
          -3.0587883102428375,
          -2.963896016522675,
          -2.873215403823493,
          -2.786481119028104,
          -2.7034496347934827,
          -2.6238970506021713,
          -2.547617154414457,
          -2.4744197095884313,
          -2.4041289371048835,
          -2.3365821676038174,
          -2.271628641473677,
          -2.2091284383619505,
          -2.1489515201095757,
          -2.0909768733311473,
          -2.035091739744152,
          -1.9811909239451473,
          -1.9291761696915706,
          -1.8789555969077645,
          -1.830443192627821,
          -1.7835583499419148,
          -1.7382254497460687,
          -1.6943734807303557,
          -1.6519356935879919,
          -1.6108492859030497,
          -1.5710551145880287,
          -1.5324974331009944,
          -1.4951236509867858,
          -1.4588841135604698,
          -1.4237318997915809,
          -1.389622636659114,
          -1.3565143284318424,
          -1.324367199492864,
          -1.293143549470972,
          -1.2628076195689961,
          -1.2333254690926005,
          -1.2046648612823976,
          -1.176795157642017,
          -1.1496872200333157,
          -1.1233133198810186,
          -1.0976470538913334,
          -1.0726632657460038,
          -1.0483379732832265,
          -1.0246483007219798,
          -1.0015724155271255,
          -0.9790894695484176,
          -0.9571795440998678,
          -0.9358235986750345,
          -0.9150034230203912,
          -0.8947015923132215,
          -0.8749014252116403,
          -0.8555869445644932,
          -0.8367428405863591,
          -0.8183544363190074,
          -0.8004076552155679,
          -0.7828889906964949,
          -0.7657854775389732,
          -0.7490846649721659,
          -0.7327745913607446,
          -0.7168437603685436,
          -0.7012811185021264,
          -0.6860760339421228,
          -0.6712182765768646,
          -0.6566979991595563,
          -0.6425057195156982,
          -0.6286323037332406,
          -0.6150689502726614,
          -0.6018071749387155,
          -0.5888387966599584,
          -0.5761559240256562,
          -0.5637509425335558,
          -0.5516165025050639,
          -0.5397455076273807,
          -0.5281311040850911,
          -0.5167666702459603,
          -0.5056458068683594,
          -0.49476232779975016,
          -0.4841102511377018,
          -0.4736837908269236,
          -0.4634773486672785,
          -0.45348550670961774,
          -0.4437030200176113,
          -0.4341248097751509,
          -0.4247459567203191,
          -0.41556169488787953,
          -0.4065674056436033,
          -0.39775861199459284,
          -0.38913097316091405,
          -0.38068027939451254,
          -0.37240244703245695,
          -0.36429351377219765,
          -0.35634963415727294,
          -0.3485670752626808,
          -0.3409422125695749,
          -0.33347152601973606,
          -0.326151596240716,
          -0.31897910093306536,
          -0.31195081141165626,
          -0.30506358929338084,
          -0.29831438332411375,
          -0.2917002263381274,
          -0.2852182323435217,
          -0.2788655937276834,
          -0.27263957857694643,
          -0.266537528105109,
          -0.2605568541856562,
          -0.2546950369828116,
          -0.24894962267688814,
          -0.2433182212795013,
          -0.23779850453458562,
          -0.23238820390125636,
          -0.22708510861487197,
          -0.22188706382270107,
          -0.216791968790917,
          -0.21179777517972775,
          -0.20690248538362144,
          -0.20210415093391776,
          -0.19740087096084113,
          -0.19279079071258787,
          -0.18827210012891538,
          -0.1838430324669027,
          -0.17950186297671022,
          -0.1752469076251616,
          -0.1710765218651824,
          -0.16698909944916496,
          -0.1629830712844188,
          -0.15905690432901154,
          -0.15520910052628378,
          -0.15143819577650308,
          -0.14774275894413214,
          -0.14412139089926435,
          -0.14057272359188955,
          -0.13709541915763268,
          -0.13368816905375336,
          -0.13034969322418455,
          -0.12707873929250646,
          -0.12387408178172044,
          -0.120734521359815,
          -0.11765888411011749,
          -0.11464602082546793,
          -0.11169480632533768,
          -0.10880413879497774,
          -0.10597293914579575,
          -0.10320015039615182,
          -0.10048473707180161,
          -0.09782568462528185,
          -0.09522199887350036,
          -0.09267270545288653,
          -0.09017684929145142,
          -0.0877334940971285,
          -0.08534172186183409,
          -0.08300063238064181,
          -0.0807093427855552,
          -0.07846698709334787,
          -0.07627271576696126,
          -0.07412569529000446,
          -0.0720251077538624,
          -0.0699701504569945,
          -0.06796003551598018,
          -0.06599398948792523,
          -0.06407125300380823,
          -0.062191080412410504,
          -0.06035273943445929,
          -0.0585555108266288,
          -0.056798688055085145,
          -0.05508157697822258,
          -0.05340349553830381,
          -0.05176377346169758,
          -0.0501617519674199,
          -0.04859678348372054,
          -0.047068231372424774,
          -0.04557546966079129,
          -0.04411788278063322,
          -0.04269486531445976,
          -0.04130582174842312,
          -0.03995016623183156,
          -0.038627322343028236,
          -0.03733672286142686,
          -0.03607780954550227,
          -0.03485003291655664,
          -0.03365285204806029,
          -0.032485734360404084,
          -0.03134815542088021,
          -0.030239598748740493,
          -0.029159555625155098,
          -0.028107524907929837,
          -0.02708301285082948,
          -0.02608553292735888,
          -0.025114605658874245,
          -0.024169758446875578,
          -0.023250525409361567,
          -0.02235644722111757,
          -0.02148707095781255,
          -0.02064194994379659,
          -0.01982064360347424,
          -0.01902271731615157,
          -0.018247742274249523,
          -0.017495295344776784,
          -0.01676495893397162,
          -0.016056320855005135,
          -0.0153689741986619,
          -0.01470251720690341,
          -0.014056553149225881,
          -0.013430690201734763,
          -0.01282454132884342,
          -0.012237724167525388,
          -0.0116698609140366,
          -0.011120578213040355,
          -0.010589507049053704,
          -0.01007628264015159,
          -0.009580544333857743,
          -0.009101935505155534,
          -0.008640103456558468,
          -0.008194699320171916,
          -0.007765377961690134,
          -0.007351797886268552,
          -0.006953621146211841,
          -0.006570513250427568,
          -0.006202143075584754,
          -0.0058481827789295115,
          -0.005508307712705551,
          -0.005182196340127898,
          -0.004869530152865897,
          -0.004569993589982835,
          -0.004283273958290756,
          -0.0040090613540740005,
          -0.0037470485861372527,
          -0.003496931100138767,
          -0.0032584069041632913,
          -0.0030311764954977505,
          -0.0028149427885681144,
          -0.0026094110440018914,
          -0.0024142887987753103,
          -0.0022292857974112734,
          -0.002054113924191636,
          -0.0018884871363480382,
          -0.0017321213981993933,
          -0.0015847346161998732,
          -0.001446046574866966,
          -0.0013157788735566334,
          -0.0011936548640543998,
          -0.001079399588952562,
          -0.0009727397207820454,
          -0.0008734035018707065,
          -0.0007811206848987451,
          -0.0006956224741227202,
          -0.0006166414672411635,
          -0.0005439115978731063,
          -0.00047716807862406563,
          -0.0004161473447120839,
          -0.0003605869981282428,
          -0.0003102257523064089,
          -0.0002648033772760794,
          -0.00022406064527444314,
          -0.00018773927679253954,
          -0.00015558188703181097,
          -0.00012733193274680477,
          -0.00010273365945055735,
          -8.153204895958166e-05,
          -6.347276725506695e-05,
          -4.830211263775336e-05,
          -3.57669641536662e-05,
          -2.5614730268491703e-05,
          -1.7593297768202232e-05,
          -1.1450980864025073e-05,
          -6.93647047977225e-06,
          -3.7987836997779856e-06,
          -1.7872133557875203e-06,
          -6.512777312658868e-07,
          -1.4067036165597846e-07,
          -5.209909173346794e-09,
          5.209909173346794e-09,
          1.4067036165597846e-07,
          6.512777312658868e-07,
          1.7872133557875203e-06,
          3.7987836997779856e-06,
          6.936470479775719e-06,
          1.1450980864025073e-05,
          1.7593297768202232e-05,
          2.5614730268498642e-05,
          3.576696415367314e-05,
          4.83021126377603e-05,
          6.347276725506695e-05,
          8.153204895958166e-05,
          0.00010273365945057122,
          0.00012733193274681864,
          0.00015558188703183873,
          0.00018773927679253954,
          0.00022406064527444314,
          0.00026480337727610714,
          0.00031022575230645055,
          0.00036058699812828443,
          0.0004161473447120839,
          0.00047716807862410726,
          0.0005439115978731618,
          0.0006166414672412052,
          0.0006956224741227757,
          0.0007811206848987451,
          0.000873403501870762,
          0.0009727397207821287,
          0.0010793995889526453,
          0.0011936548640543998,
          0.0013157788735566334,
          0.0014460465748670492,
          0.0015847346161999842,
          0.0017321213981995043,
          0.0018884871363480382,
          0.002054113924191636,
          0.002229285797411412,
          0.002414288798775449,
          0.002609411044002058,
          0.0028149427885681144,
          0.0030311764954977505,
          0.003258406904163458,
          0.0034969311001389614,
          0.003747048586137447,
          0.0040090613540740005,
          0.004283273958290951,
          0.004569993589983029,
          0.0048695301528661195,
          0.005182196340128176,
          0.005508307712705551,
          0.005848182778929789,
          0.0062021430755850315,
          0.006570513250427845,
          0.006953621146211841,
          0.007351797886268552,
          0.007765377961690412,
          0.008194699320172194,
          0.0086401034565588,
          0.009101935505155534,
          0.009580544333857743,
          0.010076282640151923,
          0.010589507049054092,
          0.011120578213040744,
          0.0116698609140366,
          0.012237724167525388,
          0.012824541328843864,
          0.013430690201735207,
          0.01405655314922638,
          0.01470251720690341,
          0.0153689741986624,
          0.016056320855005635,
          0.01676495893397212,
          0.01749529534477734,
          0.018247742274249523,
          0.019022717316152127,
          0.019820643603474797,
          0.0206419499437972,
          0.02148707095781255,
          0.02235644722111757,
          0.023250525409362233,
          0.024169758446876244,
          0.02511460565887491,
          0.02608553292735888,
          0.02708301285082948,
          0.02810752490793056,
          0.02915955562515582,
          0.03023959874874127,
          0.03134815542088021,
          0.032485734360404084,
          0.03365285204806112,
          0.03485003291655747,
          0.03607780954550316,
          0.03733672286142686,
          0.038627322343029125,
          0.03995016623183256,
          0.04130582174842412,
          0.04269486531446076,
          0.04411788278063322,
          0.0455754696607924,
          0.047068231372425884,
          0.04859678348372165,
          0.0501617519674199,
          0.05176377346169758,
          0.053403495538304924,
          0.05508157697822369,
          0.056798688055086366,
          0.0585555108266288,
          0.06035273943445929,
          0.06219108041241184,
          0.06407125300380956,
          0.06599398948792656,
          0.06796003551598018,
          0.0699701504569945,
          0.07202510775386384,
          0.07412569529000601,
          0.07627271576696282,
          0.07846698709334787,
          0.08070934278555686,
          0.08300063238064337,
          0.08534172186183575,
          0.08773349409713016,
          0.09017684929145142,
          0.09267270545288842,
          0.09522199887350213,
          0.09782568462528374,
          0.1004847370718035,
          0.10320015039615182,
          0.10597293914579775,
          0.10880413879497985,
          0.11169480632533979,
          0.11464602082546793,
          0.11765888411011749,
          0.12073452135981722,
          0.12387408178172266,
          0.12707873929250868,
          0.13034969322418455,
          0.13368816905375336,
          0.13709541915763512,
          0.140572723591892,
          0.1441213908992669,
          0.14774275894413214,
          0.15143819577650564,
          0.15520910052628656,
          0.15905690432901431,
          0.16298307128442158,
          0.16698909944916496,
          0.1710765218651853,
          0.1752469076251646,
          0.17950186297671333,
          0.1838430324669058,
          0.18827210012891538,
          0.1927907907125911,
          0.19740087096084435,
          0.2021041509339212,
          0.20690248538362144,
          0.21179777517972775,
          0.21679196879092055,
          0.22188706382270484,
          0.22708510861487552,
          0.23238820390125636,
          0.23779850453458562,
          0.2433182212795053,
          0.24894962267689213,
          0.2546950369828156,
          0.2605568541856562,
          0.2665375281051132,
          0.27263957857695065,
          0.27886559372768804,
          0.2852182323435264,
          0.2917002263381274,
          0.29831438332411864,
          0.30506358929338573,
          0.31195081141166114,
          0.31897910093307047,
          0.326151596240716,
          0.3334715260197414,
          0.34094221256958024,
          0.3485670752626864,
          0.35634963415727294,
          0.36429351377219765,
          0.3724024470324627,
          0.38068027939451854,
          0.38913097316092005,
          0.39775861199459284,
          0.4065674056436033,
          0.41556169488788597,
          0.4247459567203258,
          0.43412480977515755,
          0.4437030200176113,
          0.4534855067096246,
          0.4634773486672856,
          0.4736837908269309,
          0.48411025113770934,
          0.49476232779975016,
          0.5056458068683671,
          0.5167666702459683,
          0.5281311040850991,
          0.5397455076273889,
          0.5516165025050639,
          0.5637509425335647,
          0.5761559240256651,
          0.5888387966599675,
          0.6018071749387155,
          0.6150689502726614,
          0.6286323037332502,
          0.642505719515708,
          0.6566979991595665,
          0.6712182765768646,
          0.6860760339421228,
          0.7012811185021373,
          0.7168437603685547,
          0.7327745913607562,
          0.7490846649721659,
          0.7657854775389852,
          0.7828889906965071,
          0.8004076552155805,
          0.8183544363190203,
          0.8367428405863591,
          0.855586944564507,
          0.874901425211654,
          0.8947015923132358,
          0.9150034230204058,
          0.9358235986750345,
          0.9571795440998834,
          0.9790894695484336,
          1.0015724155271415,
          1.0246483007219798,
          1.0483379732832265,
          1.072663265746021,
          1.0976470538913516,
          1.1233133198810372,
          1.1496872200333157,
          1.176795157642017,
          1.2046648612824176,
          1.2333254690926214,
          1.2628076195690174,
          1.293143549470972,
          1.3243671994928863,
          1.356514328431866,
          1.389622636659138,
          1.4237318997916057,
          1.4588841135604698,
          1.495123650986812,
          1.5324974331010215,
          1.5710551145880567,
          1.6108492859030785,
          1.6519356935879919,
          1.6943734807303863,
          1.7382254497461003,
          1.7835583499419476,
          1.830443192627821,
          1.8789555969077645,
          1.929176169691607,
          1.981190923945185,
          2.035091739744191,
          2.0909768733311473,
          2.1489515201095757,
          2.209128438361994,
          2.2716286414737223,
          2.3365821676038645,
          2.4041289371048835,
          2.4744197095884823,
          2.54761715441451,
          2.6238970506022268,
          2.7034496347935404,
          2.786481119028104,
          2.873215403823556,
          2.9638960165227406,
          3.0587883102429068,
          3.1581819652389767,
          3.2623938423412016,
          3.3717712476712434,
          3.4866956794969663,
          3.607587142394209,
          3.7349091315195206,
          3.8691744116573235,
          4.010951742930402,
          4.16087373917189,
          4.319646087924092,
          4.488058415501968,
          4.666997150055199,
          4.857460824831752,
          5.060578379354104,
          5.277631166805457,
          5.510079573858527,
          5.759595421590995,
          6.028101667232366,
          6.317821400897696,
          6.631338779229349,
          6.971675432382844,
          7.342387131088257,
          7.747687271093884,
          8.192606275397493,
          8.683199723841081,
          9.226823520909173,
          9.832502722531213,
          10.511433450493671,
          11.277677506849274,
          12.14914190282608,
          13.148989649729401,
          14.307720873429515,
          15.666327789246964,
          17.281230832035927,
          19.232290943689613,
          21.636393785083616,
          24.671719170929887,
          28.623980920636917,
          33.98196424429749,
          41.65692720944922,
          53.56486423538555,
          74.5382144645024,
          121.28383006392119,
          null,
          null,
          -147.31739392104407,
          -85.88195326497745,
          -60.88543963504886,
          -47.32487575935187,
          -38.814020394364846,
          -32.97547744804939,
          -28.721784371414376,
          -25.48504047643238,
          -22.939723029733653,
          -20.885846510129923,
          -19.193767590123787,
          -17.775757501873183,
          -16.570329704064946,
          -15.533110341274739,
          -14.631272111292954,
          -13.840007986408846,
          -13.140222842178598,
          -12.516978956971231,
          -11.958422976010844,
          -11.455028905662395,
          -10.999053628883306,
          -10.584138446297422,
          -10.205012907966724,
          -9.857271556634608,
          -9.537203466671365,
          -9.241660565081792,
          -8.96795481666388,
          -8.713777151935004,
          -8.47713295606665,
          -8.256290301940176,
          -8.049738083757774,
          -7.856151910356636,
          -7.674366130586398,
          -7.503350741933661,
          -7.342192216021458,
          -7.190077487159397,
          -7.046280511490194,
          -6.910150927793626,
          -6.781104446292431,
          -6.6586146658487015,
          -6.542206077871112,
          -6.4314480608862885,
          -6.3259497058867264,
          -6.225355341394436,
          -6.129340650289445,
          -6.037609289073315,
          -5.949889935325779,
          -5.865933701389762,
          -5.785511862360522,
          -5.708413854702265,
          -5.634445508615261,
          -5.563427482911484,
          -5.495193875838549,
          -5.429590989199751,
          -5.366476226391592,
          -5.30571710772872,
          -5.247190388746693,
          -5.1907812691329624,
          -5.136382681601578,
          -5.083894651441593,
          -5.033223718678798,
          -4.984282415823543,
          -4.93698879506451,
          -4.891265999532042,
          -4.8470418739114605,
          -4.804248610256745,
          -4.762822425347098,
          -4.722703266356852,
          -4.6838345419822,
          -4.646162876491941,
          -4.60963788445436,
          -4.574211964140236,
          -4.539840107820082,
          -4.506479727365876,
          -4.4740904937354475,
          -4.442634189067421,
          -4.412074570245701,
          -4.3823772429089765,
          -4.353509544984378,
          -4.325440438915361,
          -4.298140411836249,
          -4.27158138301786,
          -4.245736617974065,
          -4.220580648676236,
          -4.196089199375093,
          -4.172239117575371,
          -4.149008309750418,
          -4.126375681421499,
          -4.104321081259646,
          -4.082825248898679,
          -4.061869766175045,
          -4.041437011534682,
          -4.021510117369726,
          -4.002072930067426,
          -3.983109972572436,
          -3.9646064092798365,
          -3.946548013091272,
          -3.9289211344804755,
          -3.9117126724263755,
          -3.8949100470837257,
          -3.8785011740712143,
          -3.862474440266404,
          -3.846818681005618,
          -3.8315231585943343,
          -3.816577542041199,
          -3.8019718879350095,
          -3.7876966223903157,
          -3.773742523992413,
          -3.760100707677907,
          -3.746762609491477,
          -3.7337199721637018,
          -3.7209648314589567,
          -3.7084895032456373,
          -3.6962865712446424,
          -3.684348875414919,
          -3.672669500937699,
          -3.661241767763853,
          -3.6500592206908946,
          -3.63911561993869,
          -3.628404932194841,
          -3.617921322102607,
          -3.6076591441661643,
          -3.597612935049378,
          -3.5877774062460417,
          -3.578147437100812,
          -3.5687180681613744,
          -3.5594844948437365,
          -3.550442061393442,
          -3.5415862551267967,
          -3.5329127009369916,
          -3.524417156051114,
          -3.516095505024646,
          -3.507943754961082,
          -3.4999580309449074,
          -3.492134571676866,
          -3.484469725301234,
          -3.4769599454151834,
          -3.469601787251122,
          -3.4623919040232813,
          -3.4553270434303425,
          -3.448404044306443,
          -3.4416198334131765,
          -3.4349714223657593,
          -3.4284559046868512,
          -3.422070452981842,
          -3.415812316229877,
          -3.4096788171850188,
          -3.4036673498824284,
          -3.3977753772446047,
          -3.3920004287830197,
          -3.386340098390784,
          -3.3807920422220863,
          -3.375353976654506,
          -3.370023676330393,
          -3.3647989722738094,
          -3.3596777500795847,
          -3.354657948171309,
          -3.349737556125226,
          -3.344914613057088,
          -3.340187206069284,
          -3.335553468755564,
          -3.33101157976091,
          -3.326559761394185,
          -3.3221962782912904,
          -3.317919436126738,
          -3.3137275803715376,
          -3.309619095095508,
          -3.3055924018121448,
          -3.301645958364274,
          -3.297778257848851,
          -3.2939878275792562,
          -3.290273228083595,
          -3.2866330521375393,
          -3.283065923830307,
          -3.279570497662493,
          -3.276145457674436,
          -3.2727895166039542,
          -3.2695014150722614,
          -3.26627992079701,
          -3.2631238278313477,
          -3.260031955828024,
          -3.257003149327571,
          -3.2540362770696207,
          -3.25113023132652,
          -3.2482839272583455,
          -3.2454963022885552,
          -3.2427663154994866,
          -3.240092947046948,
          -3.2374751975932377,
          -3.234912087757856,
          -3.2324026575853044,
          -3.229945966029324,
          -3.2275410904529807,
          -3.22518712614404,
          -3.2228831858450504,
          -3.220628399297636,
          -3.2184219128004785,
          -3.2162628887805025,
          -3.2141505053768107,
          -3.2120839560369037,
          -3.2100624491247634,
          -3.208085207540386,
          -3.206151468350376,
          -3.2042604824292003,
          -3.2024115141107528,
          -3.2006038408498743,
          -3.198836752893475,
          -3.197109552960965,
          -3.1954215559336374,
          -3.193772088552738,
          -3.1921604891259134,
          -3.1905861072417587,
          -3.1890483034922075,
          -3.1875464492024896,
          -3.1860799261684165,
          -3.184648126400755,
          -3.183250451876447,
          -3.1818863142964715,
          -3.180555134850113,
          -3.1792563439854407,
          -3.1779893811858,
          -3.17675369475211,
          -3.1755487415908057,
          -3.1743739870072183,
          -3.1732289045042377,
          -3.172112975586084,
          -3.1710256895670326,
          -3.1699665433849256,
          -3.1689350414193322,
          -3.167930695314207,
          -3.1669530238048997,
          -3.1660015525493983,
          -3.165075813963652,
          -3.1641753470608682,
          -3.163299697294648,
          -3.162448416405842,
          -3.1616210622730283,
          -3.160817198766475,
          -3.160036395605506,
          -3.1592782282191507,
          -3.158542277609981,
          -3.157828130221045,
          -3.1571353778057913,
          -3.156463617300907,
          -3.1558124507019683,
          -3.1551814849418256,
          -3.1545703317716427,
          -3.1539786076445,
          -3.1534059336014972,
          -3.1528519351602644,
          -3.1523162422058273,
          -3.1517984888837374,
          -3.1512983134954116,
          -3.1508153583956067,
          -3.1503492698919686,
          -3.1498996981465925,
          -3.149466297079529,
          -3.149048724274182,
          -3.148646640884541,
          -3.1482597115441844,
          -3.1478876042770105,
          -3.147529990409631,
          -3.1471865444853906,
          -3.1468569441799437,
          -3.1465408702183577,
          -3.1462380062936846,
          -3.14594803898696,
          -3.145670657688577,
          -3.145405554521003,
          -3.145152424262787,
          -3.1449109642738193,
          -3.144680874421803,
          -3.1444618570099,
          -3.1442536167055057,
          -3.144055860470125,
          -3.143868297490304,
          -3.143690639109586,
          -3.1435225987614572,
          -3.1433638919032423,
          -3.143214235950925,
          -3.1430733502148542,
          -3.142940955836304,
          -3.142816775724861,
          -3.1427005344966013,
          -3.1425919584130337,
          -3.142490775320775,
          -3.1423967145919294,
          -3.1423095070651432,
          -3.142228884987312,
          -3.142154581955902,
          -3.1420863328618687,
          -3.1420238738331445,
          -3.1419669421786636,
          -3.141915276332903,
          -3.141868615800914,
          -3.1418267011038226,
          -3.1417892737247635,
          -3.1417560760552345,
          -3.141726851341844,
          -3.141701343633425,
          -3.141679297728496,
          -3.141660459123043,
          -3.1416445739586005,
          -3.1416313889706133,
          -3.1416206514370457,
          -3.141612109127229,
          -3.141605510250914,
          -3.1416006034075172,
          -3.1415971375355256,
          -3.1415948618620533,
          -3.141593525852516,
          -3.1415928791604104,
          -3.1415926715771705,
          -3.141592652982084,
          -3.1415925732922476,
          -3.1415921824125355,
          -3.141591230185564,
          -3.1415894663416313,
          -3.1415866404486055,
          -3.1415825018617483,
          -3.141576799673445,
          -3.141569282662822,
          -3.141559699245235,
          -3.1415477974215973,
          -3.141533324727535,
          -3.14151602818234,
          -3.1414956542377075,
          -3.1414719487262235,
          -3.141444656809594,
          -3.1414135229265834,
          -3.14137829074064,
          -3.141338703087193,
          -3.14129450192059,
          -3.141245428260652,
          -3.14119122213883,
          -3.1411316225439285,
          -3.141066367367379,
          -3.140995193348035,
          -3.140917836016465,
          -3.140834029638719,
          -3.1407435071595375,
          -3.140646000144987,
          -3.140541238724481,
          -3.1404289515321713,
          -3.1403088656476794,
          -3.140180706536134,
          -3.1400441979874913,
          -3.139899062055108,
          -3.139745018993537,
          -3.1395817871955147,
          -3.139409083128106,
          -3.1392266212679836,
          -3.139034114035799,
          -3.1388312717296203,
          -3.138617802457397,
          -3.1383934120684205,
          -3.138157804083745,
          -3.137910679625529,
          -3.137651737345264,
          -3.137380673350852,
          -3.1370971811324875,
          -3.1368009514873147,
          -3.136491672442806,
          -3.136169029178828,
          -3.135832703948352,
          -3.135482375996758,
          -3.1351177214796966,
          -3.134738413379453,
          -3.1343441214197667,
          -3.1339345119790654,
          -3.133509248002051,
          -3.1330679889095934,
          -3.1326103905068767,
          -3.1321361048897414,
          -3.131644780349163,
          -3.1311360612738204,
          -3.1306095880506755,
          -3.13006499696352,
          -3.1295019200894143,
          -3.128919985192954,
          -3.1283188156183064,
          -3.1276980301789306,
          -3.1270572430449226,
          -3.126396063627907,
          -3.1257140964633963,
          -3.125010941090542,
          -3.1242861919291975,
          -3.1235394381542037,
          -3.1227702635668146,
          -3.1219782464631693,
          -3.12116295949973,
          -3.120323969555569,
          -3.1194608375914297,
          -3.1185731185054424,
          -3.1176603609853943,
          -3.1167221073574574,
          -3.115757893431236,
          -3.114767248341046,
          -3.113749694383281,
          -3.1127047468497633,
          -3.1116319138569306,
          -3.1105306961707395,
          -3.1094005870271437,
          -3.108241071947998,
          -3.107051628552256,
          -3.1058317263622905,
          -3.104580826605189,
          -3.103298382008862,
          -3.1019838365927788,
          -3.100636625453183,
          -3.0992561745425733,
          -3.0978419004432807,
          -3.096393210134943,
          -3.094909500755663,
          -3.093390159356658,
          -3.0918345626501598,
          -3.090242076750356,
          -3.088612056907126,
          -3.0869438472323303,
          -3.085236780418404,
          -3.083490177448982,
          -3.081703347301287,
          -3.0798755866399894,
          -3.078006179502263,
          -3.0760943969736996,
          -3.0741394968547833,
          -3.072140723317591,
          -3.07009730655236,
          -3.068008462403588,
          -3.0658733919952637,
          -3.063691281344858,
          -3.061461300965668,
          -3.0591826054570808,
          -3.0568543330823434,
          -3.0544756053333546,
          -3.0520455264820177,
          -3.0495631831176593,
          -3.047027643669988,
          -3.044437957917072,
          -3.0417931564777563,
          -3.03909225028794,
          -3.036334230060113,
          -3.033518065725498,
          -3.030642705858159,
          -3.027707077080353,
          -3.0247100834484244,
          -3.0216506058184667,
          -3.018527501190998,
          -3.0153396020337757,
          -3.012085715581927,
          -3.0087646231144864,
          -3.005375079206379,
          -3.001915810954907,
          -2.9983855171796616,
          -2.994782867594815,
          -2.99110650195266,
          -2.9873550291571993,
          -2.983527026346585,
          -2.9796210379430716,
          -2.975635574669161,
          -2.9715691125284986,
          -2.9674200917500317,
          -2.9631869156939,
          -2.95886794971737,
          -2.9544615199991333,
          -2.949965912320156,
          -2.945379370799171,
          -2.9407000965808683,
          -2.935926246474643,
          -2.931055931541747,
          -2.926087215628508,
          -2.921018113843247,
          -2.9158465909742812,
          -2.910570559846368,
          -2.9051878796127744,
          -2.89969635397997,
          -2.894093729361874,
          -2.888377692960294,
          -2.8825458707681375,
          -2.8765958254917243,
          -2.870525054388313,
          -2.864330987014849,
          -2.8580109828835405,
          -2.8515623290198135,
          -2.844982237417819,
          -2.8382678423884276,
          -2.831416197794434,
          -2.824424274167228,
          -2.817288955699035,
          -2.810007037104378,
          -2.8025752203440417,
          -2.7949901112045508,
          -2.7872482157255303,
          -2.7793459364671027,
          -2.771279568608815,
          -2.763045295871245,
          -2.7546391862506914,
          -2.7460571875569544,
          -2.737295122743485,
          -2.7283486850185037,
          -2.7192134327251,
          -2.709884783977335,
          -2.700358011038766,
          -2.6906282344288126,
          -2.6806904167414105,
          -2.670539356159547,
          -2.6601696796479173,
          -2.649575835805014,
          -2.638752087354564,
          -2.6276925032548464,
          -2.6163909504031406,
          -2.6048410849106682,
          -2.5930363429219945,
          -2.580969930950838,
          -2.5686348157022563,
          -2.5560237133492114,
          -2.543129078228879,
          -2.529943090921889,
          -2.5164576456747136,
          -2.5026643371227317,
          -2.4885544462679743,
          -2.47411892566243,
          -2.45934838374383,
          -2.4442330682667555,
          -2.4287628487676747,
          -2.4129271979973144,
          -2.396715172248875,
          -2.380115390504656,
          -2.363116012317385,
          -2.3457047143359375,
          -2.3278686653772693,
          -2.3095944999386004,
          -2.290868290034725,
          -2.271675515235494,
          -2.25200103076804,
          -2.231829033536023,
          -2.211143025895681,
          -2.1899257770139107,
          -2.1681592816178794,
          -2.1458247159286263,
          -2.122902390551466,
          -2.0993717000754026,
          -2.0752110691099697,
          -2.050397894462467,
          -2.0249084831292863,
          -1.9987179857437432,
          -1.9718003250871132,
          -1.9441281192301787,
          -1.9156725988290901,
          -1.886403518049761,
          -1.8562890585409777,
          -1.8252957258149105,
          -1.7933882373251464,
          -1.760529401455993,
          -1.7266799865496685,
          -1.6917985790016221,
          -1.6558414293443033,
          -1.618762285116098,
          -1.5805122091729173,
          -1.5410393819407848,
          -1.5002888859291024,
          -1.4582024706196868,
          -1.4147182956142523,
          -1.3697706496584847,
          -1.3232896428567358,
          -1.275200869045284,
          -1.2254250348927913,
          -1.1738775518391278,
          -1.1204680864541356,
          -1.0651000641884827,
          -1.0076701207809395,
          -0.948067494765279,
          -0.8861733535651202,
          -0.8218600445482718,
          -0.7549902611084067,
          -0.6854161123095373,
          -0.6129780828262668,
          -0.5375038677861457,
          -0.45880706459937315,
          -0.3766857008699196,
          -0.29092057391375636,
          -0.20127337314262483,
          -0.10748455145020319,
          -0.009270905561956866,
          0.09367718215697973,
          0.2016988970167759,
          0.31516660809327846,
          0.4344900283147295,
          0.5601210164792816,
          0.6925591398158533,
          0.8323581414302836,
          0.9801334891561355,
          1.1365712228151388,
          1.302438368124049,
          1.47859525074424,
          1.6660101276490744,
          1.8657766610453947,
          2.079134900699172,
          2.3074966249336795,
          2.5524761345198606,
          2.8159279192964455,
          3.0999930561920985,
          3.4071567948874355,
          3.740320610085531,
          4.102893145678525,
          4.498906093857041,
          4.933163367153398,
          5.411435284196704,
          5.940714455444995,
          6.529557519575169,
          7.188548324627211,
          7.930936075518067,
          8.773530737760737,
          9.737985404382275,
          10.852675874214276,
          12.15552922869431,
          13.698411777031222,
          15.554180788721581,
          17.828499007071102,
          20.680640936284004,
          24.362434793036343,
          29.296917178634963,
          36.25362405006062,
          46.79470253465951,
          64.6492787032293,
          101.46584243450529,
          221.62792886630086,
          null,
          -183.8371597289453,
          -99.20778068304335,
          -68.89190988926346,
          -53.30678610077875,
          -43.815126328279206,
          -37.42820553239433,
          -32.837194862211476,
          -29.378290599565272,
          -26.678944318637033,
          -24.51391157728164,
          -22.738996970020516,
          -21.2576082650749,
          -20.002610043291554,
          -18.92589019358583,
          -17.992067659821352,
          -17.1745427330196,
          -16.45293187391749,
          -15.811352098386706,
          -15.237243835561696,
          -14.720544884229337,
          -14.253099080129882,
          -13.828225386652592,
          -13.44039883036737,
          -13.085010817506154,
          -12.758186707779974,
          -12.456645298830589,
          -12.177589402262672,
          -11.918619770550844,
          -11.677666760949352,
          -11.452935613772425,
          -11.242862282336866,
          -11.046077514762267,
          -10.861377443387102,
          -10.687699346572803,
          -10.524101551847288,
          -10.369746677725683,
          -10.22388758454618,
          -10.08585553681817,
          -9.955050181325689,
          -9.83093102415097,
          -9.713010151431053,
          -9.600845987129995,
          -9.494037919467475,
          -9.392221658172737,
          -9.295065209173092,
          -9.202265372997784,
          -9.113544689088535,
          -9.02864876114705,
          -8.947343909214371,
          -8.86941510284566,
          -8.794664136887338,
          -8.722908017270548,
          -8.653977529144486,
          -8.58771596376355,
          -8.523977983965775,
          -8.46262861095524,
          -8.40354231752096,
          -8.346602214872911,
          -8.29169932200947,
          -8.238731908006855,
          -8.187604898877682,
          -8.138229341722765,
          -8.090521919821832,
          -8.044404513101663,
          -7.999803799104056,
          -7.9566508901651485,
          -7.914881003029814,
          -7.874433157567806,
          -7.835249901644124,
          -7.797277059532936,
          -7.760463501557119,
          -7.7247609328935525,
          -7.6901236997091384,
          -7.656508610990624,
          -7.623874774606075,
          -7.592183446288759,
          -7.56139789037076,
          -7.53148325121334,
          -7.5024064343875185,
          -7.474135996753274,
          -7.446642044669044,
          -7.4198961396387855,
          -7.393871210769968,
          -7.368541473476016,
          -7.34388235390928,
          -7.319870418658996,
          -7.296483309291098,
          -7.273699681345163,
          -7.251499147438614,
          -7.229862224158839,
          -7.2087702824524404,
          -7.188205501245795,
          -7.168150824053938,
          -7.148589918355715,
          -7.12950713753136,
          -7.110887485176063,
          -7.092716581618223,
          -7.074980632485018,
          -7.057666399170895,
          -7.040761171075677,
          -7.024252739489976,
          -7.008129373014909,
          -6.992379794411929,
          -6.976993158786763,
          -6.961959033018411,
          -6.947267376351244,
          -6.932908522074058,
          -6.918873160215885,
          -6.905152321193116,
          -6.89173736034763,
          -6.878619943319725,
          -6.8657920322037,
          -6.853245872437791,
          -6.840973980383216,
          -6.828969131550588,
          -6.8172243494345865,
          -6.805732894920532,
          -6.794488256229058,
          -6.783484139367109,
          -6.772714459055884,
          -6.762173330108106,
          -6.751855059228828,
          -6.741754137215808,
          -6.731865231536764,
          -6.722183179262537,
          -6.712702980336363,
          -6.7034197911607265,
          -6.694328918484509,
          -6.685425813574069,
          -6.67670606665303,
          -6.66816540159639,
          -6.659799670865561,
          -6.651604850671543,
          -6.643577036354422,
          -6.6357124379679515,
          -6.628007376058639,
          -6.620458277629492,
          -6.613061672278954,
          -6.605814188506293,
          -6.598712550175099,
          -6.591753573127029,
          -6.584934161938459,
          -6.578251306812957,
          -6.571702080603069,
          -6.565283635955128,
          -6.558993202571179,
          -6.55282808458253,
          -6.546785658029535,
          -6.5408633684427055,
          -6.535058728520395,
          -6.5293693158985695,
          -6.523792771008471,
          -6.518326795018086,
          -6.512969147853679,
          -6.507717646297705,
          -6.502570162159769,
          -6.497524620517279,
          -6.492578998022763,
          -6.487731321274907,
          -6.482979665250504,
          -6.478322151794712,
          -6.473756948167044,
          -6.469282265640742,
          -6.464896358153236,
          -6.460597521005513,
          -6.456384089608372,
          -6.4522544382735445,
          -6.4482069790478524,
          -6.444240160588604,
          -6.440352467078523,
          -6.436542417178618,
          -6.43280856301741,
          -6.429149489215081,
          -6.42556381194111,
          -6.422050178004072,
          -6.4186072639723255,
          -6.415233775324342,
          -6.411928445627539,
          -6.408690035744461,
          -6.405517333065308,
          -6.402409150765721,
          -6.3993643270888905,
          -6.396381724651057,
          -6.393460229769488,
          -6.3905987518121155,
          -6.387796222567977,
          -6.385051595637712,
          -6.382363845843346,
          -6.37973196865665,
          -6.377154979645403,
          -6.37463191393688,
          -6.372161825697942,
          -6.369743787631131,
          -6.367376890486176,
          -6.365060242586379,
          -6.36279296936932,
          -6.36057421294138,
          -6.358403131645607,
          -6.356278899642419,
          -6.354200706502736,
          -6.352167756813066,
          -6.350179269792152,
          -6.348234478918766,
          -6.346332631570281,
          -6.3444729886716305,
          -6.342654824354316,
          -6.3408774256251075,
          -6.3391400920441185,
          -6.3374421354119335,
          -6.335782879465485,
          -6.334161659582386,
          -6.332577822493431,
          -6.331030726003005,
          -6.329519738717135,
          -6.328044239778917,
          -6.326603618611109,
          -6.3251972746656175,
          -6.323824617179677,
          -6.322485064938508,
          -6.321178046044226,
          -6.319902997690807,
          -6.318659365944931,
          -6.317446605532486,
          -6.31626417963058,
          -6.315111559664872,
          -6.3139882251120465,
          -6.312893663307291,
          -6.311827369256594,
          -6.310788845453739,
          -6.309777601701815,
          -6.3087931549391385,
          -6.307835029069413,
          -6.306902754796037,
          -6.305995869460383,
          -6.305113916883968,
          -6.304256447214374,
          -6.3034230167748,
          -6.302613187917153,
          -6.301826528878551,
          -6.301062613641138,
          -6.300321021795123,
          -6.299601338404925,
          -6.298903153878346,
          -6.298226063838666,
          -6.29756966899959,
          -6.296933575042939,
          -6.296317392499014,
          -6.2957207366295584,
          -6.295143227313224,
          -6.294584488933475,
          -6.294044150268858,
          -6.293521844385559,
          -6.293017208532183,
          -6.292529884036695,
          -6.292059516205438,
          -6.291605754224186,
          -6.291168251061162,
          -6.290746663371953,
          -6.290340651406286,
          -6.2899498789165715,
          -6.2895740130682105,
          -6.28921272435156,
          -6.2888656864955435,
          -6.288532576382837,
          -6.288213073966582,
          -6.287906862188589,
          -6.287613626898976,
          -6.287333056777192,
          -6.2870648432544005,
          -6.2868086804371535,
          -6.2865642650323394,
          -6.286331296273348,
          -6.286109475847419,
          -6.285898507824132,
          -6.285698098585004,
          -6.285507956754157,
          -6.285327793130012,
          -6.285157320617985,
          -6.284996254164149,
          -6.284844310689812,
          -6.2847012090270065,
          -6.284566669854831,
          -6.284440415636631,
          -6.284322170557975,
          -6.284211660465407,
          -6.284108612805932,
          -6.2840127565672255,
          -6.283923822218514,
          -6.283841541652118,
          -6.283765648125617,
          -6.283695876204625,
          -6.283631961706129,
          -6.283573641642377,
          -6.283520654165297,
          -6.283472738511401,
          -6.283429634947167,
          -6.283391084714865,
          -6.2833568299788105,
          -6.283326613772006,
          -6.28330017994317,
          -6.28327727310411,
          -6.283257638577419,
          -6.283241022344494,
          -6.283227170993815,
          -6.2832158316695015,
          -6.283206752020099,
          -6.283199680147581,
          -6.283194364556547,
          -6.28319055410359,
          -6.283187997946815,
          -6.283186445495488,
          -6.283185646359788,
          -6.283185350300646,
          -6.283185307179648,
          -6.283185266908986,
          -6.283184979401418,
          -6.283184194520244,
          -6.283182662029247,
          -6.2831801315426,
          -6.283176352474708,
          -6.283171073989962,
          -6.28316404495239,
          -6.283155013875178,
          -6.283143728870044,
          -6.283129937596436,
          -6.283113387210541,
          -6.283093824314079,
          -6.283070994902858,
          -6.28304464431507,
          -6.283014517179304,
          -6.282980357362259,
          -6.282941907916122,
          -6.282898911025601,
          -6.282851107954583,
          -6.282798238992391,
          -6.282740043399622,
          -6.28267625935354,
          -6.282606623892989,
          -6.282530872862828,
          -6.28244874085782,
          -6.282359961166002,
          -6.282264265711457,
          -6.282161384996499,
          -6.282051048043232,
          -6.281932982334445,
          -6.2818069137538375,
          -6.281672566525518,
          -6.2815296631527815,
          -6.281377924356093,
          -6.281217069010296,
          -6.281046814080972,
          -6.280866874559943,
          -6.28067696339988,
          -6.2804767914479775,
          -6.28026606737868,
          -6.280044497625393,
          -6.279811786311178,
          -6.279567635178375,
          -6.2793117435171135,
          -6.279043808092693,
          -6.278763523071774,
          -6.278470579947349,
          -6.278164667462455,
          -6.27784547153258,
          -6.2775126751667205,
          -6.277165958387052,
          -6.276804998147164,
          -6.27642946824881,
          -6.276039039257129,
          -6.2756333784142875,
          -6.2752121495514945,
          -6.274775012999328,
          -6.2743216254963405,
          -6.2738516400958595,
          -6.273364706070957,
          -6.272860468817504,
          -6.272338569755267,
          -6.271798646226986,
          -6.271240331395351,
          -6.270663254137833,
          -6.270067038939299,
          -6.2694513057823285,
          -6.268815670035176,
          -6.268159742337292,
          -6.267483128482344,
          -6.266785429298638,
          -6.266066240526876,
          -6.265325152695162,
          -6.264561750991167,
          -6.263775615131364,
          -6.262966319227252,
          -6.262133431648456,
          -6.261276514882624,
          -6.260395125392009,
          -6.2594888134666276,
          -6.258557123073905,
          -6.257599591704678,
          -6.256615750215442,
          -6.255605122666738,
          -6.2545672261575325,
          -6.253501570655492,
          -6.252407658822985,
          -6.251284985838714,
          -6.250133039214796,
          -6.24895129860918,
          -6.247739235633231,
          -6.246496313654324,
          -6.245221987593295,
          -6.24391570371657,
          -6.242576899422802,
          -6.2412050030238415,
          -6.239799433519842,
          -6.238359600368311,
          -6.2368849032469065,
          -6.235374731809767,
          -6.233828465437161,
          -6.232245472978231,
          -6.23062511248659,
          -6.228966730948549,
          -6.227269664003688,
          -6.225533235657558,
          -6.223756757986192,
          -6.221939530832184,
          -6.2200808414920115,
          -6.218179964394328,
          -6.216236160768877,
          -6.214248678305725,
          -6.2122167508044575,
          -6.210139597812982,
          -6.208016424255582,
          -6.20584642004982,
          -6.203628759711889,
          -6.201362601950024,
          -6.1990470892454885,
          -6.196681347420747,
          -6.1942644851942905,
          -6.191795593721669,
          -6.189273746122201,
          -6.186697996990827,
          -6.184067381894567,
          -6.18138091685298,
          -6.178637597802037,
          -6.175836400040783,
          -6.172976277660106,
          -6.170056162952965,
          -6.167074965805323,
          -6.16403157306707,
          -6.1609248479021135,
          -6.157753629116893,
          -6.154516730466378,
          -6.15121293993673,
          -6.147841019003664,
          -6.144399701865532,
          -6.140887694650148,
          -6.137303674594243,
          -6.133646289194462,
          -6.129914155328735,
          -6.126105858346788,
          -6.122219951128554,
          -6.118254953109065,
          -6.1142093492685134,
          -6.110081589085972,
          -6.1058700854551775,
          -6.101573213560886,
          -6.0971893097139525,
          -6.092716670143473,
          -6.088153549744094,
          -6.0834981607764345,
          -6.078748671518737,
          -6.073903204867378,
          -6.068959836884133,
          -6.063916595287742,
          -6.05877145788717,
          -6.053522350954122,
          -6.048167147531792,
          -6.042703665677111,
          -6.037129666633312,
          -6.0314428529295325,
          -6.025640866404164,
          -6.019721286148152,
          -6.013681626364623,
          -6.007519334140734,
          -6.001231787127456,
          -5.994816291122958,
          -5.988270077554804,
          -5.981590300855887,
          -5.974774035729048,
          -5.967818274294567,
          -5.960719923114819,
          -5.953475800089837,
          -5.946082631217028,
          -5.938537047208357,
          -5.930835579957284,
          -5.922974658847864,
          -5.914950606897636,
          -5.906759636725352,
          -5.8983978463344915,
          -5.889861214702311,
          -5.881145597164157,
          -5.872246720581779,
          -5.863160178283569,
          -5.853881424764442,
          -5.844405770131479,
          -5.834728374281353,
          -5.824844240794139,
          -5.814748210527127,
          -5.804434954891644,
          -5.7938989687939815,
          -5.78313456322107,
          -5.7721358574496895,
          -5.7608967708565695,
          -5.749411014305713,
          -5.7376720810867585,
          -5.725673237377251,
          -5.713407512199213,
          -5.700867686838251,
          -5.688046283691801,
          -5.674935554509694,
          -5.661527467988505,
          -5.647813696677687,
          -5.633785603152322,
          -5.61943422540461,
          -5.604750261401479,
          -5.5897240527527865,
          -5.574345567429516,
          -5.558604381466673,
          -5.542489659581131,
          -5.525990134627923,
          -5.509094085813531,
          -5.491789315577279,
          -5.47406312504463,
          -5.455902287948848,
          -5.437293022908117,
          -5.41822096393555,
          -5.398671129049968,
          -5.378627886842315,
          -5.358074920841407,
          -5.33699519150783,
          -5.3153708956694175,
          -5.293183423195886,
          -5.270413310689914,
          -5.2470401919529905,
          -5.22304274496056,
          -5.198398635055689,
          -5.173084454043739,
          -5.147075654837678,
          -5.120346481271049,
          -5.092869892656171,
          -5.0646174826223564,
          -5.035559391722739,
          -5.0056642132430085,
          -4.974898891588105,
          -4.943228612555027,
          -4.910616684725165,
          -4.877024411127443,
          -4.8424109502267125,
          -4.806733165188291,
          -4.769945460248048,
          -4.731999602882057,
          -4.692844530318276,
          -4.6524261387561445,
          -4.6106870534653135,
          -4.567566377708205,
          -4.522999418174653,
          -4.476917384326153,
          -4.429247058708764,
          -4.37991043491234,
          -4.328824319409683,
          -4.275899892999433,
          -4.221042226990898,
          -4.164149748584002,
          -4.105113649111514,
          -4.043817227889022,
          -3.9801351633460977,
          -3.9139327018616985,
          -3.845064753252319,
          -3.773374880137813,
          -3.698694166368069,
          -3.620839947281474,
          -3.5396143817058814,
          -3.4548028422004933,
          -3.366172095961856,
          -3.2734682439342278,
          -3.176414379774272,
          -3.0747079232155237,
          -2.9680175737439436,
          -2.855979819977409,
          -2.738194927271066,
          -2.6142223102249913,
          -2.4835751772046617,
          -2.345714309661642,
          -2.2000408086673,
          -2.0458876029258777,
          -1.8825094643109699,
          -1.7090712156752925,
          -1.5246337372046614,
          -1.328137276433326,
          -1.1183814356887245,
          -0.8940010387895683,
          -0.65343685191612,
          -0.3948998313912897,
          -0.11632716489757389,
          0.18467217897032384,
          0.5108854352465926,
          0.8655816555023321,
          1.2526205228720197,
          1.6765920522988882,
          2.1429979110690933,
          2.658489581884165,
          3.231185304192083,
          3.8710979683478897,
          4.590722085664892,
          5.405853386946498,
          6.336756218278762,
          7.409864024792263,
          8.6603203233281,
          10.13588833458208,
          11.90317417878618,
          14.057935656752555,
          16.742990343826946,
          20.181174089189295,
          24.740510467234735,
          31.075464662217605,
          40.472950361167904,
          55.85965487052721,
          85.63463417182864,
          167.68679067661765,
          null,
          -240.18835349860052,
          -115.33281407054228,
          -77.7681942810415,
          -59.665039597155676,
          -49.011960530572175,
          -41.99541507375927,
          -37.025256861589554,
          -33.320496810076506,
          -30.45270687899598,
          -28.16725023070975,
          -26.303272410714527,
          -24.754166596152107,
          -23.4464832163056,
          -22.32796911159155,
          -21.360435858819066,
          -20.515325953785663,
          -19.77085679437166,
          -19.110124091373592,
          -18.51980862400898,
          -17.98927368892649,
          -17.50992214224042,
          -17.07472991067747,
          -16.67790193671975,
          -16.314614639414124,
          -15.980820530792279,
          -15.673098163587667,
          -15.3885355967614,
          -15.124638957514657,
          -14.879260012775983,
          -14.650538293944583,
          -14.43685447383898,
          -14.236792523670786,
          -14.049108779729071,
          -13.8727064913295,
          -13.706614749402995,
          -13.549970940622682,
          -13.402006057553756,
          -13.26203233678702,
          -13.129432805709554,
          -13.003652402739142,
          -12.88419040146477,
          -12.770593920651073,
          -12.66245234276796,
          -12.559392496043683,
          -12.461074480906237,
          -12.367188042454666,
          -12.277449407393917,
          -12.191598517504254,
          -12.109396602834765,
          -12.030624046925684,
          -11.955078503870203,
          -11.882573233220006,
          -11.812935623889565,
          -11.746005882494957,
          -11.681635865145132,
          -11.6196880347117,
          -11.56003452812713,
          -11.502556320402334,
          -11.447142473860403,
          -11.393689462620731,
          -11.342100563680397,
          -11.29228530705458,
          -11.244158978401213,
          -11.197642168376106,
          -11.152660363674627,
          -11.109143575330888,
          -11.067026000371857,
          -11.026245713387311,
          -10.986744384973907,
          -10.948467024360076,
          -10.911361743824408,
          -10.875379542782976,
          -10.84047410965726,
          -10.80660163983702,
          -10.773720668232665,
          -10.741791915072046,
          -10.710778143734082,
          -10.680644029538179,
          -10.6513560385165,
          -10.622882315293694,
          -10.595192579286618,
          -10.568258028511472,
          -10.542051250356602,
          -10.516546138739178,
          -10.491717817118774,
          -10.467542566891257,
          -10.443997760728337,
          -10.421061800469609,
          -10.398714059208114,
          -10.376934827242446,
          -10.3557052615983,
          -10.335007338846541,
          -10.314823810970045,
          -10.295138164051648,
          -10.275934579574724,
          -10.257197898146345,
          -10.238913585467076,
          -10.221067700387426,
          -10.203646864902888,
          -10.186638235951483,
          -10.170029478889152,
          -10.153808742527463,
          -10.137964635627078,
          -10.122486204749448,
          -10.107362913375372,
          -10.092584622207234,
          -10.078141570577118,
          -10.06402435888886,
          -10.050223932028034,
          -10.036731563677627,
          -10.02353884148267,
          -10.010637653010543,
          -9.998020172457368,
          -9.985678848055144,
          -9.97360639013631,
          -9.9617957598165,
          -9.950240158258282,
          -9.938933016481178,
          -9.927867985686236,
          -9.917038928064605,
          -9.906439908062469,
          -9.896065184075985,
          -9.885909200551554,
          -9.875966580468903,
          -9.86623211818508,
          -9.856700772619615,
          -9.847367660761936,
          -9.838228051483204,
          -9.829277359636391,
          -9.820511140428678,
          -9.8119250840519,
          -9.803515010557229,
          -9.795276864961105,
          -9.787206712570613,
          -9.779300734516562,
          -9.771555223483853,
          -9.763966579628944,
          -9.756531306674772,
          -9.749246008174485,
          -9.74210738393519,
          -9.735112226594056,
          -9.72825741833911,
          -9.721539927767566,
          -9.714956806875227,
          -9.70850518817035,
          -9.7021822819062,
          -9.695985373426586,
          -9.68991182061892,
          -9.683959051469907,
          -9.67812456171899,
          -9.672405912604939,
          -9.666800728701489,
          -9.661306695837693,
          -9.65592155909936,
          -9.650643120907803,
          -9.645469239172371,
          -9.640397825513642,
          -9.635426843553937,
          -9.630554307272346,
          -9.6257782794214,
          -9.62109687000259,
          -9.616508234798411,
          -9.612010573958255,
          -9.607602130636035,
          -9.60328118967728,
          -9.599046076353526,
          -9.594895155142218,
          -9.590826828549979,
          -9.586839535977651,
          -9.582931752625289,
          -9.579101988435434,
          -9.575348787073247,
          -9.571670724941802,
          -9.568066410231323,
          -9.5645344820009,
          -9.561073609291352,
          -9.557682490268135,
          -9.554359851392952,
          -9.55110444662308,
          -9.547915056637253,
          -9.544790488087056,
          -9.541729572872953,
          -9.53873116744384,
          -9.5357941521194,
          -9.532917430434262,
          -9.53009992850319,
          -9.52734059440655,
          -9.5246383975952,
          -9.52199232831419,
          -9.519401397044504,
          -9.516864633962198,
          -9.514381088414314,
          -9.511949828410925,
          -9.509569940132767,
          -9.507240527453872,
          -9.504960711478647,
          -9.502729630092922,
          -9.500546437528454,
          -9.498410303940378,
          -9.49632041499722,
          -9.494275971482947,
          -9.492276188910711,
          -9.490320297147832,
          -9.488407540051634,
          -9.486537175115801,
          -9.484708473126833,
          -9.482920717830309,
          -9.481173205606597,
          -9.479465245155689,
          -9.477796157190877,
          -9.476165274140941,
          -9.474571939860592,
          -9.473015509348896,
          -9.47149534847537,
          -9.47001083371358,
          -9.468561351881888,
          -9.46714629989122,
          -9.46576508449956,
          -9.46441712207295,
          -9.463101838352841,
          -9.461818668229515,
          -9.460567055521448,
          -9.459346452760387,
          -9.45815632098197,
          -9.456996129521707,
          -9.455865355816162,
          -9.45476348520916,
          -9.453690010762877,
          -9.452644433073635,
          -9.451626260092283,
          -9.450635006948994,
          -9.449670195782362,
          -9.448731355572654,
          -9.447818021979094,
          -9.446929737181042,
          -9.44606604972297,
          -9.445226514363098,
          -9.44441069192559,
          -9.44361814915619,
          -9.442848458581206,
          -9.442101198369732,
          -9.441375952199003,
          -9.440672309122814,
          -9.439989863442861,
          -9.439328214582982,
          -9.438686966966145,
          -9.438065729894138,
          -9.437464117429881,
          -9.43688174828225,
          -9.436318245693364,
          -9.435773237328268,
          -9.435246355166905,
          -9.434737235398332,
          -9.434245518317116,
          -9.43377084822183,
          -9.433312873315586,
          -9.432871245608561,
          -9.432445620822437,
          -9.432035658296689,
          -9.431641020896704,
          -9.431261374923626,
          -9.430896390025909,
          -9.430545739112516,
          -9.43020909826769,
          -9.429886146667306,
          -9.429576566496676,
          -9.429280042869838,
          -9.428996263750223,
          -9.428724919872698,
          -9.428465704666912,
          -9.428218314181926,
          -9.427982447012065,
          -9.427757804223972,
          -9.427544089284808,
          -9.42734100799157,
          -9.427148268401488,
          -9.426965580763461,
          -9.426792657450502,
          -9.426629212893147,
          -9.426474963513815,
          -9.42632962766206,
          -9.4261929255507,
          -9.42606457919278,
          -9.42594431233936,
          -9.42583185041806,
          -9.425726920472366,
          -9.425629251101661,
          -9.425538572401926,
          -9.425454615907128,
          -9.425377114531218,
          -9.425305802510763,
          -9.425240415348135,
          -9.425180689755267,
          -9.425126363597931,
          -9.42507717584053,
          -9.425032866491353,
          -9.424993176548291,
          -9.424957847944988,
          -9.424926623497377,
          -9.424899246850623,
          -9.4248754624264,
          -9.424855015370515,
          -9.42483765150084,
          -9.424823117255528,
          -9.424811159641509,
          -9.424801526183206,
          -9.424793964871492,
          -9.424788224112843,
          -9.424784052678655,
          -9.424781199654733,
          -9.424779414390908,
          -9.424778446450759,
          -9.424778045561442,
          -9.424777961563569,
          -9.424777944361155,
          -9.424777743871571,
          -9.424777109975528,
          -9.424775792467019,
          -9.424773541003242,
          -9.42477010505446,
          -9.424765233853778,
          -9.424758676346828,
          -9.424750181141313,
          -9.424739496456436,
          -9.42472637007213,
          -9.424710549278133,
          -9.424691780822828,
          -9.42466981086186,
          -9.424644384906507,
          -9.42461524777177,
          -9.424582143524153,
          -9.424544815429142,
          -9.424503005898316,
          -9.424456456436113,
          -9.42440490758619,
          -9.424348098877365,
          -9.42428576876913,
          -9.42421765459669,
          -9.424143492515524,
          -9.424063017445409,
          -9.423975963013934,
          -9.423882061499418,
          -9.423781043773257,
          -9.42367263924164,
          -9.42355657578662,
          -9.423432579706507,
          -9.423300375655565,
          -9.423159686582963,
          -9.423010233670981,
          -9.422851736272408,
          -9.422683911847123,
          -9.422506475897823,
          -9.42231914190486,
          -9.42212162126016,
          -9.421913623200197,
          -9.421694854737959,
          -9.421465020593915,
          -9.421223823125908,
          -9.420970962257963,
          -9.420706135407949,
          -9.420429037414085,
          -9.42013936046023,
          -9.419836793999908,
          -9.419521024679067,
          -9.41919173625748,
          -9.418848609528768,
          -9.41849132223902,
          -9.418119549003915,
          -9.417732961224345,
          -9.417331227000464,
          -9.41691401104412,
          -9.416480974589632,
          -9.416031775302821,
          -9.415566067188292,
          -9.415083500494873,
          -9.414583721619161,
          -9.414066373007135,
          -9.413531093053741,
          -9.412977516000423,
          -9.41240527183051,
          -9.411813986162395,
          -9.411203280140455,
          -9.410572770323617,
          -9.409922068571511,
          -9.409250781928142,
          -9.408558512502974,
          -9.40784485734939,
          -9.407109408340402,
          -9.406351752041541,
          -9.405571469580876,
          -9.404768136515985,
          -9.403941322697891,
          -9.40309059213177,
          -9.402215502834395,
          -9.401315606688184,
          -9.400390449291748,
          -9.39943956980684,
          -9.398462500801571,
          -9.397458768089798,
          -9.396427890566542,
          -9.395369380039316,
          -9.394282741055246,
          -9.393167470723819,
          -9.39202305853515,
          -9.390848986173609,
          -9.38964472732664,
          -9.388409747488671,
          -9.38714350375987,
          -9.385845444639665,
          -9.384515009814807,
          -9.383151629941791,
          -9.381754726423498,
          -9.380323711179795,
          -9.378857986411962,
          -9.377356944360695,
          -9.375819967057478,
          -9.374246426069124,
          -9.372635682235217,
          -9.370987085398237,
          -9.36929997412614,
          -9.367573675427064,
          -9.365807504455994,
          -9.364000764212996,
          -9.362152745232821,
          -9.360262725265542,
          -9.358329968947881,
          -9.356353727464965,
          -9.354333238202107,
          -9.352267724386309,
          -9.350156394717109,
          -9.347998442986349,
          -9.345793047686552,
          -9.343539371607394,
          -9.34123656141993,
          -9.338883747248087,
          -9.336480042226937,
          -9.334024542047308,
          -9.331516324486218,
          -9.328954448922559,
          -9.326337955837566,
          -9.323665866299404,
          -9.320937181431349,
          -9.318150881862922,
          -9.31530592716328,
          -9.31240125525627,
          -9.309435781816351,
          -9.306408399644699,
          -9.303317978024738,
          -9.300163362056205,
          -9.296943371967023,
          -9.293656802401994,
          -9.290302421687471,
          -9.286878971071024,
          -9.283385163935035,
          -9.279819684983295,
          -9.27618118939936,
          -9.27246830197562,
          -9.268679616211838,
          -9.264813693381852,
          -9.260869061567222,
          -9.256844214656292,
          -9.252737611307351,
          -9.24854767387431,
          -9.244272787293225,
          -9.239911297928174,
          -9.2354615123745,
          -9.230921696217768,
          -9.22629007274642,
          -9.221564821616017,
          -9.216744077463119,
          -9.211825928466341,
          -9.206808414852384,
          -9.20168952734451,
          -9.196467205550768,
          -9.191139336289403,
          -9.185703751848337,
          -9.180158228175857,
          -9.174500482999251,
          -9.168728173867896,
          -9.162838896117485,
          -9.156830180751346,
          -9.150699492235136,
          -9.144444226200642,
          -9.138061707054192,
          -9.131549185485184,
          -9.12490383586976,
          -9.118122753564291,
          -9.111202952083476,
          -9.10414136015691,
          -9.096934818658275,
          -9.089580077400507,
          -9.082073791790004,
          -9.074412519332821,
          -9.066592715984822,
          -9.058610732337886,
          -9.050462809633373,
          -9.042145075593542,
          -9.033653540061417,
          -9.024984090438421,
          -9.016132486909004,
          -9.00709435744048,
          -8.997865192545458,
          -8.98844033979398,
          -8.978814998060841,
          -8.968984211493419,
          -8.95894286318391,
          -8.948685668528755,
          -8.938207168257447,
          -8.927501721110877,
          -8.916563496148894,
          -8.905386464664787,
          -8.893964391682923,
          -8.882290827014632,
          -8.870359095844814,
          -8.858162288820727,
          -8.845693251611793,
          -8.832944573906953,
          -8.819908577814425,
          -8.80657730562501,
          -8.792942506898353,
          -8.778995624827823,
          -8.764727781836353,
          -8.750129764352664,
          -8.735192006712294,
          -8.719904574124719,
          -8.704257144642481,
          -8.688238990063235,
          -8.671838955690841,
          -8.655045438874481,
          -8.637846366239446,
          -8.620229169515321,
          -8.602180759859483,
          -8.583687500565967,
          -8.56473517803971,
          -8.545308970905934,
          -8.525393417114003,
          -8.504972378881373,
          -8.484029005311049,
          -8.462545692500097,
          -8.440504040940224,
          -8.4178848099943,
          -8.39466786921096,
          -8.370832146218882,
          -8.34635557091677,
          -8.321215015647708,
          -8.295386231017627,
          -8.268843776982228,
          -8.24156094879125,
          -8.21350969733634,
          -8.184660543402405,
          -8.15498248527203,
          -8.124442899072717,
          -8.093007431194147,
          -8.060639882028962,
          -8.027302080209024,
          -7.992953746419344,
          -7.957552345766373,
          -7.921052927563714,
          -7.883407951265573,
          -7.844567097129623,
          -7.804477060024601,
          -7.763081324603901,
          -7.720319919851947,
          -7.676129150760568,
          -7.630441304609377,
          -7.583184329002696,
          -7.534281478440777,
          -7.483650925780065,
          -7.431205334443802,
          -7.376851386677206,
          -7.320489262488275,
          -7.262012063150699,
          -7.201305172265491,
          -7.138245546345065,
          -7.072700925679307,
          -7.004528954835599,
          -6.9335762004820465,
          -6.859677052274272,
          -6.782652490233167,
          -6.7023086993013985,
          -6.618435508509742,
          -6.5308046282896415,
          -6.439167654804418,
          -6.343253804566865,
          -6.242767335831979,
          -6.137384605050426,
          -6.0267506966691915,
          -5.910475552343463,
          -5.788129510615397,
          -5.659238149573497,
          -5.523276302021252,
          -5.379661083998337,
          -5.227743741524583,
          -5.066800075058836,
          -4.896019143537157,
          -4.714489876242381,
          -4.521185126020685,
          -4.314942574580647,
          -4.094441740249193,
          -3.858176127342084,
          -3.604419275734723,
          -3.3311830929493107,
          -3.036166341465223,
          -2.7166904563568472,
          -2.369618902353743,
          -1.9912549252434957,
          -1.5772106286722742,
          -1.1222375345738342,
          -0.6200047259620671,
          -0.06280462509501916,
          0.5588427136360714,
          1.2567301263385335,
          2.0457145246286714,
          2.9447811842690896,
          3.978584760779192,
          5.179736261782313,
          6.5922942228673165,
          8.277271002657248,
          10.321655624962002,
          12.853885388213797,
          16.071870596457202,
          20.297313239523938,
          26.09043630193242,
          34.5213420380004,
          47.920950669835904,
          72.51324753093044,
          132.36946134857945,
          null,
          null,
          -135.59486599054873,
          -87.77042242348608,
          -66.47971592526247,
          -54.43712685227426,
          -46.69277377898712,
          -41.294407958842534,
          -37.31659714745194,
          -34.264089889832476,
          -31.84788091749583,
          -29.887971574278247,
          -28.266404669700805,
          -26.902654720904913,
          -25.739871407597732,
          -24.7367744453422,
          -23.862664805678442,
          -23.09423856087306,
          -22.41348660613015,
          -21.806271706738713,
          -21.261341030726115,
          -20.769626222823256,
          -20.323737856846606,
          -19.91759407424823,
          -19.546143616387575,
          -19.20515639602384,
          -18.891063143931262,
          -18.600831218579394,
          -18.331867408761955,
          -18.081941123685468,
          -17.849123149971,
          -17.63173641510721,
          -17.428316098119556,
          -17.23757708069319,
          -17.05838720972509,
          -16.88974519574673,
          -16.730762235805244,
          -16.58064664857084,
          -16.43869096095707,
          -16.304261001742262,
          -16.176786647458684,
          -16.05575393571582,
          -15.94069831588671,
          -15.831198850287347,
          -15.726873213268664,
          -15.627373362997792,
          -15.53238178268003,
          -15.44160820569099,
          -15.354786753462008,
          -15.271673426678051,
          -15.1920438999269,
          -15.115691577827345,
          -15.042425877166693,
          -14.972070704972309,
          -14.904463106933047,
          -14.839452064331919,
          -14.776897420793338,
          -14.716668922793842,
          -14.658645360109439,
          -14.602713794264915,
          -14.548768864649313,
          -14.496712163326283,
          -14.446451670735534,
          -14.397901245474877,
          -14.350980162212803,
          -14.305612692515956,
          -14.261727724011848,
          -14.219258413859492,
          -14.178141872973773,
          -14.138318877867148,
          -14.099733607330666,
          -14.062333401491147,
          -14.02606854105837,
          -13.990892044814167,
          -13.956759483609842,
          -13.923628809322462,
          -13.891460197384598,
          -13.860215901648322,
          -13.829860120469583,
          -13.800358873014828,
          -13.771679884890576,
          -13.74379248228588,
          -13.716667493898463,
          -13.690277159983763,
          -13.664595047931451,
          -13.639595973828987,
          -13.615255929522288,
          -13.591552014730077,
          -13.568462373807064,
          -13.545966136789534,
          -13.52404336438847,
          -13.502674996624908,
          -13.481842804829974,
          -13.461529346754382,
          -13.441717924555563,
          -13.422392545449235,
          -13.403537884830047,
          -13.385139251683082,
          -13.367182556121074,
          -13.349654278897162,
          -13.332541442754021,
          -13.3158315854814,
          -13.299512734564814,
          -13.283573383316606,
          -13.268002468388987,
          -13.252789348577167,
          -13.237923784826355,
          -13.223395921364176,
          -13.209196267885018,
          -13.195315682718347,
          -13.18174535691864,
          -13.168476799217995,
          -13.155501821787837,
          -13.142812526759162,
          -13.130401293454483,
          -13.118260766288383,
          -13.106383843295692,
          -13.094763665250051,
          -13.083393605337527,
          -13.072267259352369,
          -13.061378436384757,
          -13.050721149971482,
          -13.040289609683333,
          -13.030078213124083,
          -13.020081538317623,
          -13.010294336461778,
          -13.000711525027992,
          -12.99132818118805,
          -12.982139535549798,
          -12.97314096618489,
          -12.964327992933107,
          -12.955696271968083,
          -12.947241590610783,
          -12.938959862377574,
          -12.930847122250471,
          -12.92289952215828,
          -12.915113326657425,
          -12.907484908802488,
          -12.900010746196722,
          -12.89268741721331,
          -12.885511597379105,
          -12.878480055912416,
          -12.871589652407504,
          -12.864837333658476,
          -12.858220130615678,
          -12.851735155468411,
          -12.845379598847632,
          -12.839150727143121,
          -12.833045879929587,
          -12.827062467496535,
          -12.821197968477156,
          -12.815449927571573,
          -12.809815953360019,
          -12.804293716201995,
          -12.798880946217267,
          -12.793575431345186,
          -12.788375015478733,
          -12.783277596669869,
          -12.778281125403193,
          -12.773383602934704,
          -12.768583079692966,
          -12.763877653739886,
          -12.759265469288454,
          -12.754744715275175,
          -12.75031362398462,
          -12.745970469724089,
          -12.741713567546135,
          -12.737541272016951,
          -12.733451976028785,
          -12.729444109654434,
          -12.725516139042172,
          -12.72166656534944,
          -12.717893923713618,
          -12.714196782258549,
          -12.710573741135173,
          -12.707023431595072,
          -12.703544515095519,
          -12.70013568243477,
          -12.696795652916498,
          -12.693523173542095,
          -12.690317018229875,
          -12.687175987060064,
          -12.684098905544575,
          -12.681084623920688,
          -12.678132016467615,
          -12.675239980845166,
          -12.672407437453684,
          -12.669633328814324,
          -12.666916618969127,
          -12.664256292899918,
          -12.661651355965517,
          -12.659100833356513,
          -12.656603769566903,
          -12.65415922788212,
          -12.651766289882694,
          -12.64942405496311,
          -12.647131639865265,
          -12.644888178225965,
          -12.642692820138045,
          -12.640544731724564,
          -12.638443094725623,
          -12.636387106097411,
          -12.634375977622966,
          -12.63240893553434,
          -12.6304852201457,
          -12.628604085497008,
          -12.626764799007955,
          -12.624966641141727,
          -12.623208905078336,
          -12.621490896397162,
          -12.619811932768375,
          -12.618171343653003,
          -12.616568470011266,
          -12.615002664018991,
          -12.613473288791788,
          -12.611979718116718,
          -12.610521336191274,
          -12.609097537369356,
          -12.607707725914056,
          -12.606351315757042,
          -12.605027730264275,
          -12.603736402007925,
          -12.602476772544215,
          -12.601248292197058,
          -12.600050419847285,
          -12.598882622727256,
          -12.59774437622075,
          -12.596635163667877,
          -12.595554476174954,
          -12.594501812429106,
          -12.59347667851748,
          -12.592478587750938,
          -12.591507060492058,
          -12.590561623987341,
          -12.589641812203476,
          -12.588747165667531,
          -12.587877231310976,
          -12.587031562317389,
          -12.586209717973746,
          -12.585411263525206,
          -12.584635770033225,
          -12.583882814236985,
          -12.583151978417934,
          -12.58244285026744,
          -12.581755022757408,
          -12.581088094013758,
          -12.580441667192739,
          -12.579815350359935,
          -12.579208756371909,
          -12.57862150276039,
          -12.578053211618947,
          -12.57750350949206,
          -12.576972027266505,
          -12.576458400065023,
          -12.575962267142147,
          -12.575483271782176,
          -12.575021061199186,
          -12.574575286439067,
          -12.574145602283457,
          -12.573731667155585,
          -12.57333314302791,
          -12.572949695331541,
          -12.572580992867357,
          -12.572226707718778,
          -12.57188651516616,
          -12.571560093602725,
          -12.571247124452018,
          -12.570947292086805,
          -12.570660283749403,
          -12.570385789473374,
          -12.570123502006535,
          -12.56987311673527,
          -12.569634331610072,
          -12.569406847072292,
          -12.569190365982053,
          -12.568984593547277,
          -12.568789237253824,
          -12.568604006796654,
          -12.568428614012017,
          -12.568262772810629,
          -12.568106199111785,
          -12.567958610778382,
          -12.567819727552832,
          -12.567689270993824,
          -12.567566964413881,
          -12.567452532817738,
          -12.567345702841438,
          -12.567246202692191,
          -12.567153762088907,
          -12.567068112203401,
          -12.566988985602253,
          -12.566916116189262,
          -12.566849239148508,
          -12.566788090887968,
          -12.56673240898365,
          -12.566681932124265,
          -12.566636400056366,
          -12.566595553529947,
          -12.566559134244478,
          -12.566526884795362,
          -12.566498548620757,
          -12.566473869948783,
          -12.566452593745053,
          -12.566434465660532,
          -12.56641923197968,
          -12.566406639568878,
          -12.566396435825096,
          -12.566388368624782,
          -12.566382186272968,
          -12.566377637452556,
          -12.566374471173756,
          -12.566372436723675,
          -12.566371283616018,
          -12.566370761540883,
          -12.566370620314638,
          -12.566370609829844,
          -12.566370480005224,
          -12.56636998073562,
          -12.566368861841964,
          -12.566366873021199,
          -12.566363763796165,
          -12.566359283465392,
          -12.566353181052811,
          -12.566345205257344,
          -12.566335104402352,
          -12.566322626384931,
          -12.56630751862502,
          -12.566289528014304,
          -12.566268400864892,
          -12.566243882857762,
          -12.5662157189909,
          -12.566183653527188,
          -12.56614742994195,
          -12.566106790870158,
          -12.566061478053296,
          -12.566011232285815,
          -12.565955793361194,
          -12.565894900017563,
          -12.565828289882862,
          -12.565755699419528,
          -12.56567686386866,
          -12.565591517193665,
          -12.565499392023332,
          -12.565400219594329,
          -12.565293729693076,
          -12.56517965059699,
          -12.565057709015054,
          -12.564927630027688,
          -12.564789137025908,
          -12.564641951649705,
          -12.56448579372567,
          -12.56432038120378,
          -12.564145430093342,
          -12.563960654398073,
          -12.563765766050249,
          -12.563560474843921,
          -12.56334448836715,
          -12.563117511933225,
          -12.562879248510844,
          -12.56262939865319,
          -12.562367660425902,
          -12.562093729333876,
          -12.561807298246858,
          -12.561508057323824,
          -12.561195693936035,
          -12.56086989258881,
          -12.560530334841904,
          -12.560176699228478,
          -12.559808661172623,
          -12.559425892905363,
          -12.559028063379117,
          -12.55861483818054,
          -12.558185879441739,
          -12.557740845749745,
          -12.55727939205426,
          -12.55680116957356,
          -12.556305825698539,
          -12.555793003894815,
          -12.555262343602847,
          -12.554713480135993,
          -12.554146044576456,
          -12.553559663669024,
          -12.552953959712584,
          -12.552328550449294,
          -12.551683048951357,
          -12.551017063505343,
          -12.55033019749393,
          -12.54962204927505,
          -12.54889221205831,
          -12.548140273778618,
          -12.547365816966924,
          -12.546568418618003,
          -12.545747650055162,
          -12.544903076791789,
          -12.544034258389633,
          -12.54314074831374,
          -12.542222093783904,
          -12.541277835622541,
          -12.540307508098882,
          -12.53931063876934,
          -12.538286748313954,
          -12.537235350368794,
          -12.536155951354141,
          -12.535048050298396,
          -12.533911138657487,
          -12.532744700129696,
          -12.53154821046574,
          -12.53032113727393,
          -12.529062939820275,
          -12.52777306882335,
          -12.526450966243772,
          -12.525096065068087,
          -12.523707789086894,
          -12.522285552667029,
          -12.520828760517572,
          -12.519336807449514,
          -12.517809078128863,
          -12.516244946822932,
          -12.514643777139627,
          -12.513004921759475,
          -12.511327722160138,
          -12.509611508333183,
          -12.5078555984928,
          -12.506059298776243,
          -12.504221902935665,
          -12.502342692021056,
          -12.500420934054016,
          -12.498455883691951,
          -12.49644678188248,
          -12.494392855507563,
          -12.492293317017124,
          -12.490147364051698,
          -12.487954179053737,
          -12.485712928867192,
          -12.483422764324894,
          -12.481082819823342,
          -12.478692212884427,
          -12.476250043703562,
          -12.473755394683787,
          -12.471207329955302,
          -12.468604894879848,
          -12.465947115539436,
          -12.463232998208769,
          -12.46046152881079,
          -12.457631672354696,
          -12.454742372355716,
          -12.451792550236023,
          -12.448781104705962,
          -12.44570691112491,
          -12.44256882084094,
          -12.439365660508404,
          -12.436096231382688,
          -12.432759308591084,
          -12.429353640378942,
          -12.42587794733006,
          -12.422330921560246,
          -12.418711225883046,
          -12.41501749294638,
          -12.41124832433901,
          -12.40740228966554,
          -12.403477925588586,
          -12.399473734836878,
          -12.395388185177705,
          -12.391219708352315,
          -12.386966698972667,
          -12.382627513377782,
          -12.378200468448135,
          -12.373683840376069,
          -12.369075863390481,
          -12.364374728433686,
          -12.35957858178832,
          -12.35468552365218,
          -12.349693606658526,
          -12.344600834339502,
          -12.339405159530083,
          -12.334104482709732,
          -12.328696650279104,
          -12.323179452768573,
          -12.317550622975594,
          -12.31180783402751,
          -12.305948697366201,
          -12.299970760651057,
          -12.293871505576151,
          -12.287648345597693,
          -12.281298623567322,
          -12.274819609266567,
          -12.268208496837847,
          -12.261462402106638,
          -12.254578359789589,
          -12.2475533205828,
          -12.240384148124125,
          -12.23306761582325,
          -12.225600403552686,
          -12.217979094192426,
          -12.21020017002086,
          -12.20226000894364,
          -12.194154880552162,
          -12.185880942002523,
          -12.177434233705206,
          -12.168810674815575,
          -12.16000605851396,
          -12.151016047064134,
          -12.141836166637772,
          -12.132461801891742,
          -12.12288819028468,
          -12.113110416117674,
          -12.103123404283657,
          -12.092921913708597,
          -12.082500530466495,
          -12.07185366054941,
          -12.060975522271773,
          -12.049860138287565,
          -12.03850132719699,
          -12.02689269471764,
          -12.01502762439396,
          -12.002899267816069,
          -11.990500534317889,
          -11.977824080121753,
          -11.964862296894294,
          -11.95160729967649,
          -11.938050914146988,
          -11.924184663175804,
          -11.909999752621673,
          -11.89548705632269,
          -11.88063710022682,
          -11.865440045603547,
          -11.849885671274528,
          -11.833963354795513,
          -11.817662052516328,
          -11.800970278440705,
          -11.783876081800091,
          -11.766367023249838,
          -11.748430149587765,
          -11.730051966886707,
          -11.711218411924369,
          -11.691914821782454,
          -11.672125901477422,
          -11.651835689472227,
          -11.631027520905205,
          -11.60968398835833,
          -11.587786899970324,
          -11.565317234682217,
          -11.542255094384544,
          -11.518579652711935,
          -11.494269100208731,
          -11.46930058556158,
          -11.443650152565581,
          -11.417292672459089,
          -11.390201771224103,
          -11.362349751410747,
          -11.333707507998094,
          -11.304244437753301,
          -11.273928341496365,
          -11.242725318612745,
          -11.210599653088028,
          -11.177513690258454,
          -11.143427703382226,
          -11.108299749038396,
          -11.07208551024485,
          -11.034738126062425,
          -10.99620800630668,
          -10.956442629825862,
          -10.915386324620414,
          -10.872980027866266,
          -10.829161023667364,
          -10.783862656087708,
          -10.737014014700145,
          -10.688539589533052,
          -10.638358891880937,
          -10.58638603697482,
          -10.532529283959633,
          -10.476690527994036,
          -10.418764738558648,
          -10.3586393372041,
          -10.296193506984064,
          -10.231297424659116,
          -10.16381140540272,
          -10.093584948153467,
          -10.02045566787981,
          -9.944248098816136,
          -9.86477235010417,
          -9.781822592156482,
          -9.695175348344652,
          -9.6045875621572,
          -9.509794404630243,
          -9.410506780398675,
          -9.306408482902878,
          -9.197152939789053,
          -9.082359477933664,
          -8.961609023283756,
          -8.834439133157247,
          -8.700338236888932,
          -8.558738933626763,
          -8.40901016214811,
          -8.250448014823295,
          -8.082264913687748,
          -7.903576797466879,
          -7.7133878796529896,
          -7.510572422908318,
          -7.293852825397693,
          -7.061773117979613,
          -6.8126667104651135,
          -6.544616876425652,
          -6.255407994914045,
          -5.942464924350846,
          -5.602776996004845,
          -5.232801873862508,
          -4.828342771380154,
          -4.384389993830988,
          -3.894914098217395,
          -3.3525925117670567,
          -2.7484432195910227,
          -2.0713264530152777,
          -1.3072553397786066,
          -0.4384242390826145,
          0.5581900086338987,
          1.7128902369634815,
          3.0663831042111944,
          4.674663222391128,
          6.616933847462914,
          9.00902128034165,
          12.027309479940346,
          15.95426772174807,
          21.27232069459253,
          28.878824507246364,
          40.65436548514756,
          61.31746017135638,
          107.02098400538962,
          null,
          null,
          -162.34579535040095,
          -99.26623036156215,
          -73.85534876184741,
          -60.13089627427489,
          -51.538945016811375,
          -45.65444492501436,
          -41.37221686850193,
          -38.11654972937619,
          -35.55804289761163,
          -33.49460827293693,
          -31.795382271937417,
          -30.371888485444714,
          -29.162161565440186,
          -28.121509506382957,
          -27.216886912881286,
          -26.423333204725452,
          -25.72164261236122,
          -25.096796053470456,
          -24.536879265590542,
          -24.0323199269276,
          -23.57533917593053,
          -23.159550378180306,
          -22.779660996706262,
          -22.431247925368844,
          -22.110585999118165,
          -21.814515554110375,
          -21.540339042962074,
          -21.285739530867993,
          -21.04871585387176,
          -20.827530596197043,
          -20.620668024278277,
          -20.426799822981078,
          -20.244756996337166,
          -20.073506676543747,
          -19.91213286926861,
          -19.759820377230316,
          -19.615841306380148,
          -19.479543683275402,
          -19.35034180808138,
          -19.227708042091216,
          -19.11116578691969,
          -19.000283458395273,
          -18.894669294526327,
          -18.793966865896802,
          -18.697851180062084,
          -18.606025290238478,
          -18.518217333731474,
          -18.434177937884265,
          -18.353677941418237,
          -18.27650638731349,
          -18.20246875021555,
          -18.131385367007002,
          -18.063090043885783,
          -17.997428817218488,
          -17.93425884871996,
          -17.873447438271622,
          -17.814871140021843,
          -17.758414969375373,
          -17.70397169015393,
          -17.65144117262798,
          -17.600729814332468,
          -17.55175001661962,
          -17.50441971078777,
          -17.458661928394985,
          -17.414404411023963,
          -17.37157925533528,
          -17.33012258974288,
          -17.289974279471394,
          -17.25107765713193,
          -17.213379276276605,
          -17.176828685676824,
          -17.141378222321585,
          -17.10698282134775,
          -17.07359984130932,
          -17.041188903360336,
          -17.009711743075133,
          -16.979132073763598,
          -16.949415460252936,
          -16.92052920221381,
          -16.89244222619887,
          -16.86512498564359,
          -16.83854936815358,
          -16.812688609465283,
          -16.78751721352716,
          -16.763010878198997,
          -16.73914642611363,
          -16.71590174028813,
          -16.69325570410721,
          -16.671188145337133,
          -16.64967978385747,
          -16.628712182825566,
          -16.608267703014263,
          -16.58832946008398,
          -16.56888128457226,
          -16.549907684400917,
          -16.53139380971765,
          -16.5133254199049,
          -16.495688852600914,
          -16.478470994591934,
          -16.461659254444623,
          -16.44524153675842,
          -16.429206217927423,
          -16.413542123309327,
          -16.398238505706818,
          -16.383285025074773,
          -16.368671729371936,
          -16.354389036482942,
          -16.340427717141374,
          -16.32677887878951,
          -16.313433950315908,
          -16.30038466761498,
          -16.287623059917916,
          -16.275141436846987,
          -16.26293237614895,
          -16.250988712066608,
          -16.23930352430973,
          -16.227870127589956,
          -16.216682061686154,
          -16.205733082008972,
          -16.19501715063595,
          -16.18452842778955,
          -16.174261263733193,
          -16.164210191061365,
          -16.154369917361528,
          -16.144735318227387,
          -16.13530143060364,
          -16.12606344644434,
          -16.117016706667588,
          -16.108156695390466,
          -16.099479034429393,
          -16.090979478051462,
          -16.082653907963703,
          -16.074498328527753,
          -16.066508862188,
          -16.05868174510248,
          -16.051013322965748,
          -16.04350004701428,
          -16.03613847020499,
          -16.028925243558064,
          -16.021857112656253,
          -16.014930914292457,
          -16.008143573258646,
          -16.00149209926907,
          -15.994973584011149,
          -15.98858519831818,
          -15.982324189457676,
          -15.97618787853012,
          -15.970173657972838,
          -15.96427898916395,
          -15.958501400121925,
          -15.952838483296217,
          -15.947287893444733,
          -15.94184734559435,
          -15.936514613080503,
          -15.931287525662432,
          -15.926163967710671,
          -15.921141876463459,
          -15.916219240349198,
          -15.911394097371884,
          -15.90666453355689,
          -15.90202868145443,
          -15.897484718698157,
          -15.893030866616684,
          -15.888665388895578,
          -15.884386590287855,
          -15.880192815370862,
          -15.876082447347551,
          -15.872053906890446,
          -15.86810565102635,
          -15.86423617206027,
          -15.860443996536912,
          -15.856727684238127,
          -15.85308582721502,
          -15.849517048853171,
          -15.846020002969748,
          -15.842593372941218,
          -15.839235870860387,
          -15.835946236721732,
          -15.832723237633799,
          -15.829565667057686,
          -15.826472344070618,
          -15.823442112653545,
          -15.820473841001986,
          -15.817566420859105,
          -15.81471876687027,
          -15.811929815958251,
          -15.80919852671824,
          -15.806523878832065,
          -15.803904872500745,
          -15.801340527894835,
          -15.798829884621847,
          -15.796372001210097,
          -15.793965954608467,
          -15.791610839701402,
          -15.789305768838688,
          -15.787049871379427,
          -15.784842293249698,
          -15.782682196513454,
          -15.780568758956178,
          -15.778501173680816,
          -15.776478648715603,
          -15.774500406633338,
          -15.772565684181721,
          -15.770673731924388,
          -15.76882381389222,
          -15.767015207244665,
          -15.765247201940623,
          -15.763519100418678,
          -15.761830217286288,
          -15.760179879017642,
          -15.758567423659938,
          -15.756992200547737,
          -15.755453570025182,
          -15.753950903175786,
          -15.752483581559552,
          -15.751050996957188,
          -15.749652551121178,
          -15.748287655533481,
          -15.746955731169678,
          -15.745656208269283,
          -15.744388526112129,
          -15.74315213280052,
          -15.741946485047041,
          -15.740771047967833,
          -15.73962529488112,
          -15.73850870711088,
          -15.737420773795447,
          -15.736360991700925,
          -15.735328865039238,
          -15.734323905290683,
          -15.733345631030863,
          -15.732393567761804,
          -15.73146724774721,
          -15.730566209851665,
          -15.729689999383671,
          -15.728838167942447,
          -15.728010273268293,
          -15.727205879096493,
          -15.726424555014608,
          -15.725665876323037,
          -15.724929423898796,
          -15.724214784062374,
          -15.723521548447595,
          -15.722849313874384,
          -15.722197682224367,
          -15.721566260319179,
          -15.720954659801453,
          -15.720362497018368,
          -15.719789392907687,
          -15.719234972886222,
          -15.718698866740635,
          -15.718180708520537,
          -15.717680136433755,
          -15.717196792743778,
          -15.716730323669248,
          -15.716280379285477,
          -15.715846613427912,
          -15.715428683597489,
          -15.715026250867824,
          -15.71463897979418,
          -15.71426653832415,
          -15.713908597710025,
          -15.713564832422769,
          -15.71323492006756,
          -15.71291854130087,
          -15.712615379748984,
          -15.712325121927991,
          -15.71204745716511,
          -15.711782077521375,
          -15.71152867771563,
          -15.711286955049747,
          -15.711056609335069,
          -15.710837342820039,
          -15.710628860118945,
          -15.710430868141769,
          -15.710243076025098,
          -15.710065195064056,
          -15.709896938645228,
          -15.709738022180533,
          -15.709588163042028,
          -15.709447080497586,
          -15.709314495647446,
          -15.709190131361575,
          -15.709073712217835,
          -15.7089649644409,
          -15.708863615841919,
          -15.70876939575888,
          -15.708682034997654,
          -15.708601265773677,
          -15.708526821654266,
          -15.708458437501523,
          -15.708395849415812,
          -15.70833879467976,
          -15.7082870117028,
          -15.708240239966194,
          -15.708198219968507,
          -15.708160693171541,
          -15.708127401946683,
          -15.708098089521641,
          -15.708072499927546,
          -15.70805037794641,
          -15.7080314690589,
          -15.70801551939241,
          -15.708002275669418,
          -15.707991485156096,
          -15.70798289561114,
          -15.70797625523483,
          -15.707971312618257,
          -15.707967816692749,
          -15.707965516679398,
          -15.707964162038747,
          -15.707963502420565,
          -15.707963287613698,
          -15.707963267495991,
          -15.707963191984236,
          -15.70796281098414,
          -15.707961874340299,
          -15.707960131786129,
          -15.707957332893757,
          -15.707953227023854,
          -15.707947563275356,
          -15.707940090435095,
          -15.707930556927279,
          -15.707918710762836,
          -15.707904299488566,
          -15.707887070136104,
          -15.707866769170652,
          -15.707843142439486,
          -15.707815935120188,
          -15.707784891668577,
          -15.707749755766365,
          -15.707710270268446,
          -15.707666177149845,
          -15.707617217452285,
          -15.707563131230348,
          -15.707503657497217,
          -15.707438534169949,
          -15.70736749801429,
          -15.707290284588977,
          -15.707206628189516,
          -15.707116261791404,
          -15.707018916992777,
          -15.706914323956449,
          -15.706802211351315,
          -15.706682306293096,
          -15.7065543342844,
          -15.706418019154048,
          -15.706273082995674,
          -15.706119246105533,
          -15.705956226919515,
          -15.705783741949293,
          -15.705601505717642,
          -15.705409230692819,
          -15.705206627222024,
          -15.704993403463895,
          -15.704769265319978,
          -15.704533916365182,
          -15.70428705777715,
          -15.704028388264495,
          -15.703757603993926,
          -15.703474398516144,
          -15.70317846269053,
          -15.702869484608556,
          -15.702547149515874,
          -15.702211139733077,
          -15.701861134575006,
          -15.701496810268676,
          -15.701117839869648,
          -15.700723893176903,
          -15.700314636646107,
          -15.69988973330123,
          -15.699448842644488,
          -15.69899162056452,
          -15.698517719242782,
          -15.698026787058058,
          -15.697518468489084,
          -15.696992404015162,
          -15.696448230014767,
          -15.695885578662018,
          -15.695304077821014,
          -15.694703350937903,
          -15.694083016930671,
          -15.693442690076536,
          -15.692781979896893,
          -15.692100491039735,
          -15.691397823159472,
          -15.690673570794038,
          -15.68992732323926,
          -15.689158664420338,
          -15.688367172760392,
          -15.687552421045964,
          -15.686713976289381,
          -15.685851399587891,
          -15.684964245979458,
          -15.684052064295107,
          -15.683114397007738,
          -15.682150780077258,
          -15.681160742791942,
          -15.680143807605903,
          -15.679099489972517,
          -15.678027298173724,
          -15.67692673314502,
          -15.675797288296042,
          -15.674638449326578,
          -15.673449694037865,
          -15.67223049213904,
          -15.670980305048532,
          -15.669698585690307,
          -15.66838477828472,
          -15.667038318133852,
          -15.66565863140114,
          -15.664245134885078,
          -15.662797235786838,
          -15.661314331471575,
          -15.659795809223217,
          -15.658241045992542,
          -15.656649408138259,
          -15.655020251160927,
          -15.653352919429407,
          -15.651646745899635,
          -15.64990105182544,
          -15.648115146461107,
          -15.646288326755458,
          -15.644419877037087,
          -15.6425090686905,
          -15.640555159822812,
          -15.638557394920655,
          -15.63651500449701,
          -15.634427204727523,
          -15.632293197075992,
          -15.63011216790864,
          -15.6278832880967,
          -15.625605712606985,
          -15.623278580079926,
          -15.620901012394674,
          -15.618472114220774,
          -15.615990972555885,
          -15.613456656249104,
          -15.610868215509262,
          -15.60822468139771,
          -15.605525065304995,
          -15.60276835841075,
          -15.599953531126257,
          -15.597079532518986,
          -15.59414528971835,
          -15.591149707302087,
          -15.58809166666237,
          -15.584970025350966,
          -15.581783616402586,
          -15.5785312476355,
          -15.575211700928671,
          -15.571823731474272,
          -15.56836606700477,
          -15.564837406993483,
          -15.561236421827472,
          -15.557561751951788,
          -15.553812006983735,
          -15.54998576479603,
          -15.546081570567539,
          -15.542097935800168,
          -15.53803333730062,
          -15.533886216125381,
          -15.529654976487503,
          -15.525337984623487,
          -15.520933567618517,
          -15.51644001218836,
          -15.511855563415889,
          -15.507178423440365,
          -15.502406750097379,
          -15.497538655507139,
          -15.492572204609026,
          -15.487505413639749,
          -15.482336248552752,
          -15.47706262337611,
          -15.471682398506054,
          -15.466193378933294,
          -15.46059331239884,
          -15.4548798874762,
          -15.44905073157641,
          -15.44310340887217,
          -15.437035418137437,
          -15.430844190498151,
          -15.424527087090034,
          -15.418081396618842,
          -15.411504332818195,
          -15.404793031800173,
          -15.39794454929306,
          -15.39095585776083,
          -15.383823843398318,
          -15.37654530299567,
          -15.369116940665569,
          -15.361535364426091,
          -15.353797082631568,
          -15.345898500243795,
          -15.337835914934843,
          -15.329605513012808,
          -15.321203365160935,
          -15.312625421979908,
          -15.303867509322952,
          -15.294925323412016,
          -15.285794425723273,
          -15.276470237629,
          -15.266948034782043,
          -15.257222941228639,
          -15.247289923233756,
          -15.237143782802749,
          -15.226779150881622,
          -15.216190480217001,
          -15.205372037856126,
          -15.194317897265064,
          -15.183021930042644,
          -15.171477797205556,
          -15.159678940018322,
          -15.147618570340576,
          -15.135289660461227,
          -15.122684932387834,
          -15.109796846556632,
          -15.096617589926126,
          -15.083139063415105,
          -15.069352868641948,
          -15.055250293919999,
          -15.040822299459597,
          -15.026059501723664,
          -15.010952156880291,
          -14.99549014329033,
          -14.979662942964161,
          -14.963459621916,
          -14.946868809338174,
          -14.929878675512521,
          -14.912476908367829,
          -14.894650688586179,
          -14.87638666315199,
          -14.857670917228678,
          -14.838488944238886,
          -14.818825614012162,
          -14.798665138853547,
          -14.777991037372725,
          -14.756786095899106,
          -14.735032327293261,
          -14.712710926947203,
          -14.68980222574666,
          -14.66628563974867,
          -14.642139616302675,
          -14.61734157631925,
          -14.59186785236089,
          -14.565693622197378,
          -14.538792837434288,
          -14.511138146781885,
          -14.482700813489895,
          -14.453450626423573,
          -14.423355804201869,
          -14.392382891758954,
          -14.360496648619764,
          -14.327659928105838,
          -14.293833546600258,
          -14.258976141903393,
          -14.223044019603739,
          -14.185990986262244,
          -14.147768168071815,
          -14.108323813494238,
          -14.067603078197573,
          -14.025547790415608,
          -13.98209619461611,
          -13.937182671103491,
          -13.890737428877301,
          -13.842686168721833,
          -13.79294971310716,
          -13.741443599021459,
          -13.688077629331456,
          -13.632755377656931,
          -13.575373641040283,
          -13.51582183387665,
          -13.453981315613362,
          -13.38972464362055,
          -13.322914741331443,
          -13.253403970224849,
          -13.18103309242981,
          -13.105630108607798,
          -13.027008953263408,
          -12.944968026650235,
          -12.859288538885185,
          -12.769732637639011,
          -12.676041285663166,
          -12.577931848272538,
          -12.475095343463257,
          -12.367193298311024,
          -12.25385414427836,
          -12.134669070549197,
          -12.009187237877626,
          -11.876910234864244,
          -11.73728563296632,
          -11.58969946454323,
          -11.433467407964482,
          -11.267824412849603,
          -11.091912433623012,
          -10.904765856355656,
          -10.705294096450709,
          -10.492260704967176,
          -10.264258138104973,
          -10.01967710201136,
          -9.756669061604843,
          -9.473100066315059,
          -9.166493452329359,
          -8.833958164278782,
          -8.472098301788211,
          -8.076897891428477,
          -7.643572588889269,
          -7.166376682489245,
          -6.638348848510123,
          -6.050972715058597,
          -5.393716961263406,
          -4.653401938222764,
          -3.813311346529291,
          -2.851920640152489,
          -1.741034280993965,
          -0.4429842944454023,
          1.0937123575832892,
          2.941326613371505,
          5.204587588666616,
          8.041209243896915,
          11.700249931998915,
          16.59943975715425,
          23.49707206831257,
          33.92791394996896,
          51.53903192004515,
          87.62997697231184,
          203.36902106385386,
          null,
          -200.13693701456046,
          -112.80285214163132,
          -81.93103172221785,
          -66.143601437218,
          -56.55633972105906,
          -50.11680887937424,
          -45.49379230496204,
          -42.01397955839009,
          -39.300227288441576,
          -37.124849714261664,
          -35.342256897563104,
          -33.85501304587876,
          -32.59544816291965,
          -31.515098050619454,
          -30.578342100439333,
          -29.75841302870201,
          -29.03480722440266,
          -28.39155384623549,
          -27.816027839419696,
          -27.298117387736156,
          -26.829628180248122,
          -26.403849462010474,
          -26.01523282984185,
          -25.659151017004188,
          -25.331714353499237,
          -25.02962942965089,
          -24.750089059214435,
          -24.490685743212307,
          -24.249342980164712,
          -24.024260271524398,
          -23.813868739155026,
          -23.6167950402507,
          -23.43183182461126,
          -23.25791339101548,
          -23.094095505653776,
          -22.939538575423864,
          -22.793493542993915,
          -22.65529000348519,
          -22.52432614497559,
          -22.400060194405476,
          -22.282003112446453,
          -22.16971232963991,
          -22.06278635466304,
          -21.96086011626806,
          -21.8636009250083,
          -21.770704960623235,
          -21.681894206951895,
          -21.59691376923585,
          -21.515529519287714,
          -21.437526022712767,
          -21.362704709538054,
          -21.290882255544247,
          -21.22188914651957,
          -21.155568401763876,
          -21.091774436610898,
          -21.03037204661946,
          -20.971235498515597,
          -20.91424771502469,
          -20.859299542469305,
          -20.806289091493824,
          -20.755121142536304,
          -20.7057066087477,
          -20.657962049986708,
          -20.61180923230984,
          -20.567174728066096,
          -20.523989552294957,
          -20.482188831639665,
          -20.441711502434632,
          -20.40250003500957,
          -20.36450018159359,
          -20.327660745495052,
          -20.291933369490753,
          -20.25727234158627,
          -20.223634416504638,
          -20.190978651438577,
          -20.159266254753565,
          -20.12846044646542,
          -20.09852632943811,
          -20.069430770351634,
          -20.041142289587278,
          -20.013630959259938,
          -19.98686830870256,
          -19.96082723677577,
          -19.93548193043351,
          -19.910807789030933,
          -19.88678135390729,
          -19.863380242819524,
          -19.840583088842,
          -19.818369483380387,
          -19.79671992298095,
          -19.77561575964322,
          -19.755039154369427,
          -19.734973033708123,
          -19.71540104906833,
          -19.69630753860098,
          -19.67767749146035,
          -19.65949651427367,
          -19.64175079966192,
          -19.62442709666623,
          -19.607512682947178,
          -19.590995338633984,
          -19.574863321710314,
          -19.559105344832698,
          -19.543710553485102,
          -19.528668505380356,
          -19.51396915102676,
          -19.49960281538306,
          -19.485560180531834,
          -19.471832269305718,
          -19.45841042980571,
          -19.44528632075581,
          -19.43245189764124,
          -19.41989939958213,
          -19.407621336897435,
          -19.395610479316904,
          -19.383859844802426,
          -19.37236268894187,
          -19.361112494881848,
          -19.350102963767608,
          -19.33932800566027,
          -19.328781730904293,
          -19.318458441918793,
          -19.308352625389094,
          -19.298458944835698,
          -19.28877223353944,
          -19.279287487803426,
          -19.269999860532778,
          -19.26090465511511,
          -19.251997319585385,
          -19.243273441059635,
          -19.234728740423563,
          -19.22635906726208,
          -19.21816039501752,
          -19.210128816364318,
          -19.202260538788984,
          -19.194551880364962,
          -19.186999265712174,
          -19.179599222132108,
          -19.172348375909536,
          -19.165243448772422,
          -19.158281254502427,
          -19.15145869568827,
          -19.144772760615258,
          -19.138220520284186,
          -19.131799125553357,
          -19.125505804397992,
          -19.119337859281202,
          -19.113292664631444,
          -19.107367664421417,
          -19.10156036984352,
          -19.09586835707762,
          -19.09028926514676,
          -19.084820793856736,
          -19.079460701815858,
          -19.074206804531162,
          -19.06905697257773,
          -19.06400912983782,
          -19.05906125180665,
          -19.054211363962057,
          -19.049457540195068,
          -19.044797901298843,
          -19.040230613513472,
          -19.035753887124084,
          -19.031365975110244,
          -19.02706517184417,
          -19.022849811835965,
          -19.018718268523752,
          -19.014668953106835,
          -19.010700313420205,
          -19.006810832848572,
          -19.00299902927838,
          -18.99926345408626,
          -18.99560269116234,
          -18.992015355967176,
          -18.98850009462082,
          -18.985055583022817,
          -18.981680526001877,
          -18.978373656494046,
          -18.97513373474833,
          -18.971959547558566,
          -18.968849907520685,
          -18.96580365231429,
          -18.96281964400758,
          -18.959896768384883,
          -18.95703393429577,
          -18.954230073025027,
          -18.95148413768275,
          -18.948795102613637,
          -18.946161962824988,
          -18.94358373343251,
          -18.94105944912347,
          -18.938588163636382,
          -18.936168949256757,
          -18.933800896328265,
          -18.931483112778775,
          -18.92921472366075,
          -18.92699487070547,
          -18.92482271189057,
          -18.922697421020484,
          -18.92061818731929,
          -18.91858421503551,
          -18.916594723058537,
          -18.914648944546148,
          -18.912746126562826,
          -18.910885529728528,
          -18.909066427877423,
          -18.907288107726416,
          -18.90554986855297,
          -18.903851021882065,
          -18.902190891181863,
          -18.900568811567858,
          -18.898984129515185,
          -18.897436202578856,
          -18.895924399121647,
          -18.894448098049352,
          -18.893006688553214,
          -18.89159956985926,
          -18.89022615098433,
          -18.888885850498593,
          -18.887578096294313,
          -18.88630232536067,
          -18.88505798356449,
          -18.883844525436608,
          -18.882661413963756,
          -18.881508120385785,
          -18.880384123998017,
          -18.879288911958607,
          -18.878221979100744,
          -18.87718282774952,
          -18.87617096754337,
          -18.875185915259863,
          -18.874227194645787,
          -18.87329433625135,
          -18.872386877268386,
          -18.87150436137242,
          -18.87064633856852,
          -18.869812365040758,
          -18.869002003005225,
          -18.868214820566454,
          -18.867450391577172,
          -18.866708295501248,
          -18.86598811727978,
          -18.865289447200205,
          -18.86461188076832,
          -18.863955018583155,
          -18.86331846621463,
          -18.86270183408383,
          -18.862104737345934,
          -18.861526795775607,
          -18.86096763365485,
          -18.86042687966323,
          -18.859904166770374,
          -18.859399132130704,
          -18.858911416980323,
          -18.858440666536,
          -18.85798652989616,
          -18.857548659943866,
          -18.857126713251702,
          -18.856720349988485,
          -18.856329233827793,
          -18.855953031858203,
          -18.85559141449525,
          -18.85524405539499,
          -18.854910631369133,
          -18.85459082230175,
          -18.854284311067417,
          -18.853990783450847,
          -18.853709928067858,
          -18.853441436287746,
          -18.853185002156916,
          -18.852940322323807,
          -18.852707095965027,
          -18.852485024712685,
          -18.852273812582837,
          -18.85207316590508,
          -18.85188279325317,
          -18.85170240537673,
          -18.85153171513388,
          -18.851370437424908,
          -18.851218289126823,
          -18.851074989028806,
          -18.85094025776856,
          -18.85081381776945,
          -18.850695393178466,
          -18.85058470980497,
          -18.850481495060155,
          -18.850385477897234,
          -18.850296388752316,
          -18.850213959485924,
          -18.850137923325157,
          -18.85006801480645,
          -18.850003969718884,
          -18.849945525048085,
          -18.849892418920618,
          -18.84984439054888,
          -18.849801180176478,
          -18.849762529024034,
          -18.849728179235445,
          -18.8496978738245,
          -18.849671356621908,
          -18.84964837222267,
          -18.849628665933757,
          -18.849611983722124,
          -18.849598072162983,
          -18.849586678388363,
          -18.849577550035878,
          -18.84957043519773,
          -18.849565082369907,
          -18.849561240401542,
          -18.849558658444426,
          -18.849557085902664,
          -18.849556272382404,
          -18.84955596764171,
          -18.849555921540425,
          -18.849555883990146,
          -18.84955560490418,
          -18.8495548341475,
          -18.849553321486727,
          -18.849550816539995,
          -18.849547068726828,
          -18.849541827217873,
          -18.84953484088457,
          -18.84952585824866,
          -18.849514627431585,
          -18.849500896103663,
          -18.849484411433128,
          -18.849464920034908,
          -18.8494421679192,
          -18.849415900439762,
          -18.84938586224194,
          -18.84935179721039,
          -18.84931344841645,
          -18.849270558065196,
          -18.8492228674421,
          -18.849170116859312,
          -18.84911204560148,
          -18.849048391871168,
          -18.8489788927338,
          -18.848903284062065,
          -18.848821300479855,
          -18.848732675305634,
          -18.84863714049521,
          -18.848534426583964,
          -18.84842426262839,
          -18.848306376147036,
          -18.84818049306072,
          -18.848046337632066,
          -18.847903632404275,
          -18.847752098139157,
          -18.84759145375433,
          -18.84742141625961,
          -18.847241700692543,
          -18.84705202005301,
          -18.846852085236954,
          -18.846641604969104,
          -18.846420285734713,
          -18.846187831710296,
          -18.845943944693246,
          -18.845688324030405,
          -18.845420666545436,
          -18.845140666465074,
          -18.844848015344102,
          -18.844542401989102,
          -18.844223512380893,
          -18.84389102959561,
          -18.843544633724427,
          -18.843184001791805,
          -18.842808807672274,
          -18.842418722005718,
          -18.842013412111026,
          -18.841592541898144,
          -18.84115577177847,
          -18.840702758573467,
          -18.84023315542152,
          -18.83974661168294,
          -18.839242772843082,
          -18.838721280413466,
          -18.838181771830907,
          -18.837623880354542,
          -18.837047234960714,
          -18.836451460235637,
          -18.835836176265758,
          -18.835200998525785,
          -18.834545537764257,
          -18.833869399886623,
          -18.83317218583573,
          -18.832453491469632,
          -18.831712907436675,
          -18.83095001904771,
          -18.830164406145407,
          -18.829355642970548,
          -18.82852329802519,
          -18.82766693393265,
          -18.826786107294158,
          -18.825880368542087,
          -18.82494926178969,
          -18.823992324677185,
          -18.823009088214082,
          -18.821999076617672,
          -18.820961807147487,
          -18.819896789935676,
          -18.818803527813106,
          -18.817681516131092,
          -18.816530242578587,
          -18.8153491869947,
          -18.814137821176402,
          -18.812895608681234,
          -18.811622004624866,
          -18.810316455473362,
          -18.808978398829936,
          -18.807607263216056,
          -18.806202467846695,
          -18.804763422399507,
          -18.803289526777768,
          -18.801780170866877,
          -18.800234734284135,
          -18.798652586121666,
          -18.79703308468217,
          -18.79537557720732,
          -18.79367939959853,
          -18.791943876129803,
          -18.79016831915247,
          -18.788352028791433,
          -18.786494292632725,
          -18.78459438540197,
          -18.782651568633543,
          -18.78066509033003,
          -18.778634184611626,
          -18.77655807135523,
          -18.774435955822693,
          -18.77226702827801,
          -18.77005046359294,
          -18.76778542084069,
          -18.765471042877184,
          -18.76310645590954,
          -18.760690769051195,
          -18.758223073863274,
          -18.755702443881614,
          -18.753127934128987,
          -18.75049858061188,
          -18.74781339980135,
          -18.745071388097287,
          -18.742271521275452,
          -18.739412753916678,
          -18.736494018817535,
          -18.733514226381686,
          -18.730472263991295,
          -18.72736699535761,
          -18.724197259849937,
          -18.720961871802217,
          -18.717659619796184,
          -18.71428926592031,
          -18.710849545003494,
          -18.707339163822446,
          -18.703756800281845,
          -18.70010110256593,
          -18.696370688260625,
          -18.692564143444717,
          -18.688680021749015,
          -18.684716843382077,
          -18.680673094121012,
          -18.67654722426609,
          -18.672337647557395,
          -18.668042740052073,
          -18.66366083896043,
          -18.659190241439017,
          -18.654629203339013,
          -18.649975937907733,
          -18.64522861444139,
          -18.64038535688685,
          -18.635444242390086,
          -18.630403299789062,
          -18.62526050804836,
          -18.620013794633067,
          -18.614661033819086,
          -18.60920004493686,
          -18.603628590545604,
          -18.597944374534592,
          -18.592145040148264,
          -18.586228167931463,
          -18.580191273590927,
          -18.574031805769238,
          -18.567747143726738,
          -18.561334594927164,
          -18.55479139252221,
          -18.54811469272992,
          -18.541301572101947,
          -18.53434902467373,
          -18.527253958992056,
          -18.520013195013615,
          -18.512623460867907,
          -18.505081389477716,
          -18.497383515029632,
          -18.48952626928677,
          -18.481505977735562,
          -18.473318855557615,
          -18.46496100341745,
          -18.456428403056226,
          -18.447716912680725,
          -18.43882226213678,
          -18.429740047854843,
          -18.420465727555435,
          -18.41099461470087,
          -18.401321872678825,
          -18.391442508702863,
          -18.381351367413277,
          -18.371043124161258,
          -18.360512277957852,
          -18.349753144067797,
          -18.338759846227656,
          -18.327526308465266,
          -18.316046246496892,
          -18.304313158676305,
          -18.292320316468036,
          -18.280060754415924,
          -18.267527259574834,
          -18.254712360372224,
          -18.241608314863154,
          -18.228207098339652,
          -18.214500390253114,
          -18.200479560404304,
          -18.186135654353095,
          -18.17145937799593,
          -18.156441081254727,
          -18.141070740817543,
          -18.12533794186539,
          -18.10923185871551,
          -18.092741234305276,
          -18.075854358434526,
          -18.05855904467851,
          -18.040842605874797,
          -18.022691828081115,
          -18.004092942891255,
          -17.985031597986804,
          -17.965492825792793,
          -17.9454610100924,
          -17.924919850444706,
          -17.903852324234695,
          -17.882240646169254,
          -17.860066225017015,
          -17.837309617370334,
          -17.813950478187248,
          -17.789967507849465,
          -17.765338395445667,
          -17.740039757963224,
          -17.71404707503941,
          -17.687334618888727,
          -17.659875378986072,
          -17.63164098104087,
          -17.602601599751825,
          -17.572725864777752,
          -17.541980759300486,
          -17.5103315104911,
          -17.477741471113784,
          -17.444171991420692,
          -17.4095822803954,
          -17.373929255296773,
          -17.337167378337234,
          -17.299248479191736,
          -17.260121561883594,
          -17.21973259441839,
          -17.178024279340004,
          -17.134935803160886,
          -17.0904025623599,
          -17.044355863352422,
          -16.99672259350108,
          -16.947424859852035,
          -16.89637959184338,
          -16.843498103720634,
          -16.788685611811882,
          -16.731840701133923,
          -16.672854735013235,
          -16.611611200492565,
          -16.54798498122128,
          -16.481841548283338,
          -16.413036057949448,
          -16.341412343617712,
          -16.26680178717958,
          -16.189022052639764,
          -16.10787566197242,
          -16.023148389796592,
          -15.934607449395369,
          -15.84199943774079,
          -15.745048001321244,
          -15.64345117749459,
          -15.536878357494496,
          -15.424966806747058,
          -15.307317665342344,
          -15.183491335740108,
          -15.053002145309131,
          -14.915312147109457,
          -14.769823892098676,
          -14.615871968000128,
          -14.452713052112943,
          -14.279514164377279,
          -14.09533872899032,
          -13.899129952295112,
          -13.689690894110122,
          -13.46566043879692,
          -13.225484146895148,
          -12.967378667991177,
          -12.689287992032662,
          -12.388829268580157,
          -12.06322517171286,
          -11.70921874442983,
          -11.322965188614042,
          -10.899892974575113,
          -10.434523618340167,
          -9.9202350277875,
          -9.348946667963068,
          -8.710694657454386,
          -7.993049123442368,
          -7.180300989564634,
          -6.2523042320663045,
          -5.18279037111378,
          -3.936851436340877,
          -2.4670699356785626,
          -0.7073638321131561,
          1.437199255326309,
          4.108075534385538,
          7.525724479594825,
          12.053713603759903,
          18.337334165690606,
          27.642045260732026,
          42.83411815545673,
          72.0827191120591,
          151.67703716147375,
          null,
          null,
          -129.2320492733175,
          -90.89598754579231,
          -72.53898836573654,
          -61.77210673443886,
          -54.694945396451644,
          -49.688722510383755,
          -45.96078056626883,
          -43.077213498335745,
          -40.78053643571947,
          -38.90829527587897,
          -37.35292852336676,
          -36.040388262984585,
          -34.91803086527833,
          -33.94740430717738,
          -33.09976792052555,
          -32.353208623361915,
          -31.690727139645297,
          -31.09893376922868,
          -30.567138622840503,
          -30.086703811260538,
          -29.650573621138264,
          -29.252928123270156,
          -28.888923967471268,
          -28.554497792525073,
          -28.246215287593344,
          -27.96115399804794,
          -27.696811390523813,
          -27.451032045875607,
          -27.22194949261888,
          -27.007939357576706,
          -26.80758134548367,
          -26.619628165503933,
          -26.442979967564185,
          -26.276663181410626,
          -26.119812898439896,
          -25.97165812309416,
          -25.83150936295827,
          -25.698748136038244,
          -25.572818058347984,
          -25.453217240929312,
          -25.33949177721609,
          -25.231230142577207,
          -25.128058360381022,
          -25.029635814912275,
          -24.935651612362932,
          -24.845821407982438,
          -24.75988463117882,
          -24.67760205153058,
          -24.59875363782554,
          -24.523136669781895,
          -24.450564068326955,
          -24.38086291548159,
          -24.31387313919678,
          -24.249446342085577,
          -24.187444756012987,
          -24.12774030704259,
          -24.070213777382936,
          -24.014754052795535,
          -23.961257445464597,
          -23.90962708364778,
          -23.859772360547716,
          -23.811608435806463,
          -23.76505578385446,
          -23.720039784053412,
          -23.67649034819121,
          -23.63434158141625,
          -23.593531473160112,
          -23.554001615000573,
          -23.515696942762936,
          -23.478565500465972,
          -23.442558223983273,
          -23.407628742524828,
          -23.373733196250686,
          -23.340830068506282,
          -23.30888003133104,
          -23.27784580303055,
          -23.24769201672704,
          -23.21838509891438,
          -23.18989315713928,
          -23.162185876019404,
          -23.135234420884824,
          -23.109011348398397,
          -23.083490523573136,
          -23.058647042657796,
          -23.034457161412924,
          -23.010898228342537,
          -22.987948622486172,
          -22.965587695412793,
          -22.943795717088143,
          -22.92255382531793,
          -22.901843978493886,
          -22.881648911393427,
          -22.861952093805815,
          -22.84273769177539,
          -22.82399053127136,
          -22.805696064108496,
          -22.787840335957448,
          -22.770409956297275,
          -22.753392070173312,
          -22.736774331635644,
          -22.720544878742388,
          -22.704692310021148,
          -22.68920566229066,
          -22.674074389751667,
          -22.659288344262805,
          -22.644837756724485,
          -22.630713219498098,
          -22.61690566979456,
          -22.603406373970177,
          -22.590206912672365,
          -22.57729916678243,
          -22.56467530410552,
          -22.55232776676217,
          -22.54024925923848,
          -22.528432737055084,
          -22.51687139601807,
          -22.50555866201695,
          -22.494488181337726,
          -22.483653811460965,
          -22.473049612316416,
          -22.462669837968548,
          -22.452508928707804,
          -22.442561503525155,
          -22.43282235294823,
          -22.42328643221877,
          -22.413948854792977,
          -22.404804886146586,
          -22.395849937868494,
          -22.38707956202724,
          -22.378489445795598,
          -22.370075406319902,
          -22.36183338582084,
          -22.3537594469139,
          -22.34584976813796,
          -22.338100639681137,
          -22.330508459294187,
          -22.323069728381444,
          -22.315781048260774,
          -22.308639116583866,
          -22.30164072390883,
          -22.294782750417838,
          -22.288062162772395,
          -22.28147601109978,
          -22.275021426104217,
          -22.268695616296718,
          -22.262495865338128,
          -22.256419529489804,
          -22.250464035167,
          -22.244626876590146,
          -22.23890561352937,
          -22.233297869138127,
          -22.227801327871692,
          -22.222413733486775,
          -22.217132887118545,
          -22.211956645431542,
          -22.206882918841234,
          -22.201909669803126,
          -22.19703491116626,
          -22.192256704588544,
          -22.18757315901098,
          -22.1829824291884,
          -22.178482714274203,
          -22.17407225645681,
          -22.16974933964563,
          -22.165512288204443,
          -22.161359465730225,
          -22.15728927387552,
          -22.153300151212484,
          -22.14939057213703,
          -22.145559045811233,
          -22.1418041151426,
          -22.138124355798674,
          -22.134518375255414,
          -22.13098481187824,
          -22.127522334034182,
          -22.12412963923411,
          -22.120805453303735,
          -22.117548529582272,
          -22.114357648147767,
          -22.111231615067897,
          -22.10816926167544,
          -22.105169443867354,
          -22.102231041426545,
          -22.099352957365607,
          -22.0965341172915,
          -22.09377346879056,
          -22.091069980832998,
          -22.08842264319613,
          -22.085830465905744,
          -22.08329247869484,
          -22.080807730479155,
          -22.078375288848882,
          -22.07599423957592,
          -22.073663686136182,
          -22.071382749246354,
          -22.069150566414624,
          -22.066966291504897,
          -22.064829094313932,
          -22.062738160161107,
          -22.060692689490164,
          -22.058691897482717,
          -22.05673501368297,
          -22.054821281633323,
          -22.052949958520472,
          -22.051120314831657,
          -22.049331634020696,
          -22.047583212183483,
          -22.04587435774263,
          -22.04420439114092,
          -22.042572644543334,
          -22.04097846154729,
          -22.03942119690089,
          -22.037900216228856,
          -22.036414895765933,
          -22.03496462209751,
          -22.03354879190721,
          -22.032166811731233,
          -22.03081809771922,
          -22.029502075401442,
          -22.02821817946212,
          -22.02696585351861,
          -22.0257445499064,
          -22.024553729469567,
          -22.02339286135665,
          -22.02226142282173,
          -22.021158899030503,
          -22.020084782871272,
          -22.01903857477063,
          -22.018019782513743,
          -22.01702792106905,
          -22.016062512417257,
          -22.015123085384502,
          -22.014209175479536,
          -22.013320324734835,
          -22.012456081551473,
          -22.011616000547686,
          -22.010799642410984,
          -22.010006573753707,
          -22.009236366971937,
          -22.00848860010765,
          -22.007762856714002,
          -22.007058725723667,
          -22.006375801320125,
          -22.005713682811834,
          -22.005071974509153,
          -22.004450285603976,
          -22.003848230051982,
          -22.003265426457407,
          -22.00270149796027,
          -22.002156072126006,
          -22.00162878083738,
          -22.001119260188666,
          -22.00062715038198,
          -22.00015209562574,
          -21.99969374403515,
          -21.999251747534665,
          -21.998825761762415,
          -21.998415445976438,
          -21.998020462962756,
          -21.997640478945186,
          -21.99727516349685,
          -21.996924189453342,
          -21.996587232827462,
          -21.996263972725526,
          -21.995954091265155,
          -21.99565727349451,
          -21.99537320731294,
          -21.995101583393,
          -21.994842095103756,
          -21.994594438435385,
          -21.994358311925005,
          -21.99413341658371,
          -21.99391945582473,
          -21.993716135392734,
          -21.993523163294196,
          -21.993340249728806,
          -21.993167107021907,
          -21.993003449557865,
          -21.99284899371442,
          -21.99270345779791,
          -21.992566561979384,
          -21.992438028231543,
          -21.992317580266523,
          -21.992204943474395,
          -21.99209984486249,
          -21.992002012995382,
          -21.99191117793559,
          -21.991827071184954,
          -21.991749425626608,
          -21.991677975467606,
          -21.99161245618209,
          -21.99155260445504,
          -21.991498158126554,
          -21.99144885613659,
          -21.991404438470255,
          -21.99136464610348,
          -21.991329220949176,
          -21.99129790580376,
          -21.991270444294077,
          -21.991246580824686,
          -21.991226060525467,
          -21.991208629199555,
          -21.991194033271533,
          -21.99118201973594,
          -21.991172336105972,
          -21.991164730362435,
          -21.991158950902893,
          -21.99115474649099,
          -21.991151866205932,
          -21.99115005939208,
          -21.991149075608707,
          -21.991148664579796,
          -21.99114857614393,
          -21.991148560204238,
          -21.991148366678345,
          -21.99114774544835,
          -21.991146446310786,
          -21.99114421892652,
          -21.991140812770645,
          -21.991135977082227,
          -21.991129460814008,
          -21.991121012581967,
          -21.991110380614717,
          -21.99109731270278,
          -21.991081556147634,
          -21.99106285771057,
          -21.991040963561325,
          -21.99101561922644,
          -21.990986569537366,
          -21.99095355857826,
          -21.990916329633443,
          -21.990874625134563,
          -21.990828186607327,
          -21.990776754617894,
          -21.990720068718822,
          -21.99065786739459,
          -21.990589888006642,
          -21.99051586673798,
          -21.990435538537167,
          -21.990348637061885,
          -21.990254894621856,
          -21.990154042121183,
          -21.990045809000122,
          -21.989929923176117,
          -21.98980611098426,
          -21.98967409711696,
          -21.98953360456295,
          -21.989384354545475,
          -21.98922606645973,
          -21.989058457809456,
          -21.988881244142693,
          -21.988694138986617,
          -21.988496853781513,
          -21.988289097813738,
          -21.98807057814773,
          -21.987840999556997,
          -21.987600064454025,
          -21.98734747281912,
          -21.9870829221281,
          -21.986806107278806,
          -21.986516720516452,
          -21.986214451357657,
          -21.985898986513234,
          -21.98557000980964,
          -21.98522720210901,
          -21.984870241227817,
          -21.984498801854034,
          -21.984112555462787,
          -21.983711170230443,
          -21.983294310947073,
          -21.982861638927275,
          -21.982412811919243,
          -21.981947484012085,
          -21.981465305541313,
          -21.98096592299242,
          -21.98044897890256,
          -21.979914111760156,
          -21.979360955902482,
          -21.978789141411124,
          -21.978198294005175,
          -21.977588034932236,
          -21.976957980857016,
          -21.976307743747554,
          -21.97563693075895,
          -21.97494514411449,
          -21.974231980984186,
          -21.973497033360548,
          -21.97273988793153,
          -21.971960125950616,
          -21.971157323103878,
          -21.970331049373954,
          -21.969480868900856,
          -21.968606339839475,
          -21.96770701421372,
          -21.966782437767137,
          -21.965832149809934,
          -21.964855683062307,
          -21.963852563493894,
          -21.962822310159304,
          -21.961764435029515,
          -21.960678442819116,
          -21.959563830809145,
          -21.958420088665463,
          -21.957246698252483,
          -21.956043133442115,
          -21.954808859917765,
          -21.953543334973237,
          -21.95224600730635,
          -21.950916316807152,
          -21.94955369434045,
          -21.948157561522592,
          -21.946727330492227,
          -21.945262403674832,
          -21.943762173540907,
          -21.942226022357485,
          -21.940653321932814,
          -21.93904343335399,
          -21.93739570671724,
          -21.935709480850676,
          -21.933984083029184,
          -21.93221882868127,
          -21.930413021087503,
          -21.92856595107031,
          -21.926676896674827,
          -21.924745122840427,
          -21.922769881062703,
          -21.920750409045503,
          -21.918685930342647,
          -21.91657565398902,
          -21.91441877412062,
          -21.912214469583155,
          -21.90996190352885,
          -21.907660223000917,
          -21.905308558505347,
          -21.9029060235695,
          -21.900451714287026,
          -21.89794470884864,
          -21.89538406705813,
          -21.892768829833194,
          -21.89009801869038,
          -21.887370635213667,
          -21.884585660505984,
          -21.881742054623018,
          -21.87883875598867,
          -21.87587468079147,
          -21.872848722361095,
          -21.8697597505244,
          -21.866606610939982,
          -21.863388124410555,
          -21.860103086172202,
          -21.85675026515959,
          -21.853328403246216,
          -21.849836214458623,
          -21.846272384163594,
          -21.842635568227216,
          -21.838924392144573,
          -21.835137450139037,
          -21.831273304229683,
          -21.827330483265705,
          -21.82330748192632,
          -21.819202759684725,
          -21.815014739734647,
          -21.810741807877807,
          -21.806382311370697,
          -21.80193455772887,
          -21.797396813486884,
          -21.792767302912054,
          -21.788044206669817,
          -21.78322566043877,
          -21.778309753473003,
          -21.77329452710935,
          -21.76817797321725,
          -21.762958032588354,
          -21.75763259326339,
          -21.75219948879323,
          -21.746656496431115,
          -21.741001335253003,
          -21.73523166420244,
          -21.729345080056557,
          -21.723339115309418,
          -21.717211235968648,
          -21.7109588392614,
          -21.704579251244986,
          -21.69806972431772,
          -21.69142743462506,
          -21.68464947935564,
          -21.677732873922103,
          -21.67067454902046,
          -21.66347134756228,
          -21.65612002147299,
          -21.648617228349377,
          -21.640959527969187,
          -21.633143378645045,
          -21.625165133414363,
          -21.617021036056922,
          -21.608707216930526,
          -21.6002196886153,
          -21.59155434135618,
          -21.58270693829238,
          -21.573673110462572,
          -21.56444835157288,
          -21.555028012514782,
          -21.545407295618784,
          -21.535581248628652,
          -21.52554475838066,
          -21.515292544170318,
          -21.50481915078886,
          -21.494118941209972,
          -21.48318608890587,
          -21.472014569771094,
          -21.460598153629917,
          -21.448930395302504,
          -21.437004625202714,
          -21.424813939438398,
          -21.412351189383696,
          -21.399608970689634,
          -21.386579611697798,
          -21.373255161218786,
          -21.35962737563421,
          -21.34568770527862,
          -21.331427280053425,
          -21.31683689422231,
          -21.30190699033304,
          -21.286627642206387,
          -21.270988536928833,
          -21.254978955779766,
          -21.23858775401933,
          -21.22180333945657,
          -21.204613649710836,
          -21.187006128073154,
          -21.168967697865206,
          -21.150484735186282,
          -21.131543039928495,
          -21.11212780493018,
          -21.09222358312715,
          -21.071814252547686,
          -21.050882978984976,
          -21.029412176165,
          -21.00738346321119,
          -20.984777619190023,
          -20.96157453450079,
          -20.937753158850626,
          -20.913291445532415,
          -20.88816629169437,
          -20.862353474261663,
          -20.83582758113601,
          -20.808561937261672,
          -20.780528525106472,
          -20.751697899058055,
          -20.72203909318618,
          -20.69151952176303,
          -20.66010487186887,
          -20.627758987339693,
          -20.594443743230016,
          -20.560118909875133,
          -20.52474200553298,
          -20.48826813646982,
          -20.45064982322489,
          -20.411836811638338,
          -20.371775867061828,
          -20.330410549978755,
          -20.287680971044267,
          -20.24352352331021,
          -20.19787058911487,
          -20.150650218797743,
          -20.101785778027565,
          -20.051195560106393,
          -19.99879235912535,
          -19.94448299927881,
          -19.888167814994066,
          -19.82974007577313,
          -19.76908534876227,
          -19.70608079104102,
          -19.640594362418295,
          -19.572483948122176,
          -19.50159637911544,
          -19.427766335822096,
          -19.350815118752795,
          -19.270549266782787,
          -19.186759000594982,
          -19.09921646492123,
          -19.007673738570254,
          -18.911860575649953,
          -18.811481834641977,
          -18.706214543819776,
          -18.595704541547306,
          -18.47956261782989,
          -18.35736006855008,
          -18.228623555373797,
          -18.09282914143184,
          -17.94939534435388,
          -17.79767501243757,
          -17.636945784603004,
          -17.46639883747668,
          -17.28512554974024,
          -17.092101619708565,
          -16.886168050043835,
          -16.666008254142277,
          -16.430120328862095,
          -16.176783259511453,
          -15.904015449315757,
          -15.609523459528216,
          -15.290638153812218,
          -14.944234481793483,
          -14.566629793063276,
          -14.153453664713885,
          -13.699479476114305,
          -13.198403941010252,
          -12.642554817170556,
          -12.022497928911482,
          -11.326500572752082,
          -10.53978610089579,
          -9.643478296697927,
          -8.61307370741442,
          -7.41617583920538,
          -6.0090386762340415,
          -4.3311194721457476,
          -2.29616114995018,
          0.22308158745820705,
          3.4224707613672756,
          7.61994373994321,
          13.368175818417114,
          21.720256614779274,
          34.96177341294294,
          59.15967271974556,
          117.49811612585702,
          null,
          null,
          -149.95617458687494,
          -101.01438737769482,
          -79.39900365368926,
          -67.21945473078841,
          -59.404763582767146,
          -53.96555625279971,
          -49.96194763310965,
          -46.89211217314485,
          -44.46370543087155,
          -42.49488656796807,
          -40.866614526109174,
          -39.49769234036157,
          -38.33083569569587,
          -37.32447369986329,
          -36.44770679568762,
          -35.67708906455993,
          -34.994508578782636,
          -34.385752164052306,
          -33.83950991842272,
          -33.34666992712099,
          -32.89980905097303,
          -32.49281900994228,
          -32.12062760169999,
          -31.778987964739144,
          -31.464317267194637,
          -31.17357180593497,
          -30.90414927548387,
          -30.653811552695778,
          -30.420623142572726,
          -30.20290170052738,
          -29.999177954434927,
          -29.808163007006414,
          -29.62872148011133,
          -29.459849318542954,
          -29.300655336584917,
          -29.15034579120115,
          -29.008211418109596,
          -28.873616483902552,
          -28.745989497679943,
          -28.62481529594582,
          -28.509628269595858,
          -28.40000654524512,
          -28.295566967618,
          -28.195960757221386,
          -28.100869739597517,
          -28.01000306026758,
          -27.923094313910365,
          -27.83989902809394,
          -27.760192451503293,
          -27.683767604524355,
          -27.610433556583683,
          -27.54001390005399,
          -27.472345395048638,
          -27.407276763188047,
          -27.344667611575762,
          -27.28438747087765,
          -27.226314933630658,
          -27.17033688080681,
          -27.11634778626295,
          -27.064249090076224,
          -27.01394863293652,
          -26.965360144765683,
          -26.918402781592945,
          -26.87300070545771,
          -26.829082702745204,
          -26.786581836916007,
          -26.74543513206639,
          -26.70558328417206,
          -26.666970397231843,
          -26.629543741840063,
          -26.593253533995824,
          -26.558052732196828,
          -26.523896851077886,
          -26.49074379004249,
          -26.458553675497456,
          -26.427288715448384,
          -26.396913065340243,
          -26.367392704140887,
          -26.338695319767684,
          -26.310790203044313,
          -26.283648149456898,
          -26.25724136804791,
          -26.23154339684975,
          -26.206529024317643,
          -26.182174216270084,
          -26.158456047892496,
          -26.135352640398963,
          -26.11284310198374,
          -26.090907472728027,
          -26.06952667315552,
          -26.0486824561585,
          -26.028357362039426,
          -26.008534676434596,
          -25.9891983909074,
          -25.970333166014683,
          -25.951924296667812,
          -25.933957679623415,
          -25.916419782952435,
          -25.89929761734898,
          -25.882578709150263,
          -25.866251074950245,
          -25.850303197698054,
          -25.83472400418059,
          -25.819502843797217,
          -25.804629468540227,
          -25.790094014102444,
          -25.775886982038347,
          -25.761999222910724,
          -25.748421920360144,
          -25.735146576038712,
          -25.72216499535372,
          -25.70946927397123,
          -25.697051785032293,
          -25.68490516703862,
          -25.67302231236708,
          -25.661396356375008,
          -25.65002066706165,
          -25.63888883525234,
          -25.627994665275313,
          -25.617332166102248,
          -25.606895542925876,
          -25.596679189149892,
          -25.5866776787675,
          -25.57688575910704,
          -25.567298343924126,
          -25.557910506821006,
          -25.54871747497548,
          -25.539714623162155,
          -25.53089746805061,
          -25.522261662765402,
          -25.513802991693943,
          -25.505517365529418,
          -25.497400816536096,
          -25.48944949402574,
          -25.481659660034108,
          -25.474027685187156,
          -25.46655004474762,
          -25.459223314832485,
          -25.45204416879303,
          -25.445009373749336,
          -25.43811578727138,
          -25.431360354199896,
          -25.424740103599824,
          -25.418252145840157,
          -25.41189366979407,
          -25.40566194015345,
          -25.39955429485262,
          -25.393568142595882,
          -25.38770096048421,
          -25.381950291736395,
          -25.37631374350021,
          -25.370788984749655,
          -25.365373744264144,
          -25.360065808686063,
          -25.354863020653163,
          -25.349763277002303,
          -25.344764527041587,
          -25.33986477088772,
          -25.335062057865706,
          -25.33035448496835,
          -25.32574019537272,
          -25.321217377011322,
          -25.316784261195554,
          -25.312439121289184,
          -25.308180271429855,
          -25.304006065296413,
          -25.299914894920356,
          -25.295905189539404,
          -25.291975414491485,
          -25.2881240701476,
          -25.284349690881736,
          -25.280650844076597,
          -25.277026129163502,
          -25.273474176695164,
          -25.269993647450043,
          -25.266583231566976,
          -25.26324164770893,
          -25.259967642254722,
          -25.25675998851758,
          -25.25361748598959,
          -25.250538959610893,
          -25.24752325906283,
          -25.244569258084024,
          -25.241675853808523,
          -25.23884196612526,
          -25.236066537057905,
          -25.23334853016444,
          -25.230686929955713,
          -25.228080741332178,
          -25.22552898903829,
          -25.22303071713379,
          -25.220584988481317,
          -25.218190884249793,
          -25.21584750343287,
          -25.21355396238209,
          -25.21130939435408,
          -25.209112949071333,
          -25.20696379229615,
          -25.20486110541714,
          -25.202804085048015,
          -25.20079194263808,
          -25.19882390409414,
          -25.196899209413367,
          -25.195017112326727,
          -25.193176879952688,
          -25.19137779246079,
          -25.18961914274472,
          -25.187900236104685,
          -25.186220389938615,
          -25.184578933442026,
          -25.18297520731621,
          -25.18140856348443,
          -25.179878364815924,
          -25.17838398485744,
          -25.176924807572007,
          -25.17550022708479,
          -25.174109647435696,
          -25.17275248233863,
          -25.17142815494706,
          -25.170136097625782,
          -25.168875751728663,
          -25.16764656738212,
          -25.166448003274237,
          -25.16527952644924,
          -25.164140612107282,
          -25.163030743409244,
          -25.161949411286496,
          -25.16089611425538,
          -25.159870358236336,
          -25.158871656377492,
          -25.157899528882567,
          -25.156953502842974,
          -25.156033112074006,
          -25.15513789695494,
          -25.15426740427296,
          -25.153421187070798,
          -25.152598804497927,
          -25.151799821665282,
          -25.151023809503293,
          -25.150270344623227,
          -25.149539009181687,
          -25.14882939074817,
          -25.148141082175623,
          -25.147473681473873,
          -25.146826791685857,
          -25.146200020766575,
          -25.145592981464674,
          -25.145005291206587,
          -25.144436571983135,
          -25.143886450238554,
          -25.14335455676184,
          -25.142840526580326,
          -25.14234399885551,
          -25.14186461678095,
          -25.141402027482247,
          -25.140955881919012,
          -25.140525834788786,
          -25.140111544432816,
          -25.139712672743673,
          -25.139328885074622,
          -25.138959850150705,
          -25.13860523998147,
          -25.138264729775344,
          -25.137937997855513,
          -25.137624725577354,
          -25.137324597247293,
          -25.13703730004312,
          -25.13676252393562,
          -25.136499961611595,
          -25.13624930839811,
          -25.136010262188034,
          -25.13578252336674,
          -25.135565794740007,
          -25.135359781463027,
          -25.1351641909705,
          -25.134978732907786,
          -25.134803119063072,
          -25.134637063300527,
          -25.13448028149438,
          -25.134332491463944,
          -25.134193412909497,
          -25.13406276734902,
          -25.13394027805574,
          -25.133825669996508,
          -25.133718669770847,
          -25.133619005550823,
          -25.133526407021535
         ]
        }
       ],
       "layout": {
        "template": {
         "data": {
          "bar": [
           {
            "error_x": {
             "color": "#2a3f5f"
            },
            "error_y": {
             "color": "#2a3f5f"
            },
            "marker": {
             "line": {
              "color": "#E5ECF6",
              "width": 0.5
             }
            },
            "type": "bar"
           }
          ],
          "barpolar": [
           {
            "marker": {
             "line": {
              "color": "#E5ECF6",
              "width": 0.5
             }
            },
            "type": "barpolar"
           }
          ],
          "carpet": [
           {
            "aaxis": {
             "endlinecolor": "#2a3f5f",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "#2a3f5f"
            },
            "baxis": {
             "endlinecolor": "#2a3f5f",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "#2a3f5f"
            },
            "type": "carpet"
           }
          ],
          "choropleth": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "choropleth"
           }
          ],
          "contour": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "contour"
           }
          ],
          "contourcarpet": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "contourcarpet"
           }
          ],
          "heatmap": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "heatmap"
           }
          ],
          "heatmapgl": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "heatmapgl"
           }
          ],
          "histogram": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "histogram"
           }
          ],
          "histogram2d": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "histogram2d"
           }
          ],
          "histogram2dcontour": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "histogram2dcontour"
           }
          ],
          "mesh3d": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "mesh3d"
           }
          ],
          "parcoords": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "parcoords"
           }
          ],
          "pie": [
           {
            "automargin": true,
            "type": "pie"
           }
          ],
          "scatter": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatter"
           }
          ],
          "scatter3d": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatter3d"
           }
          ],
          "scattercarpet": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattercarpet"
           }
          ],
          "scattergeo": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattergeo"
           }
          ],
          "scattergl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattergl"
           }
          ],
          "scattermapbox": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattermapbox"
           }
          ],
          "scatterpolar": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterpolar"
           }
          ],
          "scatterpolargl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterpolargl"
           }
          ],
          "scatterternary": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterternary"
           }
          ],
          "surface": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "surface"
           }
          ],
          "table": [
           {
            "cells": {
             "fill": {
              "color": "#EBF0F8"
             },
             "line": {
              "color": "white"
             }
            },
            "header": {
             "fill": {
              "color": "#C8D4E3"
             },
             "line": {
              "color": "white"
             }
            },
            "type": "table"
           }
          ]
         },
         "layout": {
          "annotationdefaults": {
           "arrowcolor": "#2a3f5f",
           "arrowhead": 0,
           "arrowwidth": 1
          },
          "coloraxis": {
           "colorbar": {
            "outlinewidth": 0,
            "ticks": ""
           }
          },
          "colorscale": {
           "diverging": [
            [
             0,
             "#8e0152"
            ],
            [
             0.1,
             "#c51b7d"
            ],
            [
             0.2,
             "#de77ae"
            ],
            [
             0.3,
             "#f1b6da"
            ],
            [
             0.4,
             "#fde0ef"
            ],
            [
             0.5,
             "#f7f7f7"
            ],
            [
             0.6,
             "#e6f5d0"
            ],
            [
             0.7,
             "#b8e186"
            ],
            [
             0.8,
             "#7fbc41"
            ],
            [
             0.9,
             "#4d9221"
            ],
            [
             1,
             "#276419"
            ]
           ],
           "sequential": [
            [
             0,
             "#0d0887"
            ],
            [
             0.1111111111111111,
             "#46039f"
            ],
            [
             0.2222222222222222,
             "#7201a8"
            ],
            [
             0.3333333333333333,
             "#9c179e"
            ],
            [
             0.4444444444444444,
             "#bd3786"
            ],
            [
             0.5555555555555556,
             "#d8576b"
            ],
            [
             0.6666666666666666,
             "#ed7953"
            ],
            [
             0.7777777777777778,
             "#fb9f3a"
            ],
            [
             0.8888888888888888,
             "#fdca26"
            ],
            [
             1,
             "#f0f921"
            ]
           ],
           "sequentialminus": [
            [
             0,
             "#0d0887"
            ],
            [
             0.1111111111111111,
             "#46039f"
            ],
            [
             0.2222222222222222,
             "#7201a8"
            ],
            [
             0.3333333333333333,
             "#9c179e"
            ],
            [
             0.4444444444444444,
             "#bd3786"
            ],
            [
             0.5555555555555556,
             "#d8576b"
            ],
            [
             0.6666666666666666,
             "#ed7953"
            ],
            [
             0.7777777777777778,
             "#fb9f3a"
            ],
            [
             0.8888888888888888,
             "#fdca26"
            ],
            [
             1,
             "#f0f921"
            ]
           ]
          },
          "colorway": [
           "#636efa",
           "#EF553B",
           "#00cc96",
           "#ab63fa",
           "#FFA15A",
           "#19d3f3",
           "#FF6692",
           "#B6E880",
           "#FF97FF",
           "#FECB52"
          ],
          "font": {
           "color": "#2a3f5f"
          },
          "geo": {
           "bgcolor": "white",
           "lakecolor": "white",
           "landcolor": "#E5ECF6",
           "showlakes": true,
           "showland": true,
           "subunitcolor": "white"
          },
          "hoverlabel": {
           "align": "left"
          },
          "hovermode": "closest",
          "mapbox": {
           "style": "light"
          },
          "paper_bgcolor": "white",
          "plot_bgcolor": "#E5ECF6",
          "polar": {
           "angularaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "bgcolor": "#E5ECF6",
           "radialaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           }
          },
          "scene": {
           "xaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           },
           "yaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           },
           "zaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           }
          },
          "shapedefaults": {
           "line": {
            "color": "#2a3f5f"
           }
          },
          "ternary": {
           "aaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "baxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "bgcolor": "#E5ECF6",
           "caxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           }
          },
          "title": {
           "x": 0.05
          },
          "xaxis": {
           "automargin": true,
           "gridcolor": "white",
           "linecolor": "white",
           "ticks": "",
           "title": {
            "standoff": 15
           },
           "zerolinecolor": "white",
           "zerolinewidth": 2
          },
          "yaxis": {
           "automargin": true,
           "gridcolor": "white",
           "linecolor": "white",
           "ticks": "",
           "title": {
            "standoff": 15
           },
           "zerolinecolor": "white",
           "zerolinewidth": 2
          }
         }
        },
        "title": {
         "text": "Transcendental equation Inspection"
        },
        "xaxis": {
         "dtick": 5,
         "range": [
          -25,
          25
         ],
         "showticklabels": true,
         "tick0": 0,
         "tickangle": -90,
         "ticks": "outside",
         "title": {
          "font": {
           "color": "black",
           "family": "Arial, serif",
           "size": 18
          },
          "text": "x"
         }
        },
        "yaxis": {
         "dtick": 5,
         "range": [
          -50,
          50
         ],
         "tick0": 0,
         "ticks": "outside",
         "title": {
          "font": {
           "color": "black",
           "family": "Arial, serif",
           "size": 18
          },
          "text": "P(x)"
         }
        }
       }
      },
      "text/html": [
       "<div>\n",
       "        \n",
       "        \n",
       "            <div id=\"bb03286c-88cb-47ad-8c81-4f379f248fd6\" class=\"plotly-graph-div\" style=\"height:525px; width:100%;\"></div>\n",
       "            <script type=\"text/javascript\">\n",
       "                require([\"plotly\"], function(Plotly) {\n",
       "                    window.PLOTLYENV=window.PLOTLYENV || {};\n",
       "                    \n",
       "                if (document.getElementById(\"bb03286c-88cb-47ad-8c81-4f379f248fd6\")) {\n",
       "                    Plotly.newPlot(\n",
       "                        'bb03286c-88cb-47ad-8c81-4f379f248fd6',\n",
       "                        [{\"line\": {\"color\": \"black\"}, \"name\": \"P(x) = tan(x) - x\", \"type\": \"scatter\", \"x\": [-25.0, -24.994999499949994, -24.98999899989999, -24.984998499849986, -24.97999799979998, -24.974997499749975, -24.96999699969997, -24.964996499649963, -24.95999599959996, -24.954995499549955, -24.94999499949995, -24.944994499449944, -24.939993999399938, -24.934993499349936, -24.92999299929993, -24.924992499249925, -24.91999199919992, -24.914991499149917, -24.90999099909991, -24.904990499049905, -24.8999899989999, -24.894989498949894, -24.88998899889989, -24.884988498849886, -24.87998799879988, -24.874987498749874, -24.86998699869987, -24.864986498649866, -24.85998599859986, -24.854985498549855, -24.84998499849985, -24.844984498449843, -24.83998399839984, -24.834983498349835, -24.82998299829983, -24.824982498249824, -24.81998199819982, -24.814981498149816, -24.80998099809981, -24.804980498049805, -24.7999799979998, -24.794979497949797, -24.78997899789979, -24.784978497849785, -24.77997799779978, -24.774977497749774, -24.76997699769977, -24.764976497649766, -24.75997599759976, -24.754975497549754, -24.74997499749975, -24.744974497449746, -24.73997399739974, -24.734973497349735, -24.72997299729973, -24.724972497249723, -24.71997199719972, -24.714971497149715, -24.70997099709971, -24.704970497049704, -24.699969996999698, -24.694969496949696, -24.68996899689969, -24.684968496849685, -24.67996799679968, -24.674967496749677, -24.66996699669967, -24.664966496649665, -24.65996599659966, -24.654965496549654, -24.64996499649965, -24.644964496449646, -24.63996399639964, -24.634963496349634, -24.62996299629963, -24.624962496249626, -24.61996199619962, -24.614961496149615, -24.60996099609961, -24.604960496049603, -24.5999599959996, -24.594959495949595, -24.58995899589959, -24.584958495849584, -24.57995799579958, -24.574957495749576, -24.56995699569957, -24.564956495649565, -24.55995599559956, -24.554955495549557, -24.54995499549955, -24.544954495449545, -24.53995399539954, -24.534953495349534, -24.52995299529953, -24.524952495249526, -24.51995199519952, -24.514951495149514, -24.50995099509951, -24.504950495049506, -24.4999499949995, -24.494949494949495, -24.48994899489949, -24.484948494849483, -24.47994799479948, -24.474947494749475, -24.46994699469947, -24.464946494649464, -24.459945994599458, -24.454945494549456, -24.44994499449945, -24.444944494449445, -24.43994399439944, -24.434943494349437, -24.42994299429943, -24.424942494249425, -24.41994199419942, -24.414941494149414, -24.40994099409941, -24.404940494049406, -24.3999399939994, -24.394939493949394, -24.38993899389939, -24.384938493849386, -24.37993799379938, -24.374937493749375, -24.36993699369937, -24.364936493649363, -24.35993599359936, -24.354935493549355, -24.34993499349935, -24.344934493449344, -24.33993399339934, -24.334933493349336, -24.32993299329933, -24.324932493249324, -24.31993199319932, -24.314931493149317, -24.30993099309931, -24.304930493049305, -24.2999299929993, -24.294929492949294, -24.28992899289929, -24.284928492849286, -24.27992799279928, -24.274927492749274, -24.26992699269927, -24.264926492649266, -24.25992599259926, -24.254925492549255, -24.24992499249925, -24.244924492449243, -24.23992399239924, -24.234923492349235, -24.22992299229923, -24.224922492249224, -24.219921992199218, -24.214921492149216, -24.20992099209921, -24.204920492049204, -24.1999199919992, -24.194919491949197, -24.18991899189919, -24.184918491849185, -24.17991799179918, -24.174917491749174, -24.16991699169917, -24.164916491649166, -24.15991599159916, -24.154915491549154, -24.14991499149915, -24.144914491449146, -24.13991399139914, -24.134913491349135, -24.12991299129913, -24.124912491249123, -24.11991199119912, -24.114911491149115, -24.10991099109911, -24.104910491049104, -24.0999099909991, -24.094909490949096, -24.08990899089909, -24.084908490849084, -24.07990799079908, -24.074907490749077, -24.06990699069907, -24.064906490649065, -24.05990599059906, -24.054905490549054, -24.04990499049905, -24.044904490449046, -24.03990399039904, -24.034903490349034, -24.02990299029903, -24.024902490249026, -24.01990199019902, -24.014901490149015, -24.00990099009901, -24.004900490049003, -23.999899989999, -23.994899489948995, -23.98989898989899, -23.984898489848984, -23.979897989798978, -23.974897489748976, -23.96989698969897, -23.964896489648964, -23.95989598959896, -23.954895489548953, -23.94989498949895, -23.944894489448945, -23.93989398939894, -23.934893489348934, -23.92989298929893, -23.924892489248926, -23.91989198919892, -23.914891489148914, -23.90989098909891, -23.904890489048906, -23.8998899889989, -23.894889488948895, -23.88988898889889, -23.884888488848883, -23.87988798879888, -23.874887488748875, -23.86988698869887, -23.864886488648864, -23.85988598859886, -23.854885488548856, -23.84988498849885, -23.844884488448844, -23.83988398839884, -23.834883488348837, -23.82988298829883, -23.824882488248825, -23.81988198819882, -23.814881488148814, -23.80988098809881, -23.804880488048806, -23.7998799879988, -23.794879487948794, -23.78987898789879, -23.784878487848786, -23.77987798779878, -23.774877487748775, -23.76987698769877, -23.764876487648763, -23.75987598759876, -23.754875487548755, -23.74987498749875, -23.744874487448744, -23.739873987398738, -23.734873487348736, -23.72987298729873, -23.724872487248724, -23.71987198719872, -23.714871487148713, -23.70987098709871, -23.704870487048705, -23.6998699869987, -23.694869486948694, -23.68986898689869, -23.684868486848686, -23.67986798679868, -23.674867486748674, -23.66986698669867, -23.664866486648666, -23.65986598659866, -23.654865486548655, -23.64986498649865, -23.644864486448643, -23.63986398639864, -23.634863486348635, -23.62986298629863, -23.624862486248624, -23.61986198619862, -23.614861486148616, -23.60986098609861, -23.604860486048604, -23.5998599859986, -23.594859485948597, -23.58985898589859, -23.584858485848585, -23.57985798579858, -23.574857485748574, -23.56985698569857, -23.564856485648566, -23.55985598559856, -23.554855485548554, -23.54985498549855, -23.544854485448546, -23.53985398539854, -23.534853485348535, -23.52985298529853, -23.524852485248523, -23.51985198519852, -23.514851485148515, -23.50985098509851, -23.504850485048504, -23.499849984998498, -23.494849484948496, -23.48984898489849, -23.484848484848484, -23.47984798479848, -23.474847484748473, -23.46984698469847, -23.464846484648465, -23.45984598459846, -23.454845484548454, -23.44984498449845, -23.444844484448446, -23.43984398439844, -23.434843484348434, -23.42984298429843, -23.424842484248426, -23.41984198419842, -23.414841484148415, -23.40984098409841, -23.404840484048403, -23.3998399839984, -23.394839483948395, -23.38983898389839, -23.384838483848384, -23.37983798379838, -23.374837483748376, -23.36983698369837, -23.364836483648364, -23.35983598359836, -23.354835483548356, -23.34983498349835, -23.344834483448345, -23.33983398339834, -23.334833483348334, -23.32983298329833, -23.324832483248326, -23.31983198319832, -23.314831483148314, -23.30983098309831, -23.304830483048306, -23.2998299829983, -23.294829482948295, -23.28982898289829, -23.284828482848283, -23.27982798279828, -23.274827482748275, -23.26982698269827, -23.264826482648264, -23.259825982598258, -23.254825482548256, -23.24982498249825, -23.244824482448244, -23.23982398239824, -23.234823482348233, -23.22982298229823, -23.224822482248225, -23.21982198219822, -23.214821482148214, -23.20982098209821, -23.204820482048206, -23.1998199819982, -23.194819481948194, -23.18981898189819, -23.184818481848186, -23.17981798179818, -23.174817481748175, -23.16981698169817, -23.164816481648163, -23.15981598159816, -23.154815481548155, -23.14981498149815, -23.144814481448144, -23.13981398139814, -23.134813481348136, -23.12981298129813, -23.124812481248124, -23.11981198119812, -23.114811481148116, -23.10981098109811, -23.104810481048105, -23.0998099809981, -23.094809480948093, -23.08980898089809, -23.084808480848086, -23.07980798079808, -23.074807480748074, -23.06980698069807, -23.064806480648066, -23.05980598059806, -23.054805480548055, -23.04980498049805, -23.044804480448043, -23.03980398039804, -23.034803480348035, -23.02980298029803, -23.024802480248024, -23.019801980198018, -23.014801480148016, -23.00980098009801, -23.004800480048004, -22.999799979998, -22.994799479947993, -22.98979897989799, -22.984798479847985, -22.97979797979798, -22.974797479747973, -22.969796979697968, -22.964796479647966, -22.95979597959796, -22.954795479547954, -22.94979497949795, -22.944794479447946, -22.93979397939794, -22.934793479347935, -22.92979297929793, -22.924792479247923, -22.91979197919792, -22.914791479147915, -22.90979097909791, -22.904790479047904, -22.8997899789979, -22.894789478947896, -22.88978897889789, -22.884788478847884, -22.87978797879788, -22.874787478747876, -22.86978697869787, -22.864786478647865, -22.85978597859786, -22.854785478547853, -22.84978497849785, -22.844784478447846, -22.83978397839784, -22.834783478347834, -22.82978297829783, -22.824782478247826, -22.81978197819782, -22.814781478147815, -22.80978097809781, -22.804780478047803, -22.7997799779978, -22.794779477947795, -22.78977897789779, -22.784778477847784, -22.779777977797778, -22.774777477747776, -22.76977697769777, -22.764776477647764, -22.75977597759776, -22.754775477547753, -22.74977497749775, -22.744774477447745, -22.73977397739774, -22.734773477347733, -22.729772977297728, -22.724772477247726, -22.71977197719772, -22.714771477147714, -22.70977097709771, -22.704770477047706, -22.6997699769977, -22.694769476947695, -22.68976897689769, -22.684768476847683, -22.67976797679768, -22.674767476747675, -22.66976697669767, -22.664766476647664, -22.65976597659766, -22.654765476547656, -22.64976497649765, -22.644764476447644, -22.63976397639764, -22.634763476347636, -22.62976297629763, -22.624762476247625, -22.61976197619762, -22.614761476147613, -22.60976097609761, -22.604760476047606, -22.5997599759976, -22.594759475947594, -22.58975897589759, -22.584758475847586, -22.57975797579758, -22.574757475747575, -22.56975697569757, -22.564756475647563, -22.55975597559756, -22.554755475547555, -22.54975497549755, -22.544754475447544, -22.539753975397538, -22.534753475347536, -22.52975297529753, -22.524752475247524, -22.51975197519752, -22.514751475147513, -22.50975097509751, -22.504750475047505, -22.4997499749975, -22.494749474947493, -22.489748974897488, -22.484748474847486, -22.47974797479748, -22.474747474747474, -22.46974697469747, -22.464746474647466, -22.45974597459746, -22.454745474547455, -22.44974497449745, -22.444744474447443, -22.43974397439744, -22.434743474347435, -22.42974297429743, -22.424742474247424, -22.41974197419742, -22.414741474147416, -22.40974097409741, -22.404740474047404, -22.3997399739974, -22.394739473947396, -22.38973897389739, -22.384738473847385, -22.37973797379738, -22.374737473747373, -22.36973697369737, -22.364736473647366, -22.35973597359736, -22.354735473547354, -22.34973497349735, -22.344734473447346, -22.33973397339734, -22.334733473347335, -22.32973297329733, -22.324732473247323, -22.31973197319732, -22.314731473147315, -22.30973097309731, -22.304730473047304, -22.299729972997298, -22.294729472947296, -22.28972897289729, -22.284728472847284, -22.27972797279728, -22.274727472747273, -22.26972697269727, -22.264726472647265, -22.25972597259726, -22.254725472547253, -22.249724972497248, -22.244724472447245, -22.23972397239724, -22.234723472347234, -22.22972297229723, -22.224722472247226, -22.21972197219722, -22.214721472147215, -22.20972097209721, -22.204720472047203, -22.1997199719972, -22.194719471947195, -22.18971897189719, -22.184718471847184, -22.17971797179718, -22.174717471747176, -22.16971697169717, -22.164716471647164, -22.15971597159716, -22.154715471547156, -22.14971497149715, -22.144714471447145, -22.13971397139714, -22.134713471347133, -22.12971297129713, -22.124712471247125, -22.11971197119712, -22.114711471147114, -22.10971097109711, -22.104710471047106, -22.0997099709971, -22.094709470947095, -22.08970897089709, -22.084708470847083, -22.07970797079708, -22.074707470747075, -22.06970697069707, -22.064706470647064, -22.059705970597058, -22.054705470547056, -22.04970497049705, -22.044704470447044, -22.03970397039704, -22.034703470347033, -22.02970297029703, -22.024702470247025, -22.01970197019702, -22.014701470147013, -22.009700970097008, -22.004700470047005, -21.999699969997, -21.994699469946994, -21.98969896989699, -21.984698469846986, -21.97969796979698, -21.974697469746975, -21.96969696969697, -21.964696469646963, -21.95969596959696, -21.954695469546955, -21.94969496949695, -21.944694469446944, -21.93969396939694, -21.934693469346936, -21.92969296929693, -21.924692469246924, -21.91969196919692, -21.914691469146916, -21.90969096909691, -21.904690469046905, -21.8996899689969, -21.894689468946893, -21.88968896889689, -21.884688468846885, -21.87968796879688, -21.874687468746874, -21.86968696869687, -21.864686468646866, -21.85968596859686, -21.854685468546855, -21.84968496849685, -21.844684468446843, -21.83968396839684, -21.834683468346835, -21.82968296829683, -21.824682468246824, -21.819681968196818, -21.814681468146816, -21.80968096809681, -21.804680468046804, -21.7996799679968, -21.794679467946793, -21.78967896789679, -21.784678467846785, -21.77967796779678, -21.774677467746773, -21.769676967696768, -21.764676467646765, -21.75967596759676, -21.754675467546754, -21.749674967496748, -21.744674467446746, -21.73967396739674, -21.734673467346735, -21.72967296729673, -21.724672467246723, -21.71967196719672, -21.714671467146715, -21.70967096709671, -21.704670467046704, -21.6996699669967, -21.694669466946696, -21.68966896689669, -21.684668466846684, -21.67966796679668, -21.674667466746676, -21.66966696669667, -21.664666466646665, -21.65966596659666, -21.654665466546653, -21.64966496649665, -21.644664466446645, -21.63966396639664, -21.634663466346634, -21.629662966296628, -21.624662466246626, -21.61966196619662, -21.614661466146615, -21.60966096609661, -21.604660466046603, -21.5996599659966, -21.594659465946595, -21.58965896589659, -21.584658465846584, -21.579657965796578, -21.574657465746576, -21.56965696569657, -21.564656465646564, -21.55965596559656, -21.554655465546553, -21.54965496549655, -21.544654465446545, -21.53965396539654, -21.534653465346533, -21.529652965296528, -21.524652465246525, -21.51965196519652, -21.514651465146514, -21.509650965096508, -21.504650465046506, -21.4996499649965, -21.494649464946495, -21.48964896489649, -21.484648464846483, -21.47964796479648, -21.474647464746475, -21.46964696469647, -21.464646464646464, -21.45964596459646, -21.454645464546456, -21.44964496449645, -21.444644464446444, -21.43964396439644, -21.434643464346436, -21.42964296429643, -21.424642464246425, -21.41964196419642, -21.414641464146413, -21.40964096409641, -21.404640464046405, -21.3996399639964, -21.394639463946394, -21.389638963896388, -21.384638463846386, -21.37963796379638, -21.374637463746375, -21.36963696369637, -21.364636463646363, -21.35963596359636, -21.354635463546355, -21.34963496349635, -21.344634463446344, -21.339633963396338, -21.334633463346336, -21.32963296329633, -21.324632463246324, -21.31963196319632, -21.314631463146313, -21.30963096309631, -21.304630463046305, -21.2996299629963, -21.294629462946293, -21.289628962896288, -21.284628462846285, -21.27962796279628, -21.274627462746274, -21.269626962696268, -21.264626462646266, -21.25962596259626, -21.254625462546255, -21.24962496249625, -21.244624462446243, -21.23962396239624, -21.234623462346235, -21.22962296229623, -21.224622462246224, -21.21962196219622, -21.214621462146216, -21.20962096209621, -21.204620462046204, -21.1996199619962, -21.194619461946196, -21.18961896189619, -21.184618461846185, -21.17961796179618, -21.174617461746173, -21.16961696169617, -21.164616461646165, -21.15961596159616, -21.154615461546154, -21.149614961496148, -21.144614461446146, -21.13961396139614, -21.134613461346134, -21.12961296129613, -21.124612461246123, -21.11961196119612, -21.114611461146115, -21.10961096109611, -21.104610461046104, -21.099609960996098, -21.094609460946096, -21.08960896089609, -21.084608460846084, -21.07960796079608, -21.074607460746073, -21.06960696069607, -21.064606460646065, -21.05960596059606, -21.054605460546053, -21.049604960496048, -21.044604460446045, -21.03960396039604, -21.034603460346034, -21.029602960296028, -21.024602460246022, -21.01960196019602, -21.014601460146014, -21.00960096009601, -21.004600460046003, -20.999599959995997, -20.994599459945995, -20.98959895989599, -20.984598459845984, -20.97959795979598, -20.974597459745976, -20.96959695969597, -20.964596459645964, -20.95959595959596, -20.954595459545956, -20.94959495949595, -20.944594459445945, -20.93959395939594, -20.934593459345933, -20.92959295929593, -20.924592459245925, -20.91959195919592, -20.914591459145914, -20.909590959095908, -20.904590459045906, -20.8995899589959, -20.894589458945894, -20.88958895889589, -20.884588458845883, -20.87958795879588, -20.874587458745875, -20.86958695869587, -20.864586458645864, -20.859585958595858, -20.854585458545856, -20.84958495849585, -20.844584458445844, -20.83958395839584, -20.834583458345833, -20.82958295829583, -20.824582458245825, -20.81958195819582, -20.814581458145813, -20.809580958095808, -20.804580458045805, -20.7995799579958, -20.794579457945794, -20.789578957895788, -20.784578457845782, -20.77957795779578, -20.774577457745774, -20.76957695769577, -20.764576457645767, -20.759575957595757, -20.754575457545755, -20.74957495749575, -20.744574457445744, -20.73957395739574, -20.734573457345736, -20.72957295729573, -20.724572457245724, -20.71957195719572, -20.714571457145716, -20.70957095709571, -20.704570457045705, -20.6995699569957, -20.694569456945693, -20.68956895689569, -20.684568456845685, -20.67956795679568, -20.674567456745674, -20.669566956695668, -20.664566456645666, -20.65956595659566, -20.654565456545654, -20.64956495649565, -20.644564456445643, -20.63956395639564, -20.634563456345635, -20.62956295629563, -20.624562456245624, -20.619561956195618, -20.614561456145616, -20.60956095609561, -20.604560456045604, -20.5995599559956, -20.594559455945593, -20.58955895589559, -20.584558455845585, -20.57955795579558, -20.574557455745573, -20.569556955695568, -20.564556455645565, -20.55955595559556, -20.554555455545554, -20.549554955495548, -20.544554455445542, -20.53955395539554, -20.534553455345534, -20.52955295529553, -20.524552455245527, -20.519551955195517, -20.514551455145515, -20.50955095509551, -20.504550455045504, -20.4995499549955, -20.494549454945496, -20.48954895489549, -20.484548454845484, -20.47954795479548, -20.474547454745476, -20.46954695469547, -20.464546454645465, -20.45954595459546, -20.454545454545453, -20.44954495449545, -20.444544454445445, -20.43954395439544, -20.434543454345434, -20.429542954295428, -20.424542454245426, -20.41954195419542, -20.414541454145414, -20.40954095409541, -20.404540454045403, -20.3995399539954, -20.394539453945395, -20.38953895389539, -20.384538453845384, -20.379537953795378, -20.374537453745376, -20.36953695369537, -20.364536453645364, -20.35953595359536, -20.354535453545353, -20.34953495349535, -20.344534453445345, -20.33953395339534, -20.334533453345333, -20.329532953295328, -20.324532453245325, -20.31953195319532, -20.314531453145314, -20.309530953095308, -20.304530453045302, -20.2995299529953, -20.294529452945294, -20.28952895289529, -20.284528452845286, -20.279527952795277, -20.274527452745275, -20.26952695269527, -20.264526452645264, -20.25952595259526, -20.254525452545256, -20.24952495249525, -20.244524452445244, -20.23952395239524, -20.234523452345236, -20.22952295229523, -20.224522452245225, -20.21952195219522, -20.214521452145213, -20.20952095209521, -20.204520452045205, -20.1995199519952, -20.194519451945194, -20.189518951895188, -20.184518451845186, -20.17951795179518, -20.174517451745174, -20.16951695169517, -20.164516451645163, -20.15951595159516, -20.154515451545155, -20.14951495149515, -20.144514451445144, -20.139513951395138, -20.134513451345136, -20.12951295129513, -20.124512451245124, -20.11951195119512, -20.114511451145113, -20.10951095109511, -20.104510451045105, -20.0995099509951, -20.094509450945093, -20.089508950895087, -20.084508450845085, -20.07950795079508, -20.074507450745074, -20.069506950695068, -20.064506450645062, -20.05950595059506, -20.054505450545054, -20.04950495049505, -20.044504450445046, -20.039503950395037, -20.034503450345035, -20.02950295029503, -20.024502450245024, -20.01950195019502, -20.014501450145016, -20.00950095009501, -20.004500450045004, -19.999499949995, -19.994499449944996, -19.98949894989499, -19.984498449844985, -19.97949794979498, -19.974497449744973, -19.96949694969497, -19.964496449644965, -19.95949594959496, -19.954495449544954, -19.949494949494948, -19.944494449444946, -19.93949394939494, -19.934493449344934, -19.92949294929493, -19.924492449244923, -19.91949194919492, -19.914491449144915, -19.90949094909491, -19.904490449044903, -19.899489948994898, -19.894489448944896, -19.88948894889489, -19.884488448844884, -19.87948794879488, -19.874487448744873, -19.86948694869487, -19.864486448644865, -19.85948594859486, -19.854485448544853, -19.849484948494847, -19.844484448444845, -19.83948394839484, -19.834483448344834, -19.829482948294828, -19.824482448244822, -19.81948194819482, -19.814481448144814, -19.80948094809481, -19.804480448044803, -19.799479947994797, -19.794479447944795, -19.78947894789479, -19.784478447844783, -19.77947794779478, -19.774477447744772, -19.76947694769477, -19.764476447644764, -19.75947594759476, -19.754475447544756, -19.74947494749475, -19.744474447444745, -19.73947394739474, -19.734473447344733, -19.72947294729473, -19.724472447244725, -19.71947194719472, -19.714471447144714, -19.709470947094708, -19.704470447044706, -19.6994699469947, -19.694469446944694, -19.68946894689469, -19.684468446844683, -19.67946794679468, -19.674467446744675, -19.66946694669467, -19.664466446644663, -19.659465946594658, -19.654465446544656, -19.64946494649465, -19.644464446444644, -19.63946394639464, -19.634463446344633, -19.62946294629463, -19.624462446244625, -19.61946194619462, -19.614461446144613, -19.609460946094607, -19.604460446044605, -19.5994599459946, -19.594459445944594, -19.589458945894588, -19.584458445844582, -19.57945794579458, -19.574457445744574, -19.56945694569457, -19.564456445644563, -19.559455945594557, -19.554455445544555, -19.54945494549455, -19.544454445444543, -19.53945394539454, -19.534453445344532, -19.52945294529453, -19.524452445244524, -19.51945194519452, -19.514451445144516, -19.50945094509451, -19.504450445044505, -19.4994499449945, -19.494449444944493, -19.48944894489449, -19.484448444844485, -19.47944794479448, -19.474447444744474, -19.469446944694468, -19.464446444644466, -19.45944594459446, -19.454445444544454, -19.44944494449445, -19.444444444444443, -19.43944394439444, -19.434443444344435, -19.42944294429443, -19.424442444244423, -19.419441944194418, -19.414441444144416, -19.40944094409441, -19.404440444044404, -19.3994399439944, -19.394439443944393, -19.38943894389439, -19.384438443844385, -19.37943794379438, -19.374437443744373, -19.369436943694367, -19.364436443644365, -19.35943594359436, -19.354435443544354, -19.349434943494348, -19.344434443444342, -19.33943394339434, -19.334433443344334, -19.32943294329433, -19.324432443244323, -19.319431943194317, -19.314431443144315, -19.30943094309431, -19.304430443044303, -19.2994299429943, -19.294429442944292, -19.28942894289429, -19.284428442844284, -19.27942794279428, -19.274427442744276, -19.26942694269427, -19.264426442644265, -19.25942594259426, -19.254425442544253, -19.24942494249425, -19.244424442444245, -19.23942394239424, -19.234423442344234, -19.229422942294228, -19.224422442244226, -19.21942194219422, -19.214421442144214, -19.20942094209421, -19.204420442044203, -19.1994199419942, -19.194419441944195, -19.18941894189419, -19.184418441844183, -19.179417941794178, -19.174417441744176, -19.16941694169417, -19.164416441644164, -19.15941594159416, -19.154415441544153, -19.14941494149415, -19.144414441444145, -19.13941394139414, -19.134413441344133, -19.129412941294127, -19.124412441244125, -19.11941194119412, -19.114411441144114, -19.109410941094108, -19.104410441044102, -19.0994099409941, -19.094409440944094, -19.08940894089409, -19.084408440844083, -19.079407940794077, -19.074407440744075, -19.06940694069407, -19.064406440644063, -19.05940594059406, -19.054405440544052, -19.04940494049405, -19.044404440444044, -19.03940394039404, -19.034403440344036, -19.02940294029403, -19.024402440244025, -19.01940194019402, -19.014401440144013, -19.00940094009401, -19.004400440044005, -18.999399939994, -18.994399439943994, -18.989398939893988, -18.984398439843986, -18.97939793979398, -18.974397439743974, -18.96939693969397, -18.964396439643963, -18.95939593959396, -18.954395439543955, -18.94939493949395, -18.944394439443943, -18.939393939393938, -18.934393439343935, -18.92939293929393, -18.924392439243924, -18.91939193919392, -18.914391439143913, -18.90939093909391, -18.904390439043905, -18.8993899389939, -18.894389438943893, -18.889388938893887, -18.884388438843885, -18.87938793879388, -18.874387438743874, -18.869386938693868, -18.864386438643862, -18.85938593859386, -18.854385438543854, -18.84938493849385, -18.844384438443843, -18.839383938393837, -18.834383438343835, -18.82938293829383, -18.824382438243823, -18.81938193819382, -18.814381438143812, -18.80938093809381, -18.804380438043804, -18.7993799379938, -18.794379437943796, -18.78937893789379, -18.784378437843785, -18.77937793779378, -18.774377437743773, -18.76937693769377, -18.764376437643765, -18.75937593759376, -18.754375437543754, -18.749374937493748, -18.744374437443746, -18.73937393739374, -18.734373437343734, -18.72937293729373, -18.724372437243723, -18.71937193719372, -18.714371437143715, -18.70937093709371, -18.704370437043703, -18.699369936993698, -18.694369436943695, -18.68936893689369, -18.684368436843684, -18.67936793679368, -18.674367436743672, -18.66936693669367, -18.664366436643665, -18.65936593659366, -18.654365436543653, -18.649364936493647, -18.644364436443645, -18.63936393639364, -18.634363436343634, -18.629362936293628, -18.624362436243622, -18.61936193619362, -18.614361436143614, -18.60936093609361, -18.604360436043603, -18.599359935993597, -18.594359435943595, -18.58935893589359, -18.584358435843583, -18.57935793579358, -18.574357435743572, -18.56935693569357, -18.564356435643564, -18.55935593559356, -18.554355435543556, -18.54935493549355, -18.544354435443545, -18.53935393539354, -18.534353435343533, -18.52935293529353, -18.524352435243525, -18.51935193519352, -18.514351435143514, -18.509350935093508, -18.504350435043506, -18.4993499349935, -18.494349434943494, -18.48934893489349, -18.484348434843483, -18.47934793479348, -18.474347434743475, -18.46934693469347, -18.464346434643463, -18.459345934593458, -18.454345434543455, -18.44934493449345, -18.444344434443444, -18.439343934393438, -18.434343434343432, -18.42934293429343, -18.424342434243425, -18.41934193419342, -18.414341434143413, -18.409340934093407, -18.404340434043405, -18.3993399339934, -18.394339433943394, -18.389338933893388, -18.384338433843382, -18.37933793379338, -18.374337433743374, -18.36933693369337, -18.364336433643363, -18.359335933593357, -18.354335433543355, -18.34933493349335, -18.344334433443343, -18.33933393339334, -18.334333433343332, -18.32933293329333, -18.324332433243324, -18.319331933193318, -18.314331433143316, -18.30933093309331, -18.304330433043305, -18.2993299329933, -18.294329432943293, -18.28932893289329, -18.284328432843285, -18.27932793279328, -18.274327432743274, -18.269326932693268, -18.264326432643266, -18.25932593259326, -18.254325432543254, -18.24932493249325, -18.244324432443243, -18.23932393239324, -18.234323432343235, -18.22932293229323, -18.224322432243223, -18.219321932193218, -18.214321432143215, -18.20932093209321, -18.204320432043204, -18.199319931993198, -18.194319431943192, -18.18931893189319, -18.184318431843185, -18.17931793179318, -18.174317431743173, -18.169316931693167, -18.164316431643165, -18.15931593159316, -18.154315431543154, -18.149314931493148, -18.144314431443142, -18.13931393139314, -18.134313431343134, -18.12931293129313, -18.124312431243123, -18.119311931193117, -18.114311431143115, -18.10931093109311, -18.104310431043103, -18.0993099309931, -18.094309430943092, -18.08930893089309, -18.084308430843084, -18.079307930793078, -18.074307430743076, -18.06930693069307, -18.064306430643065, -18.05930593059306, -18.054305430543053, -18.04930493049305, -18.044304430443045, -18.03930393039304, -18.034303430343034, -18.029302930293028, -18.024302430243026, -18.01930193019302, -18.014301430143014, -18.00930093009301, -18.004300430043003, -17.999299929993, -17.994299429942995, -17.98929892989299, -17.984298429842983, -17.979297929792978, -17.974297429742975, -17.96929692969297, -17.964296429642964, -17.959295929592958, -17.954295429542952, -17.94929492949295, -17.944294429442945, -17.93929392939294, -17.934293429342933, -17.929292929292927, -17.924292429242925, -17.91929192919292, -17.914291429142914, -17.909290929092908, -17.904290429042902, -17.8992899289929, -17.894289428942894, -17.88928892889289, -17.884288428842883, -17.879287928792877, -17.874287428742875, -17.86928692869287, -17.864286428642863, -17.85928592859286, -17.854285428542852, -17.84928492849285, -17.844284428442844, -17.839283928392838, -17.834283428342836, -17.82928292829283, -17.824282428242824, -17.81928192819282, -17.814281428142813, -17.80928092809281, -17.804280428042805, -17.7992799279928, -17.794279427942794, -17.789278927892788, -17.784278427842786, -17.77927792779278, -17.774277427742774, -17.76927692769277, -17.764276427642763, -17.75927592759276, -17.754275427542755, -17.74927492749275, -17.744274427442743, -17.739273927392738, -17.734273427342735, -17.72927292729273, -17.724272427242724, -17.719271927192718, -17.714271427142712, -17.70927092709271, -17.704270427042704, -17.6992699269927, -17.694269426942693, -17.689268926892687, -17.684268426842685, -17.67926792679268, -17.674267426742674, -17.669266926692668, -17.664266426642662, -17.65926592659266, -17.654265426542654, -17.64926492649265, -17.644264426442643, -17.639263926392637, -17.634263426342635, -17.62926292629263, -17.624262426242623, -17.61926192619262, -17.614261426142612, -17.60926092609261, -17.604260426042604, -17.599259925992598, -17.594259425942596, -17.58925892589259, -17.584258425842584, -17.57925792579258, -17.574257425742573, -17.56925692569257, -17.564256425642565, -17.55925592559256, -17.554255425542554, -17.549254925492548, -17.544254425442546, -17.53925392539254, -17.534253425342534, -17.52925292529253, -17.524252425242523, -17.51925192519252, -17.514251425142515, -17.50925092509251, -17.504250425042503, -17.499249924992498, -17.494249424942495, -17.48924892489249, -17.484248424842484, -17.479247924792478, -17.474247424742472, -17.46924692469247, -17.464246424642464, -17.45924592459246, -17.454245424542453, -17.449244924492447, -17.444244424442445, -17.43924392439244, -17.434243424342434, -17.429242924292428, -17.424242424242422, -17.41924192419242, -17.414241424142414, -17.40924092409241, -17.404240424042403, -17.399239923992397, -17.394239423942395, -17.38923892389239, -17.384238423842383, -17.37923792379238, -17.374237423742372, -17.36923692369237, -17.364236423642364, -17.359235923592358, -17.354235423542356, -17.34923492349235, -17.344234423442344, -17.33923392339234, -17.334233423342333, -17.32923292329233, -17.324232423242325, -17.31923192319232, -17.314231423142314, -17.309230923092308, -17.304230423042306, -17.2992299229923, -17.294229422942294, -17.28922892289229, -17.284228422842283, -17.27922792279228, -17.274227422742275, -17.26922692269227, -17.264226422642263, -17.259225922592258, -17.254225422542255, -17.24922492249225, -17.244224422442244, -17.239223922392238, -17.234223422342232, -17.22922292229223, -17.224222422242224, -17.21922192219222, -17.214221422142213, -17.209220922092207, -17.204220422042205, -17.1992199219922, -17.194219421942194, -17.189218921892188, -17.184218421842182, -17.17921792179218, -17.174217421742174, -17.16921692169217, -17.164216421642163, -17.159215921592157, -17.154215421542155, -17.14921492149215, -17.144214421442143, -17.139213921392138, -17.13421342134213, -17.12921292129213, -17.124212421242124, -17.119211921192118, -17.114211421142116, -17.109210921092107, -17.104210421042104, -17.0992099209921, -17.094209420942093, -17.08920892089209, -17.084208420842085, -17.07920792079208, -17.074207420742074, -17.069206920692068, -17.064206420642066, -17.05920592059206, -17.054205420542054, -17.04920492049205, -17.044204420442043, -17.03920392039204, -17.034203420342035, -17.02920292029203, -17.024202420242023, -17.019201920192017, -17.014201420142015, -17.00920092009201, -17.004200420042004, -16.999199919991998, -16.994199419941992, -16.98919891989199, -16.984198419841984, -16.97919791979198, -16.974197419741973, -16.969196919691967, -16.964196419641965, -16.95919591959196, -16.954195419541954, -16.94919491949195, -16.944194419441942, -16.93919391939194, -16.934193419341934, -16.92919291929193, -16.924192419241926, -16.919191919191917, -16.914191419141915, -16.90919091909191, -16.904190419041903, -16.8991899189919, -16.89418941894189, -16.88918891889189, -16.884188418841884, -16.879187918791878, -16.874187418741876, -16.869186918691867, -16.864186418641864, -16.85918591859186, -16.854185418541853, -16.84918491849185, -16.84418441844184, -16.83918391839184, -16.834183418341834, -16.829182918291828, -16.824182418241826, -16.819181918191816, -16.814181418141814, -16.80918091809181, -16.804180418041803, -16.7991799179918, -16.79417941794179, -16.78917891789179, -16.784178417841783, -16.779177917791777, -16.774177417741775, -16.76917691769177, -16.764176417641764, -16.759175917591758, -16.754175417541752, -16.74917491749175, -16.744174417441744, -16.73917391739174, -16.734173417341733, -16.729172917291727, -16.724172417241725, -16.71917191719172, -16.714171417141714, -16.70917091709171, -16.704170417041702, -16.6991699169917, -16.694169416941694, -16.68916891689169, -16.684168416841686, -16.679167916791677, -16.674167416741675, -16.66916691669167, -16.664166416641663, -16.65916591659166, -16.65416541654165, -16.64916491649165, -16.644164416441644, -16.639163916391638, -16.634163416341636, -16.629162916291627, -16.624162416241624, -16.61916191619162, -16.614161416141613, -16.60916091609161, -16.6041604160416, -16.5991599159916, -16.594159415941593, -16.589158915891588, -16.584158415841586, -16.579157915791576, -16.574157415741574, -16.56915691569157, -16.564156415641563, -16.55915591559156, -16.55415541554155, -16.54915491549155, -16.544154415441543, -16.539153915391537, -16.534153415341535, -16.52915291529153, -16.524152415241524, -16.519151915191518, -16.514151415141512, -16.50915091509151, -16.504150415041504, -16.4991499149915, -16.494149414941493, -16.489148914891487, -16.484148414841485, -16.47914791479148, -16.474147414741473, -16.46914691469147, -16.464146414641462, -16.45914591459146, -16.454145414541454, -16.44914491449145, -16.444144414441446, -16.439143914391437, -16.434143414341435, -16.42914291429143, -16.424142414241423, -16.41914191419142, -16.41414141414141, -16.40914091409141, -16.404140414041404, -16.399139913991398, -16.394139413941396, -16.389138913891387, -16.384138413841384, -16.37913791379138, -16.374137413741373, -16.36913691369137, -16.36413641364136, -16.35913591359136, -16.354135413541353, -16.349134913491348, -16.344134413441346, -16.339133913391336, -16.334133413341334, -16.32913291329133, -16.324132413241323, -16.31913191319132, -16.31413141314131, -16.30913091309131, -16.304130413041303, -16.299129912991297, -16.294129412941295, -16.28912891289129, -16.284128412841284, -16.279127912791278, -16.274127412741272, -16.26912691269127, -16.264126412641264, -16.25912591259126, -16.254125412541253, -16.249124912491247, -16.244124412441245, -16.23912391239124, -16.234123412341233, -16.22912291229123, -16.224122412241222, -16.21912191219122, -16.214121412141214, -16.20912091209121, -16.204120412041206, -16.199119911991197, -16.194119411941195, -16.18911891189119, -16.184118411841183, -16.17911791179118, -16.17411741174117, -16.16911691169117, -16.164116411641164, -16.159115911591158, -16.154115411541156, -16.149114911491147, -16.144114411441144, -16.13911391139114, -16.134113411341133, -16.12911291129113, -16.12411241124112, -16.11911191119112, -16.114111411141113, -16.109110911091108, -16.104110411041106, -16.099109910991096, -16.094109410941094, -16.08910891089109, -16.084108410841083, -16.07910791079108, -16.07410741074107, -16.06910691069107, -16.064106410641063, -16.059105910591057, -16.054105410541055, -16.04910491049105, -16.044104410441044, -16.039103910391038, -16.034103410341032, -16.02910291029103, -16.024102410241024, -16.01910191019102, -16.014101410141013, -16.009100910091007, -16.004100410041005, -15.999099909991, -15.994099409940993, -15.98909890989099, -15.984098409840984, -15.979097909790978, -15.974097409740974, -15.969096909690968, -15.964096409640964, -15.959095909590959, -15.954095409540953, -15.949094909490949, -15.944094409440943, -15.93909390939094, -15.934093409340933, -15.92909290929093, -15.924092409240924, -15.919091909190918, -15.914091409140914, -15.909090909090908, -15.904090409040904, -15.899089908990899, -15.894089408940893, -15.889088908890889, -15.884088408840883, -15.87908790879088, -15.874087408740873, -15.86908690869087, -15.864086408640864, -15.859085908590858, -15.854085408540854, -15.849084908490848, -15.844084408440844, -15.839083908390839, -15.834083408340833, -15.829082908290829, -15.824082408240823, -15.81908190819082, -15.814081408140813, -15.80908090809081, -15.804080408040804, -15.799079907990798, -15.794079407940794, -15.789078907890788, -15.784078407840784, -15.779077907790779, -15.774077407740773, -15.769076907690769, -15.764076407640763, -15.75907590759076, -15.754075407540753, -15.74907490749075, -15.744074407440744, -15.739073907390738, -15.734073407340734, -15.729072907290728, -15.724072407240724, -15.719071907190719, -15.714071407140713, -15.709070907090709, -15.704070407040703, -15.6990699069907, -15.694069406940693, -15.68906890689069, -15.684068406840684, -15.679067906790678, -15.674067406740674, -15.669066906690668, -15.664066406640664, -15.659065906590659, -15.654065406540653, -15.649064906490649, -15.644064406440643, -15.63906390639064, -15.634063406340633, -15.62906290629063, -15.624062406240624, -15.619061906190618, -15.614061406140614, -15.609060906090608, -15.604060406040604, -15.599059905990599, -15.594059405940593, -15.589058905890589, -15.584058405840583, -15.57905790579058, -15.574057405740573, -15.56905690569057, -15.564056405640564, -15.559055905590558, -15.554055405540554, -15.549054905490548, -15.544054405440544, -15.539053905390539, -15.534053405340533, -15.529052905290529, -15.524052405240523, -15.51905190519052, -15.514051405140513, -15.50905090509051, -15.504050405040504, -15.499049904990498, -15.494049404940494, -15.489048904890488, -15.484048404840484, -15.479047904790479, -15.474047404740473, -15.469046904690469, -15.464046404640463, -15.45904590459046, -15.454045404540453, -15.44904490449045, -15.444044404440444, -15.439043904390438, -15.434043404340434, -15.429042904290428, -15.424042404240424, -15.419041904190419, -15.414041404140413, -15.409040904090409, -15.404040404040403, -15.3990399039904, -15.394039403940393, -15.38903890389039, -15.384038403840384, -15.379037903790378, -15.374037403740374, -15.369036903690368, -15.364036403640364, -15.359035903590359, -15.354035403540353, -15.349034903490349, -15.344034403440343, -15.33903390339034, -15.334033403340333, -15.32903290329033, -15.324032403240324, -15.319031903190318, -15.314031403140314, -15.309030903090308, -15.304030403040304, -15.299029902990299, -15.294029402940293, -15.289028902890289, -15.284028402840283, -15.27902790279028, -15.274027402740273, -15.26902690269027, -15.264026402640264, -15.259025902590258, -15.254025402540254, -15.249024902490248, -15.244024402440244, -15.239023902390239, -15.234023402340233, -15.229022902290229, -15.224022402240223, -15.219021902190219, -15.214021402140213, -15.20902090209021, -15.204020402040204, -15.199019901990198, -15.194019401940194, -15.189018901890188, -15.184018401840184, -15.179017901790179, -15.174017401740173, -15.169016901690169, -15.164016401640163, -15.159015901590159, -15.154015401540153, -15.14901490149015, -15.144014401440144, -15.139013901390138, -15.134013401340134, -15.129012901290128, -15.124012401240124, -15.119011901190119, -15.114011401140113, -15.109010901090109, -15.104010401040103, -15.099009900990099, -15.094009400940093, -15.08900890089009, -15.084008400840084, -15.079007900790078, -15.074007400740074, -15.069006900690068, -15.064006400640064, -15.059005900590059, -15.054005400540053, -15.049004900490049, -15.044004400440043, -15.039003900390039, -15.034003400340033, -15.02900290029003, -15.024002400240024, -15.019001900190018, -15.014001400140014, -15.009000900090008, -15.004000400040004, -14.998999899989998, -14.993999399939993, -14.988998899889989, -14.983998399839983, -14.978997899789979, -14.973997399739973, -14.96899689968997, -14.963996399639964, -14.958995899589958, -14.953995399539954, -14.948994899489948, -14.943994399439944, -14.938993899389938, -14.933993399339933, -14.928992899289929, -14.923992399239923, -14.918991899189919, -14.913991399139913, -14.90899089908991, -14.903990399039904, -14.898989898989898, -14.893989398939894, -14.888988898889888, -14.883988398839884, -14.878987898789878, -14.873987398739873, -14.868986898689869, -14.863986398639863, -14.858985898589859, -14.853985398539853, -14.84898489848985, -14.843984398439844, -14.838983898389838, -14.833983398339834, -14.828982898289828, -14.823982398239824, -14.818981898189818, -14.813981398139813, -14.808980898089809, -14.803980398039803, -14.798979897989799, -14.793979397939793, -14.78897889788979, -14.783978397839784, -14.778977897789778, -14.773977397739774, -14.768976897689768, -14.763976397639764, -14.758975897589758, -14.753975397539753, -14.748974897489749, -14.743974397439743, -14.738973897389739, -14.733973397339733, -14.728972897289728, -14.723972397239724, -14.718971897189718, -14.713971397139714, -14.708970897089708, -14.703970397039704, -14.698969896989698, -14.693969396939693, -14.688968896889689, -14.683968396839683, -14.678967896789679, -14.673967396739673, -14.668966896689668, -14.663966396639664, -14.658965896589658, -14.653965396539654, -14.648964896489648, -14.643964396439644, -14.638963896389638, -14.633963396339633, -14.628962896289629, -14.623962396239623, -14.618961896189619, -14.613961396139613, -14.608960896089608, -14.603960396039604, -14.598959895989598, -14.593959395939594, -14.588958895889588, -14.583958395839584, -14.578957895789578, -14.573957395739573, -14.568956895689569, -14.563956395639563, -14.558955895589559, -14.553955395539553, -14.548954895489548, -14.543954395439544, -14.538953895389538, -14.533953395339534, -14.528952895289528, -14.523952395239524, -14.518951895189518, -14.513951395139513, -14.508950895089509, -14.503950395039503, -14.498949894989499, -14.493949394939493, -14.488948894889488, -14.483948394839484, -14.478947894789478, -14.473947394739474, -14.468946894689468, -14.463946394639464, -14.458945894589458, -14.453945394539453, -14.448944894489449, -14.443944394439443, -14.438943894389439, -14.433943394339433, -14.428942894289428, -14.423942394239424, -14.418941894189418, -14.413941394139414, -14.408940894089408, -14.403940394039404, -14.398939893989398, -14.393939393939393, -14.388938893889389, -14.383938393839383, -14.378937893789379, -14.373937393739373, -14.368936893689368, -14.363936393639364, -14.358935893589358, -14.353935393539354, -14.348934893489348, -14.343934393439344, -14.338933893389338, -14.333933393339333, -14.328932893289329, -14.323932393239323, -14.318931893189319, -14.313931393139313, -14.308930893089308, -14.303930393039304, -14.298929892989298, -14.293929392939294, -14.288928892889288, -14.283928392839284, -14.278927892789278, -14.273927392739273, -14.268926892689269, -14.263926392639263, -14.258925892589259, -14.253925392539253, -14.248924892489248, -14.243924392439244, -14.238923892389238, -14.233923392339234, -14.228922892289228, -14.223922392239224, -14.218921892189218, -14.213921392139213, -14.208920892089209, -14.203920392039203, -14.198919891989199, -14.193919391939193, -14.188918891889188, -14.183918391839184, -14.178917891789178, -14.173917391739174, -14.168916891689168, -14.163916391639164, -14.158915891589158, -14.153915391539153, -14.148914891489149, -14.143914391439143, -14.138913891389139, -14.133913391339133, -14.128912891289128, -14.123912391239124, -14.118911891189118, -14.113911391139114, -14.108910891089108, -14.103910391039104, -14.098909890989098, -14.093909390939093, -14.088908890889089, -14.083908390839083, -14.078907890789079, -14.073907390739073, -14.068906890689068, -14.063906390639064, -14.058905890589058, -14.053905390539054, -14.048904890489048, -14.043904390439044, -14.038903890389038, -14.033903390339033, -14.028902890289029, -14.023902390239023, -14.018901890189019, -14.013901390139013, -14.008900890089008, -14.003900390039004, -13.998899889988998, -13.993899389938994, -13.988898889888988, -13.983898389838984, -13.978897889788978, -13.973897389738973, -13.968896889688969, -13.963896389638963, -13.958895889588959, -13.953895389538953, -13.948894889488948, -13.943894389438944, -13.938893889388938, -13.933893389338934, -13.928892889288928, -13.923892389238924, -13.918891889188918, -13.913891389138913, -13.908890889088909, -13.903890389038903, -13.898889888988899, -13.893889388938893, -13.888888888888888, -13.883888388838884, -13.878887888788878, -13.873887388738874, -13.868886888688868, -13.863886388638864, -13.858885888588858, -13.853885388538853, -13.848884888488849, -13.843884388438843, -13.838883888388839, -13.833883388338833, -13.828882888288828, -13.823882388238824, -13.818881888188818, -13.813881388138814, -13.808880888088808, -13.803880388038804, -13.798879887988798, -13.793879387938793, -13.788878887888789, -13.783878387838783, -13.778877887788779, -13.773877387738773, -13.768876887688767, -13.763876387638764, -13.758875887588758, -13.753875387538754, -13.748874887488748, -13.743874387438744, -13.738873887388738, -13.733873387338733, -13.728872887288729, -13.723872387238723, -13.718871887188719, -13.713871387138713, -13.708870887088707, -13.703870387038704, -13.698869886988698, -13.693869386938694, -13.688868886888688, -13.683868386838684, -13.678867886788678, -13.673867386738673, -13.668866886688669, -13.663866386638663, -13.658865886588659, -13.653865386538653, -13.648864886488647, -13.643864386438644, -13.638863886388638, -13.633863386338634, -13.628862886288628, -13.623862386238624, -13.618861886188618, -13.613861386138613, -13.608860886088609, -13.603860386038603, -13.598859885988599, -13.593859385938593, -13.588858885888587, -13.583858385838584, -13.578857885788578, -13.573857385738574, -13.568856885688568, -13.563856385638564, -13.558855885588558, -13.553855385538553, -13.548854885488549, -13.543854385438543, -13.538853885388539, -13.533853385338533, -13.528852885288527, -13.523852385238524, -13.518851885188518, -13.513851385138514, -13.508850885088508, -13.503850385038504, -13.498849884988498, -13.493849384938493, -13.488848884888489, -13.483848384838483, -13.478847884788479, -13.473847384738473, -13.468846884688467, -13.463846384638464, -13.458845884588458, -13.453845384538454, -13.448844884488448, -13.443844384438444, -13.438843884388438, -13.433843384338433, -13.428842884288429, -13.423842384238423, -13.418841884188419, -13.413841384138413, -13.408840884088407, -13.403840384038403, -13.398839883988398, -13.393839383938394, -13.388838883888388, -13.383838383838384, -13.378837883788378, -13.373837383738373, -13.368836883688369, -13.363836383638363, -13.358835883588359, -13.353835383538353, -13.348834883488347, -13.343834383438343, -13.338833883388338, -13.333833383338334, -13.328832883288328, -13.323832383238324, -13.318831883188318, -13.313831383138313, -13.308830883088309, -13.303830383038303, -13.298829882988299, -13.293829382938293, -13.288828882888287, -13.283828382838283, -13.278827882788278, -13.273827382738274, -13.268826882688268, -13.263826382638264, -13.258825882588258, -13.253825382538253, -13.248824882488249, -13.243824382438243, -13.238823882388239, -13.233823382338233, -13.228822882288227, -13.223822382238223, -13.218821882188218, -13.213821382138214, -13.208820882088208, -13.203820382038204, -13.198819881988198, -13.193819381938193, -13.188818881888189, -13.183818381838183, -13.178817881788179, -13.173817381738173, -13.168816881688167, -13.163816381638163, -13.158815881588158, -13.153815381538154, -13.148814881488148, -13.143814381438144, -13.138813881388138, -13.133813381338133, -13.128812881288129, -13.123812381238123, -13.118811881188119, -13.113811381138113, -13.108810881088107, -13.103810381038103, -13.098809880988098, -13.093809380938094, -13.088808880888088, -13.083808380838084, -13.078807880788078, -13.073807380738073, -13.068806880688069, -13.063806380638063, -13.058805880588059, -13.053805380538053, -13.048804880488047, -13.043804380438043, -13.038803880388038, -13.033803380338034, -13.028802880288028, -13.023802380238024, -13.018801880188018, -13.013801380138013, -13.008800880088009, -13.003800380038003, -12.998799879987999, -12.993799379937993, -12.988798879887987, -12.983798379837983, -12.978797879787978, -12.973797379737974, -12.968796879687968, -12.963796379637964, -12.958795879587958, -12.953795379537953, -12.948794879487949, -12.943794379437943, -12.938793879387939, -12.933793379337933, -12.928792879287927, -12.923792379237923, -12.918791879187918, -12.913791379137914, -12.908790879087908, -12.903790379037904, -12.898789878987898, -12.893789378937893, -12.888788878887889, -12.883788378837883, -12.878787878787879, -12.873787378737873, -12.868786878687867, -12.863786378637863, -12.858785878587858, -12.853785378537854, -12.848784878487848, -12.843784378437844, -12.838783878387838, -12.833783378337833, -12.828782878287829, -12.823782378237823, -12.818781878187819, -12.813781378137813, -12.808780878087807, -12.803780378037803, -12.798779877987798, -12.793779377937794, -12.788778877887788, -12.783778377837784, -12.778777877787778, -12.773777377737773, -12.768776877687769, -12.763776377637763, -12.758775877587759, -12.753775377537753, -12.748774877487747, -12.743774377437743, -12.738773877387738, -12.733773377337734, -12.728772877287728, -12.723772377237724, -12.718771877187718, -12.713771377137713, -12.708770877087709, -12.703770377037703, -12.698769876987699, -12.693769376937693, -12.688768876887687, -12.683768376837683, -12.678767876787678, -12.673767376737674, -12.668766876687668, -12.663766376637664, -12.658765876587658, -12.653765376537653, -12.648764876487649, -12.643764376437643, -12.638763876387639, -12.633763376337633, -12.628762876287627, -12.623762376237623, -12.618761876187618, -12.613761376137614, -12.608760876087608, -12.603760376037604, -12.598759875987598, -12.593759375937593, -12.588758875887589, -12.583758375837583, -12.578757875787579, -12.573757375737573, -12.568756875687567, -12.563756375637563, -12.558755875587558, -12.553755375537554, -12.548754875487548, -12.543754375437544, -12.538753875387538, -12.533753375337533, -12.528752875287529, -12.523752375237523, -12.518751875187519, -12.513751375137513, -12.508750875087507, -12.503750375037503, -12.498749874987498, -12.493749374937494, -12.488748874887488, -12.483748374837484, -12.478747874787478, -12.473747374737473, -12.468746874687469, -12.463746374637463, -12.458745874587459, -12.453745374537453, -12.448744874487447, -12.443744374437443, -12.438743874387438, -12.433743374337434, -12.428742874287428, -12.423742374237424, -12.418741874187418, -12.413741374137413, -12.408740874087409, -12.403740374037403, -12.398739873987399, -12.393739373937393, -12.388738873887387, -12.383738373837383, -12.378737873787378, -12.373737373737374, -12.368736873687368, -12.363736373637364, -12.358735873587358, -12.353735373537353, -12.348734873487349, -12.343734373437343, -12.338733873387339, -12.333733373337333, -12.328732873287327, -12.323732373237323, -12.318731873187318, -12.313731373137314, -12.308730873087308, -12.303730373037304, -12.298729872987298, -12.293729372937293, -12.288728872887289, -12.283728372837283, -12.278727872787279, -12.273727372737273, -12.268726872687267, -12.263726372637263, -12.258725872587258, -12.253725372537254, -12.248724872487248, -12.243724372437244, -12.238723872387238, -12.233723372337233, -12.228722872287229, -12.223722372237223, -12.218721872187219, -12.213721372137213, -12.208720872087207, -12.203720372037203, -12.198719871987198, -12.193719371937194, -12.188718871887188, -12.183718371837182, -12.178717871787178, -12.173717371737172, -12.168716871687169, -12.163716371637163, -12.158715871587159, -12.153715371537153, -12.148714871487147, -12.143714371437143, -12.138713871387138, -12.133713371337134, -12.128712871287128, -12.123712371237122, -12.118711871187118, -12.113711371137112, -12.108710871087109, -12.103710371037103, -12.098709870987099, -12.093709370937093, -12.088708870887087, -12.083708370837083, -12.078707870787078, -12.073707370737074, -12.068706870687068, -12.063706370637062, -12.058705870587058, -12.053705370537052, -12.048704870487049, -12.043704370437043, -12.038703870387039, -12.033703370337033, -12.028702870287027, -12.023702370237023, -12.018701870187018, -12.013701370137014, -12.008700870087008, -12.003700370037002, -11.998699869986998, -11.993699369936992, -11.988698869886989, -11.983698369836983, -11.978697869786979, -11.973697369736973, -11.968696869686967, -11.963696369636963, -11.958695869586958, -11.953695369536954, -11.948694869486948, -11.943694369436942, -11.938693869386938, -11.933693369336932, -11.928692869286929, -11.923692369236923, -11.918691869186919, -11.913691369136913, -11.908690869086907, -11.903690369036903, -11.898689868986898, -11.893689368936894, -11.888688868886888, -11.883688368836882, -11.878687868786878, -11.873687368736872, -11.868686868686869, -11.863686368636863, -11.858685868586859, -11.853685368536853, -11.848684868486847, -11.843684368436843, -11.838683868386838, -11.833683368336834, -11.828682868286828, -11.823682368236822, -11.818681868186818, -11.813681368136812, -11.808680868086809, -11.803680368036803, -11.798679867986799, -11.793679367936793, -11.788678867886787, -11.783678367836783, -11.778677867786778, -11.773677367736774, -11.768676867686768, -11.763676367636762, -11.758675867586758, -11.753675367536752, -11.748674867486748, -11.743674367436743, -11.738673867386739, -11.733673367336733, -11.728672867286727, -11.723672367236723, -11.718671867186718, -11.713671367136714, -11.708670867086708, -11.703670367036702, -11.698669866986698, -11.693669366936692, -11.688668866886688, -11.683668366836683, -11.678667866786679, -11.673667366736673, -11.668666866686667, -11.663666366636663, -11.658665866586658, -11.653665366536654, -11.648664866486648, -11.643664366436642, -11.638663866386638, -11.633663366336632, -11.628662866286628, -11.623662366236623, -11.618661866186619, -11.613661366136613, -11.608660866086607, -11.603660366036603, -11.598659865986598, -11.593659365936594, -11.588658865886588, -11.583658365836582, -11.578657865786578, -11.573657365736572, -11.568656865686568, -11.563656365636563, -11.558655865586559, -11.553655365536553, -11.548654865486547, -11.543654365436543, -11.538653865386538, -11.533653365336534, -11.528652865286528, -11.523652365236522, -11.518651865186518, -11.513651365136512, -11.508650865086508, -11.503650365036503, -11.498649864986499, -11.493649364936493, -11.488648864886487, -11.483648364836483, -11.478647864786478, -11.473647364736474, -11.468646864686468, -11.463646364636462, -11.458645864586458, -11.453645364536452, -11.448644864486448, -11.443644364436443, -11.438643864386439, -11.433643364336433, -11.428642864286427, -11.423642364236423, -11.418641864186418, -11.413641364136414, -11.408640864086408, -11.403640364036402, -11.398639863986398, -11.393639363936392, -11.388638863886388, -11.383638363836383, -11.378637863786379, -11.373637363736373, -11.368636863686367, -11.363636363636363, -11.358635863586358, -11.353635363536354, -11.348634863486348, -11.343634363436342, -11.338633863386338, -11.333633363336332, -11.328632863286328, -11.323632363236323, -11.318631863186319, -11.313631363136313, -11.308630863086307, -11.303630363036303, -11.298629862986298, -11.293629362936294, -11.288628862886288, -11.283628362836282, -11.278627862786278, -11.273627362736272, -11.268626862686268, -11.263626362636263, -11.258625862586259, -11.253625362536253, -11.248624862486247, -11.243624362436243, -11.238623862386238, -11.233623362336234, -11.228622862286228, -11.223622362236222, -11.218621862186218, -11.213621362136212, -11.208620862086208, -11.203620362036203, -11.198619861986199, -11.193619361936193, -11.188618861886187, -11.183618361836183, -11.178617861786178, -11.173617361736174, -11.168616861686168, -11.163616361636162, -11.158615861586158, -11.153615361536152, -11.148614861486148, -11.143614361436143, -11.138613861386139, -11.133613361336133, -11.128612861286127, -11.123612361236123, -11.118611861186118, -11.113611361136114, -11.108610861086108, -11.103610361036102, -11.098609860986098, -11.093609360936092, -11.088608860886088, -11.083608360836083, -11.078607860786079, -11.073607360736073, -11.068606860686067, -11.063606360636063, -11.058605860586058, -11.053605360536054, -11.048604860486048, -11.043604360436042, -11.038603860386038, -11.033603360336032, -11.028602860286028, -11.023602360236023, -11.018601860186019, -11.013601360136013, -11.008600860086007, -11.003600360036003, -10.998599859985998, -10.993599359935994, -10.988598859885988, -10.983598359835982, -10.978597859785978, -10.973597359735972, -10.968596859685968, -10.963596359635963, -10.958595859585959, -10.953595359535953, -10.948594859485947, -10.943594359435943, -10.938593859385938, -10.933593359335934, -10.928592859285928, -10.923592359235922, -10.918591859185918, -10.913591359135912, -10.908590859085908, -10.903590359035903, -10.898589858985899, -10.893589358935893, -10.888588858885887, -10.883588358835883, -10.878587858785878, -10.873587358735874, -10.868586858685868, -10.863586358635862, -10.858585858585858, -10.853585358535852, -10.848584858485848, -10.843584358435843, -10.838583858385839, -10.833583358335833, -10.828582858285827, -10.823582358235823, -10.818581858185818, -10.813581358135814, -10.808580858085808, -10.803580358035802, -10.798579857985798, -10.793579357935792, -10.788578857885788, -10.783578357835783, -10.778577857785779, -10.773577357735773, -10.768576857685767, -10.763576357635763, -10.758575857585758, -10.753575357535754, -10.748574857485748, -10.743574357435742, -10.738573857385738, -10.733573357335732, -10.728572857285728, -10.723572357235723, -10.718571857185719, -10.713571357135713, -10.708570857085707, -10.703570357035703, -10.698569856985698, -10.693569356935694, -10.688568856885688, -10.683568356835682, -10.678567856785678, -10.673567356735672, -10.668566856685668, -10.663566356635663, -10.658565856585659, -10.653565356535653, -10.648564856485647, -10.643564356435643, -10.638563856385638, -10.633563356335634, -10.628562856285628, -10.623562356235622, -10.618561856185618, -10.613561356135612, -10.608560856085608, -10.603560356035603, -10.598559855985599, -10.593559355935593, -10.588558855885587, -10.583558355835583, -10.578557855785578, -10.573557355735574, -10.568556855685568, -10.563556355635562, -10.558555855585558, -10.553555355535552, -10.548554855485548, -10.543554355435543, -10.538553855385539, -10.533553355335533, -10.528552855285527, -10.523552355235523, -10.518551855185517, -10.513551355135514, -10.508550855085508, -10.503550355035502, -10.498549854985498, -10.493549354935492, -10.488548854885488, -10.483548354835483, -10.478547854785479, -10.473547354735473, -10.468546854685467, -10.463546354635463, -10.458545854585457, -10.453545354535454, -10.448544854485448, -10.443544354435442, -10.438543854385438, -10.433543354335432, -10.428542854285428, -10.423542354235423, -10.418541854185419, -10.413541354135413, -10.408540854085407, -10.403540354035403, -10.398539853985397, -10.393539353935394, -10.388538853885388, -10.383538353835382, -10.378537853785378, -10.373537353735372, -10.368536853685368, -10.363536353635363, -10.358535853585359, -10.353535353535353, -10.348534853485347, -10.343534353435343, -10.338533853385337, -10.333533353335334, -10.328532853285328, -10.323532353235322, -10.318531853185318, -10.313531353135312, -10.308530853085308, -10.303530353035303, -10.298529852985299, -10.293529352935293, -10.288528852885287, -10.283528352835283, -10.278527852785277, -10.273527352735274, -10.268526852685268, -10.263526352635262, -10.258525852585258, -10.253525352535252, -10.248524852485248, -10.243524352435243, -10.238523852385239, -10.233523352335233, -10.228522852285227, -10.223522352235223, -10.218521852185217, -10.213521352135214, -10.208520852085208, -10.203520352035202, -10.198519851985198, -10.193519351935192, -10.188518851885188, -10.183518351835183, -10.178517851785179, -10.173517351735173, -10.168516851685167, -10.163516351635163, -10.158515851585157, -10.153515351535153, -10.148514851485148, -10.143514351435142, -10.138513851385138, -10.133513351335132, -10.128512851285128, -10.123512351235123, -10.118511851185119, -10.113511351135113, -10.108510851085107, -10.103510351035103, -10.098509850985097, -10.093509350935093, -10.088508850885088, -10.083508350835082, -10.078507850785078, -10.073507350735072, -10.068506850685068, -10.063506350635063, -10.058505850585059, -10.053505350535053, -10.048504850485047, -10.043504350435043, -10.038503850385037, -10.033503350335033, -10.028502850285028, -10.023502350235022, -10.018501850185018, -10.013501350135012, -10.008500850085008, -10.003500350035003, -9.998499849984999, -9.993499349934993, -9.988498849884987, -9.983498349834983, -9.978497849784977, -9.973497349734973, -9.968496849684968, -9.963496349634962, -9.958495849584958, -9.953495349534952, -9.948494849484948, -9.943494349434943, -9.938493849384939, -9.933493349334933, -9.928492849284927, -9.923492349234923, -9.918491849184917, -9.913491349134913, -9.908490849084908, -9.903490349034902, -9.898489848984898, -9.893489348934892, -9.888488848884888, -9.883488348834883, -9.878487848784879, -9.873487348734873, -9.868486848684867, -9.863486348634863, -9.858485848584857, -9.853485348534853, -9.848484848484848, -9.843484348434842, -9.838483848384838, -9.833483348334832, -9.828482848284828, -9.823482348234823, -9.818481848184819, -9.813481348134813, -9.808480848084807, -9.803480348034803, -9.798479847984797, -9.793479347934793, -9.788478847884788, -9.783478347834782, -9.778477847784778, -9.773477347734772, -9.768476847684768, -9.763476347634763, -9.758475847584759, -9.753475347534753, -9.748474847484747, -9.743474347434743, -9.738473847384737, -9.733473347334733, -9.728472847284728, -9.723472347234722, -9.718471847184718, -9.713471347134712, -9.708470847084708, -9.703470347034703, -9.698469846984699, -9.693469346934693, -9.688468846884687, -9.683468346834683, -9.678467846784677, -9.673467346734673, -9.668466846684668, -9.663466346634662, -9.658465846584658, -9.653465346534652, -9.648464846484648, -9.643464346434643, -9.638463846384639, -9.633463346334633, -9.628462846284627, -9.623462346234623, -9.618461846184617, -9.613461346134613, -9.608460846084608, -9.603460346034602, -9.598459845984598, -9.593459345934592, -9.588458845884588, -9.583458345834583, -9.578457845784577, -9.573457345734573, -9.568456845684567, -9.563456345634563, -9.558455845584557, -9.553455345534553, -9.548454845484548, -9.543454345434542, -9.538453845384538, -9.533453345334532, -9.528452845284528, -9.523452345234523, -9.518451845184517, -9.513451345134513, -9.508450845084507, -9.503450345034503, -9.498449844984497, -9.493449344934493, -9.488448844884488, -9.483448344834482, -9.478447844784478, -9.473447344734472, -9.468446844684468, -9.463446344634463, -9.458445844584457, -9.453445344534453, -9.448444844484447, -9.443444344434443, -9.438443844384437, -9.433443344334433, -9.428442844284428, -9.423442344234422, -9.418441844184418, -9.413441344134412, -9.408440844084408, -9.403440344034403, -9.398439843984397, -9.393439343934393, -9.388438843884387, -9.383438343834383, -9.378437843784377, -9.373437343734373, -9.368436843684368, -9.363436343634362, -9.358435843584358, -9.353435343534352, -9.348434843484348, -9.343434343434343, -9.338433843384337, -9.333433343334333, -9.328432843284327, -9.323432343234323, -9.318431843184317, -9.313431343134313, -9.308430843084308, -9.303430343034302, -9.298429842984298, -9.293429342934292, -9.288428842884288, -9.283428342834283, -9.278427842784277, -9.273427342734273, -9.268426842684267, -9.263426342634263, -9.258425842584257, -9.253425342534253, -9.248424842484248, -9.243424342434242, -9.238423842384238, -9.233423342334232, -9.228422842284228, -9.223422342234223, -9.218421842184217, -9.213421342134213, -9.208420842084207, -9.203420342034203, -9.198419841984197, -9.193419341934193, -9.188418841884188, -9.183418341834182, -9.178417841784178, -9.173417341734172, -9.168416841684168, -9.163416341634163, -9.158415841584157, -9.153415341534153, -9.148414841484147, -9.143414341434143, -9.138413841384137, -9.133413341334133, -9.128412841284128, -9.123412341234122, -9.118411841184118, -9.113411341134112, -9.108410841084108, -9.103410341034103, -9.098409840984097, -9.093409340934093, -9.088408840884087, -9.083408340834083, -9.078407840784077, -9.073407340734073, -9.068406840684068, -9.063406340634062, -9.058405840584058, -9.053405340534052, -9.048404840484048, -9.043404340434043, -9.038403840384037, -9.033403340334033, -9.028402840284027, -9.023402340234023, -9.018401840184017, -9.013401340134013, -9.008400840084008, -9.003400340034002, -8.998399839983996, -8.993399339933994, -8.988398839883988, -8.983398339833983, -8.978397839783977, -8.973397339733971, -8.968396839683969, -8.963396339633963, -8.958395839583957, -8.953395339533952, -8.948394839483946, -8.943394339433944, -8.938393839383938, -8.933393339333932, -8.928392839283926, -8.923392339233924, -8.918391839183919, -8.913391339133913, -8.908390839083907, -8.903390339033901, -8.8983898389839, -8.893389338933893, -8.888388838883888, -8.883388338833882, -8.878387838783876, -8.873387338733874, -8.868386838683868, -8.863386338633862, -8.858385838583857, -8.853385338533851, -8.848384838483849, -8.843384338433843, -8.838383838383837, -8.833383338333832, -8.828382838283826, -8.823382338233824, -8.818381838183818, -8.813381338133812, -8.808380838083806, -8.803380338033804, -8.798379837983799, -8.793379337933793, -8.788378837883787, -8.783378337833781, -8.77837783778378, -8.773377337733773, -8.768376837683768, -8.763376337633762, -8.758375837583756, -8.753375337533754, -8.748374837483748, -8.743374337433742, -8.738373837383737, -8.733373337333731, -8.728372837283729, -8.723372337233723, -8.718371837183717, -8.713371337133712, -8.708370837083706, -8.703370337033704, -8.698369836983698, -8.693369336933692, -8.688368836883686, -8.683368336833684, -8.678367836783679, -8.673367336733673, -8.668366836683667, -8.663366336633661, -8.658365836583659, -8.653365336533653, -8.648364836483648, -8.643364336433642, -8.638363836383636, -8.633363336333634, -8.628362836283628, -8.623362336233622, -8.618361836183617, -8.613361336133611, -8.608360836083609, -8.603360336033603, -8.598359835983597, -8.593359335933592, -8.588358835883586, -8.583358335833584, -8.578357835783578, -8.573357335733572, -8.568356835683566, -8.563356335633564, -8.558355835583559, -8.553355335533553, -8.548354835483547, -8.543354335433541, -8.538353835383539, -8.533353335333533, -8.528352835283528, -8.523352335233522, -8.518351835183516, -8.513351335133514, -8.508350835083508, -8.503350335033502, -8.498349834983497, -8.493349334933491, -8.488348834883489, -8.483348334833483, -8.478347834783477, -8.473347334733472, -8.468346834683466, -8.463346334633464, -8.458345834583458, -8.453345334533452, -8.448344834483446, -8.443344334433444, -8.438343834383438, -8.433343334333433, -8.428342834283427, -8.423342334233421, -8.418341834183419, -8.413341334133413, -8.408340834083408, -8.403340334033402, -8.398339833983396, -8.393339333933394, -8.388338833883388, -8.383338333833382, -8.378337833783377, -8.373337333733371, -8.368336833683369, -8.363336333633363, -8.358335833583357, -8.353335333533352, -8.348334833483346, -8.343334333433344, -8.338333833383338, -8.333333333333332, -8.328332833283326, -8.323332333233324, -8.318331833183318, -8.313331333133313, -8.308330833083307, -8.303330333033301, -8.298329832983299, -8.293329332933293, -8.288328832883288, -8.283328332833282, -8.278327832783276, -8.273327332733274, -8.268326832683268, -8.263326332633262, -8.258325832583257, -8.253325332533251, -8.248324832483249, -8.243324332433243, -8.238323832383237, -8.233323332333232, -8.228322832283226, -8.223322332233224, -8.218321832183218, -8.213321332133212, -8.208320832083206, -8.203320332033204, -8.198319831983198, -8.193319331933193, -8.188318831883187, -8.183318331833181, -8.178317831783179, -8.173317331733173, -8.168316831683168, -8.163316331633162, -8.158315831583156, -8.153315331533154, -8.148314831483148, -8.143314331433142, -8.138313831383137, -8.133313331333131, -8.128312831283129, -8.123312331233123, -8.118311831183117, -8.113311331133112, -8.108310831083106, -8.103310331033104, -8.098309830983098, -8.093309330933092, -8.088308830883086, -8.083308330833084, -8.078307830783078, -8.073307330733073, -8.068306830683067, -8.063306330633061, -8.058305830583059, -8.053305330533053, -8.048304830483048, -8.043304330433042, -8.038303830383036, -8.033303330333034, -8.028302830283028, -8.023302330233022, -8.018301830183017, -8.013301330133011, -8.008300830083009, -8.003300330033003, -7.998299829982997, -7.9932993299329915, -7.988298829882986, -7.983298329832984, -7.978297829782978, -7.973297329732972, -7.968296829682966, -7.963296329632964, -7.9582958295829584, -7.953295329532953, -7.948294829482947, -7.943294329432941, -7.938293829382939, -7.933293329332933, -7.928292829282928, -7.923292329232922, -7.918291829182916, -7.913291329132914, -7.908290829082908, -7.903290329032902, -7.898289828982897, -7.893289328932891, -7.888288828882889, -7.883288328832883, -7.878287828782877, -7.8732873287328715, -7.868286828682866, -7.863286328632864, -7.858285828582858, -7.853285328532852, -7.848284828482846, -7.843284328432844, -7.838283828382838, -7.833283328332833, -7.828282828282827, -7.823282328232821, -7.818281828182819, -7.813281328132813, -7.8082808280828075, -7.803280328032802, -7.798279827982796, -7.793279327932794, -7.788278827882788, -7.783278327832782, -7.778277827782777, -7.773277327732771, -7.768276827682769, -7.763276327632763, -7.758275827582757, -7.7532753275327515, -7.748274827482746, -7.743274327432744, -7.738273827382738, -7.733273327332732, -7.728272827282726, -7.723272327232724, -7.718271827182718, -7.713271327132713, -7.708270827082707, -7.703270327032701, -7.698269826982699, -7.693269326932693, -7.6882688268826875, -7.683268326832682, -7.678267826782676, -7.673267326732674, -7.668266826682668, -7.663266326632662, -7.658265826582657, -7.653265326532651, -7.648264826482649, -7.643264326432643, -7.638263826382637, -7.6332633263326315, -7.628262826282626, -7.623262326232624, -7.618261826182618, -7.613261326132612, -7.608260826082606, -7.603260326032604, -7.598259825982598, -7.593259325932593, -7.588258825882587, -7.583258325832581, -7.578257825782579, -7.573257325732573, -7.5682568256825675, -7.563256325632562, -7.558255825582556, -7.553255325532554, -7.548254825482548, -7.543254325432542, -7.538253825382537, -7.533253325332531, -7.528252825282529, -7.523252325232523, -7.518251825182517, -7.5132513251325115, -7.508250825082506, -7.5032503250325036, -7.498249824982498, -7.493249324932492, -7.488248824882486, -7.483248324832484, -7.478247824782478, -7.473247324732473, -7.468246824682467, -7.463246324632461, -7.458245824582459, -7.453245324532453, -7.4482448244824475, -7.443244324432442, -7.438243824382436, -7.433243324332434, -7.428242824282428, -7.423242324232422, -7.418241824182417, -7.413241324132411, -7.408240824082409, -7.403240324032403, -7.398239823982397, -7.3932393239323915, -7.388238823882386, -7.3832383238323835, -7.378237823782378, -7.373237323732372, -7.368236823682366, -7.363236323632364, -7.358235823582358, -7.353235323532353, -7.348234823482347, -7.343234323432341, -7.338233823382339, -7.333233323332333, -7.3282328232823275, -7.323232323232322, -7.318231823182316, -7.313231323132314, -7.308230823082308, -7.303230323032302, -7.298229822982297, -7.293229322932291, -7.288228822882289, -7.283228322832283, -7.278227822782277, -7.2732273227322715, -7.268226822682266, -7.2632263226322635, -7.258225822582258, -7.253225322532252, -7.248224822482246, -7.243224322432244, -7.238223822382238, -7.233223322332233, -7.228222822282227, -7.223222322232221, -7.218221822182219, -7.213221322132213, -7.2082208220822075, -7.203220322032202, -7.198219821982196, -7.193219321932194, -7.188218821882188, -7.183218321832182, -7.178217821782177, -7.173217321732171, -7.168216821682169, -7.163216321632163, -7.158215821582157, -7.1532153215321514, -7.148214821482146, -7.1432143214321435, -7.138213821382138, -7.133213321332132, -7.128212821282126, -7.123212321232124, -7.118211821182118, -7.113211321132113, -7.108210821082107, -7.103210321032101, -7.098209820982099, -7.093209320932093, -7.0882088208820875, -7.083208320832082, -7.078207820782076, -7.073207320732074, -7.068206820682068, -7.063206320632062, -7.058205820582057, -7.053205320532051, -7.048204820482049, -7.043204320432043, -7.038203820382037, -7.033203320332031, -7.028202820282026, -7.0232023202320235, -7.018201820182018, -7.013201320132012, -7.008200820082006, -7.0032003200320005, -6.998199819981998, -6.993199319931993, -6.988198819881987, -6.983198319831981, -6.978197819781979, -6.973197319731973, -6.9681968196819675, -6.963196319631962, -6.958195819581956, -6.953195319531954, -6.948194819481948, -6.943194319431942, -6.938193819381937, -6.933193319331931, -6.928192819281929, -6.923192319231923, -6.918191819181917, -6.913191319131911, -6.908190819081906, -6.9031903190319035, -6.898189818981898, -6.893189318931892, -6.888188818881886, -6.8831883188318805, -6.878187818781878, -6.873187318731873, -6.868186818681867, -6.863186318631861, -6.858185818581859, -6.853185318531853, -6.8481848184818475, -6.843184318431842, -6.838183818381836, -6.833183318331834, -6.828182818281828, -6.823182318231822, -6.818181818181817, -6.813181318131811, -6.808180818081809, -6.803180318031803, -6.798179817981797, -6.793179317931791, -6.788178817881786, -6.7831783178317835, -6.778177817781778, -6.773177317731772, -6.768176817681766, -6.7631763176317605, -6.758175817581758, -6.753175317531753, -6.748174817481747, -6.743174317431741, -6.738173817381739, -6.733173317331733, -6.7281728172817274, -6.723172317231722, -6.718171817181716, -6.713171317131714, -6.708170817081708, -6.703170317031702, -6.698169816981697, -6.693169316931691, -6.688168816881689, -6.683168316831683, -6.678167816781677, -6.673167316731671, -6.668166816681666, -6.6631663166316635, -6.658165816581658, -6.653165316531652, -6.648164816481646, -6.6431643164316405, -6.638163816381638, -6.633163316331633, -6.628162816281627, -6.623162316231621, -6.618161816181619, -6.613161316131613, -6.608160816081607, -6.603160316031602, -6.598159815981596, -6.593159315931594, -6.588158815881588, -6.583158315831582, -6.5781578157815765, -6.573157315731571, -6.568156815681569, -6.563156315631563, -6.558155815581557, -6.553155315531551, -6.548154815481546, -6.5431543154315435, -6.538153815381538, -6.533153315331532, -6.528152815281526, -6.5231523152315205, -6.518151815181518, -6.513151315131513, -6.508150815081507, -6.503150315031501, -6.498149814981499, -6.493149314931493, -6.488148814881487, -6.483148314831482, -6.478147814781476, -6.473147314731474, -6.468146814681468, -6.463146314631462, -6.4581458145814565, -6.453145314531451, -6.448144814481449, -6.443144314431443, -6.438143814381437, -6.433143314331431, -6.428142814281426, -6.4231423142314235, -6.418141814181418, -6.413141314131412, -6.408140814081406, -6.4031403140314005, -6.398139813981398, -6.393139313931393, -6.388138813881387, -6.383138313831381, -6.378137813781379, -6.373137313731373, -6.368136813681367, -6.363136313631362, -6.358135813581356, -6.353135313531354, -6.348134813481348, -6.343134313431342, -6.3381338133813365, -6.333133313331331, -6.328132813281329, -6.323132313231323, -6.318131813181317, -6.313131313131311, -6.308130813081306, -6.3031303130313034, -6.298129812981298, -6.293129312931292, -6.288128812881286, -6.2831283128312805, -6.278127812781278, -6.2731273127312726, -6.268126812681267, -6.263126312631261, -6.258125812581259, -6.253125312531253, -6.248124812481247, -6.243124312431242, -6.238123812381236, -6.233123312331234, -6.228122812281228, -6.223122312231222, -6.2181218121812165, -6.213121312131211, -6.208120812081209, -6.203120312031203, -6.198119811981197, -6.193119311931191, -6.188118811881186, -6.183118311831183, -6.178117811781178, -6.173117311731172, -6.168116811681166, -6.1631163116311605, -6.158115811581158, -6.1531153115311525, -6.148114811481147, -6.143114311431141, -6.138113811381139, -6.133113311331133, -6.128112811281127, -6.123112311231122, -6.118111811181116, -6.113111311131114, -6.108110811081108, -6.103110311031102, -6.0981098109810965, -6.093109310931091, -6.088108810881089, -6.083108310831083, -6.078107810781077, -6.073107310731071, -6.068106810681066, -6.063106310631063, -6.058105810581058, -6.053105310531052, -6.048104810481046, -6.0431043104310405, -6.038103810381038, -6.0331033103310325, -6.028102810281027, -6.023102310231021, -6.018101810181019, -6.013101310131013, -6.008100810081007, -6.003100310031002, -5.998099809980996, -5.993099309930994, -5.988098809880988, -5.983098309830982, -5.9780978097809765, -5.973097309730971, -5.968096809680969, -5.963096309630963, -5.958095809580957, -5.953095309530951, -5.948094809480946, -5.943094309430943, -5.938093809380938, -5.933093309330932, -5.928092809280926, -5.9230923092309204, -5.918091809180918, -5.9130913091309125, -5.908090809080907, -5.903090309030901, -5.898089808980899, -5.893089308930893, -5.888088808880887, -5.883088308830882, -5.878087808780876, -5.873087308730874, -5.868086808680868, -5.863086308630862, -5.8580858085808565, -5.853085308530851, -5.8480848084808486, -5.843084308430843, -5.838083808380837, -5.833083308330831, -5.828082808280826, -5.823082308230823, -5.818081808180818, -5.813081308130812, -5.808080808080806, -5.8030803080308, -5.798079807980798, -5.7930793079307925, -5.788078807880787, -5.783078307830781, -5.778077807780779, -5.773077307730773, -5.768076807680767, -5.763076307630762, -5.758075807580756, -5.753075307530754, -5.748074807480748, -5.743074307430742, -5.7380738073807365, -5.733073307330731, -5.7280728072807285, -5.723072307230723, -5.718071807180717, -5.713071307130711, -5.708070807080706, -5.703070307030703, -5.698069806980698, -5.693069306930692, -5.688068806880686, -5.68306830683068, -5.678067806780678, -5.6730673067306725, -5.668066806680667, -5.663066306630661, -5.658065806580659, -5.653065306530653, -5.648064806480647, -5.643064306430642, -5.638063806380636, -5.633063306330634, -5.628062806280628, -5.623062306230622, -5.6180618061806165, -5.613061306130611, -5.6080608060806085, -5.603060306030603, -5.598059805980597, -5.593059305930591, -5.588058805880586, -5.583058305830583, -5.578057805780578, -5.573057305730572, -5.568056805680566, -5.56305630563056, -5.558055805580558, -5.5530553055305525, -5.548054805480547, -5.543054305430541, -5.538053805380539, -5.533053305330533, -5.528052805280527, -5.523052305230522, -5.518051805180516, -5.513051305130514, -5.508050805080508, -5.503050305030502, -5.4980498049804964, -5.493049304930491, -5.4880488048804885, -5.483048304830483, -5.478047804780477, -5.473047304730471, -5.4680468046804656, -5.463046304630463, -5.458045804580458, -5.453045304530452, -5.448044804480446, -5.44304430443044, -5.438043804380438, -5.4330433043304325, -5.428042804280427, -5.423042304230421, -5.418041804180419, -5.413041304130413, -5.408040804080407, -5.403040304030402, -5.398039803980396, -5.393039303930394, -5.388038803880388, -5.383038303830382, -5.378037803780376, -5.373037303730371, -5.3680368036803685, -5.363036303630363, -5.358035803580357, -5.353035303530351, -5.3480348034803455, -5.343034303430343, -5.338033803380338, -5.333033303330332, -5.328032803280326, -5.32303230323032, -5.318031803180318, -5.3130313031303125, -5.308030803080307, -5.303030303030301, -5.298029802980299, -5.293029302930293, -5.288028802880287, -5.283028302830282, -5.278027802780276, -5.273027302730274, -5.268026802680268, -5.263026302630262, -5.258025802580256, -5.253025302530251, -5.2480248024802485, -5.243024302430243, -5.238023802380237, -5.233023302330231, -5.2280228022802255, -5.223022302230223, -5.218021802180218, -5.213021302130212, -5.208020802080206, -5.2030203020302, -5.198019801980198, -5.1930193019301925, -5.188018801880187, -5.183018301830181, -5.178017801780179, -5.173017301730173, -5.168016801680167, -5.163016301630162, -5.158015801580156, -5.153015301530154, -5.148014801480148, -5.143014301430142, -5.138013801380136, -5.133013301330131, -5.1280128012801285, -5.123012301230123, -5.118011801180117, -5.113011301130111, -5.1080108010801055, -5.103010301030103, -5.098009800980098, -5.093009300930092, -5.088008800880086, -5.08300830083008, -5.078007800780078, -5.0730073007300724, -5.068006800680067, -5.063006300630061, -5.058005800580059, -5.053005300530053, -5.048004800480047, -5.0430043004300416, -5.038003800380036, -5.033003300330034, -5.028002800280028, -5.023002300230022, -5.018001800180016, -5.013001300130011, -5.0080008000800085, -5.003000300030003, -4.997999799979997, -4.992999299929991, -4.9879987998799855, -4.982998299829983, -4.977997799779978, -4.972997299729972, -4.967996799679966, -4.96299629962996, -4.957995799579958, -4.952995299529952, -4.947994799479947, -4.942994299429941, -4.937993799379939, -4.932993299329933, -4.927992799279927, -4.9229922992299215, -4.917991799179916, -4.912991299129914, -4.907990799079908, -4.902990299029902, -4.897989798979896, -4.892989298929891, -4.8879887988798885, -4.882988298829883, -4.877987798779877, -4.872987298729871, -4.8679867986798655, -4.862986298629863, -4.857985798579858, -4.852985298529852, -4.847984798479846, -4.84298429842984, -4.837983798379838, -4.832983298329832, -4.827982798279827, -4.822982298229821, -4.817981798179819, -4.812981298129813, -4.807980798079807, -4.8029802980298015, -4.797979797979796, -4.792979297929794, -4.787978797879788, -4.782978297829782, -4.777977797779776, -4.772977297729771, -4.7679767976797685, -4.762976297629763, -4.757975797579757, -4.752975297529751, -4.7479747974797455, -4.742974297429743, -4.737973797379738, -4.732973297329732, -4.727972797279726, -4.72297229722972, -4.717971797179718, -4.712971297129712, -4.707970797079707, -4.702970297029701, -4.697969796979699, -4.692969296929693, -4.687968796879687, -4.6829682968296815, -4.677967796779676, -4.672967296729674, -4.667966796679668, -4.662966296629662, -4.657965796579656, -4.652965296529651, -4.647964796479648, -4.642964296429643, -4.637963796379637, -4.632963296329631, -4.6279627962796255, -4.622962296229623, -4.6179617961796176, -4.612961296129612, -4.607960796079606, -4.6029602960296, -4.597959795979598, -4.592959295929592, -4.587958795879587, -4.582958295829581, -4.577957795779579, -4.572957295729573, -4.567956795679567, -4.5629562956295615, -4.557955795579556, -4.552955295529554, -4.547954795479548, -4.542954295429542, -4.537953795379536, -4.532953295329531, -4.527952795279528, -4.522952295229523, -4.517951795179517, -4.512951295129511, -4.5079507950795055, -4.502950295029503, -4.4979497949794975, -4.492949294929492, -4.487948794879486, -4.48294829482948, -4.477947794779478, -4.472947294729472, -4.467946794679467, -4.462946294629461, -4.457945794579455, -4.452945294529453, -4.447944794479447, -4.4429442944294415, -4.437943794379436, -4.432943294329434, -4.427942794279428, -4.422942294229422, -4.417941794179416, -4.412941294129411, -4.407940794079408, -4.402940294029403, -4.397939793979397, -4.392939293929391, -4.3879387938793855, -4.382938293829383, -4.3779377937793775, -4.372937293729372, -4.367936793679366, -4.36293629362936, -4.357935793579358, -4.352935293529352, -4.347934793479347, -4.342934293429341, -4.337933793379335, -4.332933293329333, -4.327932793279327, -4.3229322932293215, -4.317931793179316, -4.312931293129314, -4.307930793079308, -4.302930293029302, -4.297929792979296, -4.292929292929291, -4.287928792879288, -4.282928292829283, -4.277927792779277, -4.272927292729271, -4.2679267926792654, -4.262926292629263, -4.2579257925792575, -4.252925292529252, -4.247924792479246, -4.24292429242924, -4.237923792379238, -4.232923292329232, -4.227922792279227, -4.222922292229221, -4.217921792179215, -4.212921292129213, -4.207920792079207, -4.2029202920292015, -4.197919791979196, -4.1929192919291935, -4.187918791879188, -4.182918291829182, -4.177917791779176, -4.172917291729171, -4.167916791679168, -4.162916291629163, -4.157915791579157, -4.152915291529151, -4.147914791479145, -4.142914291429143, -4.1379137913791375, -4.132913291329132, -4.127912791279126, -4.12291229122912, -4.117911791179118, -4.112911291129112, -4.107910791079107, -4.102910291029101, -4.097909790979095, -4.092909290929093, -4.087908790879087, -4.0829082908290815, -4.077907790779076, -4.0729072907290735, -4.067906790679068, -4.062906290629062, -4.057905790579056, -4.052905290529051, -4.047904790479048, -4.042904290429043, -4.037903790379037, -4.032903290329031, -4.027902790279025, -4.022902290229023, -4.0179017901790175, -4.012901290129012, -4.007900790079006, -4.002900290029, -3.997899789978998, -3.9928992899289923, -3.9878987898789866, -3.982898289828981, -3.977897789778975, -3.972897289728973, -3.967896789678967, -3.9628962896289615, -3.9578957895789557, -3.9528952895289535, -3.947894789478948, -3.942894289428942, -3.9378937893789363, -3.9328932893289306, -3.9278927892789284, -3.9228922892289226, -3.917891789178917, -3.912891289128911, -3.9078907890789054, -3.9028902890289032, -3.8978897889788975, -3.8928892889288917, -3.887888788878886, -3.8828882888288803, -3.877887788778878, -3.8728872887288723, -3.8678867886788666, -3.862886288628861, -3.857885788578855, -3.852885288528853, -3.847884788478847, -3.8428842884288414, -3.8378837883788357, -3.8328832883288335, -3.8278827882788278, -3.822882288228822, -3.8178817881788163, -3.8128812881288106, -3.8078807880788084, -3.8028802880288026, -3.797879787978797, -3.792879287928791, -3.7878787878787854, -3.782878287828783, -3.7778777877787775, -3.7728772877287717, -3.767876787678766, -3.7628762876287603, -3.757875787578758, -3.7528752875287523, -3.7478747874787466, -3.742874287428741, -3.737873787378735, -3.732873287328733, -3.727872787278727, -3.7228722872287214, -3.7178717871787157, -3.7128712871287135, -3.7078707870787078, -3.702870287028702, -3.6978697869786963, -3.6928692869286905, -3.6878687868786884, -3.6828682868286826, -3.677867786778677, -3.672867286728671, -3.6678667866786654, -3.662866286628663, -3.6578657865786575, -3.6528652865286517, -3.647864786478646, -3.6428642864286402, -3.637863786378638, -3.6328632863286323, -3.6278627862786266, -3.622862286228621, -3.617861786178615, -3.612861286128613, -3.607860786078607, -3.6028602860286014, -3.5978597859785957, -3.5928592859285935, -3.5878587858785878, -3.582858285828582, -3.5778577857785763, -3.5728572857285705, -3.5678567856785683, -3.5628562856285626, -3.557855785578557, -3.552855285528551, -3.5478547854785454, -3.542854285428543, -3.5378537853785375, -3.5328532853285317, -3.527852785278526, -3.5228522852285202, -3.517851785178518, -3.5128512851285123, -3.5078507850785066, -3.502850285028501, -3.497849784978495, -3.492849284928493, -3.487848784878487, -3.4828482848284814, -3.4778477847784757, -3.4728472847284735, -3.4678467846784677, -3.462846284628462, -3.4578457845784563, -3.4528452845284505, -3.4478447844784483, -3.4428442844284426, -3.437843784378437, -3.432843284328431, -3.4278427842784254, -3.422842284228423, -3.4178417841784174, -3.4128412841284117, -3.407840784078406, -3.4028402840284, -3.397839783978398, -3.3928392839283923, -3.3878387838783866, -3.382838283828381, -3.377837783778375, -3.372837283728373, -3.367836783678367, -3.3628362836283614, -3.3578357835783557, -3.3528352835283535, -3.3478347834783477, -3.342834283428342, -3.3378337833783362, -3.3328332833283305, -3.3278327832783283, -3.3228322832283226, -3.317831783178317, -3.312831283128311, -3.3078307830783054, -3.302830283028303, -3.2978297829782974, -3.2928292829282917, -3.287828782878286, -3.28282828282828, -3.277827782778278, -3.2728272827282723, -3.2678267826782665, -3.262826282628261, -3.257825782578255, -3.252825282528253, -3.247824782478247, -3.2428242824282414, -3.2378237823782356, -3.2328232823282335, -3.2278227822782277, -3.222822282228222, -3.2178217821782162, -3.2128212821282105, -3.2078207820782083, -3.2028202820282026, -3.197819781978197, -3.192819281928191, -3.1878187818781853, -3.182818281828183, -3.1778177817781774, -3.1728172817281717, -3.167816781678166, -3.16281628162816, -3.157815781578158, -3.1528152815281523, -3.1478147814781465, -3.142814281428141, -3.137813781378135, -3.132813281328133, -3.127812781278127, -3.1228122812281214, -3.1178117811781156, -3.1128112811281134, -3.1078107810781077, -3.102810281028102, -3.0978097809780962, -3.0928092809280905, -3.0878087808780883, -3.0828082808280826, -3.077807780778077, -3.072807280728071, -3.0678067806780653, -3.062806280628063, -3.0578057805780574, -3.0528052805280517, -3.047804780478046, -3.04280428042804, -3.037803780378038, -3.0328032803280323, -3.0278027802780265, -3.0228022802280208, -3.017801780178015, -3.012801280128013, -3.007800780078007, -3.0028002800280014, -2.9977997799779956, -2.9927992799279934, -2.9877987798779877, -2.982798279827982, -2.977797779777976, -2.9727972797279705, -2.9677967796779683, -2.9627962796279625, -2.957795779577957, -2.952795279527951, -2.9477947794779453, -2.942794279427943, -2.9377937793779374, -2.9327932793279317, -2.927792779277926, -2.92279227922792, -2.917791779177918, -2.9127912791279122, -2.9077907790779065, -2.9027902790279008, -2.897789778977895, -2.892789278927893, -2.887788778877887, -2.8827882788278814, -2.8777877787778756, -2.8727872787278734, -2.8677867786778677, -2.862786278627862, -2.857785778577856, -2.8527852785278505, -2.8477847784778483, -2.8427842784278425, -2.837783778377837, -2.832783278327831, -2.8277827782778253, -2.822782278227823, -2.8177817781778174, -2.8127812781278116, -2.807780778077806, -2.8027802780278, -2.797779777977798, -2.7927792779277922, -2.7877787778777865, -2.7827782778277808, -2.777777777777775, -2.772777277727773, -2.767776777677767, -2.7627762776277613, -2.7577757775777556, -2.7527752775277534, -2.7477747774777477, -2.742774277427742, -2.737773777377736, -2.7327732773277305, -2.7277727772777283, -2.7227722772277225, -2.717771777177717, -2.712771277127711, -2.7077707770777053, -2.702770277027703, -2.6977697769776974, -2.6927692769276916, -2.687768776877686, -2.68276827682768, -2.677767776777678, -2.6727672767276722, -2.6677667766776665, -2.6627662766276607, -2.657765776577655, -2.652765276527653, -2.647764776477647, -2.6427642764276413, -2.6377637763776356, -2.6327632763276334, -2.6277627762776277, -2.622762276227622, -2.617761776177616, -2.6127612761276104, -2.6077607760776083, -2.6027602760276025, -2.5977597759775968, -2.592759275927591, -2.5877587758775853, -2.582758275827583, -2.5777577757775774, -2.5727572757275716, -2.567756775677566, -2.56275627562756, -2.557755775577558, -2.552755275527552, -2.5477547754775465, -2.5427542754275407, -2.537753775377535, -2.532753275327533, -2.527752775277527, -2.5227522752275213, -2.5177517751775156, -2.5127512751275134, -2.5077507750775077, -2.502750275027502, -2.497749774977496, -2.4927492749274904, -2.4877487748774882, -2.4827482748274825, -2.4777477747774768, -2.472747274727471, -2.4677467746774653, -2.462746274627463, -2.4577457745774574, -2.4527452745274516, -2.447744774477446, -2.44274427442744, -2.437743774377438, -2.432743274327432, -2.4277427742774265, -2.4227422742274207, -2.417741774177415, -2.412741274127413, -2.407740774077407, -2.4027402740274013, -2.3977397739773956, -2.3927392739273934, -2.3877387738773876, -2.382738273827382, -2.377737773777376, -2.3727372737273704, -2.3677367736773682, -2.3627362736273625, -2.3577357735773568, -2.352735273527351, -2.3477347734773453, -2.342734273427343, -2.3377337733773373, -2.3327332733273316, -2.327732773277326, -2.32273227322732, -2.317731773177318, -2.312731273127312, -2.3077307730773065, -2.3027302730273007, -2.297729772977295, -2.292729272927293, -2.287728772877287, -2.2827282728272813, -2.2777277727772756, -2.2727272727272734, -2.2677267726772676, -2.262726272627262, -2.257725772577256, -2.2527252725272504, -2.2477247724772482, -2.2427242724272425, -2.2377237723772367, -2.232723272327231, -2.2277227722772253, -2.222722272227223, -2.2177217721772173, -2.2127212721272116, -2.207720772077206, -2.2027202720272, -2.197719771977198, -2.192719271927192, -2.1877187718771864, -2.1827182718271807, -2.177717771777175, -2.1727172717271728, -2.167716771677167, -2.1627162716271613, -2.1577157715771556, -2.1527152715271534, -2.1477147714771476, -2.142714271427142, -2.137713771377136, -2.1327132713271304, -2.127712771277128, -2.1227122712271225, -2.1177117711771167, -2.112711271127111, -2.1077107710771052, -2.102710271027103, -2.0977097709770973, -2.0927092709270916, -2.087708770877086, -2.08270827082708, -2.077707770777078, -2.072707270727072, -2.0677067706770664, -2.0627062706270607, -2.057705770577055, -2.0527052705270528, -2.047704770477047, -2.0427042704270413, -2.0377037703770355, -2.0327032703270334, -2.0277027702770276, -2.022702270227022, -2.017701770177016, -2.0127012701270104, -2.007700770077008, -2.0027002700270025, -1.9976997699769967, -1.992699269926991, -1.9876987698769852, -1.982698269826983, -1.9776977697769773, -1.9726972697269716, -1.9676967696769658, -1.96269626962696, -1.957695769576958, -1.9526952695269522, -1.9476947694769464, -1.9426942694269407, -1.937693769376935, -1.9326932693269328, -1.927692769276927, -1.9226922692269213, -1.9176917691769155, -1.9126912691269098, -1.9076907690769076, -1.9026902690269019, -1.8976897689768961, -1.8926892689268904, -1.8876887688768882, -1.8826882688268824, -1.8776877687768767, -1.872687268726871, -1.8676867686768652, -1.862686268626863, -1.8576857685768573, -1.8526852685268516, -1.8476847684768458, -1.84268426842684, -1.837683768376838, -1.8326832683268321, -1.8276827682768264, -1.8226822682268207, -1.817681768176815, -1.8126812681268127, -1.807680768076807, -1.8026802680268013, -1.7976797679767955, -1.7926792679267898, -1.7876787678767876, -1.7826782678267818, -1.777677767776776, -1.7726772677267704, -1.7676767676767682, -1.7626762676267624, -1.7576757675767567, -1.752675267526751, -1.7476747674767452, -1.742674267426743, -1.7376737673767373, -1.7326732673267315, -1.7276727672767258, -1.72267226722672, -1.7176717671767179, -1.7126712671267121, -1.7076707670767064, -1.7026702670267007, -1.697669766976695, -1.6926692669266927, -1.687668766876687, -1.6826682668266812, -1.6776677667766755, -1.6726672667266698, -1.6676667666766676, -1.6626662666266618, -1.657665766576656, -1.6526652665266504, -1.6476647664766482, -1.6426642664266424, -1.6376637663766367, -1.632663266326631, -1.6276627662766252, -1.622662266226623, -1.6176617661766173, -1.6126612661266115, -1.6076607660766058, -1.6026602660266, -1.5976597659765979, -1.5926592659265921, -1.5876587658765864, -1.5826582658265806, -1.577657765776575, -1.5726572657265727, -1.567656765676567, -1.5626562656265612, -1.5576557655765555, -1.5526552655265498, -1.5476547654765476, -1.5426542654265418, -1.537653765376536, -1.5326532653265303, -1.5276527652765282, -1.5226522652265224, -1.5176517651765167, -1.512651265126511, -1.5076507650765052, -1.502650265026503, -1.4976497649764973, -1.4926492649264915, -1.4876487648764858, -1.48264826482648, -1.4776477647764779, -1.4726472647264721, -1.4676467646764664, -1.4626462646264606, -1.457645764576455, -1.4526452645264527, -1.447644764476447, -1.4426442644264412, -1.4376437643764355, -1.4326432643264297, -1.4276427642764276, -1.4226422642264218, -1.417641764176416, -1.4126412641264103, -1.4076407640764081, -1.4026402640264024, -1.3976397639763967, -1.392639263926391, -1.3876387638763852, -1.382638263826383, -1.3776377637763773, -1.3726372637263715, -1.3676367636763658, -1.36263626362636, -1.3576357635763578, -1.352635263526352, -1.3476347634763464, -1.3426342634263406, -1.3376337633763349, -1.3326332633263327, -1.327632763276327, -1.3226322632263212, -1.3176317631763155, -1.3126312631263097, -1.3076307630763075, -1.3026302630263018, -1.297629762976296, -1.2926292629262903, -1.2876287628762881, -1.2826282628262824, -1.2776277627762767, -1.272627262726271, -1.2676267626762652, -1.262626262626263, -1.2576257625762572, -1.2526252625262515, -1.2476247624762458, -1.24262426242624, -1.2376237623762378, -1.232623262326232, -1.2276227622762264, -1.2226222622262206, -1.2176217621762149, -1.2126212621262127, -1.207620762076207, -1.2026202620262012, -1.1976197619761955, -1.1926192619261897, -1.1876187618761875, -1.1826182618261818, -1.177617761776176, -1.1726172617261703, -1.1676167616761681, -1.1626162616261624, -1.1576157615761566, -1.152615261526151, -1.1476147614761452, -1.142614261426143, -1.1376137613761372, -1.1326132613261315, -1.1276127612761258, -1.12261226122612, -1.1176117611761178, -1.112611261126112, -1.1076107610761063, -1.1026102610261006, -1.0976097609760949, -1.0926092609260927, -1.087608760876087, -1.0826082608260812, -1.0776077607760755, -1.0726072607260697, -1.0676067606760675, -1.0626062606260618, -1.057605760576056, -1.0526052605260503, -1.0476047604760481, -1.0426042604260424, -1.0376037603760366, -1.032603260326031, -1.0276027602760252, -1.022602260226023, -1.0176017601760172, -1.0126012601260115, -1.0076007600760057, -1.002600260026, -0.9975997599759978, -0.9925992599259921, -0.9875987598759863, -0.9825982598259806, -0.9775977597759749, -0.9725972597259727, -0.9675967596759669, -0.9625962596259612, -0.9575957595759554, -0.9525952595259497, -0.9475947594759475, -0.9425942594259418, -0.937593759375936, -0.9325932593259303, -0.9275927592759281, -0.9225922592259224, -0.9175917591759166, -0.9125912591259109, -0.9075907590759051, -0.902590259025903, -0.8975897589758972, -0.8925892589258915, -0.8875887588758857, -0.88258825882588, -0.8775877587758778, -0.8725872587258721, -0.8675867586758663, -0.8625862586258606, -0.8575857585758548, -0.8525852585258527, -0.8475847584758469, -0.8425842584258412, -0.8375837583758354, -0.8325832583258297, -0.8275827582758275, -0.8225822582258218, -0.817581758175816, -0.8125812581258103, -0.8075807580758081, -0.8025802580258024, -0.7975797579757966, -0.7925792579257909, -0.7875787578757851, -0.7825782578257829, -0.7775777577757772, -0.7725772577257715, -0.7675767576757657, -0.76257625762576, -0.7575757575757578, -0.752575257525752, -0.7475747574757463, -0.7425742574257406, -0.7375737573757348, -0.7325732573257326, -0.7275727572757269, -0.7225722572257212, -0.7175717571757154, -0.7125712571257097, -0.7075707570757075, -0.7025702570257017, -0.697569756975696, -0.6925692569256903, -0.6875687568756881, -0.6825682568256823, -0.6775677567756766, -0.6725672567256709, -0.6675667566756651, -0.6625662566256629, -0.6575657565756572, -0.6525652565256514, -0.6475647564756457, -0.64256425642564, -0.6375637563756378, -0.632563256325632, -0.6275627562756263, -0.6225622562256206, -0.6175617561756148, -0.6125612561256126, -0.6075607560756069, -0.6025602560256011, -0.5975597559755954, -0.5925592559255897, -0.5875587558755875, -0.5825582558255817, -0.577557755775576, -0.5725572557255703, -0.5675567556755681, -0.5625562556255623, -0.5575557555755566, -0.5525552555255508, -0.5475547554755451, -0.5425542554255429, -0.5375537553755372, -0.5325532553255314, -0.5275527552755257, -0.52255225522552, -0.5175517551755178, -0.512551255125512, -0.5075507550755063, -0.5025502550255005, -0.4975497549754948, -0.4925492549254926, -0.4875487548754869, -0.48254825482548114, -0.4775477547754754, -0.47254725472546966, -0.46754675467546747, -0.46254625462546173, -0.457545754575456, -0.45254525452545025, -0.44754475447544806, -0.4425442544254423, -0.4375437543754366, -0.43254325432543084, -0.4275427542754251, -0.4225422542254229, -0.41754175417541717, -0.4125412541254114, -0.4075407540754057, -0.40254025402539995, -0.39753975397539776, -0.392539253925392, -0.3875387538753863, -0.38253825382538054, -0.3775377537753748, -0.3725372537253726, -0.36753675367536687, -0.3625362536253611, -0.3575357535753554, -0.35253525352534965, -0.34753475347534746, -0.3425342534253417, -0.337533753375336, -0.33253325332533024, -0.32753275327532805, -0.3225322532253223, -0.31753175317531657, -0.3125312531253108, -0.3075307530753051, -0.3025302530253029, -0.29752975297529716, -0.2925292529252914, -0.2875287528752857, -0.28252825282527994, -0.27752775277527775, -0.272527252725272, -0.26752675267526627, -0.2625262526252605, -0.2575257525752548, -0.2525252525252526, -0.24752475247524686, -0.24252425242524112, -0.23752375237523538, -0.23252325232522963, -0.22752275227522745, -0.2225222522252217, -0.21752175217521597, -0.21252125212521022, -0.20752075207520804, -0.2025202520252023, -0.19751975197519656, -0.19251925192519082, -0.18751875187518507, -0.1825182518251829, -0.17751775177517715, -0.1725172517251714, -0.16751675167516566, -0.16251625162515992, -0.15751575157515774, -0.152515251525152, -0.14751475147514626, -0.14251425142514051, -0.13751375137513477, -0.13251325132513259, -0.12751275127512685, -0.1225122512251211, -0.11751175117511536, -0.11251125112510962, -0.10751075107510744, -0.1025102510251017, -0.09750975097509595, -0.09250925092509021, -0.08750875087508803, -0.08250825082508229, -0.07750775077507654, -0.0725072507250708, -0.06750675067506506, -0.06250625062506288, -0.057505750575057135, -0.052505250525051395, -0.047504750475045654, -0.04250425042503991, -0.037503750375037725, -0.032503250325031985, -0.027502750275026244, -0.022502250225020504, -0.017501750175014763, -0.012501250125012575, -0.0075007500750068345, -0.002500250025001094, 0.0025002500250046467, 0.007500750075010387, 0.012501250125012575, 0.017501750175018316, 0.022502250225024056, 0.027502750275029797, 0.032503250325031985, 0.037503750375037725, 0.042504250425043466, 0.04750475047504921, 0.05250525052505495, 0.057505750575057135, 0.06250625062506288, 0.06750675067506862, 0.07250725072507436, 0.0775077507750801, 0.08250825082508229, 0.08750875087508803, 0.09250925092509377, 0.09750975097509951, 0.10251025102510525, 0.10751075107510744, 0.11251125112511318, 0.11751175117511892, 0.12251225122512466, 0.1275127512751304, 0.13251325132513259, 0.13751375137513833, 0.14251425142514407, 0.1475147514751498, 0.152515251525152, 0.15751575157515774, 0.16251625162516348, 0.16751675167516922, 0.17251725172517496, 0.17751775177517715, 0.1825182518251829, 0.18751875187518863, 0.19251925192519437, 0.1975197519752001, 0.2025202520252023, 0.20752075207520804, 0.21252125212521378, 0.21752175217521952, 0.22252225222522526, 0.22752275227522745, 0.2325232523252332, 0.23752375237523893, 0.24252425242524467, 0.2475247524752504, 0.2525252525252526, 0.25752575257525834, 0.2625262526252641, 0.2675267526752698, 0.272527252725272, 0.27752775277527775, 0.2825282528252835, 0.28752875287528923, 0.29252925292529497, 0.29752975297529716, 0.3025302530253029, 0.30753075307530864, 0.3125312531253144, 0.3175317531753201, 0.3225322532253223, 0.32753275327532805, 0.3325332533253338, 0.33753375337533953, 0.34253425342534527, 0.34753475347534746, 0.3525352535253532, 0.35753575357535894, 0.3625362536253647, 0.3675367536753704, 0.3725372537253726, 0.37753775377537835, 0.3825382538253841, 0.38753875387538983, 0.392539253925392, 0.39753975397539776, 0.4025402540254035, 0.40754075407540924, 0.412541254125415, 0.41754175417541717, 0.4225422542254229, 0.42754275427542865, 0.4325432543254344, 0.43754375437544013, 0.4425442544254423, 0.44754475447544806, 0.4525452545254538, 0.45754575457545954, 0.4625462546254653, 0.46754675467546747, 0.4725472547254732, 0.47754775477547895, 0.4825482548254847, 0.48754875487549043, 0.4925492549254926, 0.49754975497549836, 0.5025502550255041, 0.5075507550755098, 0.512551255125512, 0.5175517551755178, 0.5225522552255235, 0.5275527552755293, 0.532553255325535, 0.5375537553755372, 0.5425542554255429, 0.5475547554755487, 0.5525552555255544, 0.5575557555755601, 0.5625562556255623, 0.5675567556755681, 0.5725572557255738, 0.5775577557755796, 0.5825582558255853, 0.5875587558755875, 0.5925592559255932, 0.597559755975599, 0.6025602560256047, 0.6075607560756104, 0.6125612561256126, 0.6175617561756184, 0.6225622562256241, 0.6275627562756299, 0.6325632563256356, 0.6375637563756378, 0.6425642564256435, 0.6475647564756493, 0.652565256525655, 0.6575657565756572, 0.6625662566256629, 0.6675667566756687, 0.6725672567256744, 0.6775677567756802, 0.6825682568256823, 0.6875687568756881, 0.6925692569256938, 0.6975697569756996, 0.7025702570257053, 0.7075707570757075, 0.7125712571257132, 0.717571757175719, 0.7225722572257247, 0.7275727572757305, 0.7325732573257326, 0.7375737573757384, 0.7425742574257441, 0.7475747574757499, 0.7525752575257556, 0.7575757575757578, 0.7625762576257635, 0.7675767576757693, 0.772577257725775, 0.7775777577757772, 0.7825782578257829, 0.7875787578757887, 0.7925792579257944, 0.7975797579758002, 0.8025802580258024, 0.8075807580758081, 0.8125812581258138, 0.8175817581758196, 0.8225822582258253, 0.8275827582758275, 0.8325832583258332, 0.837583758375839, 0.8425842584258447, 0.8475847584758505, 0.8525852585258527, 0.8575857585758584, 0.8625862586258641, 0.8675867586758699, 0.8725872587258756, 0.8775877587758778, 0.8825882588258835, 0.8875887588758893, 0.892589258925895, 0.8975897589758972, 0.902590259025903, 0.9075907590759087, 0.9125912591259144, 0.9175917591759202, 0.9225922592259224, 0.9275927592759281, 0.9325932593259338, 0.9375937593759396, 0.9425942594259453, 0.9475947594759475, 0.9525952595259533, 0.957595759575959, 0.9625962596259647, 0.9675967596759705, 0.9725972597259727, 0.9775977597759784, 0.9825982598259841, 0.9875987598759899, 0.9925992599259956, 0.9975997599759978, 1.0026002600260036, 1.0076007600760093, 1.012601260126015, 1.0176017601760172, 1.022602260226023, 1.0276027602760287, 1.0326032603260344, 1.0376037603760402, 1.0426042604260424, 1.0476047604760481, 1.0526052605260539, 1.0576057605760596, 1.0626062606260653, 1.0676067606760675, 1.0726072607260733, 1.077607760776079, 1.0826082608260847, 1.0876087608760905, 1.0926092609260927, 1.0976097609760984, 1.1026102610261042, 1.10761076107611, 1.1126112611261156, 1.1176117611761178, 1.1226122612261236, 1.1276127612761293, 1.132613261326135, 1.1376137613761372, 1.142614261426143, 1.1476147614761487, 1.1526152615261545, 1.1576157615761602, 1.1626162616261624, 1.1676167616761681, 1.1726172617261739, 1.1776177617761796, 1.1826182618261853, 1.1876187618761875, 1.1926192619261933, 1.197619761976199, 1.2026202620262048, 1.2076207620762105, 1.2126212621262127, 1.2176217621762184, 1.2226222622262242, 1.22762276227623, 1.2326232623262356, 1.2376237623762378, 1.2426242624262436, 1.2476247624762493, 1.252625262526255, 1.2576257625762572, 1.262626262626263, 1.2676267626762687, 1.2726272627262745, 1.2776277627762802, 1.2826282628262824, 1.2876287628762881, 1.2926292629262939, 1.2976297629762996, 1.3026302630263054, 1.3076307630763075, 1.3126312631263133, 1.317631763176319, 1.3226322632263248, 1.3276327632763305, 1.3326332633263327, 1.3376337633763384, 1.3426342634263442, 1.34763476347635, 1.3526352635263557, 1.3576357635763578, 1.3626362636263636, 1.3676367636763693, 1.372637263726375, 1.3776377637763773, 1.382638263826383, 1.3876387638763887, 1.3926392639263945, 1.3976397639764002, 1.4026402640264024, 1.4076407640764081, 1.4126412641264139, 1.4176417641764196, 1.4226422642264254, 1.4276427642764276, 1.4326432643264333, 1.437643764376439, 1.4426442644264448, 1.4476447644764505, 1.4526452645264527, 1.4576457645764584, 1.4626462646264642, 1.46764676467647, 1.4726472647264757, 1.4776477647764779, 1.4826482648264836, 1.4876487648764893, 1.492649264926495, 1.4976497649764973, 1.502650265026503, 1.5076507650765087, 1.5126512651265145, 1.5176517651765202, 1.5226522652265224, 1.5276527652765282, 1.532653265326534, 1.5376537653765396, 1.5426542654265454, 1.5476547654765476, 1.5526552655265533, 1.557655765576559, 1.5626562656265648, 1.5676567656765705, 1.5726572657265727, 1.5776577657765785, 1.5826582658265842, 1.58765876587659, 1.5926592659265957, 1.5976597659765979, 1.6026602660266036, 1.6076607660766093, 1.612661266126615, 1.6176617661766173, 1.622662266226623, 1.6276627662766288, 1.6326632663266345, 1.6376637663766402, 1.6426642664266424, 1.6476647664766482, 1.652665266526654, 1.6576657665766596, 1.6626662666266654, 1.6676667666766676, 1.6726672667266733, 1.677667766776679, 1.6826682668266848, 1.6876687668766905, 1.6926692669266927, 1.6976697669766985, 1.7026702670267042, 1.70767076707671, 1.7126712671267157, 1.7176717671767179, 1.7226722672267236, 1.7276727672767294, 1.732673267326735, 1.7376737673767373, 1.742674267426743, 1.7476747674767488, 1.7526752675267545, 1.7576757675767603, 1.7626762676267624, 1.7676767676767682, 1.772677267726774, 1.7776777677767797, 1.7826782678267854, 1.7876787678767876, 1.7926792679267933, 1.797679767976799, 1.8026802680268048, 1.8076807680768106, 1.8126812681268127, 1.8176817681768185, 1.8226822682268242, 1.82768276827683, 1.8326832683268357, 1.837683768376838, 1.8426842684268436, 1.8476847684768494, 1.8526852685268551, 1.8576857685768573, 1.862686268626863, 1.8676867686768688, 1.8726872687268745, 1.8776877687768803, 1.8826882688268824, 1.8876887688768882, 1.892689268926894, 1.8976897689768997, 1.9026902690269054, 1.9076907690769076, 1.9126912691269133, 1.917691769176919, 1.9226922692269248, 1.9276927692769306, 1.9326932693269328, 1.9376937693769385, 1.9426942694269442, 1.94769476947695, 1.9526952695269557, 1.957695769576958, 1.9626962696269636, 1.9676967696769694, 1.9726972697269751, 1.9776977697769773, 1.982698269826983, 1.9876987698769888, 1.9926992699269945, 1.9976997699770003, 2.0027002700270025, 2.007700770077008, 2.012701270127014, 2.0177017701770197, 2.0227022702270254, 2.0277027702770276, 2.0327032703270334, 2.037703770377039, 2.042704270427045, 2.0477047704770506, 2.0527052705270528, 2.0577057705770585, 2.0627062706270642, 2.06770677067707, 2.0727072707270757, 2.077707770777078, 2.0827082708270837, 2.0877087708770894, 2.092709270927095, 2.0977097709770973, 2.102710271027103, 2.107710771077109, 2.1127112711271145, 2.1177117711771203, 2.1227122712271225, 2.127712771277128, 2.132713271327134, 2.1377137713771397, 2.1427142714271454, 2.1477147714771476, 2.1527152715271534, 2.157715771577159, 2.162716271627165, 2.1677167716771706, 2.1727172717271728, 2.1777177717771785, 2.1827182718271843, 2.18771877187719, 2.1927192719271957, 2.197719771977198, 2.2027202720272037, 2.2077207720772094, 2.212721272127215, 2.2177217721772173, 2.222722272227223, 2.227722772277229, 2.2327232723272346, 2.2377237723772403, 2.2427242724272425, 2.2477247724772482, 2.252725272527254, 2.2577257725772597, 2.2627262726272654, 2.2677267726772676, 2.2727272727272734, 2.277727772777279, 2.282728272827285, 2.2877287728772906, 2.292729272927293, 2.2977297729772985, 2.3027302730273043, 2.30773077307731, 2.3127312731273157, 2.317731773177318, 2.3227322732273237, 2.3277327732773294, 2.332733273327335, 2.3377337733773373, 2.342734273427343, 2.347734773477349, 2.3527352735273546, 2.3577357735773603, 2.3627362736273625, 2.3677367736773682, 2.372737273727374, 2.3777377737773797, 2.3827382738273855, 2.3877387738773876, 2.3927392739273934, 2.397739773977399, 2.402740274027405, 2.4077407740774106, 2.412741274127413, 2.4177417741774185, 2.4227422742274243, 2.42774277427743, 2.4327432743274358, 2.437743774377438, 2.4427442744274437, 2.4477447744774494, 2.452745274527455, 2.4577457745774574, 2.462746274627463, 2.467746774677469, 2.4727472747274746, 2.4777477747774803, 2.4827482748274825, 2.4877487748774882, 2.492749274927494, 2.4977497749774997, 2.5027502750275055, 2.5077507750775077, 2.5127512751275134, 2.517751775177519, 2.522752275227525, 2.5277527752775306, 2.532753275327533, 2.5377537753775385, 2.5427542754275443, 2.54775477547755, 2.5527552755275558, 2.557755775577558, 2.5627562756275637, 2.5677567756775694, 2.572757275727575, 2.5777577757775774, 2.582758275827583, 2.587758775877589, 2.5927592759275946, 2.5977597759776003, 2.6027602760276025, 2.6077607760776083, 2.612761276127614, 2.6177617761776197, 2.6227622762276255, 2.6277627762776277, 2.6327632763276334, 2.637763776377639, 2.642764276427645, 2.6477647764776506, 2.652765276527653, 2.6577657765776586, 2.6627662766276643, 2.66776677667767, 2.672767276727676, 2.677767776777678, 2.6827682768276837, 2.6877687768776894, 2.692769276927695, 2.6977697769776974, 2.702770277027703, 2.707770777077709, 2.7127712771277146, 2.7177717771777203, 2.7227722772277225, 2.7277727772777283, 2.732773277327734, 2.7377737773777397, 2.7427742774277455, 2.7477747774777477, 2.7527752775277534, 2.757775777577759, 2.762776277627765, 2.7677767776777706, 2.772777277727773, 2.7777777777777786, 2.7827782778277843, 2.78777877787779, 2.792779277927796, 2.797779777977798, 2.8027802780278037, 2.8077807780778095, 2.812781278127815, 2.8177817781778174, 2.822782278227823, 2.827782778277829, 2.8327832783278346, 2.8377837783778403, 2.8427842784278425, 2.8477847784778483, 2.852785278527854, 2.8577857785778598, 2.8627862786278655, 2.8677867786778677, 2.8727872787278734, 2.877787778777879, 2.882788278827885, 2.8877887788778906, 2.892789278927893, 2.8977897789778986, 2.9027902790279043, 2.90779077907791, 2.912791279127916, 2.917791779177918, 2.9227922792279237, 2.9277927792779295, 2.932793279327935, 2.9377937793779374, 2.942794279427943, 2.947794779477949, 2.9527952795279546, 2.9577957795779604, 2.9627962796279625, 2.9677967796779683, 2.972797279727974, 2.9777977797779798, 2.9827982798279855, 2.9877987798779877, 2.9927992799279934, 2.997799779977999, 3.002800280028005, 3.0078007800780107, 3.012801280128013, 3.0178017801780186, 3.0228022802280243, 3.02780278027803, 3.032803280328036, 3.037803780378038, 3.0428042804280437, 3.0478047804780495, 3.052805280528055, 3.0578057805780574, 3.062806280628063, 3.067806780678069, 3.0728072807280746, 3.0778077807780804, 3.0828082808280826, 3.0878087808780883, 3.092809280928094, 3.0978097809781, 3.1028102810281055, 3.1078107810781077, 3.1128112811281134, 3.117811781178119, 3.122812281228125, 3.1278127812781307, 3.132813281328133, 3.1378137813781386, 3.1428142814281443, 3.14781478147815, 3.152815281528156, 3.157815781578158, 3.1628162816281638, 3.1678167816781695, 3.1728172817281752, 3.177817781778181, 3.182818281828183, 3.187818781878189, 3.1928192819281946, 3.1978197819782004, 3.2028202820282026, 3.2078207820782083, 3.212821282128214, 3.21782178217822, 3.2228222822282255, 3.2278227822782277, 3.2328232823282335, 3.237823782378239, 3.242824282428245, 3.2478247824782507, 3.252825282528253, 3.2578257825782586, 3.2628262826282644, 3.26782678267827, 3.272827282728276, 3.277827782778278, 3.2828282828282838, 3.2878287828782895, 3.2928292829282952, 3.297829782978301, 3.302830283028303, 3.307830783078309, 3.3128312831283147, 3.3178317831783204, 3.3228322832283226, 3.3278327832783283, 3.332833283328334, 3.33783378337834, 3.3428342834283455, 3.3478347834783477, 3.3528352835283535, 3.357835783578359, 3.362836283628365, 3.3678367836783707, 3.372837283728373, 3.3778377837783786, 3.3828382838283844, 3.38783878387839, 3.392839283928396, 3.397839783978398, 3.4028402840284038, 3.4078407840784095, 3.4128412841284153, 3.417841784178421, 3.422842284228423, 3.427842784278429, 3.4328432843284347, 3.4378437843784404, 3.4428442844284426, 3.4478447844784483, 3.452845284528454, 3.45784578457846, 3.4628462846284656, 3.4678467846784677, 3.4728472847284735, 3.4778477847784792, 3.482848284828485, 3.4878487848784907, 3.492849284928493, 3.4978497849784986, 3.5028502850285044, 3.50785078507851, 3.512851285128516, 3.517851785178518, 3.522852285228524, 3.5278527852785295, 3.5328532853285353, 3.537853785378541, 3.542854285428543, 3.547854785478549, 3.5528552855285547, 3.5578557855785604, 3.5628562856285626, 3.5678567856785683, 3.572857285728574, 3.57785778577858, 3.5828582858285856, 3.5878587858785878, 3.5928592859285935, 3.5978597859785992, 3.602860286028605, 3.6078607860786107, 3.612861286128613, 3.6178617861786186, 3.6228622862286244, 3.62786278627863, 3.632863286328636, 3.637863786378638, 3.642864286428644, 3.6478647864786495, 3.6528652865286553, 3.657865786578661, 3.662866286628663, 3.667866786678669, 3.6728672867286747, 3.6778677867786804, 3.6828682868286826, 3.6878687868786884, 3.692869286928694, 3.6978697869787, 3.7028702870287056, 3.7078707870787078, 3.7128712871287135, 3.7178717871787192, 3.722872287228725, 3.7278727872787307, 3.732873287328733, 3.7378737873787387, 3.7428742874287444, 3.74787478747875, 3.752875287528756, 3.757875787578758, 3.762876287628764, 3.7678767876787695, 3.7728772877287753, 3.777877787778781, 3.782878287828783, 3.787878787878789, 3.7928792879287947, 3.7978797879788004, 3.8028802880288026, 3.8078807880788084, 3.812881288128814, 3.81788178817882, 3.8228822882288256, 3.8278827882788278, 3.8328832883288335, 3.8378837883788393, 3.842884288428845, 3.8478847884788507, 3.852885288528853, 3.8578857885788587, 3.8628862886288644, 3.86788678867887, 3.872887288728876, 3.877887788778878, 3.882888288828884, 3.8878887888788896, 3.8928892889288953, 3.897889788978901, 3.9028902890289032, 3.907890789078909, 3.9128912891289147, 3.9178917891789204, 3.9228922892289226, 3.9278927892789284, 3.932893289328934, 3.93789378937894, 3.9428942894289456, 3.947894789478948, 3.9528952895289535, 3.9578957895789593, 3.962896289628965, 3.9678967896789707, 3.972897289728973, 3.9778977897789787, 3.9828982898289844, 3.98789878987899, 3.992899289928996, 3.997899789978998, 4.002900290029004, 4.00790079007901, 4.012901290129015, 4.017901790179021, 4.022902290229023, 4.027902790279029, 4.032903290329035, 4.0379037903790405, 4.042904290429043, 4.047904790479048, 4.052905290529054, 4.05790579057906, 4.062906290629066, 4.067906790679068, 4.0729072907290735, 4.077907790779079, 4.082908290829085, 4.087908790879091, 4.092909290929093, 4.097909790979099, 4.102910291029104, 4.10791079107911, 4.112911291129116, 4.117911791179118, 4.122912291229124, 4.12791279127913, 4.132913291329135, 4.137913791379141, 4.142914291429143, 4.147914791479149, 4.152915291529155, 4.1579157915791605, 4.162916291629163, 4.167916791679168, 4.172917291729174, 4.17791779177918, 4.182918291829186, 4.187918791879188, 4.1929192919291935, 4.197919791979199, 4.202920292029205, 4.207920792079211, 4.212921292129213, 4.217921792179219, 4.222922292229224, 4.22792279227923, 4.232923292329236, 4.237923792379238, 4.242924292429244, 4.24792479247925, 4.252925292529255, 4.257925792579261, 4.262926292629263, 4.267926792679269, 4.272927292729275, 4.2779277927792805, 4.282928292829283, 4.287928792879288, 4.292929292929294, 4.2979297929793, 4.302930293029306, 4.307930793079308, 4.312931293129314, 4.317931793179319, 4.322932293229325, 4.327932793279331, 4.332933293329333, 4.337933793379339, 4.3429342934293445, 4.34793479347935, 4.352935293529356, 4.357935793579358, 4.362936293629364, 4.36793679367937, 4.372937293729375, 4.377937793779381, 4.382938293829383, 4.387938793879389, 4.392939293929395, 4.3979397939794005, 4.402940294029403, 4.407940794079408, 4.412941294129414, 4.41794179417942, 4.422942294229426, 4.427942794279428, 4.432943294329434, 4.437943794379439, 4.442944294429445, 4.447944794479451, 4.452945294529453, 4.457945794579459, 4.4629462946294645, 4.46794679467947, 4.472947294729476, 4.477947794779478, 4.482948294829484, 4.48794879487949, 4.492949294929495, 4.497949794979501, 4.502950295029503, 4.507950795079509, 4.512951295129515, 4.5179517951795205, 4.522952295229523, 4.527952795279528, 4.532953295329534, 4.53795379537954, 4.542954295429546, 4.547954795479548, 4.552955295529554, 4.557955795579559, 4.562956295629565, 4.567956795679571, 4.572957295729573, 4.577957795779579, 4.5829582958295845, 4.58795879587959, 4.592959295929596, 4.597959795979598, 4.602960296029604, 4.60796079607961, 4.612961296129615, 4.617961796179621, 4.622962296229623, 4.627962796279629, 4.632963296329635, 4.6379637963796405, 4.642964296429643, 4.647964796479648, 4.652965296529654, 4.65796579657966, 4.662966296629666, 4.667966796679668, 4.672967296729674, 4.677967796779679, 4.682968296829685, 4.687968796879691, 4.692969296929693, 4.697969796979699, 4.7029702970297045, 4.70797079707971, 4.712971297129716, 4.717971797179718, 4.722972297229724, 4.72797279727973, 4.732973297329735, 4.737973797379741, 4.742974297429743, 4.747974797479749, 4.752975297529755, 4.7579757975797605, 4.762976297629763, 4.7679767976797685, 4.772977297729774, 4.77797779777978, 4.782978297829786, 4.787978797879788, 4.792979297929794, 4.797979797979799, 4.802980298029805, 4.807980798079811, 4.812981298129813, 4.817981798179819, 4.8229822982298245, 4.82798279827983, 4.832983298329836, 4.837983798379838, 4.842984298429844, 4.84798479847985, 4.852985298529855, 4.857985798579861, 4.862986298629863, 4.867986798679869, 4.872987298729875, 4.8779877987798805, 4.882988298829883, 4.8879887988798885, 4.892989298929894, 4.8979897989799, 4.902990299029906, 4.907990799079908, 4.912991299129914, 4.917991799179919, 4.922992299229925, 4.927992799279931, 4.932993299329933, 4.937993799379939, 4.9429942994299445, 4.94799479947995, 4.952995299529956, 4.957995799579958, 4.962996299629964, 4.96799679967997, 4.972997299729975, 4.977997799779981, 4.982998299829983, 4.987998799879989, 4.992999299929995, 4.9979997999800005, 5.003000300030003, 5.0080008000800085, 5.013001300130014, 5.01800180018002, 5.023002300230026, 5.028002800280028, 5.033003300330034, 5.038003800380039, 5.043004300430045, 5.048004800480051, 5.053005300530053, 5.058005800580059, 5.0630063006300645, 5.06800680068007, 5.073007300730076, 5.078007800780078, 5.083008300830084, 5.08800880088009, 5.093009300930095, 5.098009800980101, 5.103010301030103, 5.108010801080109, 5.113011301130115, 5.118011801180121, 5.123012301230123, 5.1280128012801285, 5.133013301330134, 5.13801380138014, 5.143014301430146, 5.148014801480148, 5.153015301530154, 5.158015801580159, 5.163016301630165, 5.168016801680171, 5.173017301730173, 5.178017801780179, 5.1830183018301845, 5.18801880188019, 5.193019301930196, 5.198019801980198, 5.203020302030204, 5.20802080208021, 5.213021302130215, 5.218021802180221, 5.223022302230223, 5.228022802280229, 5.233023302330235, 5.238023802380241, 5.243024302430243, 5.2480248024802485, 5.253025302530254, 5.25802580258026, 5.263026302630266, 5.268026802680268, 5.273027302730274, 5.278027802780279, 5.283028302830285, 5.288028802880291, 5.293029302930293, 5.298029802980299, 5.3030303030303045, 5.30803080308031, 5.313031303130316, 5.318031803180318, 5.323032303230324, 5.32803280328033, 5.333033303330335, 5.338033803380341, 5.343034303430343, 5.348034803480349, 5.353035303530355, 5.358035803580361, 5.363036303630363, 5.3680368036803685, 5.373037303730374, 5.37803780378038, 5.383038303830386, 5.388038803880388, 5.393039303930394, 5.398039803980399, 5.403040304030405, 5.408040804080411, 5.413041304130413, 5.418041804180419, 5.4230423042304245, 5.42804280428043, 5.433043304330436, 5.438043804380438, 5.443044304430444, 5.44804480448045, 5.453045304530455, 5.458045804580461, 5.463046304630463, 5.468046804680469, 5.473047304730475, 5.478047804780481, 5.483048304830483, 5.4880488048804885, 5.493049304930494, 5.4980498049805, 5.503050305030506, 5.508050805080508, 5.513051305130514, 5.518051805180519, 5.523052305230525, 5.528052805280531, 5.533053305330533, 5.538053805380539, 5.543054305430545, 5.54805480548055, 5.553055305530556, 5.558055805580558, 5.563056305630564, 5.56805680568057, 5.5730573057305755, 5.578057805780581, 5.583058305830583, 5.588058805880589, 5.593059305930595, 5.598059805980601, 5.603060306030603, 5.6080608060806085, 5.613061306130614, 5.61806180618062, 5.623062306230626, 5.628062806280628, 5.633063306330634, 5.638063806380639, 5.643064306430645, 5.648064806480651, 5.653065306530653, 5.658065806580659, 5.663066306630665, 5.66806680668067, 5.673067306730676, 5.678067806780678, 5.683068306830684, 5.68806880688069, 5.6930693069306955, 5.698069806980701, 5.703070307030703, 5.708070807080709, 5.713071307130715, 5.718071807180721, 5.723072307230723, 5.7280728072807285, 5.733073307330734, 5.73807380738074, 5.743074307430746, 5.748074807480748, 5.753075307530754, 5.758075807580759, 5.763076307630765, 5.768076807680771, 5.773077307730773, 5.778077807780779, 5.783078307830785, 5.78807880788079, 5.793079307930796, 5.798079807980798, 5.803080308030804, 5.80808080808081, 5.8130813081308155, 5.818081808180821, 5.823082308230823, 5.828082808280829, 5.833083308330835, 5.838083808380841, 5.843084308430846, 5.8480848084808486, 5.853085308530854, 5.85808580858086, 5.863086308630866, 5.868086808680868, 5.873087308730874, 5.878087808780879, 5.883088308830885, 5.888088808880891, 5.893089308930893, 5.898089808980899, 5.903090309030905, 5.90809080908091, 5.913091309130916, 5.918091809180918, 5.923092309230924, 5.92809280928093, 5.9330933093309355, 5.938093809380941, 5.943094309430943, 5.948094809480949, 5.953095309530955, 5.958095809580961, 5.963096309630966, 5.968096809680969, 5.973097309730974, 5.97809780978098, 5.983098309830986, 5.988098809880988, 5.993099309930994, 5.9980998099809995, 6.003100310031005, 6.008100810081011, 6.013101310131013, 6.018101810181019, 6.023102310231025, 6.02810281028103, 6.033103310331036, 6.038103810381038, 6.043104310431044, 6.04810481048105, 6.0531053105310555, 6.058105810581061, 6.063106310631063, 6.068106810681069, 6.073107310731075, 6.078107810781081, 6.083108310831086, 6.088108810881089, 6.093109310931094, 6.0981098109811, 6.103110311031106, 6.108110811081108, 6.113111311131114, 6.1181118111811195, 6.123112311231125, 6.128112811281131, 6.133113311331133, 6.138113811381139, 6.143114311431145, 6.14811481148115, 6.153115311531156, 6.158115811581158, 6.163116311631164, 6.16811681168117, 6.1731173117311755, 6.178117811781181, 6.183118311831183, 6.188118811881189, 6.193119311931195, 6.198119811981201, 6.203120312031206, 6.208120812081209, 6.213121312131214, 6.21812181218122, 6.223122312231226, 6.228122812281228, 6.233123312331234, 6.2381238123812395, 6.243124312431245, 6.248124812481251, 6.253125312531253, 6.258125812581259, 6.263126312631265, 6.26812681268127, 6.273127312731276, 6.278127812781278, 6.283128312831284, 6.28812881288129, 6.2931293129312955, 6.298129812981301, 6.3031303130313034, 6.308130813081309, 6.313131313131315, 6.318131813181321, 6.323132313231326, 6.328132813281329, 6.333133313331334, 6.33813381338134, 6.343134313431346, 6.348134813481348, 6.353135313531354, 6.3581358135813595, 6.363136313631365, 6.368136813681371, 6.373137313731373, 6.378137813781379, 6.383138313831385, 6.38813881388139, 6.393139313931396, 6.398139813981398, 6.403140314031404, 6.40814081408141, 6.4131413141314155, 6.418141814181421, 6.4231423142314235, 6.428142814281429, 6.433143314331435, 6.438143814381441, 6.443144314431446, 6.448144814481449, 6.453145314531454, 6.45814581458146, 6.463146314631466, 6.468146814681468, 6.473147314731474, 6.4781478147814795, 6.483148314831485, 6.488148814881491, 6.493149314931493, 6.498149814981499, 6.503150315031505, 6.50815081508151, 6.513151315131516, 6.518151815181518, 6.523152315231524, 6.52815281528153, 6.5331533153315355, 6.538153815381541, 6.5431543154315435, 6.548154815481549, 6.553155315531555, 6.558155815581561, 6.563156315631566, 6.568156815681569, 6.573157315731574, 6.57815781578158, 6.583158315831586, 6.588158815881588, 6.593159315931594, 6.5981598159815995, 6.603160316031605, 6.608160816081611, 6.613161316131613, 6.618161816181619, 6.623162316231625, 6.62816281628163, 6.633163316331636, 6.638163816381638, 6.643164316431644, 6.64816481648165, 6.6531653165316555, 6.658165816581661, 6.6631663166316635, 6.668166816681669, 6.673167316731675, 6.678167816781681, 6.683168316831686, 6.688168816881689, 6.693169316931694, 6.6981698169817, 6.703170317031706, 6.708170817081708, 6.713171317131714, 6.7181718171817195, 6.723172317231725, 6.728172817281731, 6.733173317331733, 6.738173817381739, 6.743174317431745, 6.74817481748175, 6.753175317531756, 6.758175817581758, 6.763176317631764, 6.76817681768177, 6.773177317731776, 6.778177817781781, 6.7831783178317835, 6.788178817881789, 6.793179317931795, 6.798179817981801, 6.8031803180318065, 6.808180818081809, 6.813181318131814, 6.81818181818182, 6.823182318231826, 6.828182818281828, 6.833183318331834, 6.8381838183818395, 6.843184318431845, 6.848184818481851, 6.853185318531853, 6.858185818581859, 6.863186318631865, 6.86818681868187, 6.873187318731876, 6.878187818781878, 6.883188318831884, 6.88818881888189, 6.893189318931896, 6.898189818981901, 6.9031903190319035, 6.908190819081909, 6.913191319131915, 6.918191819181921, 6.9231923192319265, 6.928192819281929, 6.933193319331934, 6.93819381938194, 6.943194319431946, 6.948194819481948, 6.953195319531954, 6.9581958195819595, 6.963196319631965, 6.968196819681971, 6.973197319731973, 6.978197819781979, 6.983198319831985, 6.98819881988199, 6.993199319931996, 6.998199819981998, 7.003200320032008, 7.00820082008201, 7.013201320132012, 7.018201820182021, 7.0232023202320235, 7.028202820282033, 7.033203320332035, 7.038203820382037, 7.0432043204320465, 7.048204820482049, 7.053205320532058, 7.05820582058206, 7.063206320632062, 7.068206820682072, 7.073207320732074, 7.078207820782083, 7.083208320832085, 7.0882088208820875, 7.093209320932097, 7.098209820982099, 7.103210321032108, 7.10821082108211, 7.113211321132113, 7.118211821182122, 7.123212321232124, 7.128212821282126, 7.133213321332136, 7.138213821382138, 7.143214321432147, 7.148214821482149, 7.1532153215321514, 7.158215821582161, 7.163216321632163, 7.168216821682172, 7.173217321732174, 7.178217821782177, 7.183218321832186, 7.188218821882188, 7.193219321932197, 7.1982198219822, 7.203220322032202, 7.208220822082211, 7.213221322132213, 7.2182218221822225, 7.223222322232225, 7.228222822282227, 7.233223322332236, 7.238223822382238, 7.243224322432248, 7.24822482248225, 7.253225322532252, 7.258225822582261, 7.2632263226322635, 7.268226822682273, 7.273227322732275, 7.278227822782277, 7.2832283228322865, 7.288228822882289, 7.293229322932298, 7.2982298229823, 7.303230323032302, 7.308230823082312, 7.313231323132314, 7.318231823182323, 7.323232323232325, 7.3282328232823275, 7.333233323332337, 7.338233823382339, 7.343234323432348, 7.3482348234823505, 7.353235323532353, 7.358235823582362, 7.363236323632364, 7.368236823682366, 7.373237323732376, 7.378237823782378, 7.383238323832387, 7.388238823882389, 7.3932393239323915, 7.398239823982401, 7.403240324032403, 7.408240824082412, 7.413241324132414, 7.418241824182417, 7.423242324232426, 7.428242824282428, 7.433243324332437, 7.43824382438244, 7.443244324432442, 7.448244824482451, 7.453245324532453, 7.4582458245824625, 7.463246324632465, 7.468246824682467, 7.473247324732476, 7.478247824782478, 7.483248324832488, 7.48824882488249, 7.493249324932492, 7.498249824982501, 7.5032503250325036, 7.508250825082513, 7.513251325132515, 7.518251825182517, 7.5232523252325265, 7.528252825282529, 7.533253325332538, 7.53825382538254, 7.543254325432542, 7.548254825482552, 7.553255325532554, 7.558255825582563, 7.563256325632565, 7.5682568256825675, 7.573257325732577, 7.578257825782579, 7.583258325832588, 7.5882588258825905, 7.593259325932593, 7.598259825982602, 7.603260326032604, 7.608260826082606, 7.613261326132616, 7.618261826182618, 7.623262326232627, 7.628262826282629, 7.6332633263326315, 7.638263826382641, 7.643264326432643, 7.648264826482652, 7.6532653265326545, 7.658265826582657, 7.663266326632666, 7.668266826682668, 7.673267326732677, 7.67826782678268, 7.683268326832682, 7.688268826882691, 7.693269326932693, 7.698269826982703, 7.703270327032705, 7.708270827082707, 7.713271327132716, 7.718271827182718, 7.723272327232728, 7.72827282728273, 7.733273327332732, 7.738273827382741, 7.743274327432744, 7.748274827482753, 7.753275327532755, 7.758275827582757, 7.7632763276327665, 7.768276827682769, 7.773277327732778, 7.77827782778278, 7.783278327832782, 7.788278827882792, 7.793279327932794, 7.798279827982803, 7.803280328032805, 7.8082808280828075, 7.813281328132817, 7.818281828182819, 7.823282328232828, 7.8282828282828305, 7.833283328332833, 7.838283828382842, 7.843284328432844, 7.848284828482846, 7.853285328532856, 7.858285828582858, 7.863286328632867, 7.868286828682869, 7.8732873287328715, 7.878287828782881, 7.883288328832883, 7.888288828882892, 7.8932893289328945, 7.898289828982897, 7.903290329032906, 7.908290829082908, 7.913291329132917, 7.91829182918292, 7.923292329232922, 7.928292829282931, 7.933293329332933, 7.938293829382943, 7.943294329432945, 7.948294829482947, 7.953295329532956, 7.9582958295829584, 7.963296329632968, 7.96829682968297, 7.973297329732972, 7.978297829782981, 7.983298329832984, 7.988298829882993, 7.993299329932995, 7.998299829982997, 8.003300330033007, 8.008300830083009, 8.013301330133018, 8.01830183018302, 8.023302330233022, 8.028302830283032, 8.033303330333034, 8.038303830383043, 8.043304330433045, 8.048304830483048, 8.053305330533057, 8.058305830583059, 8.063306330633068, 8.06830683068307, 8.073307330733073, 8.078307830783082, 8.083308330833084, 8.088308830883086, 8.093309330933096, 8.098309830983098, 8.103310331033107, 8.10831083108311, 8.113311331133112, 8.11831183118312, 8.123312331233123, 8.128312831283132, 8.133313331333134, 8.138313831383137, 8.143314331433146, 8.148314831483148, 8.153315331533157, 8.15831583158316, 8.163316331633162, 8.168316831683171, 8.173317331733173, 8.178317831783183, 8.183318331833185, 8.188318831883187, 8.193319331933196, 8.198319831983198, 8.203320332033208, 8.20832083208321, 8.213321332133212, 8.218321832183221, 8.223322332233224, 8.228322832283233, 8.233323332333235, 8.238323832383237, 8.243324332433247, 8.248324832483249, 8.253325332533258, 8.25832583258326, 8.263326332633262, 8.268326832683272, 8.273327332733274, 8.278327832783283, 8.283328332833285, 8.288328832883288, 8.293329332933297, 8.298329832983299, 8.303330333033308, 8.30833083308331, 8.313331333133313, 8.318331833183322, 8.323332333233324, 8.328332833283334, 8.333333333333336, 8.338333833383338, 8.343334333433347, 8.34833483348335, 8.353335333533352, 8.35833583358336, 8.363336333633363, 8.368336833683372, 8.373337333733375, 8.378337833783377, 8.383338333833386, 8.388338833883388, 8.393339333933397, 8.3983398339834, 8.403340334033402, 8.408340834083411, 8.413341334133413, 8.418341834183423, 8.423342334233425, 8.428342834283427, 8.433343334333436, 8.438343834383438, 8.443344334433448, 8.44834483448345, 8.453345334533452, 8.458345834583461, 8.463346334633464, 8.468346834683473, 8.473347334733475, 8.478347834783477, 8.483348334833487, 8.488348834883489, 8.493349334933498, 8.4983498349835, 8.503350335033502, 8.508350835083512, 8.513351335133514, 8.518351835183523, 8.523352335233525, 8.528352835283528, 8.533353335333537, 8.538353835383539, 8.543354335433548, 8.54835483548355, 8.553355335533553, 8.558355835583562, 8.563356335633564, 8.568356835683574, 8.573357335733576, 8.578357835783578, 8.583358335833587, 8.58835883588359, 8.593359335933592, 8.5983598359836, 8.603360336033603, 8.608360836083612, 8.613361336133615, 8.618361836183617, 8.623362336233626, 8.628362836283628, 8.633363336333638, 8.63836383638364, 8.643364336433642, 8.648364836483651, 8.653365336533653, 8.658365836583663, 8.663366336633665, 8.668366836683667, 8.673367336733676, 8.678367836783679, 8.683368336833688, 8.68836883688369, 8.693369336933692, 8.698369836983701, 8.703370337033704, 8.708370837083713, 8.713371337133715, 8.718371837183717, 8.723372337233727, 8.728372837283729, 8.733373337333738, 8.73837383738374, 8.743374337433742, 8.748374837483752, 8.753375337533754, 8.758375837583763, 8.763376337633765, 8.768376837683768, 8.773377337733777, 8.77837783778378, 8.783378337833788, 8.78837883788379, 8.793379337933793, 8.798379837983802, 8.803380338033804, 8.808380838083814, 8.813381338133816, 8.818381838183818, 8.823382338233827, 8.82838283828383, 8.833383338333832, 8.838383838383841, 8.843384338433843, 8.848384838483852, 8.853385338533855, 8.858385838583857, 8.863386338633866, 8.868386838683868, 8.873387338733878, 8.87838783878388, 8.883388338833882, 8.888388838883891, 8.893389338933893, 8.898389838983903, 8.903390339033905, 8.908390839083907, 8.913391339133916, 8.918391839183919, 8.923392339233928, 8.92839283928393, 8.933393339333932, 8.938393839383941, 8.943394339433944, 8.948394839483953, 8.953395339533955, 8.958395839583957, 8.963396339633967, 8.968396839683969, 8.973397339733978, 8.97839783978398, 8.983398339833983, 8.988398839883992, 8.993399339933994, 8.998399839984003, 9.003400340034005, 9.008400840084008, 9.013401340134017, 9.01840184018402, 9.023402340234028, 9.02840284028403, 9.033403340334033, 9.038403840384042, 9.043404340434044, 9.048404840484054, 9.053405340534056, 9.058405840584058, 9.063406340634067, 9.06840684068407, 9.073407340734072, 9.078407840784081, 9.083408340834083, 9.088408840884092, 9.093409340934095, 9.098409840984097, 9.103410341034106, 9.108410841084108, 9.113411341134118, 9.11841184118412, 9.123412341234122, 9.128412841284131, 9.133413341334133, 9.138413841384143, 9.143414341434145, 9.148414841484147, 9.153415341534156, 9.158415841584159, 9.163416341634168, 9.16841684168417, 9.173417341734172, 9.178417841784182, 9.183418341834184, 9.188418841884193, 9.193419341934195, 9.198419841984197, 9.203420342034207, 9.208420842084209, 9.213421342134218, 9.21842184218422, 9.223422342234223, 9.228422842284232, 9.233423342334234, 9.238423842384243, 9.243424342434245, 9.248424842484248, 9.253425342534257, 9.25842584258426, 9.263426342634268, 9.26842684268427, 9.273427342734273, 9.278427842784282, 9.283428342834284, 9.288428842884294, 9.293429342934296, 9.298429842984298, 9.303430343034307, 9.30843084308431, 9.313431343134312, 9.318431843184321, 9.323432343234323, 9.328432843284332, 9.333433343334335, 9.338433843384337, 9.343434343434346, 9.348434843484348, 9.353435343534358, 9.35843584358436, 9.363436343634362, 9.368436843684371, 9.373437343734373, 9.378437843784383, 9.383438343834385, 9.388438843884387, 9.393439343934396, 9.398439843984399, 9.403440344034408, 9.40844084408441, 9.413441344134412, 9.418441844184422, 9.423442344234424, 9.428442844284433, 9.433443344334435, 9.438443844384437, 9.443444344434447, 9.448444844484449, 9.453445344534458, 9.45844584458446, 9.463446344634463, 9.468446844684472, 9.473447344734474, 9.478447844784483, 9.483448344834486, 9.488448844884488, 9.493449344934497, 9.4984498449845, 9.503450345034508, 9.50845084508451, 9.513451345134513, 9.518451845184522, 9.523452345234524, 9.528452845284534, 9.533453345334536, 9.538453845384538, 9.543454345434547, 9.54845484548455, 9.553455345534552, 9.558455845584561, 9.563456345634563, 9.568456845684572, 9.573457345734575, 9.578457845784577, 9.583458345834586, 9.588458845884588, 9.593459345934598, 9.5984598459846, 9.603460346034602, 9.608460846084611, 9.613461346134613, 9.618461846184623, 9.623462346234625, 9.628462846284627, 9.633463346334636, 9.638463846384639, 9.643464346434648, 9.64846484648465, 9.653465346534652, 9.658465846584662, 9.663466346634664, 9.668466846684673, 9.673467346734675, 9.678467846784677, 9.683468346834687, 9.688468846884689, 9.693469346934698, 9.6984698469847, 9.703470347034703, 9.708470847084712, 9.713471347134714, 9.718471847184723, 9.723472347234726, 9.728472847284728, 9.733473347334737, 9.73847384738474, 9.743474347434748, 9.74847484748475, 9.753475347534753, 9.758475847584762, 9.763476347634764, 9.768476847684774, 9.773477347734776, 9.778477847784778, 9.783478347834787, 9.78847884788479, 9.793479347934792, 9.798479847984801, 9.803480348034803, 9.808480848084812, 9.813481348134815, 9.818481848184817, 9.823482348234826, 9.828482848284828, 9.833483348334838, 9.83848384838484, 9.843484348434842, 9.848484848484851, 9.853485348534853, 9.858485848584863, 9.863486348634865, 9.868486848684867, 9.873487348734876, 9.878487848784879, 9.883488348834888, 9.88848884888489, 9.893489348934892, 9.898489848984902, 9.903490349034904, 9.908490849084913, 9.913491349134915, 9.918491849184917, 9.923492349234927, 9.928492849284929, 9.933493349334938, 9.93849384938494, 9.943494349434943, 9.948494849484952, 9.953495349534954, 9.958495849584963, 9.963496349634966, 9.968496849684968, 9.973497349734977, 9.97849784978498, 9.983498349834989, 9.98849884988499, 9.993499349934993, 9.998499849985002, 10.003500350035004, 10.008500850085014, 10.013501350135016, 10.018501850185018, 10.023502350235027, 10.02850285028503, 10.033503350335032, 10.038503850385041, 10.043504350435043, 10.048504850485052, 10.053505350535055, 10.058505850585057, 10.063506350635066, 10.068506850685068, 10.073507350735078, 10.07850785078508, 10.083508350835082, 10.088508850885091, 10.093509350935093, 10.098509850985103, 10.103510351035105, 10.108510851085107, 10.113511351135116, 10.118511851185119, 10.123512351235128, 10.12851285128513, 10.133513351335132, 10.138513851385142, 10.143514351435144, 10.148514851485153, 10.153515351535155, 10.158515851585157, 10.163516351635167, 10.168516851685169, 10.173517351735178, 10.17851785178518, 10.183518351835183, 10.188518851885192, 10.193519351935194, 10.198519851985203, 10.203520352035206, 10.208520852085208, 10.213521352135217, 10.21852185218522, 10.223522352235229, 10.22852285228523, 10.233523352335233, 10.238523852385242, 10.243524352435244, 10.248524852485254, 10.253525352535256, 10.258525852585258, 10.263526352635267, 10.26852685268527, 10.273527352735272, 10.278527852785281, 10.283528352835283, 10.288528852885293, 10.293529352935295, 10.298529852985297, 10.303530353035306, 10.308530853085308, 10.313531353135318, 10.31853185318532, 10.323532353235322, 10.328532853285331, 10.333533353335334, 10.338533853385343, 10.343534353435345, 10.348534853485347, 10.353535353535356, 10.358535853585359, 10.363536353635368, 10.36853685368537, 10.373537353735372, 10.378537853785382, 10.383538353835384, 10.388538853885393, 10.393539353935395, 10.398539853985397, 10.403540354035407, 10.408540854085409, 10.413541354135418, 10.41854185418542, 10.423542354235423, 10.428542854285432, 10.433543354335434, 10.438543854385443, 10.443544354435446, 10.448544854485448, 10.453545354535457, 10.45854585458546, 10.463546354635469, 10.46854685468547, 10.473547354735473, 10.478547854785482, 10.483548354835484, 10.488548854885494, 10.493549354935496, 10.498549854985498, 10.503550355035507, 10.50855085508551, 10.513551355135512, 10.518551855185521, 10.523552355235523, 10.528552855285533, 10.533553355335535, 10.538553855385537, 10.543554355435546, 10.548554855485548, 10.553555355535558, 10.55855585558556, 10.563556355635562, 10.568556855685571, 10.573557355735574, 10.578557855785583, 10.583558355835585, 10.588558855885587, 10.593559355935596, 10.598559855985599, 10.603560356035608, 10.60856085608561, 10.613561356135612, 10.618561856185622, 10.623562356235624, 10.628562856285633, 10.633563356335635, 10.638563856385638, 10.643564356435647, 10.648564856485649, 10.653565356535658, 10.65856585658566, 10.663566356635663, 10.668566856685672, 10.673567356735674, 10.678567856785683, 10.683568356835686, 10.688568856885688, 10.693569356935697, 10.6985698569857, 10.703570357035709, 10.70857085708571, 10.713571357135713, 10.718571857185722, 10.723572357235724, 10.728572857285734, 10.733573357335736, 10.738573857385738, 10.743574357435747, 10.74857485748575, 10.753575357535752, 10.758575857585761, 10.763576357635763, 10.768576857685773, 10.773577357735775, 10.778577857785777, 10.783578357835786, 10.788578857885788, 10.793579357935798, 10.7985798579858, 10.803580358035802, 10.808580858085811, 10.813581358135814, 10.818581858185823, 10.823582358235825, 10.828582858285827, 10.833583358335837, 10.838583858385839, 10.843584358435848, 10.84858485848585, 10.853585358535852, 10.858585858585862, 10.863586358635864, 10.868586858685873, 10.873587358735875, 10.878587858785878, 10.883588358835887, 10.888588858885889, 10.893589358935898, 10.8985898589859, 10.903590359035903, 10.908590859085912, 10.913591359135914, 10.918591859185923, 10.923592359235926, 10.928592859285928, 10.933593359335937, 10.93859385938594, 10.943594359435949, 10.94859485948595, 10.953595359535953, 10.958595859585962, 10.963596359635964, 10.968596859685974, 10.973597359735976, 10.978597859785978, 10.983598359835987, 10.98859885988599, 10.993599359935999, 10.998599859986001, 11.003600360036003, 11.008600860086013, 11.013601360136015, 11.018601860186017, 11.023602360236026, 11.028602860286028, 11.033603360336038, 11.03860386038604, 11.043604360436042, 11.048604860486051, 11.053605360536054, 11.058605860586063, 11.063606360636065, 11.068606860686067, 11.073607360736077, 11.078607860786079, 11.083608360836088, 11.08860886088609, 11.093609360936092, 11.098609860986102, 11.103610361036104, 11.108610861086113, 11.113611361136115, 11.118611861186118, 11.123612361236127, 11.128612861286129, 11.133613361336138, 11.13861386138614, 11.143614361436143, 11.148614861486152, 11.153615361536154, 11.158615861586163, 11.163616361636166, 11.168616861686168, 11.173617361736177, 11.17861786178618, 11.183618361836189, 11.18861886188619, 11.193619361936193, 11.198619861986202, 11.203620362036204, 11.208620862086214, 11.213621362136216, 11.218621862186218, 11.223622362236227, 11.22862286228623, 11.233623362336239, 11.238623862386241, 11.243624362436243, 11.248624862486253, 11.253625362536255, 11.258625862586257, 11.263626362636266, 11.268626862686268, 11.273627362736278, 11.27862786278628, 11.283628362836282, 11.288628862886291, 11.293629362936294, 11.298629862986303, 11.303630363036305, 11.308630863086307, 11.313631363136317, 11.318631863186319, 11.323632363236328, 11.32863286328633, 11.333633363336332, 11.338633863386342, 11.343634363436344, 11.348634863486353, 11.353635363536355, 11.358635863586358, 11.363636363636367, 11.368636863686369, 11.373637363736378, 11.37863786378638, 11.383638363836383, 11.388638863886392, 11.393639363936394, 11.398639863986403, 11.403640364036406, 11.408640864086408, 11.413641364136417, 11.41864186418642, 11.423642364236429, 11.42864286428643, 11.433643364336433, 11.438643864386442, 11.443644364436445, 11.448644864486454, 11.453645364536456, 11.458645864586458, 11.463646364636467, 11.46864686468647, 11.473647364736479, 11.478647864786481, 11.483648364836483, 11.488648864886493, 11.493649364936495, 11.498649864986497, 11.503650365036506, 11.508650865086508, 11.513651365136518, 11.51865186518652, 11.523652365236522, 11.528652865286531, 11.533653365336534, 11.538653865386543, 11.543654365436545, 11.548654865486547, 11.553655365536557, 11.558655865586559, 11.563656365636568, 11.56865686568657, 11.573657365736572, 11.578657865786582, 11.583658365836584, 11.588658865886593, 11.593659365936595, 11.598659865986598, 11.603660366036607, 11.608660866086609, 11.613661366136618, 11.61866186618662, 11.623662366236623, 11.628662866286632, 11.633663366336634, 11.638663866386644, 11.643664366436646, 11.648664866486648, 11.653665366536657, 11.65866586658666, 11.663666366636669, 11.66866686668667, 11.673667366736673, 11.678667866786682, 11.683668366836685, 11.688668866886694, 11.693669366936696, 11.698669866986698, 11.703670367036707, 11.70867086708671, 11.713671367136719, 11.718671867186721, 11.723672367236723, 11.728672867286733, 11.733673367336735, 11.738673867386737, 11.743674367436746, 11.748674867486748, 11.753675367536758, 11.75867586758676, 11.763676367636762, 11.768676867686771, 11.773677367736774, 11.778677867786783, 11.783678367836785, 11.788678867886787, 11.793679367936797, 11.798679867986799, 11.803680368036808, 11.80868086808681, 11.813681368136812, 11.818681868186822, 11.823682368236824, 11.828682868286833, 11.833683368336835, 11.838683868386838, 11.843684368436847, 11.848684868486849, 11.853685368536858, 11.85868586858686, 11.863686368636863, 11.868686868686872, 11.873687368736874, 11.878687868786884, 11.883688368836886, 11.888688868886888, 11.893689368936897, 11.8986898689869, 11.903690369036909, 11.90869086908691, 11.913691369136913, 11.918691869186922, 11.923692369236925, 11.928692869286934, 11.933693369336936, 11.938693869386938, 11.943694369436948, 11.94869486948695, 11.953695369536959, 11.958695869586961, 11.963696369636963, 11.968696869686973, 11.973697369736975, 11.978697869786977, 11.983698369836986, 11.988698869886989, 11.993699369936998, 11.998699869987, 12.003700370037002, 12.008700870087011, 12.013701370137014, 12.018701870187023, 12.023702370237025, 12.028702870287027, 12.033703370337037, 12.038703870387039, 12.043704370437048, 12.04870487048705, 12.053705370537052, 12.058705870587062, 12.063706370637064, 12.068706870687073, 12.073707370737075, 12.078707870787078, 12.083708370837087, 12.08870887088709, 12.093709370937098, 12.0987098709871, 12.103710371037103, 12.108710871087112, 12.113711371137114, 12.118711871187124, 12.123712371237126, 12.128712871287128, 12.133713371337137, 12.13871387138714, 12.143714371437149, 12.148714871487151, 12.153715371537153, 12.158715871587162, 12.163716371637165, 12.168716871687174, 12.173717371737176, 12.178717871787178, 12.183718371837188, 12.18871887188719, 12.193719371937199, 12.198719871987201, 12.203720372037203, 12.208720872087213, 12.213721372137215, 12.218721872187217, 12.223722372237226, 12.228722872287229, 12.233723372337238, 12.23872387238724, 12.243724372437242, 12.248724872487252, 12.253725372537254, 12.258725872587263, 12.263726372637265, 12.268726872687267, 12.273727372737277, 12.278727872787279, 12.283728372837288, 12.28872887288729, 12.293729372937293, 12.298729872987302, 12.303730373037304, 12.308730873087313, 12.313731373137315, 12.318731873187318, 12.323732373237327, 12.32873287328733, 12.333733373337338, 12.33873387338734, 12.343734373437343, 12.348734873487352, 12.353735373537354, 12.358735873587364, 12.363736373637366, 12.368736873687368, 12.373737373737377, 12.37873787378738, 12.383738373837389, 12.388738873887391, 12.393739373937393, 12.398739873987402, 12.403740374037405, 12.408740874087414, 12.413741374137416, 12.418741874187418, 12.423742374237428, 12.42874287428743, 12.433743374337439, 12.438743874387441, 12.443744374437443, 12.448744874487453, 12.453745374537455, 12.458745874587457, 12.463746374637466, 12.468746874687469, 12.473747374737478, 12.47874787478748, 12.483748374837482, 12.488748874887492, 12.493749374937494, 12.498749874987503, 12.503750375037505, 12.508750875087507, 12.513751375137517, 12.518751875187519, 12.523752375237528, 12.52875287528753, 12.533753375337533, 12.538753875387542, 12.543754375437544, 12.548754875487553, 12.553755375537555, 12.558755875587558, 12.563756375637567, 12.56875687568757, 12.573757375737578, 12.57875787578758, 12.583758375837583, 12.588758875887592, 12.593759375937594, 12.598759875987604, 12.603760376037606, 12.608760876087608, 12.613761376137617, 12.61876187618762, 12.623762376237629, 12.628762876287631, 12.633763376337633, 12.638763876387642, 12.643764376437645, 12.648764876487654, 12.653765376537656, 12.658765876587658, 12.663766376637668, 12.66876687668767, 12.673767376737679, 12.678767876787681, 12.683768376837683, 12.688768876887693, 12.693769376937695, 12.698769876987697, 12.703770377037706, 12.708770877087709, 12.713771377137718, 12.71877187718772, 12.723772377237722, 12.728772877287732, 12.733773377337734, 12.738773877387743, 12.743774377437745, 12.748774877487747, 12.753775377537757, 12.758775877587759, 12.763776377637768, 12.76877687768777, 12.773777377737773, 12.778777877787782, 12.783778377837784, 12.788778877887793, 12.793779377937796, 12.798779877987798, 12.803780378037807, 12.80878087808781, 12.813781378137818, 12.81878187818782, 12.823782378237823, 12.828782878287832, 12.833783378337834, 12.838783878387844, 12.843784378437846, 12.848784878487848, 12.853785378537857, 12.85878587858786, 12.863786378637869, 12.868786878687871, 12.873787378737873, 12.878787878787882, 12.883788378837885, 12.888788878887894, 12.893789378937896, 12.898789878987898, 12.903790379037908, 12.90879087908791, 12.913791379137919, 12.918791879187921, 12.923792379237923, 12.928792879287933, 12.933793379337935, 12.938793879387937, 12.943794379437946, 12.948794879487949, 12.953795379537958, 12.95879587958796, 12.963796379637962, 12.968796879687972, 12.973797379737974, 12.978797879787983, 12.983798379837985, 12.988798879887987, 12.993799379937997, 12.998799879987999, 13.003800380038008, 13.00880088008801, 13.013801380138013, 13.018801880188022, 13.023802380238024, 13.028802880288033, 13.033803380338036, 13.038803880388038, 13.043804380438047, 13.04880488048805, 13.053805380538059, 13.05880588058806, 13.063806380638063, 13.068806880688072, 13.073807380738074, 13.078807880788084, 13.083808380838086, 13.088808880888088, 13.093809380938097, 13.0988098809881, 13.103810381038109, 13.108810881088111, 13.113811381138113, 13.118811881188122, 13.123812381238125, 13.128812881288134, 13.133813381338136, 13.138813881388138, 13.143814381438148, 13.14881488148815, 13.153815381538159, 13.158815881588161, 13.163816381638163, 13.168816881688173, 13.173817381738175, 13.178817881788177, 13.183818381838186, 13.188818881888189, 13.193819381938198, 13.1988198819882, 13.203820382038202, 13.208820882088212, 13.213821382138214, 13.218821882188223, 13.223822382238225, 13.228822882288227, 13.233823382338237, 13.238823882388239, 13.243824382438248, 13.24882488248825, 13.253825382538253, 13.258825882588262, 13.263826382638264, 13.268826882688273, 13.273827382738276, 13.278827882788278, 13.283828382838287, 13.28882888288829, 13.293829382938299, 13.2988298829883, 13.303830383038303, 13.308830883088312, 13.313831383138314, 13.318831883188324, 13.323832383238326, 13.328832883288328, 13.333833383338337, 13.33883388338834, 13.343834383438349, 13.348834883488351, 13.353835383538353, 13.358835883588362, 13.363836383638365, 13.368836883688374, 13.373837383738376, 13.378837883788378, 13.383838383838388, 13.38883888388839, 13.3938393839384, 13.398839883988401, 13.403840384038403, 13.408840884088413, 13.413841384138415, 13.418841884188424, 13.423842384238426, 13.428842884288429, 13.433843384338438, 13.43884388438844, 13.443844384438442, 13.448844884488452, 13.453845384538454, 13.458845884588463, 13.463846384638465, 13.468846884688467, 13.473847384738477, 13.478847884788479, 13.483848384838488, 13.48884888488849, 13.493849384938493, 13.498849884988502, 13.503850385038504, 13.508850885088513, 13.513851385138516, 13.518851885188518, 13.523852385238527, 13.52885288528853, 13.533853385338539, 13.53885388538854, 13.543854385438543, 13.548854885488552, 13.553855385538554, 13.558855885588564, 13.563856385638566, 13.568856885688568, 13.573857385738577, 13.57885788578858, 13.583858385838589, 13.588858885888591, 13.593859385938593, 13.598859885988603, 13.603860386038605, 13.608860886088614, 13.613861386138616, 13.618861886188618, 13.623862386238628, 13.62886288628863, 13.63386338633864, 13.638863886388641, 13.643864386438644, 13.648864886488653, 13.653865386538655, 13.658865886588664, 13.663866386638666, 13.668866886688669, 13.673867386738678, 13.67886788678868, 13.683868386838682, 13.688868886888692, 13.693869386938694, 13.698869886988703, 13.703870387038705, 13.708870887088707, 13.713871387138717, 13.718871887188719, 13.723872387238728, 13.72887288728873, 13.733873387338733, 13.738873887388742, 13.743874387438744, 13.748874887488753, 13.753875387538756, 13.758875887588758, 13.763876387638767, 13.76887688768877, 13.773877387738779, 13.77887788778878, 13.783878387838783, 13.788878887888792, 13.793879387938794, 13.798879887988804, 13.803880388038806, 13.808880888088808, 13.813881388138817, 13.81888188818882, 13.823882388238829, 13.828882888288831, 13.833883388338833, 13.838883888388843, 13.843884388438845, 13.848884888488854, 13.853885388538856, 13.858885888588858, 13.863886388638868, 13.86888688868887, 13.87388738873888, 13.878887888788881, 13.883888388838884, 13.888888888888893, 13.893889388938895, 13.898889888988904, 13.903890389038907, 13.908890889088909, 13.913891389138918, 13.91889188918892, 13.923892389238922, 13.928892889288932, 13.933893389338934, 13.938893889388943, 13.943894389438945, 13.948894889488948, 13.953895389538957, 13.958895889588959, 13.963896389638968, 13.96889688968897, 13.973897389738973, 13.978897889788982, 13.983898389838984, 13.988898889888993, 13.993899389938996, 13.998899889988998, 14.003900390039007, 14.00890089008901, 14.013901390139019, 14.01890189018902, 14.023902390239023, 14.028902890289032, 14.033903390339034, 14.038903890389044, 14.043904390439046, 14.048904890489048, 14.053905390539057, 14.05890589058906, 14.063906390639069, 14.068906890689071, 14.073907390739073, 14.078907890789083, 14.083908390839085, 14.088908890889094, 14.093909390939096, 14.098909890989098, 14.103910391039108, 14.10891089108911, 14.11391139113912, 14.118911891189121, 14.123912391239124, 14.128912891289133, 14.133913391339135, 14.138913891389144, 14.143914391439147, 14.148914891489149, 14.153915391539158, 14.15891589158916, 14.163916391639162, 14.168916891689172, 14.173917391739174, 14.178917891789183, 14.183918391839185, 14.188918891889188, 14.193919391939197, 14.198919891989199, 14.203920392039208, 14.20892089208921, 14.213921392139213, 14.218921892189222, 14.223922392239224, 14.228922892289233, 14.233923392339236, 14.238923892389238, 14.243924392439247, 14.24892489248925, 14.253925392539259, 14.25892589258926, 14.263926392639263, 14.268926892689272, 14.273927392739274, 14.278927892789284, 14.283928392839286, 14.288928892889288, 14.293929392939297, 14.2989298929893, 14.303930393039309, 14.308930893089311, 14.313931393139313, 14.318931893189323, 14.323932393239325, 14.328932893289334, 14.333933393339336, 14.338933893389338, 14.343934393439348, 14.34893489348935, 14.35393539353936, 14.358935893589361, 14.363936393639364, 14.368936893689373, 14.373937393739375, 14.378937893789384, 14.383938393839387, 14.388938893889389, 14.393939393939398, 14.3989398939894, 14.403940394039402, 14.408940894089412, 14.413941394139414, 14.418941894189423, 14.423942394239425, 14.428942894289428, 14.433943394339437, 14.438943894389439, 14.443944394439448, 14.44894489448945, 14.453945394539453, 14.458945894589462, 14.463946394639464, 14.468946894689473, 14.473947394739476, 14.478947894789478, 14.483948394839487, 14.48894889488949, 14.493949394939499, 14.4989498949895, 14.503950395039503, 14.508950895089512, 14.513951395139514, 14.518951895189524, 14.523952395239526, 14.528952895289528, 14.533953395339537, 14.53895389538954, 14.543954395439549, 14.548954895489551, 14.553955395539553, 14.558955895589563, 14.563956395639565, 14.568956895689574, 14.573957395739576, 14.578957895789578, 14.583958395839588, 14.58895889588959, 14.5939593959396, 14.598959895989601, 14.603960396039604, 14.608960896089613, 14.613961396139615, 14.618961896189624, 14.623962396239627, 14.628962896289629, 14.633963396339638, 14.63896389638964, 14.643964396439642, 14.648964896489652, 14.653965396539654, 14.658965896589663, 14.663966396639665, 14.668966896689668, 14.673967396739677, 14.678967896789679, 14.683968396839688, 14.68896889688969, 14.693969396939693, 14.698969896989702, 14.703970397039704, 14.708970897089714, 14.713971397139716, 14.718971897189718, 14.723972397239727, 14.72897289728973, 14.733973397339739, 14.73897389738974, 14.743974397439743, 14.748974897489752, 14.753975397539755, 14.758975897589764, 14.763976397639766, 14.768976897689768, 14.773977397739777, 14.77897789778978, 14.783978397839789, 14.788978897889791, 14.793979397939793, 14.798979897989803, 14.803980398039805, 14.808980898089814, 14.813981398139816, 14.818981898189818, 14.823982398239828, 14.82898289828983, 14.83398339833984, 14.838983898389841, 14.843984398439844, 14.848984898489853, 14.853985398539855, 14.858985898589864, 14.863986398639867, 14.868986898689869, 14.873987398739878, 14.87898789878988, 14.883988398839882, 14.888988898889892, 14.893989398939894, 14.898989898989903, 14.903990399039905, 14.908990899089908, 14.913991399139917, 14.918991899189919, 14.923992399239928, 14.92899289928993, 14.933993399339933, 14.938993899389942, 14.943994399439944, 14.948994899489954, 14.953995399539956, 14.958995899589958, 14.963996399639967, 14.96899689968997, 14.973997399739979, 14.97899789978998, 14.983998399839983, 14.988998899889992, 14.993999399939995, 14.998999899990004, 15.004000400040006, 15.009000900090008, 15.014001400140017, 15.01900190019002, 15.024002400240029, 15.029002900290031, 15.034003400340033, 15.039003900390043, 15.044004400440045, 15.049004900490054, 15.054005400540056, 15.059005900590059, 15.064006400640068, 15.06900690069007, 15.07400740074008, 15.079007900790081, 15.084008400840084, 15.089008900890093, 15.094009400940095, 15.099009900990104, 15.104010401040107, 15.109010901090109, 15.114011401140118, 15.11901190119012, 15.124012401240122, 15.129012901290132, 15.134013401340134, 15.139013901390143, 15.144014401440145, 15.149014901490148, 15.154015401540157, 15.159015901590159, 15.164016401640168, 15.16901690169017, 15.174017401740173, 15.179017901790182, 15.184018401840184, 15.189018901890194, 15.194019401940196, 15.199019901990198, 15.204020402040207, 15.20902090209021, 15.214021402140219, 15.21902190219022, 15.224022402240223, 15.229022902290232, 15.234023402340235, 15.239023902390244, 15.244024402440246, 15.249024902490248, 15.254025402540258, 15.25902590259026, 15.264026402640269, 15.269026902690271, 15.274027402740273, 15.279027902790283, 15.284028402840285, 15.289028902890294, 15.294029402940296, 15.299029902990299, 15.304030403040308, 15.30903090309031, 15.31403140314032, 15.319031903190321, 15.324032403240324, 15.329032903290333, 15.334033403340335, 15.339033903390344, 15.344034403440347, 15.349034903490349, 15.354035403540358, 15.35903590359036, 15.364036403640362, 15.369036903690372, 15.374037403740374, 15.379037903790383, 15.384038403840385, 15.389038903890388, 15.394039403940397, 15.3990399039904, 15.404040404040408, 15.40904090409041, 15.414041404140413, 15.419041904190422, 15.424042404240424, 15.429042904290434, 15.434043404340436, 15.439043904390438, 15.444044404440447, 15.44904490449045, 15.454045404540459, 15.459045904590461, 15.464046404640463, 15.469046904690472, 15.474047404740475, 15.479047904790484, 15.484048404840486, 15.489048904890488, 15.494049404940498, 15.4990499049905, 15.504050405040509, 15.509050905090511, 15.514051405140513, 15.519051905190523, 15.524052405240525, 15.529052905290534, 15.534053405340536, 15.539053905390539, 15.544054405440548, 15.54905490549055, 15.55405540554056, 15.559055905590562, 15.564056405640564, 15.569056905690573, 15.574057405740575, 15.579057905790584, 15.584058405840587, 15.589058905890589, 15.594059405940598, 15.5990599059906, 15.604060406040603, 15.609060906090612, 15.614061406140614, 15.619061906190623, 15.624062406240625, 15.629062906290628, 15.634063406340637, 15.63906390639064, 15.644064406440648, 15.64906490649065, 15.654065406540653, 15.659065906590662, 15.664066406640664, 15.669066906690674, 15.674067406740676, 15.679067906790678, 15.684068406840687, 15.68906890689069, 15.694069406940699, 15.699069906990701, 15.704070407040703, 15.709070907090712, 15.714071407140715, 15.719071907190724, 15.724072407240726, 15.729072907290728, 15.734073407340738, 15.73907390739074, 15.744074407440749, 15.749074907490751, 15.754075407540753, 15.759075907590763, 15.764076407640765, 15.769076907690774, 15.774077407740776, 15.779077907790779, 15.784078407840788, 15.78907890789079, 15.7940794079408, 15.799079907990802, 15.804080408040804, 15.809080908090813, 15.814081408140815, 15.819081908190824, 15.824082408240827, 15.829082908290829, 15.834083408340838, 15.83908390839084, 15.844084408440843, 15.849084908490852, 15.854085408540854, 15.859085908590863, 15.864086408640865, 15.869086908690868, 15.874087408740877, 15.87908790879088, 15.884088408840888, 15.88908890889089, 15.894089408940893, 15.899089908990902, 15.904090409040904, 15.909090909090914, 15.914091409140916, 15.919091909190918, 15.924092409240927, 15.92909290929093, 15.934093409340939, 15.939093909390941, 15.944094409440943, 15.949094909490952, 15.954095409540955, 15.959095909590964, 15.964096409640966, 15.969096909690968, 15.974097409740978, 15.97909790979098, 15.984098409840989, 15.989098909890991, 15.994099409940993, 15.999099909991003, 16.004100410041005, 16.009100910091014, 16.014101410141016, 16.01910191019102, 16.024102410241028, 16.02910291029103, 16.03410341034104, 16.03910391039104, 16.044104410441044, 16.049104910491053, 16.054105410541055, 16.059105910591065, 16.064106410641067, 16.06910691069107, 16.074107410741078, 16.07910791079108, 16.08410841084109, 16.089108910891092, 16.094109410941094, 16.099109910991103, 16.104110411041106, 16.109110911091108, 16.114111411141117, 16.11911191119112, 16.12411241124113, 16.12911291129113, 16.134113411341133, 16.139113911391142, 16.144114411441144, 16.149114911491154, 16.154115411541156, 16.159115911591158, 16.164116411641167, 16.16911691169117, 16.17411741174118, 16.17911791179118, 16.184118411841183, 16.189118911891192, 16.194119411941195, 16.199119911991204, 16.204120412041206, 16.20912091209121, 16.214121412141218, 16.21912191219122, 16.22412241224123, 16.22912291229123, 16.234123412341233, 16.239123912391243, 16.244124412441245, 16.249124912491254, 16.254125412541256, 16.25912591259126, 16.264126412641268, 16.26912691269127, 16.27412741274128, 16.27912791279128, 16.284128412841284, 16.289128912891293, 16.294129412941295, 16.299129912991305, 16.304130413041307, 16.30913091309131, 16.314131413141318, 16.31913191319132, 16.32413241324133, 16.329132913291332, 16.334133413341334, 16.339133913391343, 16.344134413441346, 16.349134913491348, 16.354135413541357, 16.35913591359136, 16.36413641364137, 16.36913691369137, 16.374137413741373, 16.379137913791382, 16.384138413841384, 16.389138913891394, 16.394139413941396, 16.399139913991398, 16.404140414041407, 16.40914091409141, 16.41414141414142, 16.41914191419142, 16.424142414241423, 16.429142914291432, 16.434143414341435, 16.439143914391444, 16.444144414441446, 16.44914491449145, 16.454145414541458, 16.45914591459146, 16.46414641464147, 16.46914691469147, 16.474147414741473, 16.479147914791483, 16.484148414841485, 16.489148914891494, 16.494149414941496, 16.4991499149915, 16.504150415041508, 16.50915091509151, 16.51415141514152, 16.51915191519152, 16.524152415241524, 16.529152915291533, 16.534153415341535, 16.539153915391545, 16.544154415441547, 16.54915491549155, 16.55415541554156, 16.55915591559156, 16.56415641564157, 16.569156915691572, 16.574157415741574, 16.579157915791583, 16.584158415841586, 16.589158915891588, 16.594159415941597, 16.5991599159916, 16.60416041604161, 16.60916091609161, 16.614161416141613, 16.619161916191622, 16.624162416241624, 16.629162916291634, 16.634163416341636, 16.639163916391638, 16.644164416441647, 16.64916491649165, 16.65416541654166, 16.65916591659166, 16.664166416641663, 16.669166916691672, 16.674167416741675, 16.679167916791684, 16.684168416841686, 16.68916891689169, 16.694169416941698, 16.6991699169917, 16.70417041704171, 16.70917091709171, 16.714171417141714, 16.719171917191723, 16.724172417241725, 16.729172917291734, 16.734173417341736, 16.73917391739174, 16.744174417441748, 16.74917491749175, 16.75417541754176, 16.75917591759176, 16.764176417641764, 16.769176917691773, 16.774177417741775, 16.779177917791785, 16.784178417841787, 16.78917891789179, 16.7941794179418, 16.7991799179918, 16.80418041804181, 16.809180918091812, 16.814181418141814, 16.819181918191823, 16.824182418241826, 16.829182918291828, 16.834183418341837, 16.83918391839184, 16.84418441844185, 16.84918491849185, 16.854185418541853, 16.859185918591862, 16.864186418641864, 16.869186918691874, 16.874187418741876, 16.879187918791878, 16.884188418841887, 16.88918891889189, 16.8941894189419, 16.8991899189919, 16.904190419041903, 16.909190919091913, 16.914191419141915, 16.919191919191924, 16.924192419241926, 16.92919291929193, 16.934193419341938, 16.93919391939194, 16.94419441944195, 16.94919491949195, 16.954195419541954, 16.959195919591963, 16.964196419641965, 16.969196919691974, 16.974197419741976, 16.97919791979198, 16.984198419841988, 16.98919891989199, 16.994199419942, 16.999199919992, 17.004200420042004, 17.009200920092013, 17.014201420142015, 17.019201920192025, 17.024202420242027, 17.02920292029203, 17.03420342034204, 17.03920392039204, 17.04420442044205, 17.049204920492052, 17.054205420542054, 17.059205920592063, 17.064206420642066, 17.069206920692068, 17.074207420742077, 17.07920792079208, 17.08420842084209, 17.08920892089209, 17.094209420942093, 17.099209920992102, 17.104210421042104, 17.109210921092114, 17.114211421142116, 17.119211921192118, 17.124212421242127, 17.12921292129213, 17.13421342134214, 17.13921392139214, 17.144214421442143, 17.149214921492153, 17.154215421542155, 17.159215921592164, 17.164216421642166, 17.16921692169217, 17.174217421742178, 17.17921792179218, 17.18421842184219, 17.18921892189219, 17.194219421942194, 17.199219921992203, 17.204220422042205, 17.209220922092214, 17.214221422142217, 17.21922192219222, 17.224222422242228, 17.22922292229223, 17.23422342234224, 17.23922392239224, 17.244224422442244, 17.249224922492253, 17.254225422542255, 17.259225922592265, 17.264226422642267, 17.26922692269227, 17.27422742274228, 17.27922792279228, 17.28422842284229, 17.289228922892292, 17.294229422942294, 17.299229922992303, 17.304230423042306, 17.309230923092308, 17.314231423142317, 17.31923192319232, 17.32423242324233, 17.32923292329233, 17.334233423342333, 17.339233923392342, 17.344234423442344, 17.349234923492354, 17.354235423542356, 17.359235923592358, 17.364236423642367, 17.36923692369237, 17.37423742374238, 17.37923792379238, 17.384238423842383, 17.389238923892393, 17.394239423942395, 17.399239923992404, 17.404240424042406, 17.40924092409241, 17.414241424142418, 17.41924192419242, 17.42424242424243, 17.42924292429243, 17.434243424342434, 17.439243924392443, 17.444244424442445, 17.449244924492454, 17.454245424542457, 17.45924592459246, 17.464246424642468, 17.46924692469247, 17.47424742474248, 17.47924792479248, 17.484248424842484, 17.489248924892493, 17.494249424942495, 17.499249924992505, 17.504250425042507, 17.50925092509251, 17.51425142514252, 17.51925192519252, 17.52425242524253, 17.529252925292532, 17.534253425342534, 17.539253925392543, 17.544254425442546, 17.549254925492548, 17.554255425542557, 17.55925592559256, 17.56425642564257, 17.56925692569257, 17.574257425742573, 17.579257925792582, 17.584258425842584, 17.589258925892594, 17.594259425942596, 17.599259925992598, 17.604260426042607, 17.60926092609261, 17.61426142614262, 17.61926192619262, 17.624262426242623, 17.629262926292633, 17.634263426342635, 17.639263926392644, 17.644264426442646, 17.64926492649265, 17.654265426542658, 17.65926592659266, 17.66426642664267, 17.66926692669267, 17.674267426742674, 17.679267926792683, 17.684268426842685, 17.689268926892694, 17.694269426942697, 17.6992699269927, 17.704270427042708, 17.70927092709271, 17.71427142714272, 17.71927192719272, 17.724272427242724, 17.729272927292733, 17.734273427342735, 17.739273927392745, 17.744274427442747, 17.74927492749275, 17.75427542754276, 17.75927592759276, 17.76427642764277, 17.769276927692772, 17.774277427742774, 17.779277927792783, 17.784278427842786, 17.789278927892788, 17.794279427942797, 17.7992799279928, 17.80428042804281, 17.80928092809281, 17.814281428142813, 17.819281928192822, 17.824282428242824, 17.829282928292834, 17.834283428342836, 17.839283928392838, 17.844284428442847, 17.84928492849285, 17.85428542854286, 17.85928592859286, 17.864286428642863, 17.869286928692873, 17.874287428742875, 17.879287928792884, 17.884288428842886, 17.88928892889289, 17.894289428942898, 17.8992899289929, 17.90429042904291, 17.90929092909291, 17.914291429142914, 17.919291929192923, 17.924292429242925, 17.929292929292934, 17.934293429342937, 17.93929392939294, 17.944294429442948, 17.94929492949295, 17.95429542954296, 17.95929592959296, 17.964296429642964, 17.969296929692973, 17.974297429742975, 17.979297929792985, 17.984298429842987, 17.98929892989299, 17.994299429943, 17.999299929993, 18.00430043004301, 18.009300930093012, 18.014301430143014, 18.019301930193024, 18.024302430243026, 18.029302930293028, 18.034303430343037, 18.03930393039304, 18.04430443044305, 18.04930493049305, 18.054305430543053, 18.059305930593062, 18.064306430643065, 18.069306930693074, 18.074307430743076, 18.079307930793078, 18.084308430843087, 18.08930893089309, 18.0943094309431, 18.0993099309931, 18.104310431043103, 18.109310931093113, 18.114311431143115, 18.119311931193124, 18.124312431243126, 18.12931293129313, 18.134313431343138, 18.13931393139314, 18.14431443144315, 18.14931493149315, 18.154315431543154, 18.159315931593163, 18.164316431643165, 18.169316931693174, 18.174317431743177, 18.17931793179318, 18.184318431843188, 18.18931893189319, 18.1943194319432, 18.1993199319932, 18.204320432043204, 18.209320932093213, 18.214321432143215, 18.219321932193225, 18.224322432243227, 18.22932293229323, 18.23432343234324, 18.23932393239324, 18.24432443244325, 18.249324932493252, 18.254325432543254, 18.259325932593264, 18.264326432643266, 18.269326932693268, 18.274327432743277, 18.27932793279328, 18.28432843284329, 18.28932893289329, 18.294329432943293, 18.299329932993302, 18.304330433043305, 18.309330933093314, 18.314331433143316, 18.319331933193318, 18.324332433243328, 18.32933293329333, 18.33433343334334, 18.33933393339334, 18.344334433443343, 18.349334933493353, 18.354335433543355, 18.359335933593364, 18.364336433643366, 18.36933693369337, 18.374337433743378, 18.37933793379338, 18.38433843384339, 18.38933893389339, 18.394339433943394, 18.399339933993403, 18.404340434043405, 18.409340934093414, 18.414341434143417, 18.41934193419342, 18.424342434243428, 18.42934293429343, 18.43434343434344, 18.43934393439344, 18.444344434443444, 18.449344934493453, 18.454345434543455, 18.459345934593465, 18.464346434643467, 18.46934693469347, 18.47434743474348, 18.47934793479348, 18.48434843484349, 18.489348934893492, 18.494349434943494, 18.499349934993504, 18.504350435043506, 18.509350935093508, 18.514351435143517, 18.51935193519352, 18.52435243524353, 18.52935293529353, 18.534353435343533, 18.539353935393542, 18.544354435443545, 18.549354935493554, 18.554355435543556, 18.55935593559356, 18.564356435643568, 18.56935693569357, 18.57435743574358, 18.57935793579358, 18.584358435843583, 18.589358935893593, 18.594359435943595, 18.599359935993604, 18.604360436043606, 18.60936093609361, 18.614361436143618, 18.61936193619362, 18.62436243624363, 18.62936293629363, 18.634363436343634, 18.639363936393643, 18.644364436443645, 18.649364936493654, 18.654365436543657, 18.65936593659366, 18.664366436643668, 18.66936693669367, 18.67436743674368, 18.679367936793682, 18.684368436843684, 18.689368936893693, 18.694369436943695, 18.699369936993705, 18.704370437043707, 18.70937093709371, 18.71437143714372, 18.71937193719372, 18.72437243724373, 18.729372937293732, 18.734373437343734, 18.739373937393744, 18.744374437443746, 18.749374937493755, 18.754375437543757, 18.75937593759376, 18.76437643764377, 18.76937693769377, 18.774377437743773, 18.779377937793782, 18.784378437843785, 18.789378937893794, 18.794379437943796, 18.7993799379938, 18.804380438043808, 18.80938093809381, 18.81438143814382, 18.81938193819382, 18.824382438243823, 18.829382938293833, 18.834383438343835, 18.839383938393844, 18.844384438443846, 18.84938493849385, 18.854385438543858, 18.85938593859386, 18.86438643864387, 18.86938693869387, 18.874387438743874, 18.879387938793883, 18.884388438843885, 18.889388938893894, 18.894389438943897, 18.8993899389939, 18.904390439043908, 18.90939093909391, 18.91439143914392, 18.919391939193922, 18.924392439243924, 18.929392939293933, 18.934393439343935, 18.939393939393945, 18.944394439443947, 18.94939493949395, 18.95439543954396, 18.95939593959396, 18.96439643964397, 18.969396939693972, 18.974397439743974, 18.979397939793984, 18.984398439843986, 18.989398939893995, 18.994399439943997, 18.999399939994, 19.00440044004401, 19.00940094009401, 19.014401440144013, 19.019401940194022, 19.024402440244025, 19.029402940294034, 19.034403440344036, 19.03940394039404, 19.044404440444048, 19.04940494049405, 19.05440544054406, 19.05940594059406, 19.064406440644063, 19.069406940694073, 19.074407440744075, 19.079407940794084, 19.084408440844086, 19.08940894089409, 19.094409440944098, 19.0994099409941, 19.10441044104411, 19.10941094109411, 19.114411441144114, 19.119411941194123, 19.124412441244125, 19.129412941294134, 19.134413441344137, 19.13941394139414, 19.144414441444148, 19.14941494149415, 19.15441544154416, 19.159415941594162, 19.164416441644164, 19.169416941694173, 19.174417441744176, 19.179417941794185, 19.184418441844187, 19.18941894189419, 19.1944194419442, 19.1994199419942, 19.20442044204421, 19.209420942094212, 19.214421442144214, 19.219421942194224, 19.224422442244226, 19.229422942294235, 19.234423442344237, 19.23942394239424, 19.24442444244425, 19.24942494249425, 19.254425442544253, 19.259425942594262, 19.264426442644265, 19.269426942694274, 19.274427442744276, 19.27942794279428, 19.284428442844288, 19.28942894289429, 19.2944294429443, 19.2994299429943, 19.304430443044303, 19.309430943094313, 19.314431443144315, 19.319431943194324, 19.324432443244326, 19.32943294329433, 19.334433443344338, 19.33943394339434, 19.34443444344435, 19.34943494349435, 19.354435443544354, 19.359435943594363, 19.364436443644365, 19.369436943694375, 19.374437443744377, 19.37943794379438, 19.384438443844388, 19.38943894389439, 19.3944394439444, 19.399439943994402, 19.404440444044404, 19.409440944094413, 19.414441444144416, 19.419441944194425, 19.424442444244427, 19.42944294429443, 19.43444344434444, 19.43944394439444, 19.44444444444445, 19.449444944494452, 19.454445444544454, 19.459445944594464, 19.464446444644466, 19.469446944694475, 19.474447444744477, 19.47944794479448, 19.48444844484449, 19.48944894489449, 19.494449444944493, 19.499449944994502, 19.504450445044505, 19.509450945094514, 19.514451445144516, 19.51945194519452, 19.524452445244528, 19.52945294529453, 19.53445344534454, 19.53945394539454, 19.544454445444543, 19.549454945494553, 19.554455445544555, 19.559455945594564, 19.564456445644566, 19.56945694569457, 19.574457445744578, 19.57945794579458, 19.58445844584459, 19.58945894589459, 19.594459445944594, 19.599459945994603, 19.604460446044605, 19.609460946094615, 19.614461446144617, 19.61946194619462, 19.624462446244628, 19.62946294629463, 19.63446344634464, 19.639463946394642, 19.644464446444644, 19.649464946494653, 19.654465446544656, 19.659465946594665, 19.664466446644667, 19.66946694669467, 19.67446744674468, 19.67946794679468, 19.68446844684469, 19.689468946894692, 19.694469446944694, 19.699469946994704, 19.704470447044706, 19.709470947094715, 19.714471447144717, 19.71947194719472, 19.72447244724473, 19.72947294729473, 19.734473447344733, 19.739473947394742, 19.744474447444745, 19.749474947494754, 19.754475447544756, 19.75947594759476, 19.764476447644768, 19.76947694769477, 19.77447744774478, 19.77947794779478, 19.784478447844783, 19.789478947894793, 19.794479447944795, 19.799479947994804, 19.804480448044806, 19.80948094809481, 19.814481448144818, 19.81948194819482, 19.82448244824483, 19.82948294829483, 19.834483448344834, 19.839483948394843, 19.844484448444845, 19.849484948494855, 19.854485448544857, 19.85948594859486, 19.86448644864487, 19.86948694869487, 19.87448744874488, 19.879487948794882, 19.884488448844884, 19.889488948894893, 19.894489448944896, 19.899489948994905, 19.904490449044907, 19.90949094909491, 19.91449144914492, 19.91949194919492, 19.92449244924493, 19.929492949294932, 19.934493449344934, 19.939493949394944, 19.944494449444946, 19.949494949494955, 19.954495449544957, 19.95949594959496, 19.96449644964497, 19.96949694969497, 19.974497449744973, 19.979497949794983, 19.984498449844985, 19.989498949894994, 19.994499449944996, 19.999499949995, 20.004500450045008, 20.00950095009501, 20.01450145014502, 20.01950195019502, 20.024502450245024, 20.029502950295033, 20.034503450345035, 20.039503950395044, 20.044504450445046, 20.04950495049505, 20.054505450545058, 20.05950595059506, 20.06450645064507, 20.06950695069507, 20.074507450745074, 20.079507950795083, 20.084508450845085, 20.089508950895095, 20.094509450945097, 20.0995099509951, 20.10451045104511, 20.10951095109511, 20.11451145114512, 20.119511951195122, 20.124512451245124, 20.129512951295133, 20.134513451345136, 20.139513951395145, 20.144514451445147, 20.14951495149515, 20.15451545154516, 20.15951595159516, 20.16451645164517, 20.169516951695172, 20.174517451745174, 20.179517951795184, 20.184518451845186, 20.189518951895195, 20.194519451945197, 20.1995199519952, 20.20452045204521, 20.20952095209521, 20.214521452145213, 20.219521952195223, 20.224522452245225, 20.229522952295234, 20.234523452345236, 20.23952395239524, 20.244524452445248, 20.24952495249525, 20.25452545254526, 20.25952595259526, 20.264526452645264, 20.269526952695273, 20.274527452745275, 20.279527952795284, 20.284528452845286, 20.28952895289529, 20.294529452945298, 20.2995299529953, 20.30453045304531, 20.30953095309531, 20.314531453145314, 20.319531953195323, 20.324532453245325, 20.329532953295335, 20.334533453345337, 20.33953395339534, 20.34453445344535, 20.34953495349535, 20.35453545354536, 20.359535953595362, 20.364536453645364, 20.369536953695373, 20.374537453745376, 20.379537953795385, 20.384538453845387, 20.38953895389539, 20.3945394539454, 20.3995399539954, 20.40454045404541, 20.409540954095412, 20.414541454145414, 20.419541954195424, 20.424542454245426, 20.429542954295435, 20.434543454345437, 20.43954395439544, 20.44454445444545, 20.44954495449545, 20.454545454545453, 20.459545954595463, 20.464546454645465, 20.469546954695474, 20.474547454745476, 20.47954795479548, 20.484548454845488, 20.48954895489549, 20.4945494549455, 20.4995499549955, 20.504550455045504, 20.509550955095513, 20.514551455145515, 20.519551955195524, 20.524552455245527, 20.52955295529553, 20.534553455345538, 20.53955395539554, 20.54455445544555, 20.54955495549555, 20.554555455545554, 20.559555955595563, 20.564556455645565, 20.569556955695575, 20.574557455745577, 20.57955795579558, 20.58455845584559, 20.58955895589559, 20.5945594559456, 20.599559955995602, 20.604560456045604, 20.609560956095613, 20.614561456145616, 20.619561956195625, 20.624562456245627, 20.62956295629563, 20.63456345634564, 20.63956395639564, 20.64456445644565, 20.649564956495652, 20.654565456545654, 20.659565956595664, 20.664566456645666, 20.669566956695675, 20.674567456745677, 20.67956795679568, 20.68456845684569, 20.68956895689569, 20.694569456945693, 20.699569956995703, 20.704570457045705, 20.709570957095714, 20.714571457145716, 20.71957195719572, 20.724572457245728, 20.72957295729573, 20.73457345734574, 20.73957395739574, 20.744574457445744, 20.749574957495753, 20.754575457545755, 20.759575957595764, 20.764576457645767, 20.76957695769577, 20.774577457745778, 20.77957795779578, 20.78457845784579, 20.78957895789579, 20.794579457945794, 20.799579957995803, 20.804580458045805, 20.809580958095815, 20.814581458145817, 20.81958195819582, 20.82458245824583, 20.82958295829583, 20.83458345834584, 20.839583958395842, 20.844584458445844, 20.849584958495853, 20.854585458545856, 20.859585958595865, 20.864586458645867, 20.86958695869587, 20.87458745874588, 20.87958795879588, 20.88458845884589, 20.889588958895892, 20.894589458945894, 20.899589958995904, 20.904590459045906, 20.909590959095915, 20.914591459145917, 20.91959195919592, 20.92459245924593, 20.92959295929593, 20.934593459345933, 20.939593959395943, 20.944594459445945, 20.949594959495954, 20.954595459545956, 20.95959595959596, 20.964596459645968, 20.96959695969597, 20.97459745974598, 20.97959795979598, 20.984598459845984, 20.989598959895993, 20.994599459945995, 20.999599959996004, 21.004600460046007, 21.00960096009601, 21.014601460146018, 21.01960196019602, 21.02460246024603, 21.02960296029603, 21.034603460346034, 21.039603960396043, 21.044604460446045, 21.049604960496055, 21.054605460546057, 21.05960596059606, 21.06460646064607, 21.06960696069607, 21.07460746074608, 21.079607960796082, 21.084608460846084, 21.089608960896093, 21.094609460946096, 21.099609960996105, 21.104610461046107, 21.10961096109611, 21.11461146114612, 21.11961196119612, 21.12461246124613, 21.129612961296132, 21.134613461346134, 21.139613961396144, 21.144614461446146, 21.149614961496155, 21.154615461546157, 21.15961596159616, 21.16461646164617, 21.16961696169617, 21.17461746174618, 21.179617961796183, 21.184618461846185, 21.189618961896194, 21.194619461946196, 21.1996199619962, 21.204620462046208, 21.20962096209621, 21.21462146214622, 21.21962196219622, 21.224622462246224, 21.229622962296233, 21.234623462346235, 21.239623962396244, 21.244624462446247, 21.24962496249625, 21.254625462546258, 21.25962596259626, 21.26462646264627, 21.26962696269627, 21.274627462746274, 21.279627962796283, 21.284628462846285, 21.289628962896295, 21.294629462946297, 21.2996299629963, 21.30463046304631, 21.30963096309631, 21.31463146314632, 21.319631963196322, 21.324632463246324, 21.329632963296334, 21.334633463346336, 21.339633963396345, 21.344634463446347, 21.34963496349635, 21.35463546354636, 21.35963596359636, 21.36463646364637, 21.369636963696372, 21.374637463746375, 21.379637963796384, 21.384638463846386, 21.389638963896395, 21.394639463946397, 21.3996399639964, 21.40464046404641, 21.40964096409641, 21.41464146414642, 21.419641964196423, 21.424642464246425, 21.429642964296434, 21.434643464346436, 21.43964396439644, 21.444644464446448, 21.44964496449645, 21.45464546454646, 21.45964596459646, 21.464646464646464, 21.469646964696473, 21.474647464746475, 21.479647964796484, 21.484648464846487, 21.48964896489649, 21.494649464946498, 21.4996499649965, 21.50465046504651, 21.50965096509651, 21.514651465146514, 21.519651965196523, 21.524652465246525, 21.529652965296535, 21.534653465346537, 21.53965396539654, 21.54465446544655, 21.54965496549655, 21.55465546554656, 21.559655965596562, 21.564656465646564, 21.569656965696574, 21.574657465746576, 21.579657965796585, 21.584658465846587, 21.58965896589659, 21.5946594659466, 21.5996599659966, 21.60466046604661, 21.609660966096612, 21.614661466146615, 21.619661966196624, 21.624662466246626, 21.629662966296635, 21.634663466346638, 21.63966396639664, 21.64466446644665, 21.64966496649665, 21.65466546654666, 21.659665966596663, 21.664666466646665, 21.669666966696674, 21.674667466746676, 21.67966796679668, 21.684668466846688, 21.68966896689669, 21.6946694669467, 21.6996699669967, 21.704670467046704, 21.709670967096713, 21.714671467146715, 21.719671967196724, 21.724672467246727, 21.72967296729673, 21.734673467346738, 21.73967396739674, 21.74467446744675, 21.74967496749675, 21.754675467546754, 21.759675967596763, 21.764676467646765, 21.769676967696775, 21.774677467746777, 21.77967796779678, 21.78467846784679, 21.78967896789679, 21.7946794679468, 21.799679967996802, 21.804680468046804, 21.809680968096814, 21.814681468146816, 21.819681968196825, 21.824682468246827, 21.82968296829683, 21.83468346834684, 21.83968396839684, 21.84468446844685, 21.849684968496852, 21.854685468546855, 21.859685968596864, 21.864686468646866, 21.869686968696875, 21.874687468746878, 21.87968796879688, 21.88468846884689, 21.88968896889689, 21.8946894689469, 21.899689968996903, 21.904690469046905, 21.909690969096914, 21.914691469146916, 21.91969196919692, 21.924692469246928, 21.92969296929693, 21.93469346934694, 21.93969396939694, 21.944694469446944, 21.949694969496953, 21.954695469546955, 21.959695969596964, 21.964696469646967, 21.96969696969697, 21.974697469746978, 21.97969796979698, 21.98469846984699, 21.989698969896992, 21.994699469946994, 21.999699969997003, 22.004700470047005, 22.009700970097015, 22.014701470147017, 22.01970197019702, 22.02470247024703, 22.02970297029703, 22.03470347034704, 22.039703970397042, 22.044704470447044, 22.049704970497054, 22.054705470547056, 22.059705970597065, 22.064706470647067, 22.06970697069707, 22.07470747074708, 22.07970797079708, 22.08470847084709, 22.089708970897092, 22.094709470947095, 22.099709970997104, 22.104710471047106, 22.109710971097115, 22.114711471147118, 22.11971197119712, 22.12471247124713, 22.12971297129713, 22.13471347134714, 22.139713971397143, 22.144714471447145, 22.149714971497154, 22.154715471547156, 22.15971597159716, 22.164716471647168, 22.16971697169717, 22.17471747174718, 22.17971797179718, 22.184718471847184, 22.189718971897193, 22.194719471947195, 22.199719971997204, 22.204720472047207, 22.20972097209721, 22.214721472147218, 22.21972197219722, 22.22472247224723, 22.229722972297232, 22.234723472347234, 22.239723972397243, 22.244724472447245, 22.249724972497255, 22.254725472547257, 22.25972597259726, 22.26472647264727, 22.26972697269727, 22.27472747274728, 22.279727972797282, 22.284728472847284, 22.289728972897294, 22.294729472947296, 22.299729972997305, 22.304730473047307, 22.30973097309731, 22.31473147314732, 22.31973197319732, 22.32473247324733, 22.329732973297332, 22.334733473347335, 22.339733973397344, 22.344734473447346, 22.349734973497355, 22.354735473547358, 22.35973597359736, 22.36473647364737, 22.36973697369737, 22.37473747374738, 22.379737973797383, 22.384738473847385, 22.389738973897394, 22.394739473947396, 22.3997399739974, 22.404740474047408, 22.40974097409741, 22.41474147414742, 22.41974197419742, 22.424742474247424, 22.429742974297433, 22.434743474347435, 22.439743974397445, 22.444744474447447, 22.44974497449745, 22.454745474547458, 22.45974597459746, 22.46474647464747, 22.469746974697472, 22.474747474747474, 22.479747974797483, 22.484748474847486, 22.489748974897495, 22.494749474947497, 22.4997499749975, 22.50475047504751, 22.50975097509751, 22.51475147514752, 22.519751975197522, 22.524752475247524, 22.529752975297534, 22.534753475347536, 22.539753975397545, 22.544754475447547, 22.54975497549755, 22.55475547554756, 22.55975597559756, 22.56475647564757, 22.569756975697572, 22.574757475747575, 22.579757975797584, 22.584758475847586, 22.589758975897595, 22.594759475947598, 22.5997599759976, 22.60476047604761, 22.60976097609761, 22.61476147614762, 22.619761976197623, 22.624762476247625, 22.629762976297634, 22.634763476347636, 22.63976397639764, 22.644764476447648, 22.64976497649765, 22.65476547654766, 22.65976597659766, 22.664766476647664, 22.669766976697673, 22.674767476747675, 22.679767976797685, 22.684768476847687, 22.68976897689769, 22.694769476947698, 22.6997699769977, 22.70477047704771, 22.709770977097712, 22.714771477147714, 22.719771977197723, 22.724772477247726, 22.729772977297735, 22.734773477347737, 22.73977397739774, 22.74477447744775, 22.74977497749775, 22.75477547754776, 22.759775977597762, 22.764776477647764, 22.769776977697774, 22.774777477747776, 22.779777977797785, 22.784778477847787, 22.78977897789779, 22.7947794779478, 22.7997799779978, 22.80478047804781, 22.809780978097812, 22.814781478147815, 22.819781978197824, 22.824782478247826, 22.829782978297835, 22.834783478347838, 22.83978397839784, 22.84478447844785, 22.84978497849785, 22.85478547854786, 22.859785978597863, 22.864786478647865, 22.869786978697874, 22.874787478747876, 22.87978797879788, 22.884788478847888, 22.88978897889789, 22.8947894789479, 22.8997899789979, 22.904790479047904, 22.909790979097913, 22.914791479147915, 22.919791979197925, 22.924792479247927, 22.92979297929793, 22.934793479347938, 22.93979397939794, 22.94479447944795, 22.949794979497952, 22.954795479547954, 22.959795979597963, 22.964796479647966, 22.969796979697975, 22.974797479747977, 22.97979797979798, 22.98479847984799, 22.98979897989799, 22.994799479948, 22.999799979998002, 23.004800480048004, 23.009800980098014, 23.014801480148016, 23.019801980198025, 23.024802480248027, 23.02980298029803, 23.03480348034804, 23.03980398039804, 23.04480448044805, 23.049804980498052, 23.054805480548055, 23.059805980598064, 23.064806480648066, 23.069806980698075, 23.074807480748078, 23.07980798079808, 23.08480848084809, 23.08980898089809, 23.0948094809481, 23.099809980998103, 23.104810481048105, 23.109810981098114, 23.114811481148116, 23.11981198119812, 23.124812481248128, 23.12981298129813, 23.13481348134814, 23.13981398139814, 23.144814481448144, 23.149814981498153, 23.154815481548155, 23.159815981598165, 23.164816481648167, 23.16981698169817, 23.17481748174818, 23.17981798179818, 23.18481848184819, 23.189818981898192, 23.194819481948194, 23.199819981998203, 23.204820482048206, 23.209820982098215, 23.214821482148217, 23.21982198219822, 23.22482248224823, 23.22982298229823, 23.23482348234824, 23.239823982398242, 23.244824482448244, 23.249824982498254, 23.254825482548256, 23.259825982598265, 23.264826482648267, 23.26982698269827, 23.27482748274828, 23.27982798279828, 23.28482848284829, 23.289828982898293, 23.294829482948295, 23.299829982998304, 23.304830483048306, 23.309830983098315, 23.314831483148318, 23.31983198319832, 23.32483248324833, 23.32983298329833, 23.33483348334834, 23.339833983398343, 23.344834483448345, 23.349834983498354, 23.354835483548356, 23.35983598359836, 23.364836483648368, 23.36983698369837, 23.37483748374838, 23.37983798379838, 23.384838483848384, 23.389838983898393, 23.394839483948395, 23.399839983998405, 23.404840484048407, 23.40984098409841, 23.41484148414842, 23.41984198419842, 23.42484248424843, 23.429842984298432, 23.434843484348434, 23.439843984398443, 23.444844484448446, 23.449844984498455, 23.454845484548457, 23.45984598459846, 23.46484648464847, 23.46984698469847, 23.47484748474848, 23.479847984798482, 23.484848484848484, 23.489848984898494, 23.494849484948496, 23.499849984998505, 23.504850485048507, 23.50985098509851, 23.51485148514852, 23.51985198519852, 23.52485248524853, 23.529852985298533, 23.534853485348535, 23.539853985398544, 23.544854485448546, 23.549854985498555, 23.554855485548558, 23.55985598559856, 23.56485648564857, 23.56985698569857, 23.57485748574858, 23.579857985798583, 23.584858485848585, 23.589858985898594, 23.594859485948597, 23.5998599859986, 23.604860486048608, 23.60986098609861, 23.61486148614862, 23.61986198619862, 23.624862486248624, 23.629862986298633, 23.634863486348635, 23.639863986398645, 23.644864486448647, 23.64986498649865, 23.65486548654866, 23.65986598659866, 23.66486648664867, 23.669866986698672, 23.674867486748674, 23.679867986798683, 23.684868486848686, 23.689868986898695, 23.694869486948697, 23.6998699869987, 23.70487048704871, 23.70987098709871, 23.71487148714872, 23.719871987198722, 23.724872487248724, 23.729872987298734, 23.734873487348736, 23.739873987398745, 23.744874487448747, 23.74987498749875, 23.75487548754876, 23.75987598759876, 23.76487648764877, 23.769876987698773, 23.774877487748775, 23.779877987798784, 23.784878487848786, 23.789878987898796, 23.794879487948798, 23.7998799879988, 23.80488048804881, 23.80988098809881, 23.81488148814882, 23.819881988198823, 23.824882488248825, 23.829882988298834, 23.834883488348837, 23.839883988398846, 23.844884488448848, 23.84988498849885, 23.85488548854886, 23.85988598859886, 23.864886488648864, 23.869886988698873, 23.874887488748875, 23.879887988798885, 23.884888488848887, 23.88988898889889, 23.8948894889489, 23.8998899889989, 23.90489048904891, 23.909890989098912, 23.914891489148914, 23.919891989198923, 23.924892489248926, 23.929892989298935, 23.934893489348937, 23.93989398939894, 23.94489448944895, 23.94989498949895, 23.95489548954896, 23.959895989598962, 23.964896489648964, 23.969896989698974, 23.974897489748976, 23.979897989798985, 23.984898489848987, 23.98989898989899, 23.994899489949, 23.999899989999, 24.00490049004901, 24.009900990099013, 24.014901490149015, 24.019901990199024, 24.024902490249026, 24.029902990299036, 24.034903490349038, 24.03990399039904, 24.04490449044905, 24.04990499049905, 24.05490549054906, 24.059905990599063, 24.064906490649065, 24.069906990699074, 24.074907490749077, 24.079907990799086, 24.084908490849088, 24.08990899089909, 24.0949094909491, 24.0999099909991, 24.104910491049104, 24.109910991099113, 24.114911491149115, 24.119911991199125, 24.124912491249127, 24.12991299129913, 24.13491349134914, 24.13991399139914, 24.14491449144915, 24.149914991499152, 24.154915491549154, 24.159915991599163, 24.164916491649166, 24.169916991699175, 24.174917491749177, 24.17991799179918, 24.18491849184919, 24.18991899189919, 24.1949194919492, 24.199919991999202, 24.204920492049204, 24.209920992099214, 24.214921492149216, 24.219921992199225, 24.224922492249227, 24.22992299229923, 24.23492349234924, 24.23992399239924, 24.24492449244925, 24.249924992499253, 24.254925492549255, 24.259925992599264, 24.264926492649266, 24.269926992699276, 24.274927492749278, 24.27992799279928, 24.28492849284929, 24.28992899289929, 24.2949294929493, 24.299929992999303, 24.304930493049305, 24.309930993099314, 24.314931493149317, 24.319931993199326, 24.324932493249328, 24.32993299329933, 24.33493349334934, 24.33993399339934, 24.344934493449344, 24.349934993499353, 24.354935493549355, 24.359935993599365, 24.364936493649367, 24.36993699369937, 24.37493749374938, 24.37993799379938, 24.38493849384939, 24.389938993899392, 24.394939493949394, 24.399939993999403, 24.404940494049406, 24.409940994099415, 24.414941494149417, 24.41994199419942, 24.42494249424943, 24.42994299429943, 24.43494349434944, 24.439943994399442, 24.444944494449445, 24.449944994499454, 24.454945494549456, 24.459945994599465, 24.464946494649467, 24.46994699469947, 24.47494749474948, 24.47994799479948, 24.48494849484949, 24.489948994899493, 24.494949494949495, 24.499949994999504, 24.504950495049506, 24.509950995099516, 24.514951495149518, 24.51995199519952, 24.52495249524953, 24.52995299529953, 24.53495349534954, 24.539953995399543, 24.544954495449545, 24.549954995499554, 24.554955495549557, 24.559955995599566, 24.564956495649568, 24.56995699569957, 24.57495749574958, 24.57995799579958, 24.584958495849584, 24.589958995899593, 24.594959495949595, 24.599959995999605, 24.604960496049607, 24.60996099609961, 24.61496149614962, 24.61996199619962, 24.62496249624963, 24.629962996299632, 24.634963496349634, 24.639963996399644, 24.644964496449646, 24.649964996499655, 24.654965496549657, 24.65996599659966, 24.66496649664967, 24.66996699669967, 24.67496749674968, 24.679967996799682, 24.684968496849685, 24.689968996899694, 24.694969496949696, 24.699969996999705, 24.704970497049707, 24.70997099709971, 24.71497149714972, 24.71997199719972, 24.72497249724973, 24.729972997299733, 24.734973497349735, 24.739973997399744, 24.744974497449746, 24.749974997499756, 24.754975497549758, 24.75997599759976, 24.76497649764977, 24.76997699769977, 24.77497749774978, 24.779977997799783, 24.784978497849785, 24.789978997899794, 24.794979497949797, 24.799979997999806, 24.804980498049808, 24.80998099809981, 24.81498149814982, 24.81998199819982, 24.824982498249824, 24.829982998299833, 24.834983498349835, 24.839983998399845, 24.844984498449847, 24.84998499849985, 24.85498549854986, 24.85998599859986, 24.86498649864987, 24.869986998699872, 24.874987498749874, 24.879987998799884, 24.884988498849886, 24.889988998899895, 24.894989498949897, 24.8999899989999, 24.90499049904991, 24.90999099909991, 24.91499149914992, 24.919991999199922, 24.924992499249925, 24.929992999299934, 24.934993499349936, 24.939993999399945, 24.944994499449948, 24.94999499949995, 24.95499549954996, 24.95999599959996, 24.96499649964997, 24.969996999699973, 24.974997499749975, 24.979997999799984, 24.984998499849986, 24.989998999899996, 24.994999499949998, 25.0], \"y\": [25.133526407021535, 25.133619005550823, 25.133718669770847, 25.133825669996508, 25.13394027805574, 25.13406276734902, 25.134193412909497, 25.134332491463944, 25.13448028149438, 25.134637063300527, 25.134803119063072, 25.134978732907786, 25.1351641909705, 25.135359781463027, 25.135565794740007, 25.13578252336674, 25.136010262188034, 25.13624930839811, 25.136499961611595, 25.13676252393562, 25.13703730004312, 25.137324597247293, 25.137624725577354, 25.137937997855513, 25.138264729775344, 25.13860523998147, 25.138959850150705, 25.139328885074622, 25.139712672743673, 25.140111544432816, 25.140525834788786, 25.140955881919012, 25.141402027482247, 25.14186461678095, 25.14234399885551, 25.142840526580326, 25.14335455676184, 25.143886450238558, 25.144436571983135, 25.145005291206587, 25.145592981464674, 25.146200020766575, 25.146826791685857, 25.147473681473873, 25.148141082175623, 25.148829390748173, 25.149539009181687, 25.150270344623227, 25.151023809503293, 25.151799821665282, 25.15259880449793, 25.153421187070798, 25.15426740427296, 25.15513789695494, 25.156033112074006, 25.156953502842974, 25.157899528882567, 25.158871656377496, 25.159870358236336, 25.16089611425538, 25.161949411286496, 25.163030743409244, 25.164140612107282, 25.16527952644924, 25.166448003274237, 25.167646567382125, 25.168875751728663, 25.170136097625782, 25.17142815494706, 25.17275248233863, 25.1741096474357, 25.17550022708479, 25.17692480757201, 25.17838398485744, 25.179878364815924, 25.18140856348443, 25.18297520731621, 25.184578933442026, 25.186220389938615, 25.18790023610469, 25.18961914274472, 25.19137779246079, 25.19317687995269, 25.195017112326727, 25.196899209413367, 25.198823904094144, 25.20079194263808, 25.20280408504802, 25.204861105417145, 25.20696379229615, 25.209112949071336, 25.21130939435408, 25.213553962382093, 25.215847503432872, 25.218190884249793, 25.22058498848132, 25.22303071713379, 25.225528989038292, 25.22808074133218, 25.230686929955713, 25.23334853016444, 25.236066537057905, 25.238841966125264, 25.241675853808527, 25.244569258084024, 25.24752325906283, 25.250538959610893, 25.25361748598959, 25.256759988517583, 25.259967642254722, 25.26324164770893, 25.266583231566976, 25.269993647450043, 25.273474176695164, 25.277026129163502, 25.280650844076597, 25.284349690881736, 25.288124070147603, 25.29197541449149, 25.295905189539404, 25.29991489492036, 25.304006065296413, 25.308180271429855, 25.312439121289188, 25.316784261195554, 25.321217377011326, 25.32574019537272, 25.330354484968353, 25.33506205786571, 25.33986477088772, 25.34476452704159, 25.349763277002303, 25.354863020653163, 25.360065808686066, 25.365373744264144, 25.37078898474966, 25.376313743500216, 25.381950291736395, 25.387700960484217, 25.393568142595882, 25.399554294852624, 25.405661940153458, 25.41189366979407, 25.41825214584016, 25.424740103599824, 25.4313603541999, 25.438115787271386, 25.445009373749336, 25.452044168793037, 25.459223314832485, 25.466550044747628, 25.474027685187167, 25.481659660034108, 25.48944949402575, 25.497400816536096, 25.505517365529425, 25.513802991693954, 25.522261662765402, 25.530897468050618, 25.539714623162155, 25.548717474975483, 25.557910506821013, 25.567298343924126, 25.576885759107046, 25.5866776787675, 25.5966791891499, 25.606895542925884, 25.617332166102248, 25.62799466527532, 25.63888883525234, 25.650020667061657, 25.661396356375015, 25.67302231236708, 25.68490516703863, 25.697051785032293, 25.709469273971237, 25.722164995353726, 25.735146576038712, 25.74842192036015, 25.761999222910724, 25.775886982038347, 25.79009401410245, 25.804629468540227, 25.819502843797228, 25.83472400418061, 25.850303197698054, 25.866251074950256, 25.882578709150263, 25.899297617348992, 25.91641978295246, 25.933957679623415, 25.951924296667826, 25.970333166014683, 25.98919839090741, 26.008534676434625, 26.028357362039426, 26.048682456158517, 26.06952667315552, 26.09090747272804, 26.11284310198377, 26.135352640398963, 26.158456047892514, 26.182174216270084, 26.20652902431766, 26.23154339684979, 26.25724136804791, 26.283648149456916, 26.310790203044313, 26.338695319767705, 26.36739270414093, 26.396913065340243, 26.42728871544841, 26.458553675497456, 26.490743790042515, 26.523896851077907, 26.558052732196828, 26.59325353399585, 26.629543741840063, 26.666970397231868, 26.70558328417209, 26.74543513206639, 26.78658183691604, 26.829082702745204, 26.87300070545774, 26.918402781592977, 26.965360144765683, 27.013948632936554, 27.064249090076224, 27.11634778626295, 27.17033688080685, 27.226314933630658, 27.284387470877693, 27.34466761157585, 27.407276763188047, 27.472345395048684, 27.54001390005399, 27.610433556583732, 27.683767604524462, 27.760192451503293, 27.839899028093996, 27.923094313910365, 28.01000306026764, 28.10086973959765, 28.195960757221386, 28.295566967618072, 28.40000654524512, 28.509628269595936, 28.624815295945986, 28.745989497679943, 28.873616483902644, 29.008211418109596, 29.150345791201254, 29.300655336585137, 29.459849318542954, 29.628721480111455, 29.808163007006414, 29.999177954435066, 30.20290170052768, 30.420623142572726, 30.65381155269595, 30.90414927548387, 31.17357180593517, 31.46431726719485, 31.778987964739144, 32.12062760170024, 32.49281900994228, 32.89980905097334, 33.346669927121326, 33.83950991842272, 34.38575216405271, 34.994508578782636, 35.67708906456045, 36.447706795688205, 37.32447369986329, 38.330835695696635, 39.49769234036157, 40.866614526109174, 42.49488656796933, 44.46370543087155, 46.892112173146785, 49.96194763310965, 53.96555625279971, 59.40476358277171, 67.21945473078841, 79.39900365370033, 101.01438737773742, 149.95617458687494, null, null, -117.49811612578634, -59.15967271969695, -34.96177341294294, -21.720256614771994, -13.368175818417114, -7.619943739939764, -3.422470761362117, -0.22308158745820705, 2.296161149951782, 4.3311194721457476, 6.009038676235129, 7.41617583920722, 8.61307370741442, 9.643478296698609, 10.53978610089579, 11.326500572752606, 12.022497928912413, 12.642554817170556, 13.198403941010627, 13.699479476114305, 14.153453664714192, 14.566629793063557, 14.944234481793483, 15.290638153812452, 15.609523459528216, 15.904015449315958, 16.176783259511637, 16.430120328862095, 16.66600825414244, 16.886168050043835, 17.092101619708707, 17.28512554974037, 17.46639883747668, 17.63694578460312, 17.79767501243757, 17.94939534435388, 18.092829141431938, 18.228623555373797, 18.357360068550168, 18.47956261782989, 18.595704541547306, 18.706214543819854, 18.811481834641977, 18.911860575650024, 19.00767373857039, 19.09921646492123, 19.186759000595046, 19.270549266782787, 19.350815118752852, 19.427766335822202, 19.50159637911544, 19.572483948122226, 19.640594362418295, 19.706080791041067, 19.76908534876236, 19.82974007577313, 19.88816781499411, 19.94448299927881, 19.99879235912539, 20.051195560106468, 20.101785778027565, 20.15065021879778, 20.19787058911487, 20.24352352331024, 20.287680971044328, 20.330410549978755, 20.371775867061857, 20.411836811638338, 20.450649823224914, 20.48826813646985, 20.52474200553298, 20.560118909875158, 20.594443743230016, 20.627758987339718, 20.660104871868892, 20.69151952176303, 20.7220390931862, 20.751697899058055, 20.78052852510649, 20.80856193726169, 20.83582758113601, 20.86235347426168, 20.88816629169437, 20.913291445532415, 20.937753158850644, 20.96157453450079, 20.984777619190037, 21.00738346321119, 21.029412176165, 21.05088297898499, 21.071814252547686, 21.092223583127165, 21.112127804930207, 21.131543039928495, 21.150484735186293, 21.168967697865206, 21.18700612807317, 21.20461364971086, 21.22180333945657, 21.238587754019342, 21.254978955779766, 21.270988536928844, 21.28662764220641, 21.30190699033304, 21.31683689422232, 21.331427280053425, 21.345687705278632, 21.35962737563423, 21.373255161218786, 21.386579611697808, 21.399608970689634, 21.412351189383706, 21.424813939438415, 21.437004625202714, 21.44893039530251, 21.460598153629917, 21.472014569771105, 21.483186088905885, 21.494118941209972, 21.50481915078887, 21.515292544170318, 21.52554475838067, 21.53558124862866, 21.545407295618784, 21.55502801251479, 21.56444835157288, 21.57367311046258, 21.582706938292386, 21.59155434135618, 21.600219688615308, 21.608707216930526, 21.617021036056922, 21.62516513341437, 21.633143378645045, 21.640959527969194, 21.648617228349377, 21.65612002147299, 21.663471347562286, 21.67067454902046, 21.67773287392211, 21.684649479355652, 21.69142743462506, 21.698069724317726, 21.704579251244986, 21.710958839261405, 21.717211235968655, 21.723339115309418, 21.729345080056564, 21.73523166420244, 21.74100133525301, 21.74665649643112, 21.75219948879323, 21.7576325932634, 21.762958032588354, 21.768177973217252, 21.773294527109357, 21.778309753473003, 21.783225660438774, 21.788044206669817, 21.792767302912058, 21.79739681348689, 21.80193455772887, 21.8063823113707, 21.810741807877807, 21.81501473973465, 21.819202759684728, 21.82330748192632, 21.827330483265705, 21.831273304229683, 21.835137450139037, 21.838924392144577, 21.842635568227216, 21.846272384163598, 21.849836214458623, 21.853328403246216, 21.85675026515959, 21.860103086172202, 21.863388124410555, 21.866606610939982, 21.8697597505244, 21.872848722361095, 21.87587468079147, 21.878838755988674, 21.881742054623018, 21.884585660505984, 21.88737063521367, 21.89009801869038, 21.892768829833198, 21.895384067058135, 21.89794470884864, 21.90045171428703, 21.9029060235695, 21.905308558505347, 21.90766022300092, 21.90996190352885, 21.912214469583155, 21.91441877412062, 21.91657565398902, 21.918685930342647, 21.920750409045503, 21.922769881062703, 21.924745122840427, 21.92667689667483, 21.928565951070315, 21.930413021087503, 21.932218828681272, 21.933984083029184, 21.935709480850676, 21.937395706717243, 21.93904343335399, 21.940653321932814, 21.942226022357485, 21.943762173540907, 21.945262403674832, 21.946727330492227, 21.948157561522596, 21.94955369434045, 21.950916316807152, 21.95224600730635, 21.953543334973237, 21.954808859917765, 21.956043133442115, 21.957246698252483, 21.958420088665463, 21.959563830809145, 21.960678442819116, 21.961764435029515, 21.962822310159304, 21.963852563493898, 21.964855683062307, 21.965832149809934, 21.966782437767137, 21.96770701421372, 21.968606339839475, 21.969480868900856, 21.970331049373954, 21.971157323103878, 21.971960125950616, 21.97273988793153, 21.973497033360548, 21.97423198098419, 21.97494514411449, 21.97563693075895, 21.976307743747554, 21.976957980857016, 21.977588034932236, 21.978198294005175, 21.978789141411124, 21.979360955902482, 21.979914111760156, 21.98044897890256, 21.980965922992425, 21.981465305541313, 21.981947484012085, 21.982412811919243, 21.982861638927275, 21.983294310947073, 21.983711170230443, 21.984112555462787, 21.984498801854034, 21.984870241227817, 21.98522720210901, 21.98557000980964, 21.985898986513238, 21.986214451357657, 21.986516720516452, 21.986806107278806, 21.9870829221281, 21.98734747281912, 21.987600064454025, 21.987840999556997, 21.98807057814773, 21.988289097813738, 21.988496853781513, 21.988694138986617, 21.988881244142693, 21.989058457809456, 21.98922606645973, 21.989384354545475, 21.98953360456295, 21.98967409711696, 21.98980611098426, 21.989929923176117, 21.990045809000122, 21.990154042121183, 21.990254894621856, 21.990348637061885, 21.990435538537167, 21.99051586673798, 21.990589888006642, 21.99065786739459, 21.990720068718822, 21.990776754617894, 21.990828186607327, 21.990874625134563, 21.990916329633443, 21.99095355857826, 21.990986569537366, 21.99101561922644, 21.991040963561325, 21.99106285771057, 21.991081556147634, 21.99109731270278, 21.991110380614717, 21.991121012581967, 21.991129460814008, 21.991135977082227, 21.991140812770645, 21.99114421892652, 21.991146446310786, 21.99114774544835, 21.991148366678345, 21.991148560204238, 21.99114857614393, 21.991148664579796, 21.991149075608707, 21.99115005939208, 21.991151866205932, 21.99115474649099, 21.991158950902893, 21.991164730362435, 21.991172336105972, 21.99118201973594, 21.991194033271533, 21.991208629199555, 21.991226060525467, 21.991246580824686, 21.991270444294077, 21.99129790580376, 21.991329220949176, 21.99136464610348, 21.991404438470255, 21.99144885613659, 21.991498158126554, 21.99155260445504, 21.99161245618209, 21.991677975467606, 21.991749425626608, 21.991827071184954, 21.99191117793559, 21.992002012995382, 21.99209984486249, 21.992204943474395, 21.992317580266523, 21.992438028231543, 21.992566561979384, 21.992703457797912, 21.99284899371442, 21.993003449557865, 21.993167107021907, 21.993340249728806, 21.993523163294196, 21.993716135392734, 21.99391945582473, 21.99413341658371, 21.994358311925005, 21.994594438435385, 21.994842095103756, 21.995101583393, 21.99537320731294, 21.99565727349451, 21.995954091265155, 21.996263972725526, 21.996587232827462, 21.996924189453342, 21.99727516349685, 21.997640478945186, 21.998020462962756, 21.998415445976438, 21.998825761762415, 21.999251747534665, 21.99969374403515, 22.00015209562574, 22.00062715038198, 22.001119260188666, 22.00162878083738, 22.002156072126006, 22.00270149796027, 22.003265426457407, 22.003848230051982, 22.004450285603976, 22.005071974509153, 22.005713682811834, 22.006375801320125, 22.007058725723667, 22.007762856714002, 22.00848860010765, 22.009236366971937, 22.010006573753707, 22.010799642410984, 22.011616000547686, 22.012456081551473, 22.013320324734835, 22.014209175479536, 22.015123085384502, 22.01606251241726, 22.01702792106905, 22.018019782513743, 22.01903857477063, 22.020084782871272, 22.021158899030507, 22.02226142282173, 22.02339286135665, 22.024553729469567, 22.025744549906403, 22.02696585351861, 22.02821817946212, 22.029502075401442, 22.03081809771922, 22.032166811731237, 22.03354879190721, 22.03496462209751, 22.036414895765933, 22.037900216228856, 22.039421196900893, 22.04097846154729, 22.042572644543334, 22.04420439114092, 22.04587435774263, 22.047583212183483, 22.049331634020696, 22.051120314831657, 22.052949958520472, 22.054821281633323, 22.05673501368297, 22.058691897482717, 22.060692689490164, 22.062738160161107, 22.064829094313936, 22.066966291504897, 22.069150566414628, 22.071382749246354, 22.073663686136186, 22.075994239575923, 22.078375288848882, 22.080807730479155, 22.08329247869484, 22.085830465905747, 22.088422643196132, 22.091069980832998, 22.093773468790562, 22.0965341172915, 22.09935295736561, 22.102231041426553, 22.105169443867354, 22.108169261675442, 22.111231615067897, 22.114357648147767, 22.117548529582276, 22.120805453303735, 22.124129639234113, 22.127522334034182, 22.130984811878243, 22.134518375255418, 22.138124355798674, 22.1418041151426, 22.145559045811233, 22.149390572137033, 22.153300151212488, 22.15728927387552, 22.16135946573023, 22.165512288204443, 22.169749339645634, 22.174072256456814, 22.178482714274203, 22.1829824291884, 22.18757315901098, 22.192256704588544, 22.197034911166263, 22.201909669803126, 22.206882918841238, 22.211956645431542, 22.217132887118545, 22.22241373348678, 22.227801327871692, 22.23329786913813, 22.238905613529376, 22.244626876590146, 22.250464035167003, 22.256419529489804, 22.26249586533813, 22.268695616296725, 22.275021426104217, 22.281476011099787, 22.288062162772395, 22.29478275041784, 22.301640723908836, 22.308639116583866, 22.315781048260778, 22.323069728381444, 22.33050845929419, 22.33810063968115, 22.34584976813796, 22.35375944691391, 22.36183338582084, 22.37007540631991, 22.37848944579561, 22.38707956202724, 22.395849937868498, 22.404804886146586, 22.413948854792984, 22.423286432218784, 22.43282235294823, 22.442561503525162, 22.452508928707804, 22.462669837968555, 22.473049612316434, 22.483653811460965, 22.494488181337736, 22.50555866201695, 22.516871396018082, 22.528432737055102, 22.54024925923848, 22.552327766762176, 22.56467530410552, 22.57729916678243, 22.59020691267237, 22.603406373970177, 22.61690566979457, 22.630713219498098, 22.644837756724485, 22.659288344262816, 22.674074389751667, 22.68920566229067, 22.704692310021148, 22.720544878742388, 22.736774331635655, 22.753392070173312, 22.770409956297286, 22.787840335957473, 22.805696064108496, 22.823990531271374, 22.84273769177539, 22.86195209380583, 22.881648911393455, 22.901843978493886, 22.922553825317944, 22.943795717088143, 22.965587695412808, 22.987948622486208, 23.010898228342537, 23.03445716141294, 23.058647042657796, 23.083490523573154, 23.109011348398433, 23.135234420884824, 23.16218587601942, 23.18989315713928, 23.2183850989144, 23.247692016727083, 23.27784580303055, 23.30888003133106, 23.340830068506282, 23.37373319625071, 23.407628742524878, 23.442558223983273, 23.478565500465997, 23.515696942762936, 23.554001615000573, 23.59353147316017, 23.63434158141625, 23.67649034819124, 23.720039784053412, 23.76505578385446, 23.811608435806498, 23.859772360547716, 23.909627083647816, 23.961257445464597, 24.014754052795535, 24.070213777382975, 24.12774030704259, 24.18744475601303, 24.249446342085577, 24.31387313919678, 24.380862915481636, 24.450564068326955, 24.523136669781948, 24.59875363782565, 24.67760205153058, 24.75988463117888, 24.845821407982438, 24.935651612363, 25.029635814912414, 25.128058360381022, 25.23123014257728, 25.33949177721609, 25.453217240929394, 25.572818058348155, 25.698748136038244, 25.831509362958364, 25.97165812309416, 26.119812898440003, 26.276663181410857, 26.442979967564185, 26.619628165504064, 26.80758134548367, 27.007939357576852, 27.221949492619196, 27.451032045875607, 27.696811390523994, 27.96115399804794, 28.246215287593554, 28.55449779252553, 28.888923967471268, 29.252928123270426, 29.650573621138264, 30.086703811260538, 30.56713862284122, 31.09893376922868, 31.690727139645738, 32.353208623361915, 33.09976792052555, 33.94740430717802, 34.91803086527833, 36.040388262985445, 37.35292852336676, 38.90829527587897, 40.78053643572093, 43.077213498335745, 45.96078056627114, 49.688722510383755, 54.694945396451644, 61.77210673444492, 72.53898836573654, 90.89598754580994, 129.23204927340163, null, null, -151.67703716147375, -72.08271911202871, -42.834118155428314, -27.642045260732026, -18.33733416568528, -12.053713603759903, -7.525724479592057, -4.108075534381278, -1.437199255326309, 0.707363832114531, 2.4670699356785626, 3.9368514363418328, 5.182790371115416, 6.2523042320663045, 7.18030098956525, 7.993049123442368, 8.710694657454866, 9.348946667963924, 9.9202350277875, 10.434523618340513, 10.899892974575113, 11.32296518861433, 11.709218744430355, 12.06322517171286, 12.388829268580377, 12.689287992032662, 12.967378667991177, 13.225484146895502, 13.46566043879692, 13.689690894110274, 13.899129952295112, 14.09533872899032, 14.279514164377405, 14.452713052112943, 14.615871968000242, 14.769823892098676, 14.915312147109457, 15.053002145309225, 15.183491335740108, 15.30731766534243, 15.424966806747058, 15.536878357494496, 15.643451177494663, 15.745048001321244, 15.841999437740858, 15.934607449395497, 16.023148389796592, 16.10787566197248, 16.189022052639764, 16.266801787179638, 16.34141234361782, 16.413036057949448, 16.481841548283384, 16.54798498122128, 16.611611200492607, 16.67285473501332, 16.731840701133923, 16.788685611811925, 16.843498103720634, 16.896379591843417, 16.947424859852106, 16.99672259350108, 17.044355863352454, 17.0904025623599, 17.134935803160918, 17.178024279340065, 17.21973259441839, 17.260121561883622, 17.299248479191736, 17.337167378337263, 17.373929255296826, 17.4095822803954, 17.444171991420717, 17.477741471113784, 17.5103315104911, 17.541980759300532, 17.572725864777752, 17.602601599751846, 17.63164098104087, 17.659875378986072, 17.687334618888748, 17.71404707503941, 17.740039757963245, 17.765338395445667, 17.789967507849465, 17.813950478187266, 17.837309617370334, 17.86006622501703, 17.882240646169254, 17.903852324234695, 17.92491985044472, 17.9454610100924, 17.965492825792808, 17.985031597986833, 18.004092942891255, 18.02269182808113, 18.040842605874797, 18.05855904467852, 18.07585435843455, 18.092741234305276, 18.109231858715525, 18.12533794186539, 18.141070740817554, 18.156441081254748, 18.17145937799593, 18.186135654353105, 18.200479560404304, 18.214500390253125, 18.22820709833967, 18.241608314863154, 18.254712360372235, 18.267527259574834, 18.280060754415935, 18.29232031646805, 18.304313158676305, 18.316046246496903, 18.327526308465266, 18.338759846227664, 18.34975314406781, 18.360512277957852, 18.371043124161265, 18.381351367413277, 18.39144250870287, 18.401321872678835, 18.41099461470087, 18.42046572755544, 18.429740047854843, 18.43882226213678, 18.44771691268074, 18.456428403056226, 18.464961003417457, 18.473318855557615, 18.481505977735562, 18.489526269286774, 18.497383515029632, 18.505081389477724, 18.512623460867907, 18.520013195013615, 18.52725395899206, 18.53434902467373, 18.54130157210195, 18.548114692729932, 18.55479139252221, 18.56133459492717, 18.567747143726738, 18.57403180576924, 18.580191273590934, 18.586228167931463, 18.592145040148267, 18.597944374534592, 18.603628590545608, 18.60920004493687, 18.614661033819086, 18.62001379463307, 18.62526050804836, 18.630403299789066, 18.635444242390093, 18.64038535688685, 18.645228614441393, 18.649975937907733, 18.654629203339017, 18.659190241439024, 18.66366083896043, 18.668042740052076, 18.672337647557395, 18.676547224266095, 18.68067309412102, 18.684716843382077, 18.68868002174902, 18.692564143444717, 18.69637068826063, 18.700101102565938, 18.703756800281845, 18.70733916382245, 18.710849545003494, 18.71428926592031, 18.717659619796187, 18.720961871802217, 18.72419725984994, 18.72736699535761, 18.730472263991295, 18.733514226381686, 18.736494018817535, 18.73941275391668, 18.742271521275452, 18.745071388097287, 18.747813399801352, 18.75049858061188, 18.753127934128987, 18.755702443881617, 18.758223073863274, 18.760690769051195, 18.76310645590954, 18.765471042877188, 18.767785420840692, 18.77005046359294, 18.77226702827801, 18.774435955822693, 18.77655807135523, 18.77863418461163, 18.78066509033003, 18.782651568633543, 18.78459438540197, 18.786494292632728, 18.788352028791437, 18.79016831915247, 18.791943876129803, 18.79367939959853, 18.795375577207324, 18.79703308468217, 18.798652586121666, 18.800234734284135, 18.801780170866877, 18.80328952677777, 18.804763422399507, 18.806202467846695, 18.807607263216056, 18.808978398829936, 18.810316455473362, 18.81162200462487, 18.812895608681234, 18.814137821176402, 18.8153491869947, 18.816530242578587, 18.817681516131092, 18.818803527813106, 18.819896789935676, 18.820961807147487, 18.821999076617672, 18.823009088214082, 18.823992324677185, 18.82494926178969, 18.825880368542087, 18.826786107294158, 18.82766693393265, 18.82852329802519, 18.829355642970548, 18.830164406145407, 18.83095001904771, 18.831712907436675, 18.832453491469632, 18.83317218583573, 18.833869399886623, 18.834545537764257, 18.835200998525785, 18.835836176265758, 18.836451460235637, 18.837047234960714, 18.837623880354542, 18.838181771830907, 18.838721280413466, 18.839242772843082, 18.83974661168294, 18.84023315542152, 18.840702758573467, 18.84115577177847, 18.841592541898144, 18.842013412111026, 18.842418722005718, 18.842808807672274, 18.843184001791805, 18.843544633724427, 18.84389102959561, 18.844223512380893, 18.844542401989102, 18.844848015344102, 18.845140666465074, 18.845420666545436, 18.845688324030405, 18.845943944693246, 18.846187831710296, 18.846420285734713, 18.846641604969104, 18.846852085236954, 18.84705202005301, 18.847241700692543, 18.84742141625961, 18.84759145375433, 18.847752098139157, 18.847903632404275, 18.848046337632066, 18.84818049306072, 18.848306376147036, 18.84842426262839, 18.848534426583964, 18.84863714049521, 18.848732675305634, 18.848821300479855, 18.848903284062065, 18.8489788927338, 18.849048391871168, 18.84911204560148, 18.849170116859312, 18.8492228674421, 18.849270558065196, 18.84931344841645, 18.84935179721039, 18.84938586224194, 18.849415900439762, 18.8494421679192, 18.849464920034908, 18.849484411433128, 18.849500896103663, 18.849514627431585, 18.84952585824866, 18.84953484088457, 18.849541827217873, 18.849547068726828, 18.849550816539995, 18.849553321486727, 18.8495548341475, 18.84955560490418, 18.849555883990146, 18.849555921540425, 18.84955596764171, 18.849556272382404, 18.849557085902664, 18.849558658444426, 18.849561240401542, 18.849565082369907, 18.84957043519773, 18.849577550035878, 18.849586678388363, 18.849598072162983, 18.849611983722124, 18.849628665933757, 18.84964837222267, 18.849671356621908, 18.8496978738245, 18.849728179235445, 18.849762529024034, 18.849801180176478, 18.84984439054888, 18.849892418920618, 18.849945525048085, 18.850003969718884, 18.85006801480645, 18.850137923325157, 18.850213959485924, 18.850296388752316, 18.850385477897234, 18.850481495060155, 18.85058470980497, 18.850695393178466, 18.85081381776945, 18.85094025776856, 18.851074989028806, 18.851218289126823, 18.851370437424908, 18.85153171513388, 18.85170240537673, 18.85188279325317, 18.85207316590508, 18.852273812582837, 18.852485024712685, 18.852707095965027, 18.852940322323807, 18.853185002156916, 18.853441436287746, 18.853709928067858, 18.853990783450847, 18.854284311067417, 18.85459082230175, 18.854910631369133, 18.85524405539499, 18.85559141449525, 18.855953031858203, 18.856329233827793, 18.85672034998849, 18.857126713251702, 18.857548659943866, 18.85798652989616, 18.858440666536, 18.858911416980323, 18.859399132130704, 18.859904166770374, 18.86042687966323, 18.86096763365485, 18.861526795775607, 18.862104737345934, 18.862701834083833, 18.86331846621463, 18.863955018583155, 18.86461188076832, 18.865289447200205, 18.86598811727978, 18.866708295501248, 18.867450391577172, 18.868214820566454, 18.869002003005225, 18.869812365040758, 18.87064633856852, 18.87150436137242, 18.872386877268386, 18.87329433625135, 18.874227194645787, 18.875185915259866, 18.87617096754337, 18.87718282774952, 18.878221979100744, 18.879288911958607, 18.880384123998017, 18.881508120385785, 18.882661413963756, 18.883844525436608, 18.88505798356449, 18.88630232536067, 18.887578096294313, 18.888885850498596, 18.89022615098433, 18.89159956985926, 18.893006688553214, 18.894448098049352, 18.895924399121647, 18.897436202578856, 18.898984129515185, 18.900568811567858, 18.902190891181863, 18.903851021882065, 18.90554986855297, 18.907288107726416, 18.909066427877427, 18.910885529728528, 18.912746126562826, 18.914648944546148, 18.916594723058537, 18.918584215035512, 18.92061818731929, 18.922697421020484, 18.92482271189057, 18.92699487070547, 18.929214723660753, 18.931483112778775, 18.933800896328265, 18.93616894925676, 18.938588163636382, 18.941059449123472, 18.94358373343251, 18.946161962824988, 18.94879510261364, 18.95148413768275, 18.95423007302503, 18.95703393429577, 18.959896768384887, 18.962819644007585, 18.96580365231429, 18.96884990752069, 18.971959547558566, 18.97513373474833, 18.978373656494053, 18.981680526001877, 18.98505558302282, 18.98850009462082, 18.992015355967176, 18.995602691162343, 18.99926345408626, 19.002999029278385, 19.006810832848572, 19.010700313420205, 19.01466895310684, 19.018718268523752, 19.022849811835968, 19.02706517184417, 19.031365975110244, 19.03575388712409, 19.040230613513472, 19.044797901298846, 19.049457540195068, 19.054211363962057, 19.059061251806654, 19.06400912983782, 19.069056972577734, 19.074206804531162, 19.079460701815858, 19.08482079385674, 19.09028926514676, 19.095868357077624, 19.10156036984352, 19.107367664421417, 19.113292664631448, 19.119337859281202, 19.125505804397996, 19.131799125553364, 19.138220520284186, 19.14477276061526, 19.15145869568827, 19.15828125450243, 19.165243448772433, 19.172348375909536, 19.17959922213211, 19.186999265712174, 19.19455188036497, 19.202260538788995, 19.210128816364318, 19.218160395017524, 19.22635906726208, 19.234728740423567, 19.24327344105965, 19.251997319585385, 19.260904655115116, 19.269999860532778, 19.279287487803433, 19.28877223353945, 19.298458944835698, 19.3083526253891, 19.318458441918793, 19.3287817309043, 19.33932800566029, 19.350102963767608, 19.361112494881855, 19.37236268894187, 19.383859844802426, 19.39561047931692, 19.407621336897435, 19.41989939958214, 19.43245189764124, 19.44528632075581, 19.458410429805717, 19.471832269305718, 19.485560180531845, 19.49960281538306, 19.51396915102676, 19.528668505380367, 19.543710553485102, 19.55910534483271, 19.574863321710314, 19.590995338633984, 19.60751268294719, 19.62442709666623, 19.64175079966193, 19.659496514273695, 19.67767749146035, 19.696307538600994, 19.71540104906833, 19.734973033708137, 19.755039154369456, 19.77561575964322, 19.79671992298097, 19.818369483380387, 19.840583088842017, 19.863380242819556, 19.88678135390729, 19.91080778903095, 19.93548193043351, 19.96082723677579, 19.986868308702597, 20.013630959259938, 20.041142289587295, 20.069430770351634, 20.09852632943813, 20.128460446465464, 20.159266254753565, 20.1909786514386, 20.223634416504638, 20.257272341586294, 20.291933369490803, 20.327660745495052, 20.36450018159362, 20.40250003500957, 20.441711502434632, 20.48218883163972, 20.523989552294957, 20.567174728066128, 20.61180923230984, 20.657962049986708, 20.705706608747736, 20.755121142536304, 20.80628909149386, 20.859299542469305, 20.91424771502469, 20.97123549851564, 21.03037204661946, 21.09177443661094, 21.155568401763876, 21.22188914651957, 21.290882255544297, 21.362704709538054, 21.43752602271282, 21.515529519287824, 21.59691376923585, 21.68189420695196, 21.770704960623235, 21.86360092500837, 21.9608601162682, 22.06278635466304, 22.16971232963999, 22.282003112446453, 22.40006019440556, 22.52432614497577, 22.65529000348519, 22.793493542994014, 22.939538575423864, 23.094095505653886, 23.25791339101572, 23.43183182461126, 23.616795040250835, 23.813868739155026, 24.024260271524554, 24.249342980165043, 24.490685743212307, 24.750089059214627, 25.02962942965089, 25.33171435349946, 25.659151017004675, 26.01523282984185, 26.40384946201076, 26.829628180248122, 27.298117387736156, 27.81602783942047, 28.39155384623549, 29.034807224403142, 29.75841302870201, 30.578342100439333, 31.515098050620168, 32.59544816291965, 33.85501304587973, 35.342256897563104, 37.124849714261664, 39.30022728844329, 42.01397955839009, 45.49379230496486, 50.11680887937424, 56.55633972105906, 66.14360143722647, 81.93103172221785, 112.80285214166373, 200.13693701479804, null, -203.3690210636809, -87.62997697231184, -51.53903192002832, -33.92791394995034, -23.49707206831257, -16.599439757150176, -11.700249931998915, -8.041209243894645, -5.204587588663038, -2.941326613371505, -1.0937123575820955, 0.4429842944454023, 1.7410342809948158, 2.8519206401539527, 3.813311346529291, 4.653401938223322, 5.393716961263406, 6.0509727150590376, 6.638348848510914, 7.166376682489245, 7.64357258888959, 8.076897891428477, 8.47209830178848, 8.833958164279274, 9.166493452329359, 9.473100066315268, 9.756669061604843, 10.019677102011542, 10.264258138105308, 10.492260704967176, 10.705294096450857, 10.904765856355656, 11.091912433623012, 11.267824412849844, 11.433467407964482, 11.589699464543338, 11.73728563296632, 11.876910234864244, 12.009187237877716, 12.134669070549197, 12.253854144278444, 12.367193298311024, 12.475095343463257, 12.577931848272609, 12.676041285663166, 12.769732637639077, 12.859288538885309, 12.944968026650235, 13.027008953263465, 13.105630108607798, 13.181033092429864, 13.25340397022495, 13.322914741331443, 13.389724643620596, 13.453981315613362, 13.515821833876693, 13.575373641040366, 13.632755377656931, 13.688077629331495, 13.741443599021459, 13.792949713107195, 13.842686168721903, 13.890737428877301, 13.937182671103523, 13.98209619461611, 14.025547790415608, 14.067603078197632, 14.108323813494238, 14.147768168071842, 14.185990986262244, 14.223044019603739, 14.258976141903442, 14.293833546600258, 14.327659928105861, 14.360496648619764, 14.392382891758954, 14.423355804201911, 14.453450626423573, 14.482700813489917, 14.511138146781885, 14.538792837434288, 14.565693622197415, 14.59186785236089, 14.617341576319268, 14.642139616302675, 14.66628563974867, 14.689802225746694, 14.712710926947203, 14.735032327293277, 14.756786095899106, 14.777991037372725, 14.798665138853575, 14.818825614012162, 14.8384889442389, 14.857670917228704, 14.87638666315199, 14.894650688586204, 14.912476908367829, 14.929878675512533, 14.946868809338199, 14.963459621916, 14.979662942964172, 14.99549014329033, 15.010952156880302, 15.026059501723685, 15.040822299459597, 15.05525029392001, 15.069352868641948, 15.083139063415114, 15.096617589926145, 15.109796846556632, 15.122684932387843, 15.135289660461227, 15.147618570340576, 15.159678940018338, 15.171477797205556, 15.183021930042653, 15.194317897265064, 15.205372037856126, 15.216190480217016, 15.226779150881622, 15.237143782802756, 15.247289923233756, 15.257222941228639, 15.266948034782056, 15.276470237629, 15.28579442572328, 15.294925323412016, 15.303867509322952, 15.31262542197992, 15.321203365160935, 15.329605513012813, 15.337835914934843, 15.345898500243795, 15.35379708263158, 15.361535364426091, 15.369116940665574, 15.37654530299567, 15.383823843398318, 15.39095585776084, 15.39794454929306, 15.404793031800176, 15.411504332818204, 15.418081396618842, 15.424527087090043, 15.430844190498151, 15.437035418137441, 15.44310340887218, 15.44905073157641, 15.454879887476205, 15.46059331239884, 15.466193378933298, 15.471682398506063, 15.47706262337611, 15.482336248552755, 15.487505413639749, 15.49257220460903, 15.497538655507144, 15.502406750097379, 15.507178423440369, 15.511855563415889, 15.51644001218836, 15.520933567618522, 15.525337984623487, 15.529654976487507, 15.533886216125381, 15.53803333730062, 15.542097935800173, 15.546081570567539, 15.549985764796032, 15.553812006983735, 15.557561751951788, 15.561236421827477, 15.564837406993483, 15.568366067004773, 15.571823731474272, 15.575211700928671, 15.578531247635505, 15.581783616402586, 15.584970025350968, 15.58809166666237, 15.591149707302087, 15.594145289718353, 15.597079532518986, 15.599953531126259, 15.60276835841075, 15.605525065304995, 15.608224681397715, 15.610868215509262, 15.613456656249106, 15.615990972555888, 15.618472114220774, 15.620901012394677, 15.623278580079926, 15.625605712606987, 15.627883288096703, 15.63011216790864, 15.632293197075994, 15.634427204727523, 15.636515004497012, 15.638557394920657, 15.640555159822812, 15.6425090686905, 15.644419877037087, 15.646288326755458, 15.648115146461109, 15.64990105182544, 15.651646745899637, 15.653352919429407, 15.655020251160927, 15.65664940813826, 15.658241045992542, 15.659795809223217, 15.661314331471575, 15.662797235786838, 15.66424513488508, 15.66565863140114, 15.667038318133852, 15.66838477828472, 15.669698585690307, 15.670980305048534, 15.67223049213904, 15.673449694037867, 15.674638449326578, 15.675797288296042, 15.676926733145022, 15.678027298173724, 15.679099489972517, 15.680143807605903, 15.681160742791942, 15.68215078007726, 15.683114397007738, 15.68405206429511, 15.684964245979458, 15.685851399587891, 15.686713976289383, 15.687552421045964, 15.688367172760394, 15.68915866442034, 15.68992732323926, 15.690673570794038, 15.691397823159472, 15.692100491039735, 15.692781979896893, 15.693442690076536, 15.694083016930671, 15.694703350937903, 15.695304077821014, 15.695885578662018, 15.696448230014767, 15.696992404015162, 15.697518468489084, 15.698026787058058, 15.698517719242782, 15.69899162056452, 15.699448842644488, 15.69988973330123, 15.700314636646107, 15.700723893176903, 15.701117839869648, 15.701496810268676, 15.701861134575006, 15.702211139733077, 15.702547149515876, 15.702869484608556, 15.70317846269053, 15.703474398516144, 15.703757603993926, 15.704028388264495, 15.70428705777715, 15.704533916365182, 15.704769265319978, 15.704993403463895, 15.705206627222024, 15.705409230692819, 15.705601505717642, 15.705783741949293, 15.705956226919515, 15.706119246105535, 15.706273082995674, 15.706418019154048, 15.7065543342844, 15.706682306293096, 15.706802211351315, 15.706914323956449, 15.707018916992777, 15.707116261791404, 15.707206628189516, 15.707290284588977, 15.70736749801429, 15.707438534169949, 15.707503657497217, 15.707563131230348, 15.707617217452285, 15.707666177149845, 15.707710270268446, 15.707749755766365, 15.707784891668577, 15.707815935120188, 15.707843142439486, 15.707866769170652, 15.707887070136104, 15.707904299488566, 15.707918710762836, 15.707930556927279, 15.707940090435095, 15.707947563275356, 15.707953227023854, 15.707957332893757, 15.707960131786129, 15.707961874340299, 15.70796281098414, 15.707963191984236, 15.707963267495991, 15.707963287613698, 15.707963502420565, 15.707964162038747, 15.707965516679398, 15.707967816692749, 15.707971312618257, 15.70797625523483, 15.70798289561114, 15.707991485156096, 15.708002275669418, 15.70801551939241, 15.7080314690589, 15.70805037794641, 15.708072499927546, 15.708098089521641, 15.708127401946683, 15.708160693171541, 15.708198219968507, 15.708240239966194, 15.7082870117028, 15.70833879467976, 15.708395849415812, 15.708458437501525, 15.708526821654266, 15.708601265773677, 15.708682034997654, 15.70876939575888, 15.708863615841919, 15.7089649644409, 15.709073712217837, 15.709190131361575, 15.709314495647446, 15.709447080497586, 15.709588163042028, 15.709738022180533, 15.709896938645228, 15.710065195064056, 15.710243076025098, 15.710430868141769, 15.710628860118945, 15.710837342820039, 15.711056609335069, 15.711286955049747, 15.71152867771563, 15.711782077521375, 15.71204745716511, 15.712325121927993, 15.712615379748986, 15.71291854130087, 15.71323492006756, 15.713564832422769, 15.713908597710025, 15.71426653832415, 15.71463897979418, 15.715026250867824, 15.715428683597489, 15.715846613427912, 15.716280379285477, 15.716730323669248, 15.71719679274378, 15.717680136433756, 15.718180708520537, 15.718698866740635, 15.71923497288622, 15.719789392907687, 15.72036249701837, 15.720954659801453, 15.721566260319179, 15.722197682224367, 15.722849313874384, 15.723521548447595, 15.724214784062374, 15.724929423898796, 15.725665876323038, 15.726424555014608, 15.727205879096495, 15.728010273268293, 15.728838167942449, 15.729689999383673, 15.730566209851665, 15.73146724774721, 15.732393567761804, 15.733345631030863, 15.734323905290685, 15.735328865039238, 15.736360991700925, 15.737420773795447, 15.738508707110881, 15.73962529488112, 15.740771047967833, 15.741946485047043, 15.74315213280052, 15.74438852611213, 15.745656208269283, 15.746955731169678, 15.748287655533483, 15.749652551121178, 15.75105099695719, 15.752483581559552, 15.753950903175786, 15.755453570025182, 15.756992200547737, 15.758567423659938, 15.760179879017644, 15.761830217286288, 15.763519100418678, 15.765247201940623, 15.767015207244665, 15.768823813892222, 15.770673731924388, 15.772565684181723, 15.774500406633337, 15.776478648715603, 15.778501173680818, 15.780568758956178, 15.782682196513454, 15.784842293249698, 15.787049871379429, 15.789305768838691, 15.791610839701402, 15.793965954608469, 15.7963720012101, 15.79882988462185, 15.801340527894837, 15.803904872500745, 15.806523878832067, 15.809198526718243, 15.811929815958251, 15.814718766870271, 15.817566420859105, 15.820473841001988, 15.823442112653549, 15.82647234407062, 15.829565667057688, 15.832723237633799, 15.835946236721734, 15.83923587086039, 15.84259337294122, 15.84602000296975, 15.849517048853171, 15.853085827215022, 15.85672768423813, 15.860443996536914, 15.864236172060272, 15.86810565102635, 15.872053906890448, 15.876082447347557, 15.880192815370862, 15.884386590287859, 15.888665388895578, 15.893030866616686, 15.897484718698163, 15.90202868145443, 15.906664533556894, 15.911394097371884, 15.9162192403492, 15.921141876463464, 15.926163967710671, 15.931287525662436, 15.9365146130805, 15.941847345594352, 15.947287893444738, 15.952838483296217, 15.958501400121929, 15.964278989163947, 15.97017365797284, 15.976187878530126, 15.982324189457676, 15.988585198318185, 15.994973584011156, 16.001492099269072, 16.008143573258653, 16.014930914292457, 16.021857112656257, 16.02892524355807, 16.03613847020499, 16.043500047014284, 16.051013322965748, 16.058681745102486, 16.066508862188012, 16.074498328527756, 16.08265390796371, 16.090979478051462, 16.099479034429397, 16.108156695390473, 16.11701670666759, 16.126063446444345, 16.13530143060364, 16.14473531822739, 16.154369917361535, 16.16421019106137, 16.1742612637332, 16.18452842778955, 16.195017150635955, 16.205733082008983, 16.216682061686157, 16.227870127589963, 16.23930352430973, 16.25098871206661, 16.262932376148964, 16.275141436846987, 16.287623059917923, 16.30038466761498, 16.31343395031591, 16.326778878789526, 16.340427717141374, 16.354389036482953, 16.368671729371936, 16.383285025074777, 16.398238505706832, 16.413542123309327, 16.429206217927437, 16.445241536758413, 16.461659254444626, 16.47847099459195, 16.495688852600914, 16.51332541990491, 16.53139380971767, 16.549907684400925, 16.568881284572278, 16.58832946008398, 16.608267703014278, 16.628712182825588, 16.649679783857476, 16.671188145337148, 16.69325570410721, 16.715901740288146, 16.739146426113656, 16.763010878199008, 16.787517213527178, 16.812688609465283, 16.838549368153597, 16.865124985643618, 16.89244222619888, 16.92052920221383, 16.949415460252936, 16.97913207376361, 17.009711743075165, 17.041188903360347, 17.073599841309345, 17.10698282134775, 17.1413782223216, 17.17682868567686, 17.21337927627662, 17.251077657131958, 17.289974279471394, 17.330122589742896, 17.371579255335327, 17.414404411023963, 17.458661928395017, 17.50441971078777, 17.55175001661964, 17.60072981433252, 17.65144117262798, 17.70397169015397, 17.758414969375373, 17.814871140021864, 17.873447438271686, 17.93425884871996, 17.997428817218534, 18.06309004388576, 18.131385367007027, 18.202468750215626, 18.27650638731349, 18.353677941418294, 18.434177937884353, 18.518217333731506, 18.606025290238573, 18.697851180062084, 18.79396686589687, 18.894669294526437, 19.000283458395312, 19.111165786919766, 19.227708042091216, 19.350341808081474, 19.479543683275544, 19.615841306380197, 19.759820377230422, 19.91213286926861, 20.073506676543865, 20.24475699633735, 20.426799822981145, 20.62066802427842, 20.827530596197043, 21.04871585387184, 21.285739530868252, 21.540339042962167, 21.814515554110578, 22.110585999118165, 22.43124792536896, 22.779660996706653, 23.159550378180448, 23.575339175930836, 24.0323199269276, 24.536879265590734, 25.09679605347108, 25.72164261236122, 26.423333204725978, 27.216886912881286, 28.121509506383305, 29.16216156544138, 30.371888485444714, 31.795382271938518, 33.49460827293693, 35.558042897612445, 38.116549729379244, 41.37221686850193, 45.654444925017884, 51.53894501680889, 60.13089627427864, 73.8553487618664, 99.26623036156215, 162.34579535047897, null, null, -107.0209840053114, -61.31746017135638, -40.65436548513689, -28.878824507236516, -21.272320694590306, -15.954267721744863, -12.027309479940346, -9.009021280339752, -6.616933847460631, -4.674663222390501, -3.06638310421015, -1.7128902369634815, -0.5581900086331384, 0.43842423908360395, 1.3072553397788944, 2.0713264530157875, 2.7484432195910227, 3.3525925117672593, 3.894914098217944, 4.384389993831153, 4.828342771380454, 5.232801873862508, 5.602776996004971, 5.942464924351192, 6.255407994914152, 6.544616876425849, 6.8126667104651135, 7.0617731179796985, 7.293852825397932, 7.510572422908318, 7.713387879653129, 7.903576797466879, 8.08226491368781, 8.25044801482347, 8.40901016214811, 8.558738933626866, 8.700338236888932, 8.834439133157293, 8.961609023283888, 9.082359477933664, 9.197152939789133, 9.306408482902839, 9.41050678039871, 9.509794404630348, 9.6045875621572, 9.695175348344716, 9.781822592156573, 9.864772350104198, 9.94424809881622, 10.02045566787981, 10.093584948153518, 10.163811405402793, 10.23129742465914, 10.296193506984109, 10.3586393372041, 10.41876473855869, 10.476690527994096, 10.53252928395965, 10.586386036974858, 10.638358891880937, 10.688539589533088, 10.737014014700197, 10.783862656087724, 10.829161023667394, 10.872980027866266, 10.915386324620428, 10.956442629825904, 10.996208006306695, 11.034738126062452, 11.07208551024485, 11.108299749038409, 11.143427703382262, 11.177513690258465, 11.210599653088053, 11.242725318612745, 11.273928341496376, 11.304244437753333, 11.333707507998094, 11.362349751410768, 11.390201771224103, 11.417292672459098, 11.443650152565608, 11.46930058556158, 11.494269100208747, 11.518579652711935, 11.542255094384553, 11.565317234682242, 11.587786899970324, 11.609683988358347, 11.631027520905198, 11.651835689472234, 11.672125901477443, 11.691914821782454, 11.711218411924381, 11.730051966886727, 11.748430149587772, 11.766367023249858, 11.783876081800091, 11.800970278440717, 11.817662052516345, 11.833963354795518, 11.849885671274539, 11.865440045603547, 11.880637100226831, 11.895487056322706, 11.909999752621676, 11.924184663175813, 11.938050914146988, 11.951607299676501, 11.964862296894308, 11.977824080121756, 11.990500534317897, 12.002899267816069, 12.015027624393964, 12.026892694717652, 12.038501327196993, 12.049860138287574, 12.060975522271773, 12.071853660549413, 12.082500530466506, 12.0929219137086, 12.103123404283664, 12.113110416117674, 12.122888190284684, 12.13246180189175, 12.141836166637772, 12.151016047064141, 12.16000605851396, 12.168810674815578, 12.177434233705215, 12.185880942002523, 12.194154880552167, 12.20226000894364, 12.210200170020862, 12.217979094192433, 12.225600403552686, 12.233067615823256, 12.240384148124123, 12.247553320582803, 12.254578359789596, 12.261462402106638, 12.268208496837852, 12.274819609266574, 12.281298623567325, 12.287648345597699, 12.293871505576151, 12.29997076065106, 12.305948697366208, 12.311807834027512, 12.317550622975597, 12.323179452768573, 12.328696650279108, 12.334104482709737, 12.339405159530084, 12.344600834339506, 12.349693606658526, 12.354685523652183, 12.359578581788323, 12.364374728433688, 12.369075863390485, 12.373683840376069, 12.378200468448137, 12.382627513377788, 12.38696669897267, 12.391219708352319, 12.395388185177705, 12.39947373483688, 12.40347792558859, 12.40740228966554, 12.411248324339013, 12.41501749294638, 12.418711225883046, 12.422330921560249, 12.42587794733006, 12.429353640378944, 12.432759308591084, 12.43609623138269, 12.439365660508408, 12.44256882084094, 12.445706911124912, 12.448781104705962, 12.451792550236023, 12.45474237235572, 12.457631672354696, 12.460461528810791, 12.463232998208767, 12.465947115539436, 12.46860489487985, 12.471207329955302, 12.473755394683788, 12.47625004370356, 12.478692212884429, 12.481082819823344, 12.483422764324894, 12.485712928867194, 12.487954179053741, 12.4901473640517, 12.492293317017124, 12.494392855507563, 12.496446781882481, 12.498455883691953, 12.500420934054016, 12.502342692021058, 12.504221902935665, 12.506059298776245, 12.507855598492801, 12.509611508333183, 12.51132772216014, 12.513004921759475, 12.514643777139627, 12.516244946822933, 12.517809078128865, 12.519336807449514, 12.520828760517572, 12.52228555266703, 12.523707789086895, 12.525096065068087, 12.526450966243772, 12.52777306882335, 12.529062939820275, 12.53032113727393, 12.53154821046574, 12.532744700129696, 12.533911138657487, 12.535048050298396, 12.536155951354143, 12.537235350368794, 12.538286748313956, 12.53931063876934, 12.540307508098882, 12.541277835622543, 12.542222093783904, 12.543140748313741, 12.544034258389633, 12.544903076791789, 12.545747650055164, 12.546568418618003, 12.547365816966924, 12.548140273778618, 12.54889221205831, 12.54962204927505, 12.55033019749393, 12.551017063505343, 12.551683048951359, 12.552328550449294, 12.552953959712584, 12.553559663669024, 12.554146044576456, 12.554713480135995, 12.555262343602847, 12.555793003894815, 12.556305825698539, 12.55680116957356, 12.55727939205426, 12.557740845749747, 12.558185879441739, 12.55861483818054, 12.559028063379117, 12.559425892905363, 12.559808661172623, 12.560176699228478, 12.560530334841904, 12.560869892588812, 12.561195693936035, 12.561508057323824, 12.56180729824686, 12.562093729333876, 12.562367660425902, 12.56262939865319, 12.562879248510844, 12.563117511933225, 12.56334448836715, 12.563560474843921, 12.56376576605025, 12.563960654398073, 12.564145430093342, 12.56432038120378, 12.56448579372567, 12.564641951649705, 12.564789137025908, 12.564927630027688, 12.565057709015054, 12.56517965059699, 12.565293729693076, 12.565400219594329, 12.565499392023332, 12.565591517193665, 12.56567686386866, 12.565755699419528, 12.565828289882862, 12.565894900017563, 12.565955793361194, 12.566011232285815, 12.566061478053296, 12.566106790870158, 12.56614742994195, 12.566183653527188, 12.5662157189909, 12.566243882857762, 12.566268400864892, 12.566289528014304, 12.56630751862502, 12.566322626384931, 12.566335104402352, 12.566345205257344, 12.566353181052811, 12.566359283465392, 12.566363763796165, 12.566366873021199, 12.566368861841964, 12.56636998073562, 12.566370480005224, 12.566370609829844, 12.566370620314638, 12.566370761540883, 12.566371283616018, 12.566372436723675, 12.566374471173756, 12.566377637452556, 12.566382186272968, 12.566388368624782, 12.566396435825096, 12.566406639568878, 12.56641923197968, 12.566434465660532, 12.566452593745053, 12.566473869948783, 12.566498548620757, 12.566526884795362, 12.566559134244478, 12.566595553529947, 12.566636400056366, 12.566681932124265, 12.56673240898365, 12.566788090887968, 12.566849239148508, 12.566916116189262, 12.566988985602253, 12.567068112203401, 12.567153762088907, 12.567246202692191, 12.567345702841438, 12.567452532817738, 12.567566964413883, 12.567689270993824, 12.567819727552832, 12.567958610778382, 12.568106199111785, 12.568262772810629, 12.568428614012017, 12.568604006796654, 12.568789237253824, 12.568984593547277, 12.569190365982053, 12.569406847072292, 12.569634331610072, 12.56987311673527, 12.570123502006535, 12.570385789473374, 12.570660283749403, 12.570947292086805, 12.571247124452018, 12.571560093602725, 12.57188651516616, 12.572226707718778, 12.572580992867357, 12.572949695331543, 12.57333314302791, 12.573731667155585, 12.574145602283457, 12.574575286439067, 12.575021061199186, 12.575483271782176, 12.575962267142147, 12.576458400065023, 12.576972027266505, 12.57750350949206, 12.578053211618947, 12.57862150276039, 12.579208756371909, 12.579815350359935, 12.580441667192739, 12.581088094013758, 12.581755022757408, 12.582442850267443, 12.583151978417934, 12.583882814236985, 12.584635770033227, 12.585411263525206, 12.586209717973748, 12.587031562317389, 12.587877231310978, 12.588747165667533, 12.589641812203476, 12.590561623987341, 12.591507060492058, 12.59247858775094, 12.593476678517481, 12.594501812429106, 12.595554476174954, 12.596635163667877, 12.59774437622075, 12.598882622727258, 12.600050419847285, 12.60124829219706, 12.602476772544215, 12.603736402007925, 12.605027730264275, 12.606351315757042, 12.607707725914057, 12.609097537369356, 12.610521336191276, 12.61197971811672, 12.613473288791788, 12.615002664018993, 12.616568470011266, 12.618171343653003, 12.619811932768377, 12.621490896397162, 12.623208905078338, 12.624966641141727, 12.626764799007956, 12.62860408549701, 12.6304852201457, 12.632408935534341, 12.634375977622966, 12.636387106097411, 12.638443094725625, 12.640544731724564, 12.642692820138047, 12.644888178225965, 12.647131639865265, 12.649424054963113, 12.651766289882694, 12.654159227882122, 12.656603769566907, 12.659100833356513, 12.661651355965521, 12.664256292899918, 12.666916618969129, 12.669633328814328, 12.672407437453684, 12.675239980845168, 12.678132016467615, 12.681084623920691, 12.684098905544579, 12.687175987060066, 12.690317018229877, 12.693523173542095, 12.696795652916501, 12.700135682434773, 12.703544515095519, 12.707023431595074, 12.710573741135173, 12.71419678225855, 12.717893923713623, 12.721666565349441, 12.725516139042174, 12.729444109654434, 12.733451976028785, 12.737541272016955, 12.741713567546137, 12.745970469724092, 12.75031362398462, 12.754744715275177, 12.75926546928846, 12.763877653739886, 12.76858307969297, 12.773383602934704, 12.778281125403195, 12.783277596669874, 12.788375015478733, 12.79357543134519, 12.798880946217267, 12.804293716201997, 12.809815953360024, 12.815449927571573, 12.82119796847716, 12.827062467496534, 12.833045879929589, 12.839150727143126, 12.845379598847632, 12.851735155468415, 12.858220130615685, 12.864837333658478, 12.871589652407511, 12.878480055912416, 12.885511597379109, 12.892687417213319, 12.900010746196724, 12.907484908802493, 12.915113326657425, 12.922899522158286, 12.93084712225048, 12.938959862377576, 12.947241590610789, 12.955696271968083, 12.964327992933113, 12.973140966184898, 12.982139535549802, 12.991328181188058, 13.000711525027992, 13.010294336461781, 13.020081538317633, 13.030078213124087, 13.04028960968334, 13.050721149971482, 13.06137843638476, 13.072267259352381, 13.08339360533753, 13.094763665250058, 13.106383843295692, 13.118260766288387, 13.130401293454497, 13.142812526759162, 13.155501821787846, 13.168476799217995, 13.181745356918643, 13.19531568271836, 13.209196267885018, 13.223395921364187, 13.237923784826355, 13.25278934857717, 13.268002468389003, 13.283573383316606, 13.299512734564825, 13.315831585481392, 13.332541442754026, 13.349654278897182, 13.367182556121074, 13.385139251683094, 13.403537884830069, 13.42239254544924, 13.441717924555583, 13.461529346754382, 13.481842804829988, 13.502674996624929, 13.524043364388477, 13.54596613678955, 13.568462373807064, 13.591552014730095, 13.615255929522313, 13.639595973828996, 13.664595047931469, 13.690277159983763, 13.716667493898482, 13.743792482285908, 13.771679884890585, 13.800358873014847, 13.829860120469583, 13.860215901648333, 13.891460197384632, 13.923628809322473, 13.956759483609865, 13.990892044814167, 14.026068541058383, 14.062333401491186, 14.09973360733068, 14.138318877867174, 14.178141872973773, 14.219258413859507, 14.261727724011894, 14.305612692515956, 14.350980162212835, 14.397901245474877, 14.446451670735552, 14.496712163326336, 14.548768864649313, 14.602713794264954, 14.658645360109439, 14.716668922793863, 14.776897420793404, 14.839452064331919, 14.904463106933095, 14.972070704972284, 15.042425877166718, 15.115691577827425, 15.1920438999269, 15.27167342667811, 15.354786753462099, 15.44160820569102, 15.53238178268013, 15.627373362997792, 15.726873213268735, 15.83119885028746, 15.940698315886749, 16.055753935715906, 16.176786647458684, 16.304261001742354, 16.438690960957217, 16.58064664857089, 16.73076223580535, 16.88974519574673, 17.058387209725215, 17.237577080693384, 17.428316098119627, 17.63173641510736, 17.849123149971, 18.081941123685553, 18.331867408762232, 18.600831218579494, 18.89106314393148, 19.20515639602384, 19.546143616387702, 19.917594074248644, 20.32373785684676, 20.769626222823586, 21.261341030726115, 21.806271706738915, 22.41348660613083, 23.09423856087306, 23.86266480567902, 24.7367744453422, 25.739871407598116, 26.90265472090625, 28.266404669700805, 29.887971574279508, 31.84788091749583, 34.26408988983344, 37.31659714745562, 41.294407958842534, 46.692773778991636, 54.437126852270914, 66.47971592526793, 87.77042242351747, 135.59486599054873, null, null, -132.36946134854296, -72.5132475308933, -47.920950669835904, -34.52134203799305, -26.090436301925102, -20.297313239522197, -16.07187059645461, -12.853885388213797, -10.321655624960396, -8.277271002655278, -6.592294222866771, -5.179736261781393, -3.978584760779192, -2.9447811842684057, -2.045714524627776, -1.2567301263382689, -0.5588427136356042, 0.06280462509501916, 0.6200047259622536, 1.1222375345743423, 1.5772106286724288, 1.9912549252437763, 2.369618902353743, 2.7166904563569663, 3.0361663414655498, 3.331183092949412, 3.6044192757349096, 3.858176127342084, 4.094441740249274, 4.314942574580875, 4.521185126020685, 4.7144898762425145, 4.896019143537157, 5.066800075058896, 5.227743741524749, 5.379661083998337, 5.52327630202135, 5.659238149573497, 5.788129510615441, 5.91047555234359, 6.0267506966691915, 6.137384605050502, 6.242767335831942, 6.343253804566901, 6.439167654804518, 6.5308046282896415, 6.618435508509803, 6.70230869930137, 6.782652490233194, 6.8596770522743515, 6.9335762004820465, 7.004528954835648, 7.072700925679378, 7.138245546345088, 7.201305172265535, 7.262012063150699, 7.320489262488316, 7.376851386677265, 7.4312053344438205, 7.483650925780102, 7.534281478440777, 7.58318432900273, 7.630441304609427, 7.676129150760584, 7.720319919851978, 7.763081324603901, 7.804477060024615, 7.844567097129664, 7.883407951265587, 7.921052927563741, 7.957552345766373, 7.9929537464193565, 8.02730208020906, 8.060639882028974, 8.09300743119417, 8.124442899072717, 8.15498248527204, 8.184660543402435, 8.21350969733634, 8.24156094879127, 8.268843776982228, 8.295386231017638, 8.321215015647734, 8.34635557091677, 8.370832146218898, 8.39466786921096, 8.417884809994309, 8.440504040940247, 8.462545692500097, 8.484029005311065, 8.504972378881366, 8.52539341711401, 8.545308970905955, 8.56473517803971, 8.58368750056598, 8.602180759859477, 8.620229169515326, 8.637846366239465, 8.655045438874481, 8.671838955690852, 8.688238990063253, 8.704257144642487, 8.71990457412473, 8.735192006712294, 8.750129764352675, 8.764727781836369, 8.778995624827829, 8.792942506898363, 8.80657730562501, 8.819908577814434, 8.832944573906968, 8.845693251611797, 8.858162288820736, 8.870359095844814, 8.882290827014637, 8.893964391682935, 8.90538646466479, 8.916563496148902, 8.927501721110877, 8.93820716825745, 8.948685668528766, 8.958942863183914, 8.968984211493426, 8.978814998060841, 8.988440339793984, 8.997865192545467, 9.00709435744048, 9.016132486909012, 9.024984090438421, 9.03365354006142, 9.04214507559355, 9.050462809633373, 9.058610732337891, 9.066592715984822, 9.074412519332824, 9.082073791790013, 9.089580077400507, 9.09693481865828, 9.104141360156907, 9.111202952083477, 9.1181227535643, 9.12490383586976, 9.13154918548519, 9.138061707054188, 9.144444226200644, 9.150699492235143, 9.156830180751346, 9.16283889611749, 9.168728173867903, 9.174500482999253, 9.180158228175863, 9.185703751848337, 9.191139336289408, 9.196467205550775, 9.201689527344513, 9.206808414852388, 9.211825928466341, 9.216744077463122, 9.22156482161602, 9.226290072746421, 9.230921696217772, 9.2354615123745, 9.239911297928176, 9.24427278729323, 9.248547673874311, 9.252737611307355, 9.256844214656292, 9.260869061567222, 9.264813693381855, 9.26867961621184, 9.272468301975621, 9.27618118939936, 9.279819684983297, 9.283385163935039, 9.286878971071024, 9.290302421687475, 9.293656802401994, 9.296943371967023, 9.300163362056207, 9.303317978024738, 9.3064083996447, 9.309435781816351, 9.312401255256272, 9.315305927163283, 9.318150881862922, 9.32093718143135, 9.323665866299404, 9.326337955837568, 9.328954448922563, 9.331516324486218, 9.33402454204731, 9.336480042226937, 9.338883747248088, 9.341236561419931, 9.343539371607394, 9.345793047686554, 9.347998442986352, 9.350156394717109, 9.35226772438631, 9.354333238202107, 9.356353727464967, 9.358329968947885, 9.360262725265544, 9.362152745232823, 9.364000764212996, 9.365807504455995, 9.367573675427066, 9.36929997412614, 9.370987085398237, 9.372635682235217, 9.374246426069124, 9.37581996705748, 9.377356944360695, 9.378857986411962, 9.380323711179795, 9.381754726423498, 9.383151629941793, 9.384515009814807, 9.385845444639665, 9.38714350375987, 9.388409747488671, 9.389644727326642, 9.390848986173609, 9.392023058535152, 9.393167470723819, 9.394282741055246, 9.395369380039318, 9.396427890566542, 9.397458768089798, 9.398462500801571, 9.39943956980684, 9.400390449291748, 9.401315606688184, 9.402215502834396, 9.40309059213177, 9.403941322697891, 9.404768136515985, 9.405571469580876, 9.406351752041543, 9.407109408340402, 9.407844857349392, 9.408558512502974, 9.409250781928142, 9.409922068571511, 9.410572770323617, 9.411203280140455, 9.411813986162395, 9.41240527183051, 9.412977516000424, 9.413531093053741, 9.414066373007136, 9.414583721619163, 9.415083500494873, 9.415566067188292, 9.416031775302821, 9.416480974589632, 9.41691401104412, 9.417331227000464, 9.417732961224345, 9.418119549003915, 9.41849132223902, 9.418848609528768, 9.41919173625748, 9.419521024679067, 9.419836793999908, 9.42013936046023, 9.420429037414085, 9.420706135407949, 9.420970962257963, 9.421223823125908, 9.421465020593915, 9.421694854737959, 9.421913623200197, 9.42212162126016, 9.42231914190486, 9.422506475897823, 9.422683911847123, 9.422851736272408, 9.423010233670981, 9.423159686582963, 9.423300375655565, 9.423432579706507, 9.42355657578662, 9.42367263924164, 9.423781043773257, 9.423882061499418, 9.423975963013934, 9.424063017445409, 9.424143492515524, 9.42421765459669, 9.42428576876913, 9.424348098877365, 9.42440490758619, 9.424456456436113, 9.424503005898316, 9.424544815429142, 9.424582143524153, 9.42461524777177, 9.424644384906507, 9.42466981086186, 9.424691780822828, 9.424710549278133, 9.42472637007213, 9.424739496456436, 9.424750181141313, 9.424758676346828, 9.424765233853778, 9.42477010505446, 9.424773541003242, 9.424775792467019, 9.424777109975528, 9.424777743871571, 9.424777944361155, 9.424777961563569, 9.424778045561442, 9.424778446450759, 9.424779414390908, 9.424781199654733, 9.424784052678655, 9.424788224112843, 9.424793964871492, 9.424801526183206, 9.424811159641509, 9.424823117255528, 9.42483765150084, 9.424855015370515, 9.4248754624264, 9.424899246850623, 9.424926623497377, 9.424957847944988, 9.424993176548291, 9.425032866491353, 9.425077175840531, 9.425126363597931, 9.425180689755267, 9.425240415348135, 9.425305802510763, 9.425377114531218, 9.425454615907128, 9.425538572401926, 9.425629251101661, 9.425726920472368, 9.42583185041806, 9.42594431233936, 9.42606457919278, 9.4261929255507, 9.42632962766206, 9.426474963513815, 9.426629212893147, 9.426792657450502, 9.426965580763463, 9.427148268401488, 9.42734100799157, 9.427544089284808, 9.427757804223972, 9.427982447012065, 9.428218314181926, 9.428465704666912, 9.428724919872698, 9.428996263750223, 9.429280042869838, 9.429576566496676, 9.429886146667306, 9.43020909826769, 9.430545739112516, 9.43089639002591, 9.431261374923626, 9.431641020896704, 9.432035658296689, 9.432445620822437, 9.432871245608561, 9.433312873315586, 9.43377084822183, 9.434245518317116, 9.434737235398332, 9.435246355166907, 9.435773237328268, 9.436318245693364, 9.43688174828225, 9.437464117429883, 9.43806572989414, 9.438686966966145, 9.439328214582982, 9.439989863442861, 9.440672309122814, 9.441375952199005, 9.442101198369732, 9.442848458581206, 9.44361814915619, 9.44441069192559, 9.4452265143631, 9.44606604972297, 9.446929737181042, 9.447818021979094, 9.448731355572656, 9.449670195782362, 9.450635006948994, 9.451626260092283, 9.452644433073635, 9.453690010762877, 9.45476348520916, 9.455865355816162, 9.456996129521709, 9.458156320981972, 9.459346452760387, 9.460567055521448, 9.461818668229515, 9.463101838352843, 9.464417122072952, 9.46576508449956, 9.46714629989122, 9.468561351881888, 9.47001083371358, 9.471495348475372, 9.473015509348896, 9.474571939860592, 9.476165274140941, 9.477796157190879, 9.47946524515569, 9.481173205606597, 9.482920717830309, 9.484708473126833, 9.486537175115803, 9.488407540051636, 9.490320297147832, 9.492276188910713, 9.494275971482947, 9.496320414997221, 9.498410303940378, 9.500546437528454, 9.502729630092924, 9.504960711478647, 9.507240527453874, 9.509569940132769, 9.511949828410925, 9.514381088414316, 9.516864633962202, 9.519401397044504, 9.521992328314191, 9.5246383975952, 9.527340594406553, 9.530099928503194, 9.532917430434262, 9.535794152119403, 9.53873116744384, 9.541729572872955, 9.544790488087061, 9.547915056637253, 9.551104446623082, 9.554359851392952, 9.557682490268137, 9.561073609291357, 9.5645344820009, 9.568066410231324, 9.571670724941802, 9.57534878707325, 9.57910198843544, 9.582931752625289, 9.586839535977653, 9.590826828549979, 9.594895155142222, 9.59904607635353, 9.60328118967728, 9.607602130636039, 9.612010573958255, 9.616508234798415, 9.621096870002592, 9.6257782794214, 9.63055430727235, 9.635426843553937, 9.640397825513645, 9.645469239172375, 9.650643120907803, 9.655921559099363, 9.661306695837693, 9.666800728701492, 9.672405912604942, 9.67812456171899, 9.683959051469913, 9.68991182061892, 9.695985373426591, 9.702182281906204, 9.70850518817035, 9.714956806875232, 9.721539927767575, 9.72825741833911, 9.735112226594062, 9.74210738393519, 9.749246008174488, 9.756531306674782, 9.763966579628944, 9.771555223483858, 9.779300734516562, 9.787206712570619, 9.795276864961117, 9.803515010557229, 9.811925084051905, 9.820511140428678, 9.829277359636398, 9.838228051483217, 9.847367660761936, 9.856700772619622, 9.86623211818508, 9.87596658046891, 9.885909200551568, 9.896065184075985, 9.906439908062476, 9.917038928064605, 9.927867985686243, 9.938933016481185, 9.950240158258282, 9.961795759816509, 9.97360639013631, 9.985678848055153, 9.998020172457377, 10.010637653010543, 10.02353884148268, 10.036731563677627, 10.050223932028043, 10.064024358888869, 10.078141570577118, 10.092584622207244, 10.107362913375372, 10.122486204749459, 10.13796463562709, 10.153808742527463, 10.170029478889163, 10.186638235951483, 10.2036468649029, 10.22106770038744, 10.238913585467076, 10.257197898146357, 10.27593457957475, 10.295138164051648, 10.31482381097006, 10.335007338846541, 10.355705261598315, 10.376934827242476, 10.398714059208114, 10.421061800469626, 10.443997760728337, 10.467542566891275, 10.49171781711881, 10.516546138739178, 10.542051250356621, 10.568258028511472, 10.595192579286637, 10.622882315293733, 10.6513560385165, 10.6806440295382, 10.710778143734082, 10.741791915072069, 10.773720668232711, 10.80660163983702, 10.840474109657283, 10.875379542782976, 10.911361743824434, 10.948467024360102, 10.986744384973907, 11.02624571338734, 11.067026000371857, 11.109143575330918, 11.15266036367466, 11.197642168376106, 11.244158978401249, 11.29228530705458, 11.342100563680432, 11.39368946262077, 11.447142473860403, 11.502556320402373, 11.56003452812713, 11.619688034711743, 11.681635865145179, 11.746005882494957, 11.812935623889615, 11.882573233220006, 11.955078503870256, 12.03062404692574, 12.109396602834765, 12.191598517504314, 12.277449407393917, 12.367188042454666, 12.461074480906307, 12.559392496043683, 12.662452342768034, 12.770593920651232, 12.88419040146477, 13.003652402739231, 13.129432805709554, 13.262032336787115, 13.402006057553962, 13.549970940622682, 13.706614749403109, 13.8727064913295, 14.049108779729199, 14.236792523671063, 14.43685447383898, 14.650538293944741, 14.879260012775983, 15.124638957514836, 15.38853559676179, 15.673098163587667, 15.980820530792506, 16.314614639414124, 16.67790193672002, 17.074729910677764, 17.50992214224042, 17.98927368892685, 18.51980862400898, 19.110124091374036, 19.770856794372158, 20.515325953785663, 21.36043585881971, 22.32796911159155, 23.44648321630646, 24.754166596153116, 26.303272410714527, 28.167250230711208, 30.45270687899598, 33.3204968100788, 37.025256861592574, 41.99541507375927, 49.01196053057818, 59.665039597155676, 77.76819428105885, 115.33281407058332, 240.18835349860052, null, -167.68679067661765, -85.63463417182864, -55.8596548705128, -40.472950361167904, -31.07546466221223, -24.740510467227203, -20.181174089189295, -16.742990343824804, -14.057935656752555, -11.903174178784802, -10.135888334579793, -8.6603203233281, -7.4098640247914425, -6.336756218278762, -5.40585338694588, -4.590722085663806, -3.8710979683478897, -3.231185304191653, -2.658489581884165, -2.142997911068745, -1.6765920522982576, -1.2526205228720197, -0.8655816555020674, -0.5108854352465926, -0.1846721789701018, 0.11632716489777906, 0.3948998313912897, 0.6534368519162967, 0.8940010387895683, 1.118381435688879, 1.3281372764334707, 1.5246337372046614, 1.7090712156754195, 1.8825094643109699, 2.0458876029259905, 2.2000408086674064, 2.345714309661642, 2.4835751772047567, 2.6142223102249913, 2.7381949272711523, 2.855979819977491, 2.9680175737439436, 3.0747079232155983, 3.176414379774272, 3.2734682439342953, 3.36617209596192, 3.4548028422004933, 3.53961438170594, 3.620839947281474, 3.698694166368069, 3.773374880137865, 3.845064753252319, 3.9139327018617465, 3.98013516334619, 4.043817227889022, 4.105113649111557, 4.164149748584002, 4.221042226990937, 4.27589989299951, 4.328824319409683, 4.379910434912375, 4.429247058708764, 4.476917384326187, 4.522999418174717, 4.567566377708205, 4.610687053465344, 4.6524261387561445, 4.692844530318305, 4.731999602882112, 4.769945460248048, 4.806733165188316, 4.8424109502267125, 4.877024411127467, 4.910616684725189, 4.943228612555027, 4.974898891588127, 5.0056642132430085, 5.03555939172276, 5.064617482622377, 5.092869892656171, 5.120346481271069, 5.147075654837678, 5.1730844540437575, 5.198398635055707, 5.22304274496056, 5.247040191953007, 5.270413310689914, 5.293183423195902, 5.3153708956694325, 5.33699519150783, 5.358074920841422, 5.378627886842315, 5.3986711290499825, 5.418220963935564, 5.437293022908117, 5.455902287948861, 5.47406312504463, 5.491789315577279, 5.509094085813543, 5.525990134627923, 5.542489659581142, 5.558604381466696, 5.574345567429516, 5.589724052752797, 5.604750261401479, 5.61943422540462, 5.633785603152343, 5.647813696677687, 5.661527467988515, 5.674935554509694, 5.6880462836918095, 5.700867686838269, 5.713407512199213, 5.72567323737726, 5.7376720810867585, 5.749411014305721, 5.760896770856586, 5.7721358574496895, 5.783134563221078, 5.7938989687939815, 5.804434954891652, 5.814748210527134, 5.824844240794139, 5.83472837428136, 5.844405770131479, 5.853881424764449, 5.863160178283575, 5.872246720581779, 5.8811455971641635, 5.889861214702311, 5.898397846334498, 5.906759636725358, 5.914950606897636, 5.92297465884787, 5.930835579957284, 5.938537047208363, 5.946082631217033, 5.953475800089837, 5.960719923114825, 5.967818274294567, 5.9747740357290535, 5.981590300855891, 5.988270077554804, 5.994816291122962, 6.001231787127456, 6.007519334140734, 6.013681626364628, 6.019721286148152, 6.025640866404167, 6.0314428529295405, 6.037129666633312, 6.042703665677115, 6.048167147531792, 6.053522350954125, 6.058771457887177, 6.063916595287742, 6.068959836884137, 6.073903204867378, 6.07874867151874, 6.083498160776442, 6.088153549744094, 6.092716670143476, 6.0971893097139525, 6.10157321356089, 6.105870085455184, 6.110081589085972, 6.114209349268516, 6.118254953109065, 6.122219951128557, 6.1261058583467936, 6.129914155328735, 6.1336462891944645, 6.1373036745942455, 6.140887694650151, 6.144399701865532, 6.147841019003664, 6.151212939936733, 6.15451673046638, 6.157753629116895, 6.1609248479021135, 6.16403157306707, 6.167074965805326, 6.170056162952967, 6.172976277660108, 6.175836400040783, 6.178637597802039, 6.181380916852982, 6.18406738189457, 6.186697996990829, 6.189273746122201, 6.191795593721671, 6.194264485194292, 6.196681347420749, 6.19904708924549, 6.201362601950024, 6.203628759711891, 6.205846420049821, 6.208016424255584, 6.210139597812982, 6.2122167508044575, 6.214248678305726, 6.2162361607688785, 6.218179964394329, 6.2200808414920115, 6.221939530832184, 6.223756757986193, 6.225533235657559, 6.227269664003689, 6.228966730948549, 6.2306251124865915, 6.2322454729782315, 6.233828465437162, 6.2353747318097685, 6.2368849032469065, 6.2383596003683115, 6.239799433519843, 6.241205003023842, 6.242576899422803, 6.24391570371657, 6.245221987593296, 6.246496313654325, 6.247739235633232, 6.24895129860918, 6.250133039214796, 6.251284985838715, 6.252407658822986, 6.253501570655493, 6.2545672261575325, 6.255605122666738, 6.256615750215443, 6.257599591704679, 6.258557123073906, 6.2594888134666276, 6.26039512539201, 6.261276514882625, 6.262133431648456, 6.262966319227252, 6.263775615131364, 6.2645617509911675, 6.265325152695163, 6.266066240526876, 6.266785429298638, 6.267483128482344, 6.268159742337293, 6.268815670035176, 6.269451305782329, 6.270067038939299, 6.270663254137833, 6.271240331395351, 6.271798646226987, 6.272338569755267, 6.272860468817504, 6.273364706070957, 6.2738516400958595, 6.2743216254963405, 6.274775012999329, 6.2752121495514945, 6.275633378414288, 6.276039039257129, 6.276429468248811, 6.276804998147164, 6.277165958387052, 6.2775126751667205, 6.277845471532581, 6.278164667462456, 6.278470579947349, 6.278763523071774, 6.279043808092693, 6.2793117435171135, 6.279567635178376, 6.279811786311178, 6.280044497625393, 6.28026606737868, 6.2804767914479775, 6.28067696339988, 6.280866874559943, 6.281046814080972, 6.281217069010296, 6.281377924356093, 6.2815296631527815, 6.281672566525518, 6.2818069137538375, 6.281932982334445, 6.282051048043232, 6.282161384996499, 6.282264265711457, 6.282359961166002, 6.28244874085782, 6.282530872862828, 6.28260662389299, 6.28267625935354, 6.282740043399623, 6.282798238992391, 6.282851107954583, 6.282898911025601, 6.282941907916122, 6.282980357362259, 6.283014517179304, 6.28304464431507, 6.283070994902858, 6.283093824314079, 6.283113387210541, 6.283129937596436, 6.283143728870044, 6.283155013875178, 6.28316404495239, 6.283171073989962, 6.283176352474708, 6.2831801315426, 6.283182662029247, 6.283184194520244, 6.283184979401418, 6.283185266908986, 6.283185307179648, 6.283185350300646, 6.283185646359788, 6.283186445495488, 6.283187997946815, 6.28319055410359, 6.283194364556547, 6.283199680147581, 6.283206752020099, 6.2832158316695015, 6.283227170993815, 6.283241022344494, 6.283257638577419, 6.28327727310411, 6.28330017994317, 6.283326613772006, 6.2833568299788105, 6.283391084714866, 6.283429634947167, 6.283472738511401, 6.283520654165297, 6.283573641642377, 6.283631961706129, 6.283695876204626, 6.283765648125617, 6.283841541652118, 6.283923822218514, 6.2840127565672255, 6.284108612805932, 6.284211660465407, 6.284322170557975, 6.284440415636631, 6.284566669854831, 6.2847012090270065, 6.284844310689812, 6.284996254164149, 6.285157320617986, 6.285327793130012, 6.285507956754158, 6.285698098585004, 6.285898507824132, 6.286109475847419, 6.286331296273348, 6.2865642650323394, 6.2868086804371535, 6.2870648432544005, 6.287333056777193, 6.287613626898976, 6.287906862188589, 6.288213073966582, 6.288532576382837, 6.288865686495544, 6.28921272435156, 6.2895740130682105, 6.2899498789165715, 6.290340651406286, 6.290746663371954, 6.291168251061162, 6.291605754224186, 6.292059516205438, 6.292529884036695, 6.293017208532184, 6.293521844385559, 6.294044150268858, 6.294584488933475, 6.295143227313225, 6.2957207366295584, 6.296317392499014, 6.296933575042939, 6.29756966899959, 6.2982260638386665, 6.298903153878346, 6.299601338404925, 6.300321021795123, 6.301062613641138, 6.301826528878551, 6.302613187917154, 6.3034230167748, 6.304256447214374, 6.305113916883969, 6.305995869460384, 6.306902754796038, 6.307835029069413, 6.3087931549391385, 6.309777601701816, 6.3107888454537395, 6.311827369256595, 6.312893663307291, 6.313988225112047, 6.315111559664873, 6.316264179630581, 6.317446605532487, 6.318659365944931, 6.319902997690808, 6.321178046044227, 6.322485064938509, 6.323824617179678, 6.3251972746656175, 6.32660361861111, 6.328044239778918, 6.329519738717136, 6.331030726003005, 6.332577822493431, 6.334161659582387, 6.335782879465487, 6.337442135411934, 6.3391400920441185, 6.3408774256251075, 6.342654824354317, 6.344472988671631, 6.346332631570282, 6.348234478918766, 6.350179269792152, 6.352167756813068, 6.354200706502738, 6.356278899642421, 6.358403131645607, 6.360574212941382, 6.3627929693693215, 6.36506024258638, 6.3673768904861765, 6.369743787631131, 6.372161825697944, 6.374631913936882, 6.377154979645405, 6.37973196865665, 6.382363845843346, 6.385051595637714, 6.387796222567979, 6.390598751812117, 6.393460229769488, 6.396381724651057, 6.399364327088892, 6.402409150765723, 6.40551733306531, 6.408690035744461, 6.411928445627539, 6.415233775324345, 6.418607263972328, 6.422050178004074, 6.42556381194111, 6.429149489215083, 6.432808563017413, 6.436542417178621, 6.440352467078526, 6.444240160588604, 6.448206979047855, 6.452254438273547, 6.456384089608375, 6.460597521005513, 6.464896358153236, 6.469282265640746, 6.473756948167047, 6.478322151794715, 6.482979665250504, 6.487731321274907, 6.492578998022767, 6.497524620517282, 6.502570162159772, 6.507717646297705, 6.512969147853679, 6.5183267950180905, 6.523792771008474, 6.529369315898573, 6.535058728520395, 6.540863368442709, 6.546785658029539, 6.552828084582535, 6.558993202571183, 6.565283635955128, 6.571702080603075, 6.5782513068129616, 6.584934161938463, 6.591753573127029, 6.598712550175099, 6.605814188506297, 6.61306167227896, 6.620458277629497, 6.628007376058639, 6.6357124379679515, 6.6435770363544275, 6.651604850671548, 6.659799670865567, 6.66816540159639, 6.67670606665303, 6.685425813574076, 6.694328918484516, 6.703419791160733, 6.712702980336363, 6.722183179262544, 6.731865231536771, 6.741754137215815, 6.751855059228835, 6.762173330108106, 6.772714459055892, 6.783484139367117, 6.794488256229066, 6.805732894920532, 6.8172243494345865, 6.828969131550596, 6.840973980383225, 6.8532458724378, 6.8657920322037, 6.878619943319725, 6.89173736034764, 6.905152321193126, 6.9188731602158935, 6.932908522074058, 6.947267376351244, 6.961959033018421, 6.976993158786773, 6.99237979441194, 7.008129373014909, 7.024252739489986, 7.0407611710756886, 7.057666399170907, 7.074980632485031, 7.092716581618223, 7.110887485176076, 7.129507137531373, 7.148589918355729, 7.168150824053938, 7.188205501245795, 7.2087702824524555, 7.229862224158854, 7.251499147438629, 7.273699681345163, 7.296483309291098, 7.319870418659013, 7.343882353909297, 7.368541473476034, 7.393871210769968, 7.4198961396387855, 7.446642044669064, 7.474135996753294, 7.502406434387539, 7.53148325121334, 7.561397890370781, 7.592183446288781, 7.623874774606097, 7.656508610990647, 7.6901236997091384, 7.724760932893577, 7.760463501557146, 7.797277059532963, 7.835249901644124, 7.874433157567806, 7.914881003029842, 7.956650890165179, 7.999803799104087, 8.044404513101663, 8.090521919821832, 8.138229341722798, 8.187604898877717, 8.23873190800689, 8.29169932200947, 8.346602214872911, 8.403542317521001, 8.462628610955283, 8.52397798396582, 8.58771596376355, 8.653977529144534, 8.7229080172706, 8.79466413688739, 8.869415102845714, 8.947343909214371, 9.028648761147108, 9.113544689088597, 9.20226537299785, 9.295065209173092, 9.392221658172737, 9.494037919467548, 9.600845987130073, 9.713010151431135, 9.83093102415097, 9.955050181325689, 10.085855536818265, 10.223887584546281, 10.36974667772579, 10.524101551847288, 10.687699346572803, 10.861377443387228, 11.046077514762404, 11.24286228233701, 11.452935613772425, 11.677666760949517, 11.91861977055102, 12.177589402262864, 12.456645298830795, 12.758186707779974, 13.085010817506395, 13.440398830367632, 13.828225386652882, 14.253099080129882, 14.720544884229337, 15.237243835562081, 15.811352098387136, 16.45293187391797, 17.1745427330196, 17.992067659821352, 18.92589019358654, 20.00261004329238, 21.257608265075863, 22.738996970020516, 24.51391157728164, 26.67894431863874, 29.378290599567425, 32.83719486221428, 37.42820553239433, 43.815126328284634, 53.306786100787136, 68.89190988927808, 99.20778068307507, 183.8371597289453, null, -221.62792886611885, -101.46584243446526, -64.6492787032293, -46.79470253465951, -36.25362405005467, -29.29691717863086, -24.362434793033344, -20.680640936284004, -17.828499007071102, -15.554180788720132, -13.698411777030024, -12.155529228693304, -10.852675874214276, -9.737985404382275, -8.7735307377601, -7.930936075517508, -7.188548324626714, -6.529557519575169, -5.940714455444599, -5.411435284196347, -4.933163367153073, -4.498906093856748, -4.102893145678525, -3.740320610085284, -3.407156794887208, -3.099993056191889, -2.8159279192964455, -2.5524761345198606, -2.3074966249335116, -2.0791349006990156, -1.8657766610452482, -1.6660101276490744, -1.47859525074424, -1.3024383681239282, -1.1365712228150242, -0.9801334891560272, -0.8323581414302836, -0.6925591398158533, -0.5601210164791901, -0.43449002831464245, -0.31516660809319585, -0.2016988970167759, -0.09367718215690513, 0.00927090556202792, 0.1074845514502707, 0.20127337314268967, 0.29092057391375636, 0.3766857008699791, 0.45880706459943, 0.5375038677862003, 0.6129780828263196, 0.6854161123095373, 0.7549902611084551, 0.8218600445483184, 0.886173353565165, 0.948067494765279, 1.0076701207809395, 1.0651000641885227, 1.1204680864541743, 1.173877551839165, 1.2254250348927913, 1.275200869045284, 1.323289642856769, 1.3697706496585171, 1.4147182956142834, 1.4582024706196868, 1.5002888859291317, 1.5410393819408132, 1.5805122091729449, 1.6187622851161247, 1.6558414293443033, 1.691798579001647, 1.726679986549693, 1.7605294014560164, 1.793388237325169, 1.8252957258149105, 1.8562890585409995, 1.8864035180497818, 1.9156725988291106, 1.9441281192301787, 1.9718003250871132, 1.9987179857437618, 2.0249084831293045, 2.0503978944624848, 2.0752110691099697, 2.0993717000754026, 2.1229023905514826, 2.1458247159286423, 2.168159281617895, 2.1899257770139107, 2.2111430258956957, 2.231829033536038, 2.2520010307680542, 2.2716755152355077, 2.290868290034725, 2.3095944999386133, 2.327868665377282, 2.3457047143359504, 2.3631160123173975, 2.380115390504656, 2.3967151722488866, 2.412927197997326, 2.428762848767686, 2.4442330682667555, 2.45934838374383, 2.4741189256624407, 2.4885544462679845, 2.5026643371227415, 2.5164576456747136, 2.529943090921889, 2.543129078228888, 2.5560237133492203, 2.568634815702265, 2.580969930950838, 2.593036342922003, 2.6048410849106762, 2.616390950403149, 2.6276925032548544, 2.638752087354564, 2.649575835805022, 2.6601696796479244, 2.670539356159554, 2.6806904167414176, 2.6906282344288126, 2.700358011038773, 2.7098847839773414, 2.7192134327251067, 2.7283486850185037, 2.737295122743485, 2.7460571875569606, 2.7546391862506976, 2.763045295871251, 2.771279568608815, 2.7793459364671027, 2.787248215725536, 2.794990111204556, 2.802575220344047, 2.810007037104378, 2.8172889556990404, 2.824424274167233, 2.8314161977944385, 2.838267842388433, 2.844982237417819, 2.851562329019818, 2.858010982883545, 2.8643309870148532, 2.8705250543883176, 2.8765958254917243, 2.8825458707681415, 2.8883776929602973, 2.8940937293618774, 2.89969635397997, 2.9051878796127744, 2.910570559846372, 2.915846590974285, 2.921018113843251, 2.926087215628508, 2.931055931541747, 2.9359262464746467, 2.940700096580872, 2.945379370799174, 2.949965912320156, 2.9544615199991364, 2.9588679497173733, 2.9631869156939032, 2.967420091750035, 2.9715691125284986, 2.975635574669164, 2.9796210379430748, 2.9835270263465876, 2.987355029157202, 2.99110650195266, 2.9947828675948176, 2.9983855171796643, 3.00191581095491, 3.005375079206379, 3.0087646231144864, 3.012085715581929, 3.015339602033778, 3.0185275011910004, 3.0216506058184667, 3.0247100834484244, 3.0277070770803554, 3.030642705858161, 3.0335180657254996, 3.036334230060113, 3.0390922502879416, 3.0417931564777585, 3.0444379579170744, 3.0470276436699897, 3.0495631831176593, 3.0520455264820194, 3.0544756053333564, 3.056854333082345, 3.059182605457082, 3.061461300965668, 3.06369128134486, 3.0658733919952654, 3.06800846240359, 3.07009730655236, 3.072140723317591, 3.0741394968547846, 3.076094396973701, 3.0780061795022644, 3.0798755866399894, 3.081703347301287, 3.0834901774489833, 3.0852367804184055, 3.0869438472323316, 3.088612056907126, 3.090242076750357, 3.0918345626501607, 3.093390159356659, 3.094909500755664, 3.096393210134943, 3.0978419004432816, 3.0992561745425746, 3.100636625453184, 3.1019838365927797, 3.103298382008862, 3.10458082660519, 3.1058317263622914, 3.1070516285522567, 3.108241071947998, 3.1094005870271437, 3.1105306961707404, 3.111631913856931, 3.112704746849764, 3.113749694383281, 3.114767248341046, 3.1157578934312364, 3.116722107357458, 3.1176603609853952, 3.1185731185054424, 3.1194608375914306, 3.1203239695555696, 3.1211629594997303, 3.1219782464631702, 3.1227702635668146, 3.1235394381542045, 3.124286191929198, 3.1250109410905424, 3.1257140964633967, 3.126396063627907, 3.127057243044923, 3.127698030178931, 3.128318815618307, 3.128919985192954, 3.1295019200894143, 3.1300649969635206, 3.130609588050676, 3.131136061273821, 3.131644780349163, 3.1321361048897414, 3.132610390506877, 3.1330679889095934, 3.133509248002051, 3.1339345119790654, 3.134344121419767, 3.1347384133794534, 3.135117721479697, 3.135482375996758, 3.135832703948352, 3.136169029178828, 3.1364916724428062, 3.136800951487315, 3.1370971811324875, 3.137380673350852, 3.137651737345264, 3.137910679625529, 3.138157804083745, 3.1383934120684205, 3.138617802457397, 3.1388312717296203, 3.139034114035799, 3.1392266212679836, 3.139409083128106, 3.1395817871955147, 3.1397450189935374, 3.139899062055108, 3.1400441979874913, 3.140180706536134, 3.1403088656476794, 3.1404289515321713, 3.140541238724481, 3.1406460001449874, 3.1407435071595375, 3.140834029638719, 3.140917836016465, 3.140995193348035, 3.141066367367379, 3.1411316225439285, 3.14119122213883, 3.141245428260652, 3.14129450192059, 3.141338703087193, 3.14137829074064, 3.1414135229265834, 3.141444656809594, 3.1414719487262235, 3.1414956542377075, 3.14151602818234, 3.141533324727535, 3.1415477974215973, 3.141559699245235, 3.141569282662822, 3.141576799673445, 3.1415825018617483, 3.1415866404486055, 3.1415894663416313, 3.141591230185564, 3.1415921824125355, 3.1415925732922476, 3.141592652982084, 3.1415926715771705, 3.1415928791604104, 3.141593525852516, 3.1415948618620533, 3.1415971375355256, 3.1416006034075172, 3.141605510250914, 3.141612109127229, 3.1416206514370457, 3.1416313889706133, 3.1416445739586005, 3.141660459123043, 3.141679297728496, 3.141701343633425, 3.141726851341844, 3.1417560760552345, 3.1417892737247635, 3.1418267011038226, 3.141868615800914, 3.141915276332903, 3.1419669421786636, 3.142023873833145, 3.1420863328618687, 3.142154581955902, 3.142228884987312, 3.1423095070651432, 3.1423967145919294, 3.142490775320775, 3.1425919584130337, 3.1427005344966013, 3.142816775724861, 3.142940955836304, 3.1430733502148542, 3.143214235950925, 3.1433638919032423, 3.1435225987614572, 3.1436906391095865, 3.1438682974903043, 3.144055860470125, 3.1442536167055057, 3.1444618570099, 3.1446808744218036, 3.1449109642738193, 3.145152424262787, 3.145405554521003, 3.145670657688577, 3.14594803898696, 3.146238006293685, 3.1465408702183577, 3.1468569441799437, 3.147186544485391, 3.1475299904096317, 3.1478876042770105, 3.1482597115441844, 3.148646640884541, 3.149048724274182, 3.1494662970795293, 3.149899698146593, 3.1503492698919686, 3.1508153583956067, 3.151298313495412, 3.151798488883738, 3.1523162422058277, 3.1528519351602644, 3.1534059336014972, 3.1539786076445004, 3.1545703317716427, 3.155181484941826, 3.1558124507019683, 3.1564636173009077, 3.157135377805792, 3.1578281302210454, 3.158542277609982, 3.1592782282191507, 3.1600363956055064, 3.1608171987664755, 3.1616210622730287, 3.162448416405842, 3.163299697294648, 3.164175347060869, 3.165075813963653, 3.1660015525493987, 3.1669530238048997, 3.167930695314207, 3.1689350414193327, 3.169966543384926, 3.1710256895670335, 3.172112975586084, 3.1732289045042377, 3.1743739870072187, 3.1755487415908066, 3.1767536947521107, 3.1779893811858, 3.179256343985442, 3.1805551348501138, 3.1818863142964724, 3.183250451876448, 3.184648126400755, 3.186079926168418, 3.1875464492024905, 3.189048303492209, 3.1905861072417587, 3.1921604891259134, 3.193772088552739, 3.1954215559336383, 3.197109552960966, 3.198836752893475, 3.2006038408498743, 3.202411514110754, 3.2042604824292016, 3.2061514683503773, 3.208085207540386, 3.2100624491247634, 3.212083956036905, 3.2141505053768125, 3.216262888780504, 3.2184219128004785, 3.2206283992976372, 3.2228831858450517, 3.2251871261440415, 3.2275410904529824, 3.229945966029324, 3.232402657585306, 3.234912087757858, 3.2374751975932394, 3.240092947046948, 3.2427663154994866, 3.2454963022885575, 3.2482839272583472, 3.251130231326522, 3.2540362770696207, 3.257003149327571, 3.260031955828026, 3.2631238278313495, 3.266279920797012, 3.2695014150722614, 3.2727895166039542, 3.2761454576744384, 3.2795704976624953, 3.2830659238303093, 3.2866330521375393, 3.290273228083598, 3.293987827579259, 3.2977782578488535, 3.3016459583642765, 3.3055924018121448, 3.3096190950955107, 3.3137275803715407, 3.317919436126741, 3.3221962782912904, 3.326559761394185, 3.331011579760913, 3.3355534687555677, 3.3401872060692877, 3.344914613057088, 3.349737556125226, 3.3546579481713126, 3.3596777500795882, 3.3647989722738134, 3.370023676330393, 3.375353976654506, 3.3807920422220903, 3.3863400983907876, 3.3920004287830237, 3.3977753772446047, 3.403667349882433, 3.409678817185023, 3.4158123162298812, 3.4220704529818464, 3.4284559046868512, 3.434971422365764, 3.4416198334131813, 3.4484040443064483, 3.4553270434303425, 3.4623919040232813, 3.4696017872511273, 3.4769599454151887, 3.4844697253012393, 3.492134571676866, 3.4999580309449074, 3.5079437549610883, 3.5160955050246514, 3.5244171560511197, 3.5329127009369916, 3.5415862551267967, 3.550442061393449, 3.559484494843743, 3.568718068161381, 3.578147437100812, 3.5877774062460484, 3.5976129350493853, 3.607659144166172, 3.6179213221026147, 3.628404932194841, 3.639115619938698, 3.6500592206909026, 3.661241767763861, 3.672669500937699, 3.684348875414919, 3.6962865712446513, 3.708489503245646, 3.7209648314589656, 3.7337199721637018, 3.746762609491477, 3.7601007076779167, 3.7737425239924227, 3.7876966223903263, 3.8019718879350095, 3.816577542041199, 3.8315231585943454, 3.846818681005629, 3.862474440266415, 3.8785011740712143, 3.8949100470837372, 3.911712672426388, 3.928921134480488, 3.9465480130912844, 3.9646064092798365, 3.9831099725724495, 4.00207293006744, 4.02151011736974, 4.041437011534682, 4.061869766175045, 4.082825248898694, 4.104321081259661, 4.126375681421515, 4.149008309750418, 4.172239117575371, 4.19608919937511, 4.220580648676254, 4.245736617974083, 4.27158138301786, 4.298140411836249, 4.325440438915381, 4.353509544984398, 4.382377242908998, 4.412074570245701, 4.442634189067443, 4.474090493735471, 4.506479727365899, 4.539840107820106, 4.574211964140236, 4.609637884454386, 4.646162876491967, 4.683834541982227, 4.722703266356881, 4.762822425347098, 4.804248610256775, 4.8470418739114915, 4.891265999532074, 4.93698879506451, 4.984282415823543, 5.033223718678833, 5.083894651441629, 5.136382681601616, 5.1907812691329624, 5.247190388746693, 5.305717107728762, 5.366476226391637, 5.429590989199797, 5.495193875838549, 5.563427482911534, 5.634445508615313, 5.708413854702318, 5.785511862360578, 5.865933701389762, 5.94988993532584, 6.037609289073379, 6.129340650289512, 6.225355341394505, 6.3259497058867264, 6.431448060886365, 6.542206077871192, 6.658614665848786, 6.781104446292431, 6.910150927793626, 7.046280511490293, 7.190077487159503, 7.342192216021569, 7.503350741933661, 7.674366130586398, 7.856151910356769, 8.049738083757916, 8.256290301940329, 8.47713295606665, 8.713777151935178, 8.967954816664069, 9.241660565081995, 9.537203466671585, 9.857271556634608, 10.205012907966982, 10.584138446297702, 10.999053628883615, 11.455028905662736, 11.958422976010844, 12.51697895697165, 13.140222842179067, 13.840007986409374, 14.631272111292954, 15.533110341274739, 16.570329704065735, 17.77575750187411, 19.19376759012488, 20.885846510129923, 22.939723029733653, 25.485040476434406, 28.721784371416987, 32.97547744805289, 38.814020394364846, 47.324875759359294, 60.88543963506136, 85.8819532650027, 147.31739392111953, null, null, -121.28383006386758, -74.53821446448183, -53.564864235374756, -41.65692720944922, -33.981964244293, -28.623980920633684, -24.671719170927446, -21.636393785083616, -19.232290943689613, -17.281230832034673, -15.666327789245916, -14.307720873428627, -13.148989649729401, -12.14914190282608, -11.277677506848695, -10.51143345049316, -9.832502722530759, -9.226823520909173, -8.683199723840715, -8.192606275397162, -7.747687271093584, -7.342387131087982, -6.971675432382844, -6.631338779229118, -6.317821400897482, -6.028101667232168, -5.759595421590811, -5.510079573858527, -5.277631166805298, -5.060578379353955, -4.8574608248316125, -4.666997150055199, -4.488058415501968, -4.319646087923975, -4.16087373917178, -4.010951742930298, -3.8691744116573235, -3.7349091315195206, -3.60758714239412, -3.486695679496883, -3.3717712476711634, -3.2623938423412016, -3.158181965238904, -3.0587883102428375, -2.963896016522675, -2.873215403823493, -2.786481119028104, -2.7034496347934827, -2.6238970506021713, -2.547617154414457, -2.4744197095884313, -2.4041289371048835, -2.3365821676038174, -2.271628641473677, -2.2091284383619505, -2.1489515201095757, -2.0909768733311473, -2.035091739744152, -1.9811909239451473, -1.9291761696915706, -1.8789555969077645, -1.830443192627821, -1.7835583499419148, -1.7382254497460687, -1.6943734807303557, -1.6519356935879919, -1.6108492859030497, -1.5710551145880287, -1.5324974331009944, -1.4951236509867858, -1.4588841135604698, -1.4237318997915809, -1.389622636659114, -1.3565143284318424, -1.324367199492864, -1.293143549470972, -1.2628076195689961, -1.2333254690926005, -1.2046648612823976, -1.176795157642017, -1.1496872200333157, -1.1233133198810186, -1.0976470538913334, -1.0726632657460038, -1.0483379732832265, -1.0246483007219798, -1.0015724155271255, -0.9790894695484176, -0.9571795440998678, -0.9358235986750345, -0.9150034230203912, -0.8947015923132215, -0.8749014252116403, -0.8555869445644932, -0.8367428405863591, -0.8183544363190074, -0.8004076552155679, -0.7828889906964949, -0.7657854775389732, -0.7490846649721659, -0.7327745913607446, -0.7168437603685436, -0.7012811185021264, -0.6860760339421228, -0.6712182765768646, -0.6566979991595563, -0.6425057195156982, -0.6286323037332406, -0.6150689502726614, -0.6018071749387155, -0.5888387966599584, -0.5761559240256562, -0.5637509425335558, -0.5516165025050639, -0.5397455076273807, -0.5281311040850911, -0.5167666702459603, -0.5056458068683594, -0.49476232779975016, -0.4841102511377018, -0.4736837908269236, -0.4634773486672785, -0.45348550670961774, -0.4437030200176113, -0.4341248097751509, -0.4247459567203191, -0.41556169488787953, -0.4065674056436033, -0.39775861199459284, -0.38913097316091405, -0.38068027939451254, -0.37240244703245695, -0.36429351377219765, -0.35634963415727294, -0.3485670752626808, -0.3409422125695749, -0.33347152601973606, -0.326151596240716, -0.31897910093306536, -0.31195081141165626, -0.30506358929338084, -0.29831438332411375, -0.2917002263381274, -0.2852182323435217, -0.2788655937276834, -0.27263957857694643, -0.266537528105109, -0.2605568541856562, -0.2546950369828116, -0.24894962267688814, -0.2433182212795013, -0.23779850453458562, -0.23238820390125636, -0.22708510861487197, -0.22188706382270107, -0.216791968790917, -0.21179777517972775, -0.20690248538362144, -0.20210415093391776, -0.19740087096084113, -0.19279079071258787, -0.18827210012891538, -0.1838430324669027, -0.17950186297671022, -0.1752469076251616, -0.1710765218651824, -0.16698909944916496, -0.1629830712844188, -0.15905690432901154, -0.15520910052628378, -0.15143819577650308, -0.14774275894413214, -0.14412139089926435, -0.14057272359188955, -0.13709541915763268, -0.13368816905375336, -0.13034969322418455, -0.12707873929250646, -0.12387408178172044, -0.120734521359815, -0.11765888411011749, -0.11464602082546793, -0.11169480632533768, -0.10880413879497774, -0.10597293914579575, -0.10320015039615182, -0.10048473707180161, -0.09782568462528185, -0.09522199887350036, -0.09267270545288653, -0.09017684929145142, -0.0877334940971285, -0.08534172186183409, -0.08300063238064181, -0.0807093427855552, -0.07846698709334787, -0.07627271576696126, -0.07412569529000446, -0.0720251077538624, -0.0699701504569945, -0.06796003551598018, -0.06599398948792523, -0.06407125300380823, -0.062191080412410504, -0.06035273943445929, -0.0585555108266288, -0.056798688055085145, -0.05508157697822258, -0.05340349553830381, -0.05176377346169758, -0.0501617519674199, -0.04859678348372054, -0.047068231372424774, -0.04557546966079129, -0.04411788278063322, -0.04269486531445976, -0.04130582174842312, -0.03995016623183156, -0.038627322343028236, -0.03733672286142686, -0.03607780954550227, -0.03485003291655664, -0.03365285204806029, -0.032485734360404084, -0.03134815542088021, -0.030239598748740493, -0.029159555625155098, -0.028107524907929837, -0.02708301285082948, -0.02608553292735888, -0.025114605658874245, -0.024169758446875578, -0.023250525409361567, -0.02235644722111757, -0.02148707095781255, -0.02064194994379659, -0.01982064360347424, -0.01902271731615157, -0.018247742274249523, -0.017495295344776784, -0.01676495893397162, -0.016056320855005135, -0.0153689741986619, -0.01470251720690341, -0.014056553149225881, -0.013430690201734763, -0.01282454132884342, -0.012237724167525388, -0.0116698609140366, -0.011120578213040355, -0.010589507049053704, -0.01007628264015159, -0.009580544333857743, -0.009101935505155534, -0.008640103456558468, -0.008194699320171916, -0.007765377961690134, -0.007351797886268552, -0.006953621146211841, -0.006570513250427568, -0.006202143075584754, -0.0058481827789295115, -0.005508307712705551, -0.005182196340127898, -0.004869530152865897, -0.004569993589982835, -0.004283273958290756, -0.0040090613540740005, -0.0037470485861372527, -0.003496931100138767, -0.0032584069041632913, -0.0030311764954977505, -0.0028149427885681144, -0.0026094110440018914, -0.0024142887987753103, -0.0022292857974112734, -0.002054113924191636, -0.0018884871363480382, -0.0017321213981993933, -0.0015847346161998732, -0.001446046574866966, -0.0013157788735566334, -0.0011936548640543998, -0.001079399588952562, -0.0009727397207820454, -0.0008734035018707065, -0.0007811206848987451, -0.0006956224741227202, -0.0006166414672411635, -0.0005439115978731063, -0.00047716807862406563, -0.0004161473447120839, -0.0003605869981282428, -0.0003102257523064089, -0.0002648033772760794, -0.00022406064527444314, -0.00018773927679253954, -0.00015558188703181097, -0.00012733193274680477, -0.00010273365945055735, -8.153204895958166e-05, -6.347276725506695e-05, -4.830211263775336e-05, -3.57669641536662e-05, -2.5614730268491703e-05, -1.7593297768202232e-05, -1.1450980864025073e-05, -6.93647047977225e-06, -3.7987836997779856e-06, -1.7872133557875203e-06, -6.512777312658868e-07, -1.4067036165597846e-07, -5.209909173346794e-09, 5.209909173346794e-09, 1.4067036165597846e-07, 6.512777312658868e-07, 1.7872133557875203e-06, 3.7987836997779856e-06, 6.936470479775719e-06, 1.1450980864025073e-05, 1.7593297768202232e-05, 2.5614730268498642e-05, 3.576696415367314e-05, 4.83021126377603e-05, 6.347276725506695e-05, 8.153204895958166e-05, 0.00010273365945057122, 0.00012733193274681864, 0.00015558188703183873, 0.00018773927679253954, 0.00022406064527444314, 0.00026480337727610714, 0.00031022575230645055, 0.00036058699812828443, 0.0004161473447120839, 0.00047716807862410726, 0.0005439115978731618, 0.0006166414672412052, 0.0006956224741227757, 0.0007811206848987451, 0.000873403501870762, 0.0009727397207821287, 0.0010793995889526453, 0.0011936548640543998, 0.0013157788735566334, 0.0014460465748670492, 0.0015847346161999842, 0.0017321213981995043, 0.0018884871363480382, 0.002054113924191636, 0.002229285797411412, 0.002414288798775449, 0.002609411044002058, 0.0028149427885681144, 0.0030311764954977505, 0.003258406904163458, 0.0034969311001389614, 0.003747048586137447, 0.0040090613540740005, 0.004283273958290951, 0.004569993589983029, 0.0048695301528661195, 0.005182196340128176, 0.005508307712705551, 0.005848182778929789, 0.0062021430755850315, 0.006570513250427845, 0.006953621146211841, 0.007351797886268552, 0.007765377961690412, 0.008194699320172194, 0.0086401034565588, 0.009101935505155534, 0.009580544333857743, 0.010076282640151923, 0.010589507049054092, 0.011120578213040744, 0.0116698609140366, 0.012237724167525388, 0.012824541328843864, 0.013430690201735207, 0.01405655314922638, 0.01470251720690341, 0.0153689741986624, 0.016056320855005635, 0.01676495893397212, 0.01749529534477734, 0.018247742274249523, 0.019022717316152127, 0.019820643603474797, 0.0206419499437972, 0.02148707095781255, 0.02235644722111757, 0.023250525409362233, 0.024169758446876244, 0.02511460565887491, 0.02608553292735888, 0.02708301285082948, 0.02810752490793056, 0.02915955562515582, 0.03023959874874127, 0.03134815542088021, 0.032485734360404084, 0.03365285204806112, 0.03485003291655747, 0.03607780954550316, 0.03733672286142686, 0.038627322343029125, 0.03995016623183256, 0.04130582174842412, 0.04269486531446076, 0.04411788278063322, 0.0455754696607924, 0.047068231372425884, 0.04859678348372165, 0.0501617519674199, 0.05176377346169758, 0.053403495538304924, 0.05508157697822369, 0.056798688055086366, 0.0585555108266288, 0.06035273943445929, 0.06219108041241184, 0.06407125300380956, 0.06599398948792656, 0.06796003551598018, 0.0699701504569945, 0.07202510775386384, 0.07412569529000601, 0.07627271576696282, 0.07846698709334787, 0.08070934278555686, 0.08300063238064337, 0.08534172186183575, 0.08773349409713016, 0.09017684929145142, 0.09267270545288842, 0.09522199887350213, 0.09782568462528374, 0.1004847370718035, 0.10320015039615182, 0.10597293914579775, 0.10880413879497985, 0.11169480632533979, 0.11464602082546793, 0.11765888411011749, 0.12073452135981722, 0.12387408178172266, 0.12707873929250868, 0.13034969322418455, 0.13368816905375336, 0.13709541915763512, 0.140572723591892, 0.1441213908992669, 0.14774275894413214, 0.15143819577650564, 0.15520910052628656, 0.15905690432901431, 0.16298307128442158, 0.16698909944916496, 0.1710765218651853, 0.1752469076251646, 0.17950186297671333, 0.1838430324669058, 0.18827210012891538, 0.1927907907125911, 0.19740087096084435, 0.2021041509339212, 0.20690248538362144, 0.21179777517972775, 0.21679196879092055, 0.22188706382270484, 0.22708510861487552, 0.23238820390125636, 0.23779850453458562, 0.2433182212795053, 0.24894962267689213, 0.2546950369828156, 0.2605568541856562, 0.2665375281051132, 0.27263957857695065, 0.27886559372768804, 0.2852182323435264, 0.2917002263381274, 0.29831438332411864, 0.30506358929338573, 0.31195081141166114, 0.31897910093307047, 0.326151596240716, 0.3334715260197414, 0.34094221256958024, 0.3485670752626864, 0.35634963415727294, 0.36429351377219765, 0.3724024470324627, 0.38068027939451854, 0.38913097316092005, 0.39775861199459284, 0.4065674056436033, 0.41556169488788597, 0.4247459567203258, 0.43412480977515755, 0.4437030200176113, 0.4534855067096246, 0.4634773486672856, 0.4736837908269309, 0.48411025113770934, 0.49476232779975016, 0.5056458068683671, 0.5167666702459683, 0.5281311040850991, 0.5397455076273889, 0.5516165025050639, 0.5637509425335647, 0.5761559240256651, 0.5888387966599675, 0.6018071749387155, 0.6150689502726614, 0.6286323037332502, 0.642505719515708, 0.6566979991595665, 0.6712182765768646, 0.6860760339421228, 0.7012811185021373, 0.7168437603685547, 0.7327745913607562, 0.7490846649721659, 0.7657854775389852, 0.7828889906965071, 0.8004076552155805, 0.8183544363190203, 0.8367428405863591, 0.855586944564507, 0.874901425211654, 0.8947015923132358, 0.9150034230204058, 0.9358235986750345, 0.9571795440998834, 0.9790894695484336, 1.0015724155271415, 1.0246483007219798, 1.0483379732832265, 1.072663265746021, 1.0976470538913516, 1.1233133198810372, 1.1496872200333157, 1.176795157642017, 1.2046648612824176, 1.2333254690926214, 1.2628076195690174, 1.293143549470972, 1.3243671994928863, 1.356514328431866, 1.389622636659138, 1.4237318997916057, 1.4588841135604698, 1.495123650986812, 1.5324974331010215, 1.5710551145880567, 1.6108492859030785, 1.6519356935879919, 1.6943734807303863, 1.7382254497461003, 1.7835583499419476, 1.830443192627821, 1.8789555969077645, 1.929176169691607, 1.981190923945185, 2.035091739744191, 2.0909768733311473, 2.1489515201095757, 2.209128438361994, 2.2716286414737223, 2.3365821676038645, 2.4041289371048835, 2.4744197095884823, 2.54761715441451, 2.6238970506022268, 2.7034496347935404, 2.786481119028104, 2.873215403823556, 2.9638960165227406, 3.0587883102429068, 3.1581819652389767, 3.2623938423412016, 3.3717712476712434, 3.4866956794969663, 3.607587142394209, 3.7349091315195206, 3.8691744116573235, 4.010951742930402, 4.16087373917189, 4.319646087924092, 4.488058415501968, 4.666997150055199, 4.857460824831752, 5.060578379354104, 5.277631166805457, 5.510079573858527, 5.759595421590995, 6.028101667232366, 6.317821400897696, 6.631338779229349, 6.971675432382844, 7.342387131088257, 7.747687271093884, 8.192606275397493, 8.683199723841081, 9.226823520909173, 9.832502722531213, 10.511433450493671, 11.277677506849274, 12.14914190282608, 13.148989649729401, 14.307720873429515, 15.666327789246964, 17.281230832035927, 19.232290943689613, 21.636393785083616, 24.671719170929887, 28.623980920636917, 33.98196424429749, 41.65692720944922, 53.56486423538555, 74.5382144645024, 121.28383006392119, null, null, -147.31739392104407, -85.88195326497745, -60.88543963504886, -47.32487575935187, -38.814020394364846, -32.97547744804939, -28.721784371414376, -25.48504047643238, -22.939723029733653, -20.885846510129923, -19.193767590123787, -17.775757501873183, -16.570329704064946, -15.533110341274739, -14.631272111292954, -13.840007986408846, -13.140222842178598, -12.516978956971231, -11.958422976010844, -11.455028905662395, -10.999053628883306, -10.584138446297422, -10.205012907966724, -9.857271556634608, -9.537203466671365, -9.241660565081792, -8.96795481666388, -8.713777151935004, -8.47713295606665, -8.256290301940176, -8.049738083757774, -7.856151910356636, -7.674366130586398, -7.503350741933661, -7.342192216021458, -7.190077487159397, -7.046280511490194, -6.910150927793626, -6.781104446292431, -6.6586146658487015, -6.542206077871112, -6.4314480608862885, -6.3259497058867264, -6.225355341394436, -6.129340650289445, -6.037609289073315, -5.949889935325779, -5.865933701389762, -5.785511862360522, -5.708413854702265, -5.634445508615261, -5.563427482911484, -5.495193875838549, -5.429590989199751, -5.366476226391592, -5.30571710772872, -5.247190388746693, -5.1907812691329624, -5.136382681601578, -5.083894651441593, -5.033223718678798, -4.984282415823543, -4.93698879506451, -4.891265999532042, -4.8470418739114605, -4.804248610256745, -4.762822425347098, -4.722703266356852, -4.6838345419822, -4.646162876491941, -4.60963788445436, -4.574211964140236, -4.539840107820082, -4.506479727365876, -4.4740904937354475, -4.442634189067421, -4.412074570245701, -4.3823772429089765, -4.353509544984378, -4.325440438915361, -4.298140411836249, -4.27158138301786, -4.245736617974065, -4.220580648676236, -4.196089199375093, -4.172239117575371, -4.149008309750418, -4.126375681421499, -4.104321081259646, -4.082825248898679, -4.061869766175045, -4.041437011534682, -4.021510117369726, -4.002072930067426, -3.983109972572436, -3.9646064092798365, -3.946548013091272, -3.9289211344804755, -3.9117126724263755, -3.8949100470837257, -3.8785011740712143, -3.862474440266404, -3.846818681005618, -3.8315231585943343, -3.816577542041199, -3.8019718879350095, -3.7876966223903157, -3.773742523992413, -3.760100707677907, -3.746762609491477, -3.7337199721637018, -3.7209648314589567, -3.7084895032456373, -3.6962865712446424, -3.684348875414919, -3.672669500937699, -3.661241767763853, -3.6500592206908946, -3.63911561993869, -3.628404932194841, -3.617921322102607, -3.6076591441661643, -3.597612935049378, -3.5877774062460417, -3.578147437100812, -3.5687180681613744, -3.5594844948437365, -3.550442061393442, -3.5415862551267967, -3.5329127009369916, -3.524417156051114, -3.516095505024646, -3.507943754961082, -3.4999580309449074, -3.492134571676866, -3.484469725301234, -3.4769599454151834, -3.469601787251122, -3.4623919040232813, -3.4553270434303425, -3.448404044306443, -3.4416198334131765, -3.4349714223657593, -3.4284559046868512, -3.422070452981842, -3.415812316229877, -3.4096788171850188, -3.4036673498824284, -3.3977753772446047, -3.3920004287830197, -3.386340098390784, -3.3807920422220863, -3.375353976654506, -3.370023676330393, -3.3647989722738094, -3.3596777500795847, -3.354657948171309, -3.349737556125226, -3.344914613057088, -3.340187206069284, -3.335553468755564, -3.33101157976091, -3.326559761394185, -3.3221962782912904, -3.317919436126738, -3.3137275803715376, -3.309619095095508, -3.3055924018121448, -3.301645958364274, -3.297778257848851, -3.2939878275792562, -3.290273228083595, -3.2866330521375393, -3.283065923830307, -3.279570497662493, -3.276145457674436, -3.2727895166039542, -3.2695014150722614, -3.26627992079701, -3.2631238278313477, -3.260031955828024, -3.257003149327571, -3.2540362770696207, -3.25113023132652, -3.2482839272583455, -3.2454963022885552, -3.2427663154994866, -3.240092947046948, -3.2374751975932377, -3.234912087757856, -3.2324026575853044, -3.229945966029324, -3.2275410904529807, -3.22518712614404, -3.2228831858450504, -3.220628399297636, -3.2184219128004785, -3.2162628887805025, -3.2141505053768107, -3.2120839560369037, -3.2100624491247634, -3.208085207540386, -3.206151468350376, -3.2042604824292003, -3.2024115141107528, -3.2006038408498743, -3.198836752893475, -3.197109552960965, -3.1954215559336374, -3.193772088552738, -3.1921604891259134, -3.1905861072417587, -3.1890483034922075, -3.1875464492024896, -3.1860799261684165, -3.184648126400755, -3.183250451876447, -3.1818863142964715, -3.180555134850113, -3.1792563439854407, -3.1779893811858, -3.17675369475211, -3.1755487415908057, -3.1743739870072183, -3.1732289045042377, -3.172112975586084, -3.1710256895670326, -3.1699665433849256, -3.1689350414193322, -3.167930695314207, -3.1669530238048997, -3.1660015525493983, -3.165075813963652, -3.1641753470608682, -3.163299697294648, -3.162448416405842, -3.1616210622730283, -3.160817198766475, -3.160036395605506, -3.1592782282191507, -3.158542277609981, -3.157828130221045, -3.1571353778057913, -3.156463617300907, -3.1558124507019683, -3.1551814849418256, -3.1545703317716427, -3.1539786076445, -3.1534059336014972, -3.1528519351602644, -3.1523162422058273, -3.1517984888837374, -3.1512983134954116, -3.1508153583956067, -3.1503492698919686, -3.1498996981465925, -3.149466297079529, -3.149048724274182, -3.148646640884541, -3.1482597115441844, -3.1478876042770105, -3.147529990409631, -3.1471865444853906, -3.1468569441799437, -3.1465408702183577, -3.1462380062936846, -3.14594803898696, -3.145670657688577, -3.145405554521003, -3.145152424262787, -3.1449109642738193, -3.144680874421803, -3.1444618570099, -3.1442536167055057, -3.144055860470125, -3.143868297490304, -3.143690639109586, -3.1435225987614572, -3.1433638919032423, -3.143214235950925, -3.1430733502148542, -3.142940955836304, -3.142816775724861, -3.1427005344966013, -3.1425919584130337, -3.142490775320775, -3.1423967145919294, -3.1423095070651432, -3.142228884987312, -3.142154581955902, -3.1420863328618687, -3.1420238738331445, -3.1419669421786636, -3.141915276332903, -3.141868615800914, -3.1418267011038226, -3.1417892737247635, -3.1417560760552345, -3.141726851341844, -3.141701343633425, -3.141679297728496, -3.141660459123043, -3.1416445739586005, -3.1416313889706133, -3.1416206514370457, -3.141612109127229, -3.141605510250914, -3.1416006034075172, -3.1415971375355256, -3.1415948618620533, -3.141593525852516, -3.1415928791604104, -3.1415926715771705, -3.141592652982084, -3.1415925732922476, -3.1415921824125355, -3.141591230185564, -3.1415894663416313, -3.1415866404486055, -3.1415825018617483, -3.141576799673445, -3.141569282662822, -3.141559699245235, -3.1415477974215973, -3.141533324727535, -3.14151602818234, -3.1414956542377075, -3.1414719487262235, -3.141444656809594, -3.1414135229265834, -3.14137829074064, -3.141338703087193, -3.14129450192059, -3.141245428260652, -3.14119122213883, -3.1411316225439285, -3.141066367367379, -3.140995193348035, -3.140917836016465, -3.140834029638719, -3.1407435071595375, -3.140646000144987, -3.140541238724481, -3.1404289515321713, -3.1403088656476794, -3.140180706536134, -3.1400441979874913, -3.139899062055108, -3.139745018993537, -3.1395817871955147, -3.139409083128106, -3.1392266212679836, -3.139034114035799, -3.1388312717296203, -3.138617802457397, -3.1383934120684205, -3.138157804083745, -3.137910679625529, -3.137651737345264, -3.137380673350852, -3.1370971811324875, -3.1368009514873147, -3.136491672442806, -3.136169029178828, -3.135832703948352, -3.135482375996758, -3.1351177214796966, -3.134738413379453, -3.1343441214197667, -3.1339345119790654, -3.133509248002051, -3.1330679889095934, -3.1326103905068767, -3.1321361048897414, -3.131644780349163, -3.1311360612738204, -3.1306095880506755, -3.13006499696352, -3.1295019200894143, -3.128919985192954, -3.1283188156183064, -3.1276980301789306, -3.1270572430449226, -3.126396063627907, -3.1257140964633963, -3.125010941090542, -3.1242861919291975, -3.1235394381542037, -3.1227702635668146, -3.1219782464631693, -3.12116295949973, -3.120323969555569, -3.1194608375914297, -3.1185731185054424, -3.1176603609853943, -3.1167221073574574, -3.115757893431236, -3.114767248341046, -3.113749694383281, -3.1127047468497633, -3.1116319138569306, -3.1105306961707395, -3.1094005870271437, -3.108241071947998, -3.107051628552256, -3.1058317263622905, -3.104580826605189, -3.103298382008862, -3.1019838365927788, -3.100636625453183, -3.0992561745425733, -3.0978419004432807, -3.096393210134943, -3.094909500755663, -3.093390159356658, -3.0918345626501598, -3.090242076750356, -3.088612056907126, -3.0869438472323303, -3.085236780418404, -3.083490177448982, -3.081703347301287, -3.0798755866399894, -3.078006179502263, -3.0760943969736996, -3.0741394968547833, -3.072140723317591, -3.07009730655236, -3.068008462403588, -3.0658733919952637, -3.063691281344858, -3.061461300965668, -3.0591826054570808, -3.0568543330823434, -3.0544756053333546, -3.0520455264820177, -3.0495631831176593, -3.047027643669988, -3.044437957917072, -3.0417931564777563, -3.03909225028794, -3.036334230060113, -3.033518065725498, -3.030642705858159, -3.027707077080353, -3.0247100834484244, -3.0216506058184667, -3.018527501190998, -3.0153396020337757, -3.012085715581927, -3.0087646231144864, -3.005375079206379, -3.001915810954907, -2.9983855171796616, -2.994782867594815, -2.99110650195266, -2.9873550291571993, -2.983527026346585, -2.9796210379430716, -2.975635574669161, -2.9715691125284986, -2.9674200917500317, -2.9631869156939, -2.95886794971737, -2.9544615199991333, -2.949965912320156, -2.945379370799171, -2.9407000965808683, -2.935926246474643, -2.931055931541747, -2.926087215628508, -2.921018113843247, -2.9158465909742812, -2.910570559846368, -2.9051878796127744, -2.89969635397997, -2.894093729361874, -2.888377692960294, -2.8825458707681375, -2.8765958254917243, -2.870525054388313, -2.864330987014849, -2.8580109828835405, -2.8515623290198135, -2.844982237417819, -2.8382678423884276, -2.831416197794434, -2.824424274167228, -2.817288955699035, -2.810007037104378, -2.8025752203440417, -2.7949901112045508, -2.7872482157255303, -2.7793459364671027, -2.771279568608815, -2.763045295871245, -2.7546391862506914, -2.7460571875569544, -2.737295122743485, -2.7283486850185037, -2.7192134327251, -2.709884783977335, -2.700358011038766, -2.6906282344288126, -2.6806904167414105, -2.670539356159547, -2.6601696796479173, -2.649575835805014, -2.638752087354564, -2.6276925032548464, -2.6163909504031406, -2.6048410849106682, -2.5930363429219945, -2.580969930950838, -2.5686348157022563, -2.5560237133492114, -2.543129078228879, -2.529943090921889, -2.5164576456747136, -2.5026643371227317, -2.4885544462679743, -2.47411892566243, -2.45934838374383, -2.4442330682667555, -2.4287628487676747, -2.4129271979973144, -2.396715172248875, -2.380115390504656, -2.363116012317385, -2.3457047143359375, -2.3278686653772693, -2.3095944999386004, -2.290868290034725, -2.271675515235494, -2.25200103076804, -2.231829033536023, -2.211143025895681, -2.1899257770139107, -2.1681592816178794, -2.1458247159286263, -2.122902390551466, -2.0993717000754026, -2.0752110691099697, -2.050397894462467, -2.0249084831292863, -1.9987179857437432, -1.9718003250871132, -1.9441281192301787, -1.9156725988290901, -1.886403518049761, -1.8562890585409777, -1.8252957258149105, -1.7933882373251464, -1.760529401455993, -1.7266799865496685, -1.6917985790016221, -1.6558414293443033, -1.618762285116098, -1.5805122091729173, -1.5410393819407848, -1.5002888859291024, -1.4582024706196868, -1.4147182956142523, -1.3697706496584847, -1.3232896428567358, -1.275200869045284, -1.2254250348927913, -1.1738775518391278, -1.1204680864541356, -1.0651000641884827, -1.0076701207809395, -0.948067494765279, -0.8861733535651202, -0.8218600445482718, -0.7549902611084067, -0.6854161123095373, -0.6129780828262668, -0.5375038677861457, -0.45880706459937315, -0.3766857008699196, -0.29092057391375636, -0.20127337314262483, -0.10748455145020319, -0.009270905561956866, 0.09367718215697973, 0.2016988970167759, 0.31516660809327846, 0.4344900283147295, 0.5601210164792816, 0.6925591398158533, 0.8323581414302836, 0.9801334891561355, 1.1365712228151388, 1.302438368124049, 1.47859525074424, 1.6660101276490744, 1.8657766610453947, 2.079134900699172, 2.3074966249336795, 2.5524761345198606, 2.8159279192964455, 3.0999930561920985, 3.4071567948874355, 3.740320610085531, 4.102893145678525, 4.498906093857041, 4.933163367153398, 5.411435284196704, 5.940714455444995, 6.529557519575169, 7.188548324627211, 7.930936075518067, 8.773530737760737, 9.737985404382275, 10.852675874214276, 12.15552922869431, 13.698411777031222, 15.554180788721581, 17.828499007071102, 20.680640936284004, 24.362434793036343, 29.296917178634963, 36.25362405006062, 46.79470253465951, 64.6492787032293, 101.46584243450529, 221.62792886630086, null, -183.8371597289453, -99.20778068304335, -68.89190988926346, -53.30678610077875, -43.815126328279206, -37.42820553239433, -32.837194862211476, -29.378290599565272, -26.678944318637033, -24.51391157728164, -22.738996970020516, -21.2576082650749, -20.002610043291554, -18.92589019358583, -17.992067659821352, -17.1745427330196, -16.45293187391749, -15.811352098386706, -15.237243835561696, -14.720544884229337, -14.253099080129882, -13.828225386652592, -13.44039883036737, -13.085010817506154, -12.758186707779974, -12.456645298830589, -12.177589402262672, -11.918619770550844, -11.677666760949352, -11.452935613772425, -11.242862282336866, -11.046077514762267, -10.861377443387102, -10.687699346572803, -10.524101551847288, -10.369746677725683, -10.22388758454618, -10.08585553681817, -9.955050181325689, -9.83093102415097, -9.713010151431053, -9.600845987129995, -9.494037919467475, -9.392221658172737, -9.295065209173092, -9.202265372997784, -9.113544689088535, -9.02864876114705, -8.947343909214371, -8.86941510284566, -8.794664136887338, -8.722908017270548, -8.653977529144486, -8.58771596376355, -8.523977983965775, -8.46262861095524, -8.40354231752096, -8.346602214872911, -8.29169932200947, -8.238731908006855, -8.187604898877682, -8.138229341722765, -8.090521919821832, -8.044404513101663, -7.999803799104056, -7.9566508901651485, -7.914881003029814, -7.874433157567806, -7.835249901644124, -7.797277059532936, -7.760463501557119, -7.7247609328935525, -7.6901236997091384, -7.656508610990624, -7.623874774606075, -7.592183446288759, -7.56139789037076, -7.53148325121334, -7.5024064343875185, -7.474135996753274, -7.446642044669044, -7.4198961396387855, -7.393871210769968, -7.368541473476016, -7.34388235390928, -7.319870418658996, -7.296483309291098, -7.273699681345163, -7.251499147438614, -7.229862224158839, -7.2087702824524404, -7.188205501245795, -7.168150824053938, -7.148589918355715, -7.12950713753136, -7.110887485176063, -7.092716581618223, -7.074980632485018, -7.057666399170895, -7.040761171075677, -7.024252739489976, -7.008129373014909, -6.992379794411929, -6.976993158786763, -6.961959033018411, -6.947267376351244, -6.932908522074058, -6.918873160215885, -6.905152321193116, -6.89173736034763, -6.878619943319725, -6.8657920322037, -6.853245872437791, -6.840973980383216, -6.828969131550588, -6.8172243494345865, -6.805732894920532, -6.794488256229058, -6.783484139367109, -6.772714459055884, -6.762173330108106, -6.751855059228828, -6.741754137215808, -6.731865231536764, -6.722183179262537, -6.712702980336363, -6.7034197911607265, -6.694328918484509, -6.685425813574069, -6.67670606665303, -6.66816540159639, -6.659799670865561, -6.651604850671543, -6.643577036354422, -6.6357124379679515, -6.628007376058639, -6.620458277629492, -6.613061672278954, -6.605814188506293, -6.598712550175099, -6.591753573127029, -6.584934161938459, -6.578251306812957, -6.571702080603069, -6.565283635955128, -6.558993202571179, -6.55282808458253, -6.546785658029535, -6.5408633684427055, -6.535058728520395, -6.5293693158985695, -6.523792771008471, -6.518326795018086, -6.512969147853679, -6.507717646297705, -6.502570162159769, -6.497524620517279, -6.492578998022763, -6.487731321274907, -6.482979665250504, -6.478322151794712, -6.473756948167044, -6.469282265640742, -6.464896358153236, -6.460597521005513, -6.456384089608372, -6.4522544382735445, -6.4482069790478524, -6.444240160588604, -6.440352467078523, -6.436542417178618, -6.43280856301741, -6.429149489215081, -6.42556381194111, -6.422050178004072, -6.4186072639723255, -6.415233775324342, -6.411928445627539, -6.408690035744461, -6.405517333065308, -6.402409150765721, -6.3993643270888905, -6.396381724651057, -6.393460229769488, -6.3905987518121155, -6.387796222567977, -6.385051595637712, -6.382363845843346, -6.37973196865665, -6.377154979645403, -6.37463191393688, -6.372161825697942, -6.369743787631131, -6.367376890486176, -6.365060242586379, -6.36279296936932, -6.36057421294138, -6.358403131645607, -6.356278899642419, -6.354200706502736, -6.352167756813066, -6.350179269792152, -6.348234478918766, -6.346332631570281, -6.3444729886716305, -6.342654824354316, -6.3408774256251075, -6.3391400920441185, -6.3374421354119335, -6.335782879465485, -6.334161659582386, -6.332577822493431, -6.331030726003005, -6.329519738717135, -6.328044239778917, -6.326603618611109, -6.3251972746656175, -6.323824617179677, -6.322485064938508, -6.321178046044226, -6.319902997690807, -6.318659365944931, -6.317446605532486, -6.31626417963058, -6.315111559664872, -6.3139882251120465, -6.312893663307291, -6.311827369256594, -6.310788845453739, -6.309777601701815, -6.3087931549391385, -6.307835029069413, -6.306902754796037, -6.305995869460383, -6.305113916883968, -6.304256447214374, -6.3034230167748, -6.302613187917153, -6.301826528878551, -6.301062613641138, -6.300321021795123, -6.299601338404925, -6.298903153878346, -6.298226063838666, -6.29756966899959, -6.296933575042939, -6.296317392499014, -6.2957207366295584, -6.295143227313224, -6.294584488933475, -6.294044150268858, -6.293521844385559, -6.293017208532183, -6.292529884036695, -6.292059516205438, -6.291605754224186, -6.291168251061162, -6.290746663371953, -6.290340651406286, -6.2899498789165715, -6.2895740130682105, -6.28921272435156, -6.2888656864955435, -6.288532576382837, -6.288213073966582, -6.287906862188589, -6.287613626898976, -6.287333056777192, -6.2870648432544005, -6.2868086804371535, -6.2865642650323394, -6.286331296273348, -6.286109475847419, -6.285898507824132, -6.285698098585004, -6.285507956754157, -6.285327793130012, -6.285157320617985, -6.284996254164149, -6.284844310689812, -6.2847012090270065, -6.284566669854831, -6.284440415636631, -6.284322170557975, -6.284211660465407, -6.284108612805932, -6.2840127565672255, -6.283923822218514, -6.283841541652118, -6.283765648125617, -6.283695876204625, -6.283631961706129, -6.283573641642377, -6.283520654165297, -6.283472738511401, -6.283429634947167, -6.283391084714865, -6.2833568299788105, -6.283326613772006, -6.28330017994317, -6.28327727310411, -6.283257638577419, -6.283241022344494, -6.283227170993815, -6.2832158316695015, -6.283206752020099, -6.283199680147581, -6.283194364556547, -6.28319055410359, -6.283187997946815, -6.283186445495488, -6.283185646359788, -6.283185350300646, -6.283185307179648, -6.283185266908986, -6.283184979401418, -6.283184194520244, -6.283182662029247, -6.2831801315426, -6.283176352474708, -6.283171073989962, -6.28316404495239, -6.283155013875178, -6.283143728870044, -6.283129937596436, -6.283113387210541, -6.283093824314079, -6.283070994902858, -6.28304464431507, -6.283014517179304, -6.282980357362259, -6.282941907916122, -6.282898911025601, -6.282851107954583, -6.282798238992391, -6.282740043399622, -6.28267625935354, -6.282606623892989, -6.282530872862828, -6.28244874085782, -6.282359961166002, -6.282264265711457, -6.282161384996499, -6.282051048043232, -6.281932982334445, -6.2818069137538375, -6.281672566525518, -6.2815296631527815, -6.281377924356093, -6.281217069010296, -6.281046814080972, -6.280866874559943, -6.28067696339988, -6.2804767914479775, -6.28026606737868, -6.280044497625393, -6.279811786311178, -6.279567635178375, -6.2793117435171135, -6.279043808092693, -6.278763523071774, -6.278470579947349, -6.278164667462455, -6.27784547153258, -6.2775126751667205, -6.277165958387052, -6.276804998147164, -6.27642946824881, -6.276039039257129, -6.2756333784142875, -6.2752121495514945, -6.274775012999328, -6.2743216254963405, -6.2738516400958595, -6.273364706070957, -6.272860468817504, -6.272338569755267, -6.271798646226986, -6.271240331395351, -6.270663254137833, -6.270067038939299, -6.2694513057823285, -6.268815670035176, -6.268159742337292, -6.267483128482344, -6.266785429298638, -6.266066240526876, -6.265325152695162, -6.264561750991167, -6.263775615131364, -6.262966319227252, -6.262133431648456, -6.261276514882624, -6.260395125392009, -6.2594888134666276, -6.258557123073905, -6.257599591704678, -6.256615750215442, -6.255605122666738, -6.2545672261575325, -6.253501570655492, -6.252407658822985, -6.251284985838714, -6.250133039214796, -6.24895129860918, -6.247739235633231, -6.246496313654324, -6.245221987593295, -6.24391570371657, -6.242576899422802, -6.2412050030238415, -6.239799433519842, -6.238359600368311, -6.2368849032469065, -6.235374731809767, -6.233828465437161, -6.232245472978231, -6.23062511248659, -6.228966730948549, -6.227269664003688, -6.225533235657558, -6.223756757986192, -6.221939530832184, -6.2200808414920115, -6.218179964394328, -6.216236160768877, -6.214248678305725, -6.2122167508044575, -6.210139597812982, -6.208016424255582, -6.20584642004982, -6.203628759711889, -6.201362601950024, -6.1990470892454885, -6.196681347420747, -6.1942644851942905, -6.191795593721669, -6.189273746122201, -6.186697996990827, -6.184067381894567, -6.18138091685298, -6.178637597802037, -6.175836400040783, -6.172976277660106, -6.170056162952965, -6.167074965805323, -6.16403157306707, -6.1609248479021135, -6.157753629116893, -6.154516730466378, -6.15121293993673, -6.147841019003664, -6.144399701865532, -6.140887694650148, -6.137303674594243, -6.133646289194462, -6.129914155328735, -6.126105858346788, -6.122219951128554, -6.118254953109065, -6.1142093492685134, -6.110081589085972, -6.1058700854551775, -6.101573213560886, -6.0971893097139525, -6.092716670143473, -6.088153549744094, -6.0834981607764345, -6.078748671518737, -6.073903204867378, -6.068959836884133, -6.063916595287742, -6.05877145788717, -6.053522350954122, -6.048167147531792, -6.042703665677111, -6.037129666633312, -6.0314428529295325, -6.025640866404164, -6.019721286148152, -6.013681626364623, -6.007519334140734, -6.001231787127456, -5.994816291122958, -5.988270077554804, -5.981590300855887, -5.974774035729048, -5.967818274294567, -5.960719923114819, -5.953475800089837, -5.946082631217028, -5.938537047208357, -5.930835579957284, -5.922974658847864, -5.914950606897636, -5.906759636725352, -5.8983978463344915, -5.889861214702311, -5.881145597164157, -5.872246720581779, -5.863160178283569, -5.853881424764442, -5.844405770131479, -5.834728374281353, -5.824844240794139, -5.814748210527127, -5.804434954891644, -5.7938989687939815, -5.78313456322107, -5.7721358574496895, -5.7608967708565695, -5.749411014305713, -5.7376720810867585, -5.725673237377251, -5.713407512199213, -5.700867686838251, -5.688046283691801, -5.674935554509694, -5.661527467988505, -5.647813696677687, -5.633785603152322, -5.61943422540461, -5.604750261401479, -5.5897240527527865, -5.574345567429516, -5.558604381466673, -5.542489659581131, -5.525990134627923, -5.509094085813531, -5.491789315577279, -5.47406312504463, -5.455902287948848, -5.437293022908117, -5.41822096393555, -5.398671129049968, -5.378627886842315, -5.358074920841407, -5.33699519150783, -5.3153708956694175, -5.293183423195886, -5.270413310689914, -5.2470401919529905, -5.22304274496056, -5.198398635055689, -5.173084454043739, -5.147075654837678, -5.120346481271049, -5.092869892656171, -5.0646174826223564, -5.035559391722739, -5.0056642132430085, -4.974898891588105, -4.943228612555027, -4.910616684725165, -4.877024411127443, -4.8424109502267125, -4.806733165188291, -4.769945460248048, -4.731999602882057, -4.692844530318276, -4.6524261387561445, -4.6106870534653135, -4.567566377708205, -4.522999418174653, -4.476917384326153, -4.429247058708764, -4.37991043491234, -4.328824319409683, -4.275899892999433, -4.221042226990898, -4.164149748584002, -4.105113649111514, -4.043817227889022, -3.9801351633460977, -3.9139327018616985, -3.845064753252319, -3.773374880137813, -3.698694166368069, -3.620839947281474, -3.5396143817058814, -3.4548028422004933, -3.366172095961856, -3.2734682439342278, -3.176414379774272, -3.0747079232155237, -2.9680175737439436, -2.855979819977409, -2.738194927271066, -2.6142223102249913, -2.4835751772046617, -2.345714309661642, -2.2000408086673, -2.0458876029258777, -1.8825094643109699, -1.7090712156752925, -1.5246337372046614, -1.328137276433326, -1.1183814356887245, -0.8940010387895683, -0.65343685191612, -0.3948998313912897, -0.11632716489757389, 0.18467217897032384, 0.5108854352465926, 0.8655816555023321, 1.2526205228720197, 1.6765920522988882, 2.1429979110690933, 2.658489581884165, 3.231185304192083, 3.8710979683478897, 4.590722085664892, 5.405853386946498, 6.336756218278762, 7.409864024792263, 8.6603203233281, 10.13588833458208, 11.90317417878618, 14.057935656752555, 16.742990343826946, 20.181174089189295, 24.740510467234735, 31.075464662217605, 40.472950361167904, 55.85965487052721, 85.63463417182864, 167.68679067661765, null, -240.18835349860052, -115.33281407054228, -77.7681942810415, -59.665039597155676, -49.011960530572175, -41.99541507375927, -37.025256861589554, -33.320496810076506, -30.45270687899598, -28.16725023070975, -26.303272410714527, -24.754166596152107, -23.4464832163056, -22.32796911159155, -21.360435858819066, -20.515325953785663, -19.77085679437166, -19.110124091373592, -18.51980862400898, -17.98927368892649, -17.50992214224042, -17.07472991067747, -16.67790193671975, -16.314614639414124, -15.980820530792279, -15.673098163587667, -15.3885355967614, -15.124638957514657, -14.879260012775983, -14.650538293944583, -14.43685447383898, -14.236792523670786, -14.049108779729071, -13.8727064913295, -13.706614749402995, -13.549970940622682, -13.402006057553756, -13.26203233678702, -13.129432805709554, -13.003652402739142, -12.88419040146477, -12.770593920651073, -12.66245234276796, -12.559392496043683, -12.461074480906237, -12.367188042454666, -12.277449407393917, -12.191598517504254, -12.109396602834765, -12.030624046925684, -11.955078503870203, -11.882573233220006, -11.812935623889565, -11.746005882494957, -11.681635865145132, -11.6196880347117, -11.56003452812713, -11.502556320402334, -11.447142473860403, -11.393689462620731, -11.342100563680397, -11.29228530705458, -11.244158978401213, -11.197642168376106, -11.152660363674627, -11.109143575330888, -11.067026000371857, -11.026245713387311, -10.986744384973907, -10.948467024360076, -10.911361743824408, -10.875379542782976, -10.84047410965726, -10.80660163983702, -10.773720668232665, -10.741791915072046, -10.710778143734082, -10.680644029538179, -10.6513560385165, -10.622882315293694, -10.595192579286618, -10.568258028511472, -10.542051250356602, -10.516546138739178, -10.491717817118774, -10.467542566891257, -10.443997760728337, -10.421061800469609, -10.398714059208114, -10.376934827242446, -10.3557052615983, -10.335007338846541, -10.314823810970045, -10.295138164051648, -10.275934579574724, -10.257197898146345, -10.238913585467076, -10.221067700387426, -10.203646864902888, -10.186638235951483, -10.170029478889152, -10.153808742527463, -10.137964635627078, -10.122486204749448, -10.107362913375372, -10.092584622207234, -10.078141570577118, -10.06402435888886, -10.050223932028034, -10.036731563677627, -10.02353884148267, -10.010637653010543, -9.998020172457368, -9.985678848055144, -9.97360639013631, -9.9617957598165, -9.950240158258282, -9.938933016481178, -9.927867985686236, -9.917038928064605, -9.906439908062469, -9.896065184075985, -9.885909200551554, -9.875966580468903, -9.86623211818508, -9.856700772619615, -9.847367660761936, -9.838228051483204, -9.829277359636391, -9.820511140428678, -9.8119250840519, -9.803515010557229, -9.795276864961105, -9.787206712570613, -9.779300734516562, -9.771555223483853, -9.763966579628944, -9.756531306674772, -9.749246008174485, -9.74210738393519, -9.735112226594056, -9.72825741833911, -9.721539927767566, -9.714956806875227, -9.70850518817035, -9.7021822819062, -9.695985373426586, -9.68991182061892, -9.683959051469907, -9.67812456171899, -9.672405912604939, -9.666800728701489, -9.661306695837693, -9.65592155909936, -9.650643120907803, -9.645469239172371, -9.640397825513642, -9.635426843553937, -9.630554307272346, -9.6257782794214, -9.62109687000259, -9.616508234798411, -9.612010573958255, -9.607602130636035, -9.60328118967728, -9.599046076353526, -9.594895155142218, -9.590826828549979, -9.586839535977651, -9.582931752625289, -9.579101988435434, -9.575348787073247, -9.571670724941802, -9.568066410231323, -9.5645344820009, -9.561073609291352, -9.557682490268135, -9.554359851392952, -9.55110444662308, -9.547915056637253, -9.544790488087056, -9.541729572872953, -9.53873116744384, -9.5357941521194, -9.532917430434262, -9.53009992850319, -9.52734059440655, -9.5246383975952, -9.52199232831419, -9.519401397044504, -9.516864633962198, -9.514381088414314, -9.511949828410925, -9.509569940132767, -9.507240527453872, -9.504960711478647, -9.502729630092922, -9.500546437528454, -9.498410303940378, -9.49632041499722, -9.494275971482947, -9.492276188910711, -9.490320297147832, -9.488407540051634, -9.486537175115801, -9.484708473126833, -9.482920717830309, -9.481173205606597, -9.479465245155689, -9.477796157190877, -9.476165274140941, -9.474571939860592, -9.473015509348896, -9.47149534847537, -9.47001083371358, -9.468561351881888, -9.46714629989122, -9.46576508449956, -9.46441712207295, -9.463101838352841, -9.461818668229515, -9.460567055521448, -9.459346452760387, -9.45815632098197, -9.456996129521707, -9.455865355816162, -9.45476348520916, -9.453690010762877, -9.452644433073635, -9.451626260092283, -9.450635006948994, -9.449670195782362, -9.448731355572654, -9.447818021979094, -9.446929737181042, -9.44606604972297, -9.445226514363098, -9.44441069192559, -9.44361814915619, -9.442848458581206, -9.442101198369732, -9.441375952199003, -9.440672309122814, -9.439989863442861, -9.439328214582982, -9.438686966966145, -9.438065729894138, -9.437464117429881, -9.43688174828225, -9.436318245693364, -9.435773237328268, -9.435246355166905, -9.434737235398332, -9.434245518317116, -9.43377084822183, -9.433312873315586, -9.432871245608561, -9.432445620822437, -9.432035658296689, -9.431641020896704, -9.431261374923626, -9.430896390025909, -9.430545739112516, -9.43020909826769, -9.429886146667306, -9.429576566496676, -9.429280042869838, -9.428996263750223, -9.428724919872698, -9.428465704666912, -9.428218314181926, -9.427982447012065, -9.427757804223972, -9.427544089284808, -9.42734100799157, -9.427148268401488, -9.426965580763461, -9.426792657450502, -9.426629212893147, -9.426474963513815, -9.42632962766206, -9.4261929255507, -9.42606457919278, -9.42594431233936, -9.42583185041806, -9.425726920472366, -9.425629251101661, -9.425538572401926, -9.425454615907128, -9.425377114531218, -9.425305802510763, -9.425240415348135, -9.425180689755267, -9.425126363597931, -9.42507717584053, -9.425032866491353, -9.424993176548291, -9.424957847944988, -9.424926623497377, -9.424899246850623, -9.4248754624264, -9.424855015370515, -9.42483765150084, -9.424823117255528, -9.424811159641509, -9.424801526183206, -9.424793964871492, -9.424788224112843, -9.424784052678655, -9.424781199654733, -9.424779414390908, -9.424778446450759, -9.424778045561442, -9.424777961563569, -9.424777944361155, -9.424777743871571, -9.424777109975528, -9.424775792467019, -9.424773541003242, -9.42477010505446, -9.424765233853778, -9.424758676346828, -9.424750181141313, -9.424739496456436, -9.42472637007213, -9.424710549278133, -9.424691780822828, -9.42466981086186, -9.424644384906507, -9.42461524777177, -9.424582143524153, -9.424544815429142, -9.424503005898316, -9.424456456436113, -9.42440490758619, -9.424348098877365, -9.42428576876913, -9.42421765459669, -9.424143492515524, -9.424063017445409, -9.423975963013934, -9.423882061499418, -9.423781043773257, -9.42367263924164, -9.42355657578662, -9.423432579706507, -9.423300375655565, -9.423159686582963, -9.423010233670981, -9.422851736272408, -9.422683911847123, -9.422506475897823, -9.42231914190486, -9.42212162126016, -9.421913623200197, -9.421694854737959, -9.421465020593915, -9.421223823125908, -9.420970962257963, -9.420706135407949, -9.420429037414085, -9.42013936046023, -9.419836793999908, -9.419521024679067, -9.41919173625748, -9.418848609528768, -9.41849132223902, -9.418119549003915, -9.417732961224345, -9.417331227000464, -9.41691401104412, -9.416480974589632, -9.416031775302821, -9.415566067188292, -9.415083500494873, -9.414583721619161, -9.414066373007135, -9.413531093053741, -9.412977516000423, -9.41240527183051, -9.411813986162395, -9.411203280140455, -9.410572770323617, -9.409922068571511, -9.409250781928142, -9.408558512502974, -9.40784485734939, -9.407109408340402, -9.406351752041541, -9.405571469580876, -9.404768136515985, -9.403941322697891, -9.40309059213177, -9.402215502834395, -9.401315606688184, -9.400390449291748, -9.39943956980684, -9.398462500801571, -9.397458768089798, -9.396427890566542, -9.395369380039316, -9.394282741055246, -9.393167470723819, -9.39202305853515, -9.390848986173609, -9.38964472732664, -9.388409747488671, -9.38714350375987, -9.385845444639665, -9.384515009814807, -9.383151629941791, -9.381754726423498, -9.380323711179795, -9.378857986411962, -9.377356944360695, -9.375819967057478, -9.374246426069124, -9.372635682235217, -9.370987085398237, -9.36929997412614, -9.367573675427064, -9.365807504455994, -9.364000764212996, -9.362152745232821, -9.360262725265542, -9.358329968947881, -9.356353727464965, -9.354333238202107, -9.352267724386309, -9.350156394717109, -9.347998442986349, -9.345793047686552, -9.343539371607394, -9.34123656141993, -9.338883747248087, -9.336480042226937, -9.334024542047308, -9.331516324486218, -9.328954448922559, -9.326337955837566, -9.323665866299404, -9.320937181431349, -9.318150881862922, -9.31530592716328, -9.31240125525627, -9.309435781816351, -9.306408399644699, -9.303317978024738, -9.300163362056205, -9.296943371967023, -9.293656802401994, -9.290302421687471, -9.286878971071024, -9.283385163935035, -9.279819684983295, -9.27618118939936, -9.27246830197562, -9.268679616211838, -9.264813693381852, -9.260869061567222, -9.256844214656292, -9.252737611307351, -9.24854767387431, -9.244272787293225, -9.239911297928174, -9.2354615123745, -9.230921696217768, -9.22629007274642, -9.221564821616017, -9.216744077463119, -9.211825928466341, -9.206808414852384, -9.20168952734451, -9.196467205550768, -9.191139336289403, -9.185703751848337, -9.180158228175857, -9.174500482999251, -9.168728173867896, -9.162838896117485, -9.156830180751346, -9.150699492235136, -9.144444226200642, -9.138061707054192, -9.131549185485184, -9.12490383586976, -9.118122753564291, -9.111202952083476, -9.10414136015691, -9.096934818658275, -9.089580077400507, -9.082073791790004, -9.074412519332821, -9.066592715984822, -9.058610732337886, -9.050462809633373, -9.042145075593542, -9.033653540061417, -9.024984090438421, -9.016132486909004, -9.00709435744048, -8.997865192545458, -8.98844033979398, -8.978814998060841, -8.968984211493419, -8.95894286318391, -8.948685668528755, -8.938207168257447, -8.927501721110877, -8.916563496148894, -8.905386464664787, -8.893964391682923, -8.882290827014632, -8.870359095844814, -8.858162288820727, -8.845693251611793, -8.832944573906953, -8.819908577814425, -8.80657730562501, -8.792942506898353, -8.778995624827823, -8.764727781836353, -8.750129764352664, -8.735192006712294, -8.719904574124719, -8.704257144642481, -8.688238990063235, -8.671838955690841, -8.655045438874481, -8.637846366239446, -8.620229169515321, -8.602180759859483, -8.583687500565967, -8.56473517803971, -8.545308970905934, -8.525393417114003, -8.504972378881373, -8.484029005311049, -8.462545692500097, -8.440504040940224, -8.4178848099943, -8.39466786921096, -8.370832146218882, -8.34635557091677, -8.321215015647708, -8.295386231017627, -8.268843776982228, -8.24156094879125, -8.21350969733634, -8.184660543402405, -8.15498248527203, -8.124442899072717, -8.093007431194147, -8.060639882028962, -8.027302080209024, -7.992953746419344, -7.957552345766373, -7.921052927563714, -7.883407951265573, -7.844567097129623, -7.804477060024601, -7.763081324603901, -7.720319919851947, -7.676129150760568, -7.630441304609377, -7.583184329002696, -7.534281478440777, -7.483650925780065, -7.431205334443802, -7.376851386677206, -7.320489262488275, -7.262012063150699, -7.201305172265491, -7.138245546345065, -7.072700925679307, -7.004528954835599, -6.9335762004820465, -6.859677052274272, -6.782652490233167, -6.7023086993013985, -6.618435508509742, -6.5308046282896415, -6.439167654804418, -6.343253804566865, -6.242767335831979, -6.137384605050426, -6.0267506966691915, -5.910475552343463, -5.788129510615397, -5.659238149573497, -5.523276302021252, -5.379661083998337, -5.227743741524583, -5.066800075058836, -4.896019143537157, -4.714489876242381, -4.521185126020685, -4.314942574580647, -4.094441740249193, -3.858176127342084, -3.604419275734723, -3.3311830929493107, -3.036166341465223, -2.7166904563568472, -2.369618902353743, -1.9912549252434957, -1.5772106286722742, -1.1222375345738342, -0.6200047259620671, -0.06280462509501916, 0.5588427136360714, 1.2567301263385335, 2.0457145246286714, 2.9447811842690896, 3.978584760779192, 5.179736261782313, 6.5922942228673165, 8.277271002657248, 10.321655624962002, 12.853885388213797, 16.071870596457202, 20.297313239523938, 26.09043630193242, 34.5213420380004, 47.920950669835904, 72.51324753093044, 132.36946134857945, null, null, -135.59486599054873, -87.77042242348608, -66.47971592526247, -54.43712685227426, -46.69277377898712, -41.294407958842534, -37.31659714745194, -34.264089889832476, -31.84788091749583, -29.887971574278247, -28.266404669700805, -26.902654720904913, -25.739871407597732, -24.7367744453422, -23.862664805678442, -23.09423856087306, -22.41348660613015, -21.806271706738713, -21.261341030726115, -20.769626222823256, -20.323737856846606, -19.91759407424823, -19.546143616387575, -19.20515639602384, -18.891063143931262, -18.600831218579394, -18.331867408761955, -18.081941123685468, -17.849123149971, -17.63173641510721, -17.428316098119556, -17.23757708069319, -17.05838720972509, -16.88974519574673, -16.730762235805244, -16.58064664857084, -16.43869096095707, -16.304261001742262, -16.176786647458684, -16.05575393571582, -15.94069831588671, -15.831198850287347, -15.726873213268664, -15.627373362997792, -15.53238178268003, -15.44160820569099, -15.354786753462008, -15.271673426678051, -15.1920438999269, -15.115691577827345, -15.042425877166693, -14.972070704972309, -14.904463106933047, -14.839452064331919, -14.776897420793338, -14.716668922793842, -14.658645360109439, -14.602713794264915, -14.548768864649313, -14.496712163326283, -14.446451670735534, -14.397901245474877, -14.350980162212803, -14.305612692515956, -14.261727724011848, -14.219258413859492, -14.178141872973773, -14.138318877867148, -14.099733607330666, -14.062333401491147, -14.02606854105837, -13.990892044814167, -13.956759483609842, -13.923628809322462, -13.891460197384598, -13.860215901648322, -13.829860120469583, -13.800358873014828, -13.771679884890576, -13.74379248228588, -13.716667493898463, -13.690277159983763, -13.664595047931451, -13.639595973828987, -13.615255929522288, -13.591552014730077, -13.568462373807064, -13.545966136789534, -13.52404336438847, -13.502674996624908, -13.481842804829974, -13.461529346754382, -13.441717924555563, -13.422392545449235, -13.403537884830047, -13.385139251683082, -13.367182556121074, -13.349654278897162, -13.332541442754021, -13.3158315854814, -13.299512734564814, -13.283573383316606, -13.268002468388987, -13.252789348577167, -13.237923784826355, -13.223395921364176, -13.209196267885018, -13.195315682718347, -13.18174535691864, -13.168476799217995, -13.155501821787837, -13.142812526759162, -13.130401293454483, -13.118260766288383, -13.106383843295692, -13.094763665250051, -13.083393605337527, -13.072267259352369, -13.061378436384757, -13.050721149971482, -13.040289609683333, -13.030078213124083, -13.020081538317623, -13.010294336461778, -13.000711525027992, -12.99132818118805, -12.982139535549798, -12.97314096618489, -12.964327992933107, -12.955696271968083, -12.947241590610783, -12.938959862377574, -12.930847122250471, -12.92289952215828, -12.915113326657425, -12.907484908802488, -12.900010746196722, -12.89268741721331, -12.885511597379105, -12.878480055912416, -12.871589652407504, -12.864837333658476, -12.858220130615678, -12.851735155468411, -12.845379598847632, -12.839150727143121, -12.833045879929587, -12.827062467496535, -12.821197968477156, -12.815449927571573, -12.809815953360019, -12.804293716201995, -12.798880946217267, -12.793575431345186, -12.788375015478733, -12.783277596669869, -12.778281125403193, -12.773383602934704, -12.768583079692966, -12.763877653739886, -12.759265469288454, -12.754744715275175, -12.75031362398462, -12.745970469724089, -12.741713567546135, -12.737541272016951, -12.733451976028785, -12.729444109654434, -12.725516139042172, -12.72166656534944, -12.717893923713618, -12.714196782258549, -12.710573741135173, -12.707023431595072, -12.703544515095519, -12.70013568243477, -12.696795652916498, -12.693523173542095, -12.690317018229875, -12.687175987060064, -12.684098905544575, -12.681084623920688, -12.678132016467615, -12.675239980845166, -12.672407437453684, -12.669633328814324, -12.666916618969127, -12.664256292899918, -12.661651355965517, -12.659100833356513, -12.656603769566903, -12.65415922788212, -12.651766289882694, -12.64942405496311, -12.647131639865265, -12.644888178225965, -12.642692820138045, -12.640544731724564, -12.638443094725623, -12.636387106097411, -12.634375977622966, -12.63240893553434, -12.6304852201457, -12.628604085497008, -12.626764799007955, -12.624966641141727, -12.623208905078336, -12.621490896397162, -12.619811932768375, -12.618171343653003, -12.616568470011266, -12.615002664018991, -12.613473288791788, -12.611979718116718, -12.610521336191274, -12.609097537369356, -12.607707725914056, -12.606351315757042, -12.605027730264275, -12.603736402007925, -12.602476772544215, -12.601248292197058, -12.600050419847285, -12.598882622727256, -12.59774437622075, -12.596635163667877, -12.595554476174954, -12.594501812429106, -12.59347667851748, -12.592478587750938, -12.591507060492058, -12.590561623987341, -12.589641812203476, -12.588747165667531, -12.587877231310976, -12.587031562317389, -12.586209717973746, -12.585411263525206, -12.584635770033225, -12.583882814236985, -12.583151978417934, -12.58244285026744, -12.581755022757408, -12.581088094013758, -12.580441667192739, -12.579815350359935, -12.579208756371909, -12.57862150276039, -12.578053211618947, -12.57750350949206, -12.576972027266505, -12.576458400065023, -12.575962267142147, -12.575483271782176, -12.575021061199186, -12.574575286439067, -12.574145602283457, -12.573731667155585, -12.57333314302791, -12.572949695331541, -12.572580992867357, -12.572226707718778, -12.57188651516616, -12.571560093602725, -12.571247124452018, -12.570947292086805, -12.570660283749403, -12.570385789473374, -12.570123502006535, -12.56987311673527, -12.569634331610072, -12.569406847072292, -12.569190365982053, -12.568984593547277, -12.568789237253824, -12.568604006796654, -12.568428614012017, -12.568262772810629, -12.568106199111785, -12.567958610778382, -12.567819727552832, -12.567689270993824, -12.567566964413881, -12.567452532817738, -12.567345702841438, -12.567246202692191, -12.567153762088907, -12.567068112203401, -12.566988985602253, -12.566916116189262, -12.566849239148508, -12.566788090887968, -12.56673240898365, -12.566681932124265, -12.566636400056366, -12.566595553529947, -12.566559134244478, -12.566526884795362, -12.566498548620757, -12.566473869948783, -12.566452593745053, -12.566434465660532, -12.56641923197968, -12.566406639568878, -12.566396435825096, -12.566388368624782, -12.566382186272968, -12.566377637452556, -12.566374471173756, -12.566372436723675, -12.566371283616018, -12.566370761540883, -12.566370620314638, -12.566370609829844, -12.566370480005224, -12.56636998073562, -12.566368861841964, -12.566366873021199, -12.566363763796165, -12.566359283465392, -12.566353181052811, -12.566345205257344, -12.566335104402352, -12.566322626384931, -12.56630751862502, -12.566289528014304, -12.566268400864892, -12.566243882857762, -12.5662157189909, -12.566183653527188, -12.56614742994195, -12.566106790870158, -12.566061478053296, -12.566011232285815, -12.565955793361194, -12.565894900017563, -12.565828289882862, -12.565755699419528, -12.56567686386866, -12.565591517193665, -12.565499392023332, -12.565400219594329, -12.565293729693076, -12.56517965059699, -12.565057709015054, -12.564927630027688, -12.564789137025908, -12.564641951649705, -12.56448579372567, -12.56432038120378, -12.564145430093342, -12.563960654398073, -12.563765766050249, -12.563560474843921, -12.56334448836715, -12.563117511933225, -12.562879248510844, -12.56262939865319, -12.562367660425902, -12.562093729333876, -12.561807298246858, -12.561508057323824, -12.561195693936035, -12.56086989258881, -12.560530334841904, -12.560176699228478, -12.559808661172623, -12.559425892905363, -12.559028063379117, -12.55861483818054, -12.558185879441739, -12.557740845749745, -12.55727939205426, -12.55680116957356, -12.556305825698539, -12.555793003894815, -12.555262343602847, -12.554713480135993, -12.554146044576456, -12.553559663669024, -12.552953959712584, -12.552328550449294, -12.551683048951357, -12.551017063505343, -12.55033019749393, -12.54962204927505, -12.54889221205831, -12.548140273778618, -12.547365816966924, -12.546568418618003, -12.545747650055162, -12.544903076791789, -12.544034258389633, -12.54314074831374, -12.542222093783904, -12.541277835622541, -12.540307508098882, -12.53931063876934, -12.538286748313954, -12.537235350368794, -12.536155951354141, -12.535048050298396, -12.533911138657487, -12.532744700129696, -12.53154821046574, -12.53032113727393, -12.529062939820275, -12.52777306882335, -12.526450966243772, -12.525096065068087, -12.523707789086894, -12.522285552667029, -12.520828760517572, -12.519336807449514, -12.517809078128863, -12.516244946822932, -12.514643777139627, -12.513004921759475, -12.511327722160138, -12.509611508333183, -12.5078555984928, -12.506059298776243, -12.504221902935665, -12.502342692021056, -12.500420934054016, -12.498455883691951, -12.49644678188248, -12.494392855507563, -12.492293317017124, -12.490147364051698, -12.487954179053737, -12.485712928867192, -12.483422764324894, -12.481082819823342, -12.478692212884427, -12.476250043703562, -12.473755394683787, -12.471207329955302, -12.468604894879848, -12.465947115539436, -12.463232998208769, -12.46046152881079, -12.457631672354696, -12.454742372355716, -12.451792550236023, -12.448781104705962, -12.44570691112491, -12.44256882084094, -12.439365660508404, -12.436096231382688, -12.432759308591084, -12.429353640378942, -12.42587794733006, -12.422330921560246, -12.418711225883046, -12.41501749294638, -12.41124832433901, -12.40740228966554, -12.403477925588586, -12.399473734836878, -12.395388185177705, -12.391219708352315, -12.386966698972667, -12.382627513377782, -12.378200468448135, -12.373683840376069, -12.369075863390481, -12.364374728433686, -12.35957858178832, -12.35468552365218, -12.349693606658526, -12.344600834339502, -12.339405159530083, -12.334104482709732, -12.328696650279104, -12.323179452768573, -12.317550622975594, -12.31180783402751, -12.305948697366201, -12.299970760651057, -12.293871505576151, -12.287648345597693, -12.281298623567322, -12.274819609266567, -12.268208496837847, -12.261462402106638, -12.254578359789589, -12.2475533205828, -12.240384148124125, -12.23306761582325, -12.225600403552686, -12.217979094192426, -12.21020017002086, -12.20226000894364, -12.194154880552162, -12.185880942002523, -12.177434233705206, -12.168810674815575, -12.16000605851396, -12.151016047064134, -12.141836166637772, -12.132461801891742, -12.12288819028468, -12.113110416117674, -12.103123404283657, -12.092921913708597, -12.082500530466495, -12.07185366054941, -12.060975522271773, -12.049860138287565, -12.03850132719699, -12.02689269471764, -12.01502762439396, -12.002899267816069, -11.990500534317889, -11.977824080121753, -11.964862296894294, -11.95160729967649, -11.938050914146988, -11.924184663175804, -11.909999752621673, -11.89548705632269, -11.88063710022682, -11.865440045603547, -11.849885671274528, -11.833963354795513, -11.817662052516328, -11.800970278440705, -11.783876081800091, -11.766367023249838, -11.748430149587765, -11.730051966886707, -11.711218411924369, -11.691914821782454, -11.672125901477422, -11.651835689472227, -11.631027520905205, -11.60968398835833, -11.587786899970324, -11.565317234682217, -11.542255094384544, -11.518579652711935, -11.494269100208731, -11.46930058556158, -11.443650152565581, -11.417292672459089, -11.390201771224103, -11.362349751410747, -11.333707507998094, -11.304244437753301, -11.273928341496365, -11.242725318612745, -11.210599653088028, -11.177513690258454, -11.143427703382226, -11.108299749038396, -11.07208551024485, -11.034738126062425, -10.99620800630668, -10.956442629825862, -10.915386324620414, -10.872980027866266, -10.829161023667364, -10.783862656087708, -10.737014014700145, -10.688539589533052, -10.638358891880937, -10.58638603697482, -10.532529283959633, -10.476690527994036, -10.418764738558648, -10.3586393372041, -10.296193506984064, -10.231297424659116, -10.16381140540272, -10.093584948153467, -10.02045566787981, -9.944248098816136, -9.86477235010417, -9.781822592156482, -9.695175348344652, -9.6045875621572, -9.509794404630243, -9.410506780398675, -9.306408482902878, -9.197152939789053, -9.082359477933664, -8.961609023283756, -8.834439133157247, -8.700338236888932, -8.558738933626763, -8.40901016214811, -8.250448014823295, -8.082264913687748, -7.903576797466879, -7.7133878796529896, -7.510572422908318, -7.293852825397693, -7.061773117979613, -6.8126667104651135, -6.544616876425652, -6.255407994914045, -5.942464924350846, -5.602776996004845, -5.232801873862508, -4.828342771380154, -4.384389993830988, -3.894914098217395, -3.3525925117670567, -2.7484432195910227, -2.0713264530152777, -1.3072553397786066, -0.4384242390826145, 0.5581900086338987, 1.7128902369634815, 3.0663831042111944, 4.674663222391128, 6.616933847462914, 9.00902128034165, 12.027309479940346, 15.95426772174807, 21.27232069459253, 28.878824507246364, 40.65436548514756, 61.31746017135638, 107.02098400538962, null, null, -162.34579535040095, -99.26623036156215, -73.85534876184741, -60.13089627427489, -51.538945016811375, -45.65444492501436, -41.37221686850193, -38.11654972937619, -35.55804289761163, -33.49460827293693, -31.795382271937417, -30.371888485444714, -29.162161565440186, -28.121509506382957, -27.216886912881286, -26.423333204725452, -25.72164261236122, -25.096796053470456, -24.536879265590542, -24.0323199269276, -23.57533917593053, -23.159550378180306, -22.779660996706262, -22.431247925368844, -22.110585999118165, -21.814515554110375, -21.540339042962074, -21.285739530867993, -21.04871585387176, -20.827530596197043, -20.620668024278277, -20.426799822981078, -20.244756996337166, -20.073506676543747, -19.91213286926861, -19.759820377230316, -19.615841306380148, -19.479543683275402, -19.35034180808138, -19.227708042091216, -19.11116578691969, -19.000283458395273, -18.894669294526327, -18.793966865896802, -18.697851180062084, -18.606025290238478, -18.518217333731474, -18.434177937884265, -18.353677941418237, -18.27650638731349, -18.20246875021555, -18.131385367007002, -18.063090043885783, -17.997428817218488, -17.93425884871996, -17.873447438271622, -17.814871140021843, -17.758414969375373, -17.70397169015393, -17.65144117262798, -17.600729814332468, -17.55175001661962, -17.50441971078777, -17.458661928394985, -17.414404411023963, -17.37157925533528, -17.33012258974288, -17.289974279471394, -17.25107765713193, -17.213379276276605, -17.176828685676824, -17.141378222321585, -17.10698282134775, -17.07359984130932, -17.041188903360336, -17.009711743075133, -16.979132073763598, -16.949415460252936, -16.92052920221381, -16.89244222619887, -16.86512498564359, -16.83854936815358, -16.812688609465283, -16.78751721352716, -16.763010878198997, -16.73914642611363, -16.71590174028813, -16.69325570410721, -16.671188145337133, -16.64967978385747, -16.628712182825566, -16.608267703014263, -16.58832946008398, -16.56888128457226, -16.549907684400917, -16.53139380971765, -16.5133254199049, -16.495688852600914, -16.478470994591934, -16.461659254444623, -16.44524153675842, -16.429206217927423, -16.413542123309327, -16.398238505706818, -16.383285025074773, -16.368671729371936, -16.354389036482942, -16.340427717141374, -16.32677887878951, -16.313433950315908, -16.30038466761498, -16.287623059917916, -16.275141436846987, -16.26293237614895, -16.250988712066608, -16.23930352430973, -16.227870127589956, -16.216682061686154, -16.205733082008972, -16.19501715063595, -16.18452842778955, -16.174261263733193, -16.164210191061365, -16.154369917361528, -16.144735318227387, -16.13530143060364, -16.12606344644434, -16.117016706667588, -16.108156695390466, -16.099479034429393, -16.090979478051462, -16.082653907963703, -16.074498328527753, -16.066508862188, -16.05868174510248, -16.051013322965748, -16.04350004701428, -16.03613847020499, -16.028925243558064, -16.021857112656253, -16.014930914292457, -16.008143573258646, -16.00149209926907, -15.994973584011149, -15.98858519831818, -15.982324189457676, -15.97618787853012, -15.970173657972838, -15.96427898916395, -15.958501400121925, -15.952838483296217, -15.947287893444733, -15.94184734559435, -15.936514613080503, -15.931287525662432, -15.926163967710671, -15.921141876463459, -15.916219240349198, -15.911394097371884, -15.90666453355689, -15.90202868145443, -15.897484718698157, -15.893030866616684, -15.888665388895578, -15.884386590287855, -15.880192815370862, -15.876082447347551, -15.872053906890446, -15.86810565102635, -15.86423617206027, -15.860443996536912, -15.856727684238127, -15.85308582721502, -15.849517048853171, -15.846020002969748, -15.842593372941218, -15.839235870860387, -15.835946236721732, -15.832723237633799, -15.829565667057686, -15.826472344070618, -15.823442112653545, -15.820473841001986, -15.817566420859105, -15.81471876687027, -15.811929815958251, -15.80919852671824, -15.806523878832065, -15.803904872500745, -15.801340527894835, -15.798829884621847, -15.796372001210097, -15.793965954608467, -15.791610839701402, -15.789305768838688, -15.787049871379427, -15.784842293249698, -15.782682196513454, -15.780568758956178, -15.778501173680816, -15.776478648715603, -15.774500406633338, -15.772565684181721, -15.770673731924388, -15.76882381389222, -15.767015207244665, -15.765247201940623, -15.763519100418678, -15.761830217286288, -15.760179879017642, -15.758567423659938, -15.756992200547737, -15.755453570025182, -15.753950903175786, -15.752483581559552, -15.751050996957188, -15.749652551121178, -15.748287655533481, -15.746955731169678, -15.745656208269283, -15.744388526112129, -15.74315213280052, -15.741946485047041, -15.740771047967833, -15.73962529488112, -15.73850870711088, -15.737420773795447, -15.736360991700925, -15.735328865039238, -15.734323905290683, -15.733345631030863, -15.732393567761804, -15.73146724774721, -15.730566209851665, -15.729689999383671, -15.728838167942447, -15.728010273268293, -15.727205879096493, -15.726424555014608, -15.725665876323037, -15.724929423898796, -15.724214784062374, -15.723521548447595, -15.722849313874384, -15.722197682224367, -15.721566260319179, -15.720954659801453, -15.720362497018368, -15.719789392907687, -15.719234972886222, -15.718698866740635, -15.718180708520537, -15.717680136433755, -15.717196792743778, -15.716730323669248, -15.716280379285477, -15.715846613427912, -15.715428683597489, -15.715026250867824, -15.71463897979418, -15.71426653832415, -15.713908597710025, -15.713564832422769, -15.71323492006756, -15.71291854130087, -15.712615379748984, -15.712325121927991, -15.71204745716511, -15.711782077521375, -15.71152867771563, -15.711286955049747, -15.711056609335069, -15.710837342820039, -15.710628860118945, -15.710430868141769, -15.710243076025098, -15.710065195064056, -15.709896938645228, -15.709738022180533, -15.709588163042028, -15.709447080497586, -15.709314495647446, -15.709190131361575, -15.709073712217835, -15.7089649644409, -15.708863615841919, -15.70876939575888, -15.708682034997654, -15.708601265773677, -15.708526821654266, -15.708458437501523, -15.708395849415812, -15.70833879467976, -15.7082870117028, -15.708240239966194, -15.708198219968507, -15.708160693171541, -15.708127401946683, -15.708098089521641, -15.708072499927546, -15.70805037794641, -15.7080314690589, -15.70801551939241, -15.708002275669418, -15.707991485156096, -15.70798289561114, -15.70797625523483, -15.707971312618257, -15.707967816692749, -15.707965516679398, -15.707964162038747, -15.707963502420565, -15.707963287613698, -15.707963267495991, -15.707963191984236, -15.70796281098414, -15.707961874340299, -15.707960131786129, -15.707957332893757, -15.707953227023854, -15.707947563275356, -15.707940090435095, -15.707930556927279, -15.707918710762836, -15.707904299488566, -15.707887070136104, -15.707866769170652, -15.707843142439486, -15.707815935120188, -15.707784891668577, -15.707749755766365, -15.707710270268446, -15.707666177149845, -15.707617217452285, -15.707563131230348, -15.707503657497217, -15.707438534169949, -15.70736749801429, -15.707290284588977, -15.707206628189516, -15.707116261791404, -15.707018916992777, -15.706914323956449, -15.706802211351315, -15.706682306293096, -15.7065543342844, -15.706418019154048, -15.706273082995674, -15.706119246105533, -15.705956226919515, -15.705783741949293, -15.705601505717642, -15.705409230692819, -15.705206627222024, -15.704993403463895, -15.704769265319978, -15.704533916365182, -15.70428705777715, -15.704028388264495, -15.703757603993926, -15.703474398516144, -15.70317846269053, -15.702869484608556, -15.702547149515874, -15.702211139733077, -15.701861134575006, -15.701496810268676, -15.701117839869648, -15.700723893176903, -15.700314636646107, -15.69988973330123, -15.699448842644488, -15.69899162056452, -15.698517719242782, -15.698026787058058, -15.697518468489084, -15.696992404015162, -15.696448230014767, -15.695885578662018, -15.695304077821014, -15.694703350937903, -15.694083016930671, -15.693442690076536, -15.692781979896893, -15.692100491039735, -15.691397823159472, -15.690673570794038, -15.68992732323926, -15.689158664420338, -15.688367172760392, -15.687552421045964, -15.686713976289381, -15.685851399587891, -15.684964245979458, -15.684052064295107, -15.683114397007738, -15.682150780077258, -15.681160742791942, -15.680143807605903, -15.679099489972517, -15.678027298173724, -15.67692673314502, -15.675797288296042, -15.674638449326578, -15.673449694037865, -15.67223049213904, -15.670980305048532, -15.669698585690307, -15.66838477828472, -15.667038318133852, -15.66565863140114, -15.664245134885078, -15.662797235786838, -15.661314331471575, -15.659795809223217, -15.658241045992542, -15.656649408138259, -15.655020251160927, -15.653352919429407, -15.651646745899635, -15.64990105182544, -15.648115146461107, -15.646288326755458, -15.644419877037087, -15.6425090686905, -15.640555159822812, -15.638557394920655, -15.63651500449701, -15.634427204727523, -15.632293197075992, -15.63011216790864, -15.6278832880967, -15.625605712606985, -15.623278580079926, -15.620901012394674, -15.618472114220774, -15.615990972555885, -15.613456656249104, -15.610868215509262, -15.60822468139771, -15.605525065304995, -15.60276835841075, -15.599953531126257, -15.597079532518986, -15.59414528971835, -15.591149707302087, -15.58809166666237, -15.584970025350966, -15.581783616402586, -15.5785312476355, -15.575211700928671, -15.571823731474272, -15.56836606700477, -15.564837406993483, -15.561236421827472, -15.557561751951788, -15.553812006983735, -15.54998576479603, -15.546081570567539, -15.542097935800168, -15.53803333730062, -15.533886216125381, -15.529654976487503, -15.525337984623487, -15.520933567618517, -15.51644001218836, -15.511855563415889, -15.507178423440365, -15.502406750097379, -15.497538655507139, -15.492572204609026, -15.487505413639749, -15.482336248552752, -15.47706262337611, -15.471682398506054, -15.466193378933294, -15.46059331239884, -15.4548798874762, -15.44905073157641, -15.44310340887217, -15.437035418137437, -15.430844190498151, -15.424527087090034, -15.418081396618842, -15.411504332818195, -15.404793031800173, -15.39794454929306, -15.39095585776083, -15.383823843398318, -15.37654530299567, -15.369116940665569, -15.361535364426091, -15.353797082631568, -15.345898500243795, -15.337835914934843, -15.329605513012808, -15.321203365160935, -15.312625421979908, -15.303867509322952, -15.294925323412016, -15.285794425723273, -15.276470237629, -15.266948034782043, -15.257222941228639, -15.247289923233756, -15.237143782802749, -15.226779150881622, -15.216190480217001, -15.205372037856126, -15.194317897265064, -15.183021930042644, -15.171477797205556, -15.159678940018322, -15.147618570340576, -15.135289660461227, -15.122684932387834, -15.109796846556632, -15.096617589926126, -15.083139063415105, -15.069352868641948, -15.055250293919999, -15.040822299459597, -15.026059501723664, -15.010952156880291, -14.99549014329033, -14.979662942964161, -14.963459621916, -14.946868809338174, -14.929878675512521, -14.912476908367829, -14.894650688586179, -14.87638666315199, -14.857670917228678, -14.838488944238886, -14.818825614012162, -14.798665138853547, -14.777991037372725, -14.756786095899106, -14.735032327293261, -14.712710926947203, -14.68980222574666, -14.66628563974867, -14.642139616302675, -14.61734157631925, -14.59186785236089, -14.565693622197378, -14.538792837434288, -14.511138146781885, -14.482700813489895, -14.453450626423573, -14.423355804201869, -14.392382891758954, -14.360496648619764, -14.327659928105838, -14.293833546600258, -14.258976141903393, -14.223044019603739, -14.185990986262244, -14.147768168071815, -14.108323813494238, -14.067603078197573, -14.025547790415608, -13.98209619461611, -13.937182671103491, -13.890737428877301, -13.842686168721833, -13.79294971310716, -13.741443599021459, -13.688077629331456, -13.632755377656931, -13.575373641040283, -13.51582183387665, -13.453981315613362, -13.38972464362055, -13.322914741331443, -13.253403970224849, -13.18103309242981, -13.105630108607798, -13.027008953263408, -12.944968026650235, -12.859288538885185, -12.769732637639011, -12.676041285663166, -12.577931848272538, -12.475095343463257, -12.367193298311024, -12.25385414427836, -12.134669070549197, -12.009187237877626, -11.876910234864244, -11.73728563296632, -11.58969946454323, -11.433467407964482, -11.267824412849603, -11.091912433623012, -10.904765856355656, -10.705294096450709, -10.492260704967176, -10.264258138104973, -10.01967710201136, -9.756669061604843, -9.473100066315059, -9.166493452329359, -8.833958164278782, -8.472098301788211, -8.076897891428477, -7.643572588889269, -7.166376682489245, -6.638348848510123, -6.050972715058597, -5.393716961263406, -4.653401938222764, -3.813311346529291, -2.851920640152489, -1.741034280993965, -0.4429842944454023, 1.0937123575832892, 2.941326613371505, 5.204587588666616, 8.041209243896915, 11.700249931998915, 16.59943975715425, 23.49707206831257, 33.92791394996896, 51.53903192004515, 87.62997697231184, 203.36902106385386, null, -200.13693701456046, -112.80285214163132, -81.93103172221785, -66.143601437218, -56.55633972105906, -50.11680887937424, -45.49379230496204, -42.01397955839009, -39.300227288441576, -37.124849714261664, -35.342256897563104, -33.85501304587876, -32.59544816291965, -31.515098050619454, -30.578342100439333, -29.75841302870201, -29.03480722440266, -28.39155384623549, -27.816027839419696, -27.298117387736156, -26.829628180248122, -26.403849462010474, -26.01523282984185, -25.659151017004188, -25.331714353499237, -25.02962942965089, -24.750089059214435, -24.490685743212307, -24.249342980164712, -24.024260271524398, -23.813868739155026, -23.6167950402507, -23.43183182461126, -23.25791339101548, -23.094095505653776, -22.939538575423864, -22.793493542993915, -22.65529000348519, -22.52432614497559, -22.400060194405476, -22.282003112446453, -22.16971232963991, -22.06278635466304, -21.96086011626806, -21.8636009250083, -21.770704960623235, -21.681894206951895, -21.59691376923585, -21.515529519287714, -21.437526022712767, -21.362704709538054, -21.290882255544247, -21.22188914651957, -21.155568401763876, -21.091774436610898, -21.03037204661946, -20.971235498515597, -20.91424771502469, -20.859299542469305, -20.806289091493824, -20.755121142536304, -20.7057066087477, -20.657962049986708, -20.61180923230984, -20.567174728066096, -20.523989552294957, -20.482188831639665, -20.441711502434632, -20.40250003500957, -20.36450018159359, -20.327660745495052, -20.291933369490753, -20.25727234158627, -20.223634416504638, -20.190978651438577, -20.159266254753565, -20.12846044646542, -20.09852632943811, -20.069430770351634, -20.041142289587278, -20.013630959259938, -19.98686830870256, -19.96082723677577, -19.93548193043351, -19.910807789030933, -19.88678135390729, -19.863380242819524, -19.840583088842, -19.818369483380387, -19.79671992298095, -19.77561575964322, -19.755039154369427, -19.734973033708123, -19.71540104906833, -19.69630753860098, -19.67767749146035, -19.65949651427367, -19.64175079966192, -19.62442709666623, -19.607512682947178, -19.590995338633984, -19.574863321710314, -19.559105344832698, -19.543710553485102, -19.528668505380356, -19.51396915102676, -19.49960281538306, -19.485560180531834, -19.471832269305718, -19.45841042980571, -19.44528632075581, -19.43245189764124, -19.41989939958213, -19.407621336897435, -19.395610479316904, -19.383859844802426, -19.37236268894187, -19.361112494881848, -19.350102963767608, -19.33932800566027, -19.328781730904293, -19.318458441918793, -19.308352625389094, -19.298458944835698, -19.28877223353944, -19.279287487803426, -19.269999860532778, -19.26090465511511, -19.251997319585385, -19.243273441059635, -19.234728740423563, -19.22635906726208, -19.21816039501752, -19.210128816364318, -19.202260538788984, -19.194551880364962, -19.186999265712174, -19.179599222132108, -19.172348375909536, -19.165243448772422, -19.158281254502427, -19.15145869568827, -19.144772760615258, -19.138220520284186, -19.131799125553357, -19.125505804397992, -19.119337859281202, -19.113292664631444, -19.107367664421417, -19.10156036984352, -19.09586835707762, -19.09028926514676, -19.084820793856736, -19.079460701815858, -19.074206804531162, -19.06905697257773, -19.06400912983782, -19.05906125180665, -19.054211363962057, -19.049457540195068, -19.044797901298843, -19.040230613513472, -19.035753887124084, -19.031365975110244, -19.02706517184417, -19.022849811835965, -19.018718268523752, -19.014668953106835, -19.010700313420205, -19.006810832848572, -19.00299902927838, -18.99926345408626, -18.99560269116234, -18.992015355967176, -18.98850009462082, -18.985055583022817, -18.981680526001877, -18.978373656494046, -18.97513373474833, -18.971959547558566, -18.968849907520685, -18.96580365231429, -18.96281964400758, -18.959896768384883, -18.95703393429577, -18.954230073025027, -18.95148413768275, -18.948795102613637, -18.946161962824988, -18.94358373343251, -18.94105944912347, -18.938588163636382, -18.936168949256757, -18.933800896328265, -18.931483112778775, -18.92921472366075, -18.92699487070547, -18.92482271189057, -18.922697421020484, -18.92061818731929, -18.91858421503551, -18.916594723058537, -18.914648944546148, -18.912746126562826, -18.910885529728528, -18.909066427877423, -18.907288107726416, -18.90554986855297, -18.903851021882065, -18.902190891181863, -18.900568811567858, -18.898984129515185, -18.897436202578856, -18.895924399121647, -18.894448098049352, -18.893006688553214, -18.89159956985926, -18.89022615098433, -18.888885850498593, -18.887578096294313, -18.88630232536067, -18.88505798356449, -18.883844525436608, -18.882661413963756, -18.881508120385785, -18.880384123998017, -18.879288911958607, -18.878221979100744, -18.87718282774952, -18.87617096754337, -18.875185915259863, -18.874227194645787, -18.87329433625135, -18.872386877268386, -18.87150436137242, -18.87064633856852, -18.869812365040758, -18.869002003005225, -18.868214820566454, -18.867450391577172, -18.866708295501248, -18.86598811727978, -18.865289447200205, -18.86461188076832, -18.863955018583155, -18.86331846621463, -18.86270183408383, -18.862104737345934, -18.861526795775607, -18.86096763365485, -18.86042687966323, -18.859904166770374, -18.859399132130704, -18.858911416980323, -18.858440666536, -18.85798652989616, -18.857548659943866, -18.857126713251702, -18.856720349988485, -18.856329233827793, -18.855953031858203, -18.85559141449525, -18.85524405539499, -18.854910631369133, -18.85459082230175, -18.854284311067417, -18.853990783450847, -18.853709928067858, -18.853441436287746, -18.853185002156916, -18.852940322323807, -18.852707095965027, -18.852485024712685, -18.852273812582837, -18.85207316590508, -18.85188279325317, -18.85170240537673, -18.85153171513388, -18.851370437424908, -18.851218289126823, -18.851074989028806, -18.85094025776856, -18.85081381776945, -18.850695393178466, -18.85058470980497, -18.850481495060155, -18.850385477897234, -18.850296388752316, -18.850213959485924, -18.850137923325157, -18.85006801480645, -18.850003969718884, -18.849945525048085, -18.849892418920618, -18.84984439054888, -18.849801180176478, -18.849762529024034, -18.849728179235445, -18.8496978738245, -18.849671356621908, -18.84964837222267, -18.849628665933757, -18.849611983722124, -18.849598072162983, -18.849586678388363, -18.849577550035878, -18.84957043519773, -18.849565082369907, -18.849561240401542, -18.849558658444426, -18.849557085902664, -18.849556272382404, -18.84955596764171, -18.849555921540425, -18.849555883990146, -18.84955560490418, -18.8495548341475, -18.849553321486727, -18.849550816539995, -18.849547068726828, -18.849541827217873, -18.84953484088457, -18.84952585824866, -18.849514627431585, -18.849500896103663, -18.849484411433128, -18.849464920034908, -18.8494421679192, -18.849415900439762, -18.84938586224194, -18.84935179721039, -18.84931344841645, -18.849270558065196, -18.8492228674421, -18.849170116859312, -18.84911204560148, -18.849048391871168, -18.8489788927338, -18.848903284062065, -18.848821300479855, -18.848732675305634, -18.84863714049521, -18.848534426583964, -18.84842426262839, -18.848306376147036, -18.84818049306072, -18.848046337632066, -18.847903632404275, -18.847752098139157, -18.84759145375433, -18.84742141625961, -18.847241700692543, -18.84705202005301, -18.846852085236954, -18.846641604969104, -18.846420285734713, -18.846187831710296, -18.845943944693246, -18.845688324030405, -18.845420666545436, -18.845140666465074, -18.844848015344102, -18.844542401989102, -18.844223512380893, -18.84389102959561, -18.843544633724427, -18.843184001791805, -18.842808807672274, -18.842418722005718, -18.842013412111026, -18.841592541898144, -18.84115577177847, -18.840702758573467, -18.84023315542152, -18.83974661168294, -18.839242772843082, -18.838721280413466, -18.838181771830907, -18.837623880354542, -18.837047234960714, -18.836451460235637, -18.835836176265758, -18.835200998525785, -18.834545537764257, -18.833869399886623, -18.83317218583573, -18.832453491469632, -18.831712907436675, -18.83095001904771, -18.830164406145407, -18.829355642970548, -18.82852329802519, -18.82766693393265, -18.826786107294158, -18.825880368542087, -18.82494926178969, -18.823992324677185, -18.823009088214082, -18.821999076617672, -18.820961807147487, -18.819896789935676, -18.818803527813106, -18.817681516131092, -18.816530242578587, -18.8153491869947, -18.814137821176402, -18.812895608681234, -18.811622004624866, -18.810316455473362, -18.808978398829936, -18.807607263216056, -18.806202467846695, -18.804763422399507, -18.803289526777768, -18.801780170866877, -18.800234734284135, -18.798652586121666, -18.79703308468217, -18.79537557720732, -18.79367939959853, -18.791943876129803, -18.79016831915247, -18.788352028791433, -18.786494292632725, -18.78459438540197, -18.782651568633543, -18.78066509033003, -18.778634184611626, -18.77655807135523, -18.774435955822693, -18.77226702827801, -18.77005046359294, -18.76778542084069, -18.765471042877184, -18.76310645590954, -18.760690769051195, -18.758223073863274, -18.755702443881614, -18.753127934128987, -18.75049858061188, -18.74781339980135, -18.745071388097287, -18.742271521275452, -18.739412753916678, -18.736494018817535, -18.733514226381686, -18.730472263991295, -18.72736699535761, -18.724197259849937, -18.720961871802217, -18.717659619796184, -18.71428926592031, -18.710849545003494, -18.707339163822446, -18.703756800281845, -18.70010110256593, -18.696370688260625, -18.692564143444717, -18.688680021749015, -18.684716843382077, -18.680673094121012, -18.67654722426609, -18.672337647557395, -18.668042740052073, -18.66366083896043, -18.659190241439017, -18.654629203339013, -18.649975937907733, -18.64522861444139, -18.64038535688685, -18.635444242390086, -18.630403299789062, -18.62526050804836, -18.620013794633067, -18.614661033819086, -18.60920004493686, -18.603628590545604, -18.597944374534592, -18.592145040148264, -18.586228167931463, -18.580191273590927, -18.574031805769238, -18.567747143726738, -18.561334594927164, -18.55479139252221, -18.54811469272992, -18.541301572101947, -18.53434902467373, -18.527253958992056, -18.520013195013615, -18.512623460867907, -18.505081389477716, -18.497383515029632, -18.48952626928677, -18.481505977735562, -18.473318855557615, -18.46496100341745, -18.456428403056226, -18.447716912680725, -18.43882226213678, -18.429740047854843, -18.420465727555435, -18.41099461470087, -18.401321872678825, -18.391442508702863, -18.381351367413277, -18.371043124161258, -18.360512277957852, -18.349753144067797, -18.338759846227656, -18.327526308465266, -18.316046246496892, -18.304313158676305, -18.292320316468036, -18.280060754415924, -18.267527259574834, -18.254712360372224, -18.241608314863154, -18.228207098339652, -18.214500390253114, -18.200479560404304, -18.186135654353095, -18.17145937799593, -18.156441081254727, -18.141070740817543, -18.12533794186539, -18.10923185871551, -18.092741234305276, -18.075854358434526, -18.05855904467851, -18.040842605874797, -18.022691828081115, -18.004092942891255, -17.985031597986804, -17.965492825792793, -17.9454610100924, -17.924919850444706, -17.903852324234695, -17.882240646169254, -17.860066225017015, -17.837309617370334, -17.813950478187248, -17.789967507849465, -17.765338395445667, -17.740039757963224, -17.71404707503941, -17.687334618888727, -17.659875378986072, -17.63164098104087, -17.602601599751825, -17.572725864777752, -17.541980759300486, -17.5103315104911, -17.477741471113784, -17.444171991420692, -17.4095822803954, -17.373929255296773, -17.337167378337234, -17.299248479191736, -17.260121561883594, -17.21973259441839, -17.178024279340004, -17.134935803160886, -17.0904025623599, -17.044355863352422, -16.99672259350108, -16.947424859852035, -16.89637959184338, -16.843498103720634, -16.788685611811882, -16.731840701133923, -16.672854735013235, -16.611611200492565, -16.54798498122128, -16.481841548283338, -16.413036057949448, -16.341412343617712, -16.26680178717958, -16.189022052639764, -16.10787566197242, -16.023148389796592, -15.934607449395369, -15.84199943774079, -15.745048001321244, -15.64345117749459, -15.536878357494496, -15.424966806747058, -15.307317665342344, -15.183491335740108, -15.053002145309131, -14.915312147109457, -14.769823892098676, -14.615871968000128, -14.452713052112943, -14.279514164377279, -14.09533872899032, -13.899129952295112, -13.689690894110122, -13.46566043879692, -13.225484146895148, -12.967378667991177, -12.689287992032662, -12.388829268580157, -12.06322517171286, -11.70921874442983, -11.322965188614042, -10.899892974575113, -10.434523618340167, -9.9202350277875, -9.348946667963068, -8.710694657454386, -7.993049123442368, -7.180300989564634, -6.2523042320663045, -5.18279037111378, -3.936851436340877, -2.4670699356785626, -0.7073638321131561, 1.437199255326309, 4.108075534385538, 7.525724479594825, 12.053713603759903, 18.337334165690606, 27.642045260732026, 42.83411815545673, 72.0827191120591, 151.67703716147375, null, null, -129.2320492733175, -90.89598754579231, -72.53898836573654, -61.77210673443886, -54.694945396451644, -49.688722510383755, -45.96078056626883, -43.077213498335745, -40.78053643571947, -38.90829527587897, -37.35292852336676, -36.040388262984585, -34.91803086527833, -33.94740430717738, -33.09976792052555, -32.353208623361915, -31.690727139645297, -31.09893376922868, -30.567138622840503, -30.086703811260538, -29.650573621138264, -29.252928123270156, -28.888923967471268, -28.554497792525073, -28.246215287593344, -27.96115399804794, -27.696811390523813, -27.451032045875607, -27.22194949261888, -27.007939357576706, -26.80758134548367, -26.619628165503933, -26.442979967564185, -26.276663181410626, -26.119812898439896, -25.97165812309416, -25.83150936295827, -25.698748136038244, -25.572818058347984, -25.453217240929312, -25.33949177721609, -25.231230142577207, -25.128058360381022, -25.029635814912275, -24.935651612362932, -24.845821407982438, -24.75988463117882, -24.67760205153058, -24.59875363782554, -24.523136669781895, -24.450564068326955, -24.38086291548159, -24.31387313919678, -24.249446342085577, -24.187444756012987, -24.12774030704259, -24.070213777382936, -24.014754052795535, -23.961257445464597, -23.90962708364778, -23.859772360547716, -23.811608435806463, -23.76505578385446, -23.720039784053412, -23.67649034819121, -23.63434158141625, -23.593531473160112, -23.554001615000573, -23.515696942762936, -23.478565500465972, -23.442558223983273, -23.407628742524828, -23.373733196250686, -23.340830068506282, -23.30888003133104, -23.27784580303055, -23.24769201672704, -23.21838509891438, -23.18989315713928, -23.162185876019404, -23.135234420884824, -23.109011348398397, -23.083490523573136, -23.058647042657796, -23.034457161412924, -23.010898228342537, -22.987948622486172, -22.965587695412793, -22.943795717088143, -22.92255382531793, -22.901843978493886, -22.881648911393427, -22.861952093805815, -22.84273769177539, -22.82399053127136, -22.805696064108496, -22.787840335957448, -22.770409956297275, -22.753392070173312, -22.736774331635644, -22.720544878742388, -22.704692310021148, -22.68920566229066, -22.674074389751667, -22.659288344262805, -22.644837756724485, -22.630713219498098, -22.61690566979456, -22.603406373970177, -22.590206912672365, -22.57729916678243, -22.56467530410552, -22.55232776676217, -22.54024925923848, -22.528432737055084, -22.51687139601807, -22.50555866201695, -22.494488181337726, -22.483653811460965, -22.473049612316416, -22.462669837968548, -22.452508928707804, -22.442561503525155, -22.43282235294823, -22.42328643221877, -22.413948854792977, -22.404804886146586, -22.395849937868494, -22.38707956202724, -22.378489445795598, -22.370075406319902, -22.36183338582084, -22.3537594469139, -22.34584976813796, -22.338100639681137, -22.330508459294187, -22.323069728381444, -22.315781048260774, -22.308639116583866, -22.30164072390883, -22.294782750417838, -22.288062162772395, -22.28147601109978, -22.275021426104217, -22.268695616296718, -22.262495865338128, -22.256419529489804, -22.250464035167, -22.244626876590146, -22.23890561352937, -22.233297869138127, -22.227801327871692, -22.222413733486775, -22.217132887118545, -22.211956645431542, -22.206882918841234, -22.201909669803126, -22.19703491116626, -22.192256704588544, -22.18757315901098, -22.1829824291884, -22.178482714274203, -22.17407225645681, -22.16974933964563, -22.165512288204443, -22.161359465730225, -22.15728927387552, -22.153300151212484, -22.14939057213703, -22.145559045811233, -22.1418041151426, -22.138124355798674, -22.134518375255414, -22.13098481187824, -22.127522334034182, -22.12412963923411, -22.120805453303735, -22.117548529582272, -22.114357648147767, -22.111231615067897, -22.10816926167544, -22.105169443867354, -22.102231041426545, -22.099352957365607, -22.0965341172915, -22.09377346879056, -22.091069980832998, -22.08842264319613, -22.085830465905744, -22.08329247869484, -22.080807730479155, -22.078375288848882, -22.07599423957592, -22.073663686136182, -22.071382749246354, -22.069150566414624, -22.066966291504897, -22.064829094313932, -22.062738160161107, -22.060692689490164, -22.058691897482717, -22.05673501368297, -22.054821281633323, -22.052949958520472, -22.051120314831657, -22.049331634020696, -22.047583212183483, -22.04587435774263, -22.04420439114092, -22.042572644543334, -22.04097846154729, -22.03942119690089, -22.037900216228856, -22.036414895765933, -22.03496462209751, -22.03354879190721, -22.032166811731233, -22.03081809771922, -22.029502075401442, -22.02821817946212, -22.02696585351861, -22.0257445499064, -22.024553729469567, -22.02339286135665, -22.02226142282173, -22.021158899030503, -22.020084782871272, -22.01903857477063, -22.018019782513743, -22.01702792106905, -22.016062512417257, -22.015123085384502, -22.014209175479536, -22.013320324734835, -22.012456081551473, -22.011616000547686, -22.010799642410984, -22.010006573753707, -22.009236366971937, -22.00848860010765, -22.007762856714002, -22.007058725723667, -22.006375801320125, -22.005713682811834, -22.005071974509153, -22.004450285603976, -22.003848230051982, -22.003265426457407, -22.00270149796027, -22.002156072126006, -22.00162878083738, -22.001119260188666, -22.00062715038198, -22.00015209562574, -21.99969374403515, -21.999251747534665, -21.998825761762415, -21.998415445976438, -21.998020462962756, -21.997640478945186, -21.99727516349685, -21.996924189453342, -21.996587232827462, -21.996263972725526, -21.995954091265155, -21.99565727349451, -21.99537320731294, -21.995101583393, -21.994842095103756, -21.994594438435385, -21.994358311925005, -21.99413341658371, -21.99391945582473, -21.993716135392734, -21.993523163294196, -21.993340249728806, -21.993167107021907, -21.993003449557865, -21.99284899371442, -21.99270345779791, -21.992566561979384, -21.992438028231543, -21.992317580266523, -21.992204943474395, -21.99209984486249, -21.992002012995382, -21.99191117793559, -21.991827071184954, -21.991749425626608, -21.991677975467606, -21.99161245618209, -21.99155260445504, -21.991498158126554, -21.99144885613659, -21.991404438470255, -21.99136464610348, -21.991329220949176, -21.99129790580376, -21.991270444294077, -21.991246580824686, -21.991226060525467, -21.991208629199555, -21.991194033271533, -21.99118201973594, -21.991172336105972, -21.991164730362435, -21.991158950902893, -21.99115474649099, -21.991151866205932, -21.99115005939208, -21.991149075608707, -21.991148664579796, -21.99114857614393, -21.991148560204238, -21.991148366678345, -21.99114774544835, -21.991146446310786, -21.99114421892652, -21.991140812770645, -21.991135977082227, -21.991129460814008, -21.991121012581967, -21.991110380614717, -21.99109731270278, -21.991081556147634, -21.99106285771057, -21.991040963561325, -21.99101561922644, -21.990986569537366, -21.99095355857826, -21.990916329633443, -21.990874625134563, -21.990828186607327, -21.990776754617894, -21.990720068718822, -21.99065786739459, -21.990589888006642, -21.99051586673798, -21.990435538537167, -21.990348637061885, -21.990254894621856, -21.990154042121183, -21.990045809000122, -21.989929923176117, -21.98980611098426, -21.98967409711696, -21.98953360456295, -21.989384354545475, -21.98922606645973, -21.989058457809456, -21.988881244142693, -21.988694138986617, -21.988496853781513, -21.988289097813738, -21.98807057814773, -21.987840999556997, -21.987600064454025, -21.98734747281912, -21.9870829221281, -21.986806107278806, -21.986516720516452, -21.986214451357657, -21.985898986513234, -21.98557000980964, -21.98522720210901, -21.984870241227817, -21.984498801854034, -21.984112555462787, -21.983711170230443, -21.983294310947073, -21.982861638927275, -21.982412811919243, -21.981947484012085, -21.981465305541313, -21.98096592299242, -21.98044897890256, -21.979914111760156, -21.979360955902482, -21.978789141411124, -21.978198294005175, -21.977588034932236, -21.976957980857016, -21.976307743747554, -21.97563693075895, -21.97494514411449, -21.974231980984186, -21.973497033360548, -21.97273988793153, -21.971960125950616, -21.971157323103878, -21.970331049373954, -21.969480868900856, -21.968606339839475, -21.96770701421372, -21.966782437767137, -21.965832149809934, -21.964855683062307, -21.963852563493894, -21.962822310159304, -21.961764435029515, -21.960678442819116, -21.959563830809145, -21.958420088665463, -21.957246698252483, -21.956043133442115, -21.954808859917765, -21.953543334973237, -21.95224600730635, -21.950916316807152, -21.94955369434045, -21.948157561522592, -21.946727330492227, -21.945262403674832, -21.943762173540907, -21.942226022357485, -21.940653321932814, -21.93904343335399, -21.93739570671724, -21.935709480850676, -21.933984083029184, -21.93221882868127, -21.930413021087503, -21.92856595107031, -21.926676896674827, -21.924745122840427, -21.922769881062703, -21.920750409045503, -21.918685930342647, -21.91657565398902, -21.91441877412062, -21.912214469583155, -21.90996190352885, -21.907660223000917, -21.905308558505347, -21.9029060235695, -21.900451714287026, -21.89794470884864, -21.89538406705813, -21.892768829833194, -21.89009801869038, -21.887370635213667, -21.884585660505984, -21.881742054623018, -21.87883875598867, -21.87587468079147, -21.872848722361095, -21.8697597505244, -21.866606610939982, -21.863388124410555, -21.860103086172202, -21.85675026515959, -21.853328403246216, -21.849836214458623, -21.846272384163594, -21.842635568227216, -21.838924392144573, -21.835137450139037, -21.831273304229683, -21.827330483265705, -21.82330748192632, -21.819202759684725, -21.815014739734647, -21.810741807877807, -21.806382311370697, -21.80193455772887, -21.797396813486884, -21.792767302912054, -21.788044206669817, -21.78322566043877, -21.778309753473003, -21.77329452710935, -21.76817797321725, -21.762958032588354, -21.75763259326339, -21.75219948879323, -21.746656496431115, -21.741001335253003, -21.73523166420244, -21.729345080056557, -21.723339115309418, -21.717211235968648, -21.7109588392614, -21.704579251244986, -21.69806972431772, -21.69142743462506, -21.68464947935564, -21.677732873922103, -21.67067454902046, -21.66347134756228, -21.65612002147299, -21.648617228349377, -21.640959527969187, -21.633143378645045, -21.625165133414363, -21.617021036056922, -21.608707216930526, -21.6002196886153, -21.59155434135618, -21.58270693829238, -21.573673110462572, -21.56444835157288, -21.555028012514782, -21.545407295618784, -21.535581248628652, -21.52554475838066, -21.515292544170318, -21.50481915078886, -21.494118941209972, -21.48318608890587, -21.472014569771094, -21.460598153629917, -21.448930395302504, -21.437004625202714, -21.424813939438398, -21.412351189383696, -21.399608970689634, -21.386579611697798, -21.373255161218786, -21.35962737563421, -21.34568770527862, -21.331427280053425, -21.31683689422231, -21.30190699033304, -21.286627642206387, -21.270988536928833, -21.254978955779766, -21.23858775401933, -21.22180333945657, -21.204613649710836, -21.187006128073154, -21.168967697865206, -21.150484735186282, -21.131543039928495, -21.11212780493018, -21.09222358312715, -21.071814252547686, -21.050882978984976, -21.029412176165, -21.00738346321119, -20.984777619190023, -20.96157453450079, -20.937753158850626, -20.913291445532415, -20.88816629169437, -20.862353474261663, -20.83582758113601, -20.808561937261672, -20.780528525106472, -20.751697899058055, -20.72203909318618, -20.69151952176303, -20.66010487186887, -20.627758987339693, -20.594443743230016, -20.560118909875133, -20.52474200553298, -20.48826813646982, -20.45064982322489, -20.411836811638338, -20.371775867061828, -20.330410549978755, -20.287680971044267, -20.24352352331021, -20.19787058911487, -20.150650218797743, -20.101785778027565, -20.051195560106393, -19.99879235912535, -19.94448299927881, -19.888167814994066, -19.82974007577313, -19.76908534876227, -19.70608079104102, -19.640594362418295, -19.572483948122176, -19.50159637911544, -19.427766335822096, -19.350815118752795, -19.270549266782787, -19.186759000594982, -19.09921646492123, -19.007673738570254, -18.911860575649953, -18.811481834641977, -18.706214543819776, -18.595704541547306, -18.47956261782989, -18.35736006855008, -18.228623555373797, -18.09282914143184, -17.94939534435388, -17.79767501243757, -17.636945784603004, -17.46639883747668, -17.28512554974024, -17.092101619708565, -16.886168050043835, -16.666008254142277, -16.430120328862095, -16.176783259511453, -15.904015449315757, -15.609523459528216, -15.290638153812218, -14.944234481793483, -14.566629793063276, -14.153453664713885, -13.699479476114305, -13.198403941010252, -12.642554817170556, -12.022497928911482, -11.326500572752082, -10.53978610089579, -9.643478296697927, -8.61307370741442, -7.41617583920538, -6.0090386762340415, -4.3311194721457476, -2.29616114995018, 0.22308158745820705, 3.4224707613672756, 7.61994373994321, 13.368175818417114, 21.720256614779274, 34.96177341294294, 59.15967271974556, 117.49811612585702, null, null, -149.95617458687494, -101.01438737769482, -79.39900365368926, -67.21945473078841, -59.404763582767146, -53.96555625279971, -49.96194763310965, -46.89211217314485, -44.46370543087155, -42.49488656796807, -40.866614526109174, -39.49769234036157, -38.33083569569587, -37.32447369986329, -36.44770679568762, -35.67708906455993, -34.994508578782636, -34.385752164052306, -33.83950991842272, -33.34666992712099, -32.89980905097303, -32.49281900994228, -32.12062760169999, -31.778987964739144, -31.464317267194637, -31.17357180593497, -30.90414927548387, -30.653811552695778, -30.420623142572726, -30.20290170052738, -29.999177954434927, -29.808163007006414, -29.62872148011133, -29.459849318542954, -29.300655336584917, -29.15034579120115, -29.008211418109596, -28.873616483902552, -28.745989497679943, -28.62481529594582, -28.509628269595858, -28.40000654524512, -28.295566967618, -28.195960757221386, -28.100869739597517, -28.01000306026758, -27.923094313910365, -27.83989902809394, -27.760192451503293, -27.683767604524355, -27.610433556583683, -27.54001390005399, -27.472345395048638, -27.407276763188047, -27.344667611575762, -27.28438747087765, -27.226314933630658, -27.17033688080681, -27.11634778626295, -27.064249090076224, -27.01394863293652, -26.965360144765683, -26.918402781592945, -26.87300070545771, -26.829082702745204, -26.786581836916007, -26.74543513206639, -26.70558328417206, -26.666970397231843, -26.629543741840063, -26.593253533995824, -26.558052732196828, -26.523896851077886, -26.49074379004249, -26.458553675497456, -26.427288715448384, -26.396913065340243, -26.367392704140887, -26.338695319767684, -26.310790203044313, -26.283648149456898, -26.25724136804791, -26.23154339684975, -26.206529024317643, -26.182174216270084, -26.158456047892496, -26.135352640398963, -26.11284310198374, -26.090907472728027, -26.06952667315552, -26.0486824561585, -26.028357362039426, -26.008534676434596, -25.9891983909074, -25.970333166014683, -25.951924296667812, -25.933957679623415, -25.916419782952435, -25.89929761734898, -25.882578709150263, -25.866251074950245, -25.850303197698054, -25.83472400418059, -25.819502843797217, -25.804629468540227, -25.790094014102444, -25.775886982038347, -25.761999222910724, -25.748421920360144, -25.735146576038712, -25.72216499535372, -25.70946927397123, -25.697051785032293, -25.68490516703862, -25.67302231236708, -25.661396356375008, -25.65002066706165, -25.63888883525234, -25.627994665275313, -25.617332166102248, -25.606895542925876, -25.596679189149892, -25.5866776787675, -25.57688575910704, -25.567298343924126, -25.557910506821006, -25.54871747497548, -25.539714623162155, -25.53089746805061, -25.522261662765402, -25.513802991693943, -25.505517365529418, -25.497400816536096, -25.48944949402574, -25.481659660034108, -25.474027685187156, -25.46655004474762, -25.459223314832485, -25.45204416879303, -25.445009373749336, -25.43811578727138, -25.431360354199896, -25.424740103599824, -25.418252145840157, -25.41189366979407, -25.40566194015345, -25.39955429485262, -25.393568142595882, -25.38770096048421, -25.381950291736395, -25.37631374350021, -25.370788984749655, -25.365373744264144, -25.360065808686063, -25.354863020653163, -25.349763277002303, -25.344764527041587, -25.33986477088772, -25.335062057865706, -25.33035448496835, -25.32574019537272, -25.321217377011322, -25.316784261195554, -25.312439121289184, -25.308180271429855, -25.304006065296413, -25.299914894920356, -25.295905189539404, -25.291975414491485, -25.2881240701476, -25.284349690881736, -25.280650844076597, -25.277026129163502, -25.273474176695164, -25.269993647450043, -25.266583231566976, -25.26324164770893, -25.259967642254722, -25.25675998851758, -25.25361748598959, -25.250538959610893, -25.24752325906283, -25.244569258084024, -25.241675853808523, -25.23884196612526, -25.236066537057905, -25.23334853016444, -25.230686929955713, -25.228080741332178, -25.22552898903829, -25.22303071713379, -25.220584988481317, -25.218190884249793, -25.21584750343287, -25.21355396238209, -25.21130939435408, -25.209112949071333, -25.20696379229615, -25.20486110541714, -25.202804085048015, -25.20079194263808, -25.19882390409414, -25.196899209413367, -25.195017112326727, -25.193176879952688, -25.19137779246079, -25.18961914274472, -25.187900236104685, -25.186220389938615, -25.184578933442026, -25.18297520731621, -25.18140856348443, -25.179878364815924, -25.17838398485744, -25.176924807572007, -25.17550022708479, -25.174109647435696, -25.17275248233863, -25.17142815494706, -25.170136097625782, -25.168875751728663, -25.16764656738212, -25.166448003274237, -25.16527952644924, -25.164140612107282, -25.163030743409244, -25.161949411286496, -25.16089611425538, -25.159870358236336, -25.158871656377492, -25.157899528882567, -25.156953502842974, -25.156033112074006, -25.15513789695494, -25.15426740427296, -25.153421187070798, -25.152598804497927, -25.151799821665282, -25.151023809503293, -25.150270344623227, -25.149539009181687, -25.14882939074817, -25.148141082175623, -25.147473681473873, -25.146826791685857, -25.146200020766575, -25.145592981464674, -25.145005291206587, -25.144436571983135, -25.143886450238554, -25.14335455676184, -25.142840526580326, -25.14234399885551, -25.14186461678095, -25.141402027482247, -25.140955881919012, -25.140525834788786, -25.140111544432816, -25.139712672743673, -25.139328885074622, -25.138959850150705, -25.13860523998147, -25.138264729775344, -25.137937997855513, -25.137624725577354, -25.137324597247293, -25.13703730004312, -25.13676252393562, -25.136499961611595, -25.13624930839811, -25.136010262188034, -25.13578252336674, -25.135565794740007, -25.135359781463027, -25.1351641909705, -25.134978732907786, -25.134803119063072, -25.134637063300527, -25.13448028149438, -25.134332491463944, -25.134193412909497, -25.13406276734902, -25.13394027805574, -25.133825669996508, -25.133718669770847, -25.133619005550823, -25.133526407021535]}],\n",
       "                        {\"template\": {\"data\": {\"bar\": [{\"error_x\": {\"color\": \"#2a3f5f\"}, \"error_y\": {\"color\": \"#2a3f5f\"}, \"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"bar\"}], \"barpolar\": [{\"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"barpolar\"}], \"carpet\": [{\"aaxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"baxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"type\": \"carpet\"}], \"choropleth\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"choropleth\"}], \"contour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"contour\"}], \"contourcarpet\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"contourcarpet\"}], \"heatmap\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmap\"}], \"heatmapgl\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmapgl\"}], \"histogram\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"histogram\"}], \"histogram2d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2d\"}], \"histogram2dcontour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2dcontour\"}], \"mesh3d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"mesh3d\"}], \"parcoords\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"parcoords\"}], \"pie\": [{\"automargin\": true, \"type\": \"pie\"}], \"scatter\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter\"}], \"scatter3d\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter3d\"}], \"scattercarpet\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattercarpet\"}], \"scattergeo\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergeo\"}], \"scattergl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergl\"}], \"scattermapbox\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattermapbox\"}], \"scatterpolar\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolar\"}], \"scatterpolargl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolargl\"}], \"scatterternary\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterternary\"}], \"surface\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"surface\"}], \"table\": [{\"cells\": {\"fill\": {\"color\": \"#EBF0F8\"}, \"line\": {\"color\": \"white\"}}, \"header\": {\"fill\": {\"color\": \"#C8D4E3\"}, \"line\": {\"color\": \"white\"}}, \"type\": \"table\"}]}, \"layout\": {\"annotationdefaults\": {\"arrowcolor\": \"#2a3f5f\", \"arrowhead\": 0, \"arrowwidth\": 1}, \"coloraxis\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"colorscale\": {\"diverging\": [[0, \"#8e0152\"], [0.1, \"#c51b7d\"], [0.2, \"#de77ae\"], [0.3, \"#f1b6da\"], [0.4, \"#fde0ef\"], [0.5, \"#f7f7f7\"], [0.6, \"#e6f5d0\"], [0.7, \"#b8e186\"], [0.8, \"#7fbc41\"], [0.9, \"#4d9221\"], [1, \"#276419\"]], \"sequential\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"sequentialminus\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]]}, \"colorway\": [\"#636efa\", \"#EF553B\", \"#00cc96\", \"#ab63fa\", \"#FFA15A\", \"#19d3f3\", \"#FF6692\", \"#B6E880\", \"#FF97FF\", \"#FECB52\"], \"font\": {\"color\": \"#2a3f5f\"}, \"geo\": {\"bgcolor\": \"white\", \"lakecolor\": \"white\", \"landcolor\": \"#E5ECF6\", \"showlakes\": true, \"showland\": true, \"subunitcolor\": \"white\"}, \"hoverlabel\": {\"align\": \"left\"}, \"hovermode\": \"closest\", \"mapbox\": {\"style\": \"light\"}, \"paper_bgcolor\": \"white\", \"plot_bgcolor\": \"#E5ECF6\", \"polar\": {\"angularaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"radialaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"scene\": {\"xaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"yaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"zaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}}, \"shapedefaults\": {\"line\": {\"color\": \"#2a3f5f\"}}, \"ternary\": {\"aaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"baxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"caxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"title\": {\"x\": 0.05}, \"xaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}, \"yaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}}}, \"title\": {\"text\": \"Transcendental equation Inspection\"}, \"xaxis\": {\"dtick\": 5, \"range\": [-25.0, 25.0], \"showticklabels\": true, \"tick0\": 0, \"tickangle\": -90, \"ticks\": \"outside\", \"title\": {\"font\": {\"color\": \"black\", \"family\": \"Arial, serif\", \"size\": 18}, \"text\": \"x\"}}, \"yaxis\": {\"dtick\": 5, \"range\": [-50, 50], \"tick0\": 0, \"ticks\": \"outside\", \"title\": {\"font\": {\"color\": \"black\", \"family\": \"Arial, serif\", \"size\": 18}, \"text\": \"P(x)\"}}},\n",
       "                        {\"responsive\": true}\n",
       "                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('bb03286c-88cb-47ad-8c81-4f379f248fd6');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })\n",
       "                };\n",
       "                });\n",
       "            </script>\n",
       "        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "button = widgets.Button(description=\"Analyze Graph\", \n",
    "                        layout = Layout(width='30%', height='60px'),\n",
    "                         button_style = 'info'\n",
    "                       )\n",
    "display(button)\n",
    "\n",
    "def on_button_clicked(b):\n",
    "    x = np.linspace(-25,25,10000) # Notice we changes the range of x values, in order to visualize the solution better\n",
    "    f = np.tan(x)-x  \n",
    "    utol = 250\n",
    "    ltol = -250\n",
    "    f[f>utol] = np.inf\n",
    "    f[f<ltol] = -np.inf\n",
    "\n",
    "    trace = go.Scatter(\n",
    "        x = x,\n",
    "        y = f,\n",
    "        name = 'P(x) = tan(x) - x',\n",
    "        line = dict(\n",
    "        color = ('black')\n",
    "        )\n",
    "    )\n",
    "    layout = go.Layout(\n",
    "        title = 'Transcendental equation Inspection',\n",
    "        xaxis = dict(\n",
    "            title='x',\n",
    "            titlefont=dict(\n",
    "            family='Arial, serif',\n",
    "            size=18,\n",
    "            color='black'),\n",
    "            showticklabels=True,\n",
    "            tickangle= 270,\n",
    "            range = [np.min(x),np.max(x)],\n",
    "         #   autotick=False,\n",
    "            ticks='outside',\n",
    "            tick0=0,\n",
    "            dtick=5\n",
    "\n",
    "        ),\n",
    "        yaxis = dict(\n",
    "            title='P(x)',\n",
    "            titlefont=dict(\n",
    "            family='Arial, serif',\n",
    "            size=18,\n",
    "            color='black'),\n",
    "            range = [-50,50],\n",
    "      #      autotick=False,\n",
    "            ticks='outside',\n",
    "            tick0=0,\n",
    "            dtick=5\n",
    "        ),\n",
    "    )\n",
    "\n",
    "    data = [trace]\n",
    "\n",
    "    fig = go.Figure(data=data, layout=layout)\n",
    "\n",
    "    iplot(fig)\n",
    "button.on_click(on_button_clicked)\n",
    "on_button_clicked(0)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hidden": false
   },
   "source": [
    "### Analysis\n",
    "---\n",
    "We see that this function crosses the $x$ axis many times, actually infinitely many times (if we were to extend the plot). Our bisection algorithm can only narrow down on one root at a time. In fact, since the function contains asymptotes, the bisection method may not even converge (remember the function must be continuous on the interval). With appropriate guesses for the initial conditions, we would be able to obtain all roots (in theory) but this would be a tedious task. It took a combination of inspection and the bisection method to recognize that there were multiple solutions and obtain their exact values. \n",
    "\n",
    "\n",
    "### Practice Problems\n",
    "---\n",
    "\n",
    "For extra practice, I strongly encourage you to try out the algorithms in order to solve the first exercise in this notebook for second- and third-order polynomials. The answers are all integer values so you do not need to worry about accuracy too much. Additionally, consider the following transcendental equations. You may run into some problems (technical and theoretical) solving them, that is OK and all part of the learning process. \n",
    "\n",
    "Find all solutions to:\n",
    "\n",
    "1. $\\ln(x) = x-5$  (think about the domain of definition of ln(x))\n",
    "2. $\\cos(x) = x/4$ (plot the function)\n",
    "3. $\\sin(x) = x-1$ (Try this one with the secant method for fun)\n",
    "4. $\\cos(x) = x^2$\n",
    "5. $\\ln(x) = \\cos(x)$ "
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "hidden": false
   },
   "source": [
    "## Conclusion\n",
    "---\n",
    "\n",
    "In this Jupyter notebook you learned the basics of root-finding algorithms. Namely, we studied the process of finding and approximating the roots of a function by inspection, the bisection method,and the secant method. Equally as important, you gained some experience and exposure (if you haven't seen some already) to scientific computing. \n",
    "\n",
    "Additionally, we applied our methods within the context of solving transcendental equations. It is likely that this is the first time you have been exposed to transcendental equations and the methods we have discussed here. Hopefully, working through the notebook helped you understand the different ways in which one can break down a problem like this. Which did you like best? Being able to adapt and apply the mathematical tools that you have acquired in class is an invaluable skill to have. These skills often end up transferring to general problem-solving skills. I encourage you to reflect upon which of the methods you enjoyed and why. It will offer insight into your own personal learning process.\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "[![Callysto.ca License](https://github.com/callysto/curriculum-notebooks/blob/master/callysto-notebook-banner-bottom.jpg?raw=true)](https://github.com/callysto/curriculum-notebooks/blob/master/LICENSE.md)"
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Edit Metadata",
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.7.4"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
